@@ -27,6 +27,7 @@ use constant FILE_MANIFEST                                          => 'manifest
 use constant RENDER                                                 => 'render';
 use constant RENDER_COMPACT                                         => 'compact';
     push @EXPORT, qw(RENDER_COMPACT);
+use constant RENDER_FILE                                            => 'file';
 use constant RENDER_MENU                                            => 'menu';
     push @EXPORT, qw(RENDER_MENU);
 use constant RENDER_PRETTY                                          => 'pretty';
@@ -37,6 +38,8 @@ use constant RENDER_TYPE_HTML                                       => 'html';
     push @EXPORT, qw(RENDER_TYPE_HTML);
 use constant RENDER_TYPE_MARKDOWN                                   => 'markdown';
     push @EXPORT, qw(RENDER_TYPE_MARKDOWN);
+use constant RENDER_TYPE_PDF                                        => 'pdf';
+    push @EXPORT, qw(RENDER_TYPE_PDF);
 
 ####################################################################################################################################
 # CONSTRUCTOR
@@ -101,14 +104,12 @@ sub new
     {
         my $oSourceHash = {};
         my $strKey = $oSource->paramGet('key');
-        my $strFile = $oSource->paramGet('file', false);
         my $strSourceType = $oSource->paramGet('type', false);
 
         logDebugMisc
         (
             $strOperation, 'load source',
             {name => 'strKey', value => $strKey},
-            {name => 'strFile', value => $strFile},
             {name => 'strSourceType', value => $strSourceType}
         );
 
@@ -118,16 +119,7 @@ sub new
             next;
         }
 
-        # If file is defined
-        if (defined($strFile))
-        {
-            $oSourceHash->{doc} = new pgBackRestDoc::Common::Doc($self->{strDocPath} . "/${strFile}");
-        }
-        # Else should be in doc/xml
-        else
-        {
-            $$oSourceHash{doc} = new pgBackRestDoc::Common::Doc("$self->{strDocPath}/xml/${strKey}.xml");
-        }
+        $$oSourceHash{doc} = new pgBackRestDoc::Common::Doc("$self->{strDocPath}/xml/${strKey}.xml");
 
         # Read variables from source
         $self->variableListParse($$oSourceHash{doc}->nodeGet('variable-list', false), $rhVariableOverride);
@@ -149,6 +141,7 @@ sub new
         }
 
         # Get the file param
+        $${oRenderHash}{file} = $oRender->paramGet(RENDER_FILE, false);
         $${oRenderHash}{&RENDER_COMPACT} = $oRender->paramGet(RENDER_COMPACT, false, 'n') eq 'y' ? true : false;
         $${oRenderHash}{&RENDER_PRETTY} = $oRender->paramGet(RENDER_PRETTY, false, 'n') eq 'y' ? true : false;
         $${oRenderHash}{&RENDER_MENU} = false;
@@ -156,9 +149,16 @@ sub new
         logDebugMisc
         (
             $strOperation, '    load render',
-            {name => 'strType', value => $strType}
+            {name => 'strType', value => $strType},
+            {name => 'strFile', value => $${oRenderHash}{file}}
         );
 
+        # Error if file is set and render type is not pdf
+        if (defined($${oRenderHash}{file}) && $strType ne RENDER_TYPE_PDF)
+        {
+            confess &log(ERROR, 'only the pdf render type can have file set')
+        }
+
         # Iterate the render sources
         foreach my $oRenderOut ($oRender->nodeList('render-source'))
         {
@@ -361,12 +361,19 @@ sub variableReplace
 
     foreach my $strName (sort(keys(%{$self->{oVariable}})))
     {
-        # If the value is not defined then replace it as an empty string. This means the key *was* defined but no value given.
-        my $strValue = defined($self->{oVariable}{$strName}) ? $self->{oVariable}{$strName} : '';
+        my $strValue = $self->{oVariable}{$strName};
 
         $strBuffer =~ s/\{\[$strName\]\}/$strValue/g;
     }
 
+    if (defined($strType) && $strType eq 'latex')
+    {
+        $strBuffer =~ s/\\\_/\_/g;
+        $strBuffer =~ s/\_/\\\_/g;
+        $strBuffer =~ s/\\\#/\#/g;
+        $strBuffer =~ s/\#/\\\#/g;
+    }
+
     return $strBuffer;
 }
 
