@@ -12,6 +12,8 @@ use Exporter qw(import);
     our @EXPORT = qw();
 use File::Basename qw(dirname);
 
+use pgBackRestBuild::Config::Data;
+
 use pgBackRestDoc::Common::DocRender;
 use pgBackRestDoc::Common::Log;
 use pgBackRestDoc::Common::String;
@@ -267,7 +269,7 @@ sub contributorTextGet
 }
 
 ####################################################################################################################################
-# Find a commit by subject prefix. Error if the prefix appears more than once.
+# Find a commit by subject prefix.  Error if the prefix appears more than once.
 ####################################################################################################################################
 sub commitFindSubject
 {
@@ -377,8 +379,7 @@ sub docGet
         my @stryReleaseCommitRemaining;
         my $bReleaseCheckCommit = false;
 
-        # Check versions except for bug fix releases that are not the most recent release (since bug fixes on are separate branches)
-        if ($strVersion ge '2.01' && !($strVersion =~ /^[0-9]+\.[0-9]+\.[0-9]+$/ && $iReleaseIdx != 0))
+        if ($strVersion ge '2.01')
         {
             # Should commits in the release be checked?
             $bReleaseCheckCommit = !$bReleaseDev ? true : false;
@@ -387,17 +388,9 @@ sub docGet
             my $rhReleaseCommitBegin = $self->commitFindSubject(\@hyGitLog, "Begin v${strVersion} development\\.");
             my $strReleaseCommitBegin = defined($rhReleaseCommitBegin) ? $rhReleaseCommitBegin->{commit} : undef;
 
-            # Get the end commit of the last release (skipping bug fixes which are on separate branches)
-            my $iReleaseLastVersionIdx = $iReleaseIdx + 1;
-            my $strReleaseLastVersion = $oyRelease[$iReleaseLastVersionIdx]->paramGet('version');
-
-            while ($strReleaseLastVersion =~ /^[0-9]+\.[0-9]+\.[0-9]+$/)
-            {
-                $iReleaseLastVersionIdx++;
-                $strReleaseLastVersion = $oyRelease[$iReleaseLastVersionIdx]->paramGet('version');
-            }
-
-            my $rhReleaseLastCommitEnd = $self->commitFindSubject(\@hyGitLog, "v${strReleaseLastVersion}\\: .+");
+            # Get the end commit of the last release
+            my $strReleaseLastVersion = $oyRelease[$iReleaseIdx + 1]->paramGet('version');
+            my $rhReleaseLastCommitEnd =  $self->commitFindSubject(\@hyGitLog, "v${strReleaseLastVersion}\\: .+");
 
             if (!defined($rhReleaseLastCommitEnd))
             {
@@ -522,6 +515,7 @@ sub docGet
         $oReleaseSection->nodeAdd('subsubtitle')->textSet($strDateOut);
 
         # Add release sections
+        my $bAdditionalNotes = false;
         my $bReleaseNote = false;
 
         my $hSectionType =
@@ -551,10 +545,16 @@ sub docGet
 
                     if ($oRelease->nodeGet($strSectionType)->nodeTest($strItemType))
                     {
-                        # Add release note if present
-                        if (!$bReleaseNote && defined($oRelease->nodeGet($strSectionType)->textGet(false)))
+                        if ($strSectionType ne XML_RELEASE_CORE_LIST && !$bAdditionalNotes)
                         {
-                            $oReleaseSection->nodeAdd('p')->textSet($oRelease->nodeGet($strSectionType)->textGet());
+                            $oReleaseSection->nodeAdd('subtitle')->textSet('Additional Notes');
+                            $bAdditionalNotes = true;
+                        }
+
+                        # Add release note if present
+                        if (!$bReleaseNote && $oRelease->nodeGet($strSectionType)->nodeTest('p'))
+                        {
+                            $oReleaseSection->nodeAdd('p')->textSet($oRelease->nodeGet($strSectionType)->nodeGet('p')->textGet());
                             $bReleaseNote = true;
                         }
 
