@@ -28,6 +28,7 @@ STRING_EXTERN(WAL_SEGMENT_REGEXP_STR,                               WAL_SEGMENT_
 STRING_EXTERN(WAL_SEGMENT_PARTIAL_REGEXP_STR,                       WAL_SEGMENT_PARTIAL_REGEXP);
 STRING_EXTERN(WAL_SEGMENT_DIR_REGEXP_STR,                           WAL_SEGMENT_DIR_REGEXP);
 STRING_EXTERN(WAL_SEGMENT_FILE_REGEXP_STR,                          WAL_SEGMENT_FILE_REGEXP);
+STRING_EXTERN(WAL_TIMELINE_HISTORY_REGEXP_STR,                      WAL_TIMELINE_HISTORY_REGEXP);
 
 /***********************************************************************************************************************************
 Global error file constant
@@ -60,16 +61,15 @@ archiveAsyncErrorClear(ArchiveMode archiveMode, const String *archiveFile)
         FUNCTION_LOG_PARAM(STRING, archiveFile);
     FUNCTION_LOG_END();
 
-    storageRemoveP(
-        storageSpoolWrite(), strNewFmt(STORAGE_SPOOL_ARCHIVE_OUT "/%s" STATUS_EXT_ERROR, strPtr(archiveFile)));
+    ASSERT(archiveFile != NULL);
+
+    storageRemoveP(storageSpoolWrite(), strNewFmt(STORAGE_SPOOL_ARCHIVE_OUT "/%s" STATUS_EXT_ERROR, strZ(archiveFile)));
     storageRemoveP(storageSpoolWrite(), STRDEF(STORAGE_SPOOL_ARCHIVE_OUT "/" STATUS_FILE_GLOBAL_ERROR));
 
     FUNCTION_LOG_RETURN_VOID();
 }
 
-/***********************************************************************************************************************************
-Check for ok/error status files in the spool in/out directory
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 bool
 archiveAsyncStatus(ArchiveMode archiveMode, const String *walSegment, bool throwOnError)
 {
@@ -79,6 +79,8 @@ archiveAsyncStatus(ArchiveMode archiveMode, const String *walSegment, bool throw
         FUNCTION_LOG_PARAM(BOOL, throwOnError);
     FUNCTION_LOG_END();
 
+    ASSERT(walSegment != NULL);
+
     bool result = false;
 
     MEM_CONTEXT_TEMP_BEGIN()
@@ -88,21 +90,21 @@ archiveAsyncStatus(ArchiveMode archiveMode, const String *walSegment, bool throw
 
         const String *spoolQueue = archiveAsyncSpoolQueue(archiveMode);
 
-        String *okFile = strNewFmt("%s" STATUS_EXT_OK, strPtr(walSegment));
-        bool okFileExists = storageExistsP(storageSpool(), strNewFmt("%s/%s", strPtr(spoolQueue), strPtr(okFile)));
+        String *okFile = strNewFmt("%s" STATUS_EXT_OK, strZ(walSegment));
+        bool okFileExists = storageExistsP(storageSpool(), strNewFmt("%s/%s", strZ(spoolQueue), strZ(okFile)));
 
         // If the ok file does not exist then check to see if a file-specific or global error exists
         if (!okFileExists)
         {
             // Check for a file-specific error first
-            errorFile = strNewFmt("%s" STATUS_EXT_ERROR, strPtr(walSegment));
-            errorFileExists = storageExistsP(storageSpool(), strNewFmt("%s/%s", strPtr(spoolQueue), strPtr(errorFile)));
+            errorFile = strNewFmt("%s" STATUS_EXT_ERROR, strZ(walSegment));
+            errorFileExists = storageExistsP(storageSpool(), strNewFmt("%s/%s", strZ(spoolQueue), strZ(errorFile)));
 
             // If that doesn't exist then check for a global error
             if (!errorFileExists)
             {
                 errorFile = STATUS_FILE_GLOBAL_ERROR_STR;
-                errorFileExists = storageExistsP(storageSpool(), strNewFmt("%s/%s", strPtr(spoolQueue), strPtr(errorFile)));
+                errorFileExists = storageExistsP(storageSpool(), strNewFmt("%s/%s", strZ(spoolQueue), strZ(errorFile)));
             }
         }
 
@@ -113,7 +115,7 @@ archiveAsyncStatus(ArchiveMode archiveMode, const String *walSegment, bool throw
             const String *statusFile = okFileExists ? okFile: errorFile;
 
             String *content = strNewBuf(
-                storageGetP(storageNewReadP(storageSpool(), strNewFmt("%s/%s", strPtr(spoolQueue), strPtr(statusFile)))));
+                storageGetP(storageNewReadP(storageSpool(), strNewFmt("%s/%s", strZ(spoolQueue), strZ(statusFile)))));
 
             // Get the code and message if the file has content
             int code = 0;
@@ -122,18 +124,18 @@ archiveAsyncStatus(ArchiveMode archiveMode, const String *walSegment, bool throw
             if (strSize(content) != 0)
             {
                 // Find the line feed after the error code -- should be the first one
-                const char *linefeedPtr = strchr(strPtr(content), '\n');
+                const char *linefeedPtr = strchr(strZ(content), '\n');
 
                 // Error if linefeed not found
                 if (linefeedPtr == NULL)
-                    THROW_FMT(FormatError, "%s content must have at least two lines", strPtr(statusFile));
+                    THROW_FMT(FormatError, "%s content must have at least two lines", strZ(statusFile));
 
                 // Error if message is zero-length
                 if (strlen(linefeedPtr + 1) == 0)
-                    THROW_FMT(FormatError, "%s message must be > 0", strPtr(statusFile));
+                    THROW_FMT(FormatError, "%s message must be > 0", strZ(statusFile));
 
                 // Get contents
-                code = varIntForce(VARSTR(strNewN(strPtr(content), (size_t)(linefeedPtr - strPtr(content)))));
+                code = varIntForce(VARSTR(strNewN(strZ(content), (size_t)(linefeedPtr - strZ(content)))));
                 message = strTrim(strNew(linefeedPtr + 1));
             }
 
@@ -147,11 +149,11 @@ archiveAsyncStatus(ArchiveMode archiveMode, const String *walSegment, bool throw
                     if (code != 0)
                     {
                         message = strNewFmt(
-                            "WAL segment '%s' was not pushed due to error [%d] and was manually skipped: %s", strPtr(walSegment),
-                            code, strPtr(message));
+                            "WAL segment '%s' was not pushed due to error [%d] and was manually skipped: %s", strZ(walSegment),
+                            code, strZ(message));
                     }
 
-                    LOG_WARN(strPtr(message));
+                    LOG_WARN(strZ(message));
                 }
 
                 result = true;
@@ -160,10 +162,10 @@ archiveAsyncStatus(ArchiveMode archiveMode, const String *walSegment, bool throw
             {
                 // Error status files must have content
                 if (strSize(content) == 0)
-                    THROW_FMT(AssertError, "status file '%s' has no content", strPtr(statusFile));
+                    THROW_FMT(AssertError, "status file '%s' has no content", strZ(statusFile));
 
                 // Throw error using the code passed in the file
-                THROW_CODE(code, strPtr(message));
+                THROW_CODE(code, strZ(message));
             }
         }
     }
@@ -172,9 +174,7 @@ archiveAsyncStatus(ArchiveMode archiveMode, const String *walSegment, bool throw
     FUNCTION_LOG_RETURN(BOOL, result);
 }
 
-/***********************************************************************************************************************************
-Write an error status file
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void
 archiveAsyncStatusErrorWrite(ArchiveMode archiveMode, const String *walSegment, int code, const String *message)
 {
@@ -195,17 +195,15 @@ archiveAsyncStatusErrorWrite(ArchiveMode archiveMode, const String *walSegment,
         storagePutP(
             storageNewWriteP(
                 storageSpoolWrite(),
-                strNewFmt("%s/%s" STATUS_EXT_ERROR, strPtr(archiveAsyncSpoolQueue(archiveMode)), strPtr(errorFile))),
-            BUFSTR(strNewFmt("%d\n%s", code, strPtr(message))));
+                strNewFmt("%s/%s" STATUS_EXT_ERROR, strZ(archiveAsyncSpoolQueue(archiveMode)), strZ(errorFile))),
+            BUFSTR(strNewFmt("%d\n%s", code, strZ(message))));
     }
     MEM_CONTEXT_TEMP_END();
 
     FUNCTION_LOG_RETURN_VOID();
 }
 
-/***********************************************************************************************************************************
-Write an ok status file
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void
 archiveAsyncStatusOkWrite(ArchiveMode archiveMode, const String *walSegment, const String *warning)
 {
@@ -222,9 +220,8 @@ archiveAsyncStatusOkWrite(ArchiveMode archiveMode, const String *walSegment, con
         // Write file
         storagePutP(
             storageNewWriteP(
-                storageSpoolWrite(),
-                strNewFmt("%s/%s" STATUS_EXT_OK, strPtr(archiveAsyncSpoolQueue(archiveMode)), strPtr(walSegment))),
-            warning == NULL ? NULL : BUFSTR(strNewFmt("0\n%s", strPtr(warning))));
+                storageSpoolWrite(), strNewFmt("%s/%s" STATUS_EXT_OK, strZ(archiveAsyncSpoolQueue(archiveMode)), strZ(walSegment))),
+            warning == NULL ? NULL : BUFSTR(strNewFmt("0\n%s", strZ(warning))));
     }
     MEM_CONTEXT_TEMP_END();
 
@@ -253,9 +250,15 @@ archiveAsyncExec(ArchiveMode archiveMode, const StringList *commandExec)
         // Detach from parent process
         forkDetach();
 
+        // Close any open file descriptors above the standard three (stdin, stdout, stderr). Don't check the return value since we
+        // don't know which file descriptors are actually open (might be none). It's possible that there are open files >= 1024 but
+        // there is no easy way to detect that and this should give us enough descriptors to do our work.
+        for (int fd = 3; fd < 1024; fd++)
+            close(fd);
+
         // Execute the binary.  This statement will not return if it is successful.
         THROW_ON_SYS_ERROR_FMT(
-            execvp(strPtr(strLstGet(commandExec, 0)), (char ** const)strLstPtr(commandExec)) == -1, ExecuteError,
+            execvp(strZ(strLstGet(commandExec, 0)), (char ** const)strLstPtr(commandExec)) == -1, ExecuteError,
             "unable to execute asynchronous '%s'", archiveMode == archiveModeGet ? CFGCMD_ARCHIVE_GET : CFGCMD_ARCHIVE_PUSH);
     }
 
@@ -282,9 +285,19 @@ archiveAsyncExec(ArchiveMode archiveMode, const StringList *commandExec)
     FUNCTION_LOG_RETURN_VOID();
 }
 
-/***********************************************************************************************************************************
-Is the segment partial?
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
+int
+archiveIdComparator(const void *item1, const void *item2)
+{
+    StringList *archiveSort1 = strLstNewSplitZ(*(String **)item1, "-");
+    StringList *archiveSort2 = strLstNewSplitZ(*(String **)item2, "-");
+    int int1 = atoi(strZ(strLstGet(archiveSort1, 1)));
+    int int2 = atoi(strZ(strLstGet(archiveSort2, 1)));
+
+    return (int1 - int2);
+}
+
+/**********************************************************************************************************************************/
 bool
 walIsPartial(const String *walSegment)
 {
@@ -298,9 +311,7 @@ walIsPartial(const String *walSegment)
     FUNCTION_LOG_RETURN(BOOL, strEndsWithZ(walSegment, WAL_SEGMENT_PARTIAL_EXT));
 }
 
-/***********************************************************************************************************************************
-Generates the location of the wal directory using a relative wal path and the supplied pg path
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 String *
 walPath(const String *walFile, const String *pgPath, const String *command)
 {
@@ -322,10 +333,10 @@ walPath(const String *walFile, const String *pgPath, const String *command)
         {
             THROW_FMT(
                 OptionRequiredError,
-                "option '" CFGOPT_PG1_PATH "' must be specified when relative wal paths are used\n"
+                "option '%s' must be specified when relative wal paths are used\n"
                     "HINT: is %%f passed to %s instead of %%p?\n"
                     "HINT: PostgreSQL may pass relative paths even with %%p depending on the environment.",
-                strPtr(command));
+                cfgOptionName(cfgOptPgPath), strZ(command));
         }
 
         // Get the working directory
@@ -336,19 +347,25 @@ walPath(const String *walFile, const String *pgPath, const String *command)
         if (!strEqZ(pgPath, currentWorkDir))
         {
             // If not we'll change the working directory to pgPath and see if that equals the working directory we got called with
-            THROW_ON_SYS_ERROR_FMT(chdir(strPtr(pgPath)) != 0, PathMissingError, "unable to chdir() to '%s'", strPtr(pgPath));
+            THROW_ON_SYS_ERROR_FMT(chdir(strZ(pgPath)) != 0, PathMissingError, "unable to chdir() to '%s'", strZ(pgPath));
 
             // Get the new working directory
             char newWorkDir[4096];
             THROW_ON_SYS_ERROR(getcwd(newWorkDir, sizeof(newWorkDir)) == NULL, FormatError, "unable to get cwd");
 
-            // Error if the new working directory is not equal to the original current working directory.  This means that
-            // PostgreSQL and pgBackrest have a different idea about where the PostgreSQL data directory is located.
+            // Error if the new working directory is not equal to the original current working directory. This means that PostgreSQL
+            // and pgBackrest have a different idea about where the PostgreSQL data directory is located.
             if (strcmp(currentWorkDir, newWorkDir) != 0)
-                THROW_FMT(AssertError, "working path '%s' is not the same path as '%s'", currentWorkDir, strPtr(pgPath));
+            {
+                THROW_FMT(
+                    OptionInvalidValueError,
+                    PG_NAME " working directory '%s' is not the same as option %s '%s'\n"
+                        "HINT: is the " PG_NAME " data_directory configured the same as the %s option?",
+                    currentWorkDir, cfgOptionName(cfgOptPgPath), strZ(pgPath), cfgOptionName(cfgOptPgPath));
+            }
         }
 
-        result = strNewFmt("%s/%s", strPtr(pgPath), strPtr(walFile));
+        result = strNewFmt("%s/%s", strZ(pgPath), strZ(walFile));
     }
     else
         result = strDup(walFile);
@@ -356,9 +373,7 @@ walPath(const String *walFile, const String *pgPath, const String *command)
     FUNCTION_LOG_RETURN(STRING, result);
 }
 
-/***********************************************************************************************************************************
-Is the file a segment or some other file (e.g. .history, .backup, etc)
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 bool
 walIsSegment(const String *walSegment)
 {
@@ -383,12 +398,7 @@ walIsSegment(const String *walSegment)
     FUNCTION_LOG_RETURN(BOOL, regExpMatch(regExpSegment, walSegment));
 }
 
-/***********************************************************************************************************************************
-Find a WAL segment in the repository
-
-The file name can have several things appended such as a hash, compression extension, and partial extension so it is possible to
-have multiple files that match the segment, though more than one match is not a good thing.
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 String *
 walSegmentFind(const Storage *storage, const String *archiveId, const String *walSegment, TimeMSec timeout)
 {
@@ -408,18 +418,20 @@ walSegmentFind(const Storage *storage, const String *archiveId, const String *wa
 
     MEM_CONTEXT_TEMP_BEGIN()
     {
-        Wait *wait = timeout > 0 ? waitNew(timeout) : NULL;
+        Wait *wait = waitNew(timeout);
 
         do
         {
             // Get a list of all WAL segments that match
             StringList *list = storageListP(
-                storage, strNewFmt(STORAGE_REPO_ARCHIVE "/%s/%s", strPtr(archiveId), strPtr(strSubN(walSegment, 0, 16))),
-                .expression = strNewFmt("^%s%s-[0-f]{40}(\\.gz){0,1}$", strPtr(strSubN(walSegment, 0, 24)),
-                    walIsPartial(walSegment) ? WAL_SEGMENT_PARTIAL_EXT : ""), .nullOnMissing = true);
+                storage, strNewFmt(STORAGE_REPO_ARCHIVE "/%s/%s", strZ(archiveId), strZ(strSubN(walSegment, 0, 16))),
+                .expression = strNewFmt(
+                    "^%s%s-[0-f]{40}" COMPRESS_TYPE_REGEXP "{0,1}$", strZ(strSubN(walSegment, 0, 24)),
+                        walIsPartial(walSegment) ? WAL_SEGMENT_PARTIAL_EXT : ""),
+                .nullOnMissing = true);
 
             // If there are results
-            if (list != NULL && strLstSize(list) > 0)
+            if (list != NULL && !strLstEmpty(list))
             {
                 // Error if there is more than one match
                 if (strLstSize(list) > 1)
@@ -428,7 +440,7 @@ walSegmentFind(const Storage *storage, const String *archiveId, const String *wa
                         ArchiveDuplicateError,
                         "duplicates found in archive for WAL segment %s: %s\n"
                             "HINT: are multiple primaries archiving to this stanza?",
-                        strPtr(walSegment), strPtr(strLstJoin(strLstSort(list, sortOrderAsc), ", ")));
+                        strZ(walSegment), strZ(strLstJoin(strLstSort(list, sortOrderAsc), ", ")));
                 }
 
                 // Copy file name of WAL segment found into the prior context
@@ -439,7 +451,7 @@ walSegmentFind(const Storage *storage, const String *archiveId, const String *wa
                 MEM_CONTEXT_PRIOR_END();
             }
         }
-        while (result == NULL && wait != NULL && waitMore(wait));
+        while (result == NULL && waitMore(wait));
     }
     MEM_CONTEXT_TEMP_END();
 
@@ -449,16 +461,15 @@ walSegmentFind(const Storage *storage, const String *archiveId, const String *wa
             ArchiveTimeoutError,
             "WAL segment %s was not archived before the %" PRIu64 "ms timeout\n"
                 "HINT: check the archive_command to ensure that all options are correct (especially --stanza).\n"
-                "HINT: check the PostgreSQL server log for errors.",
-            strPtr(walSegment), timeout);
+                "HINT: check the PostgreSQL server log for errors.\n"
+                "HINT: run the 'start' command if the stanza was previously stopped.",
+            strZ(walSegment), timeout);
     }
 
     FUNCTION_LOG_RETURN(STRING, result);
 }
 
-/***********************************************************************************************************************************
-Get the next WAL segment given a WAL segment and WAL segment size
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 String *
 walSegmentNext(const String *walSegment, size_t walSegmentSize, unsigned int pgVersion)
 {
@@ -480,9 +491,9 @@ walSegmentNext(const String *walSegment, size_t walSegmentSize, unsigned int pgV
 
     MEM_CONTEXT_TEMP_BEGIN()
     {
-        timeline = (uint32_t)strtol(strPtr(strSubN(walSegment, 0, 8)), NULL, 16);
-        major = (uint32_t)strtol(strPtr(strSubN(walSegment, 8, 8)), NULL, 16);
-        minor = (uint32_t)strtol(strPtr(strSubN(walSegment, 16, 8)), NULL, 16);
+        timeline = (uint32_t)strtol(strZ(strSubN(walSegment, 0, 8)), NULL, 16);
+        major = (uint32_t)strtol(strZ(strSubN(walSegment, 8, 8)), NULL, 16);
+        minor = (uint32_t)strtol(strZ(strSubN(walSegment, 16, 8)), NULL, 16);
 
         // Increment minor and adjust major dir on overflow
         minor++;
@@ -505,9 +516,7 @@ walSegmentNext(const String *walSegment, size_t walSegmentSize, unsigned int pgV
     FUNCTION_LOG_RETURN(STRING, strNewFmt("%08X%08X%08X", timeline, major, minor));
 }
 
-/***********************************************************************************************************************************
-Build a list of WAL segments based on a beginning WAL and number of WAL in the range (inclusive)
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 StringList *
 walSegmentRange(const String *walSegmentBegin, size_t walSegmentSize, unsigned int pgVersion, unsigned int range)
 {
