@@ -20,10 +20,16 @@ Archive Push Command
 #include "config/exec.h"
 #include "info/infoArchive.h"
 #include "postgres/interface.h"
+#include "postgres/version.h"
 #include "protocol/helper.h"
 #include "protocol/parallel.h"
 #include "storage/helper.h"
 
+/***********************************************************************************************************************************
+Constants for log messages that are used multiple times to keep them consistent
+***********************************************************************************************************************************/
+#define UNABLE_TO_FIND_VALID_REPO_MSG                               "unable to find a valid repository"
+
 /***********************************************************************************************************************************
 Ready file extension constants
 ***********************************************************************************************************************************/
@@ -42,7 +48,7 @@ archivePushDropWarning(const String *walFile, uint64_t queueMax)
     FUNCTION_TEST_END();
 
     FUNCTION_TEST_RETURN(
-        strNewFmt("dropped WAL file '%s' because archive queue exceeded %s", strPtr(walFile), strPtr(strSizeFormat(queueMax))));
+        strNewFmt("dropped WAL file '%s' because archive queue exceeded %s", strZ(walFile), strZ(strSizeFormat(queueMax))));
 }
 
 /***********************************************************************************************************************************
@@ -63,7 +69,7 @@ archivePushDrop(const String *walPath, const StringList *const processList)
     for (unsigned int processIdx = 0; processIdx < strLstSize(processList); processIdx++)
     {
         queueSize += storageInfoP(
-            storagePg(), strNewFmt("%s/%s", strPtr(walPath), strPtr(strLstGet(processList, processIdx)))).size;
+            storagePg(), strNewFmt("%s/%s", strZ(walPath), strZ(strLstGet(processList, processIdx)))).size;
 
         if (queueSize > queueMax)
         {
@@ -96,7 +102,7 @@ archivePushReadyList(const String *walPath)
         // Read the ready files from the archive_status directory
         StringList *readyListRaw = strLstSort(
             storageListP(
-                storagePg(), strNewFmt("%s/" PG_PATH_ARCHIVE_STATUS, strPtr(walPath)),
+                storagePg(), strNewFmt("%s/" PG_PATH_ARCHIVE_STATUS, strZ(walPath)),
                 .expression = STRDEF("\\" STATUS_EXT_READY "$"), .errorOnMissing = true),
             sortOrderAsc);
 
@@ -154,7 +160,7 @@ archivePushProcessList(const String *walPath)
             else
             {
                 storageRemoveP(
-                    storageSpoolWrite(), strNewFmt(STORAGE_SPOOL_ARCHIVE_OUT "/%s", strPtr(statusFile)), .errorOnMissing = true);
+                    storageSpoolWrite(), strNewFmt(STORAGE_SPOOL_ARCHIVE_OUT "/%s", strZ(statusFile)), .errorOnMissing = true);
             }
         }
 
@@ -168,7 +174,7 @@ archivePushProcessList(const String *walPath)
         {
             storageRemoveP(
                 storageSpoolWrite(),
-                strNewFmt(STORAGE_SPOOL_ARCHIVE_OUT "/%s" STATUS_EXT_OK, strPtr(strLstGet(okRemoveList, okRemoveIdx))),
+                strNewFmt(STORAGE_SPOOL_ARCHIVE_OUT "/%s" STATUS_EXT_OK, strZ(strLstGet(okRemoveList, okRemoveIdx))),
                 .errorOnMissing = true);
         }
 
@@ -186,68 +192,110 @@ Check that pg_control and archive.info match and get the archive id and archive
 As much information as possible is collected here so that async archiving has as little work as possible to do for each file.  Sync
 archiving does not benefit but it makes sense to use the same function.
 ***********************************************************************************************************************************/
-#define FUNCTION_LOG_ARCHIVE_PUSH_CHECK_RESULT_TYPE                                                                                \
-    ArchivePushCheckResult
-#define FUNCTION_LOG_ARCHIVE_PUSH_CHECK_RESULT_FORMAT(value, buffer, bufferSize)                                                   \
-    objToLog(&value, "ArchivePushCheckResult", buffer, bufferSize)
-
 typedef struct ArchivePushCheckResult
 {
     unsigned int pgVersion;                                         // PostgreSQL version
     uint64_t pgSystemId;                                            // PostgreSQL system id
-    String *archiveId;                                              // Archive id for current pg version
-    String *archiveCipherPass;                                      // Archive cipher passphrase
+    List *repoList;                                                 // Data for each repo
+    StringList *errorList;                                          // Errors while checking repos
 } ArchivePushCheckResult;
 
 static ArchivePushCheckResult
-archivePushCheck(bool pgPathSet, CipherType cipherType, const String *cipherPass)
+archivePushCheck(bool pgPathSet)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
         FUNCTION_LOG_PARAM(BOOL, pgPathSet);
-        FUNCTION_LOG_PARAM(ENUM, cipherType);
-        FUNCTION_TEST_PARAM(STRING, cipherPass);
     FUNCTION_LOG_END();
 
-    ArchivePushCheckResult result = {0};
+    ArchivePushCheckResult result = {.repoList = lstNewP(sizeof(ArchivePushFileRepoData)), .errorList = strLstNew()};
 
     MEM_CONTEXT_TEMP_BEGIN()
     {
-        // Attempt to load the archive info file
-        InfoArchive *info = infoArchiveLoadFile(storageRepo(), INFO_ARCHIVE_PATH_FILE_STR, cipherType, cipherPass);
-
-        // Get archive id for the most recent version -- archive-push will only operate against the most recent version
-        String *archiveId = infoPgArchiveId(infoArchivePg(info), infoPgDataCurrentId(infoArchivePg(info)));
-        InfoPgData archiveInfo = infoPgData(infoArchivePg(info), infoPgDataCurrentId(infoArchivePg(info)));
-
-        // Ensure that stanza version and system identifier match pg_control when available
+        // If we have access to pg_control then load it to get the pg version and system id. If we can't load pg_control then we'll
+        // still compare the pg info stored in the repo to the WAL segment and also all the repos against each other.
         if (pgPathSet)
         {
             // Get info from pg_control
-            PgControl controlInfo = pgControlFromFile(storagePg());
-
-            if (controlInfo.version != archiveInfo.version || controlInfo.systemId != archiveInfo.systemId)
-            {
-                THROW_FMT(
-                    ArchiveMismatchError,
-                    "PostgreSQL version %s, system-id %" PRIu64 " do not match stanza version %s, system-id %" PRIu64
-                    "\nHINT: are you archiving to the correct stanza?",
-                    strPtr(pgVersionToStr(controlInfo.version)), controlInfo.systemId, strPtr(pgVersionToStr(archiveInfo.version)),
-                    archiveInfo.systemId);
-            }
+            PgControl pgControl = pgControlFromFile(storagePg());
+            result.pgVersion = pgControl.version;
+            result.pgSystemId = pgControl.systemId;
         }
 
-        MEM_CONTEXT_PRIOR_BEGIN()
+        for (unsigned int repoIdx = 0; repoIdx < cfgOptionGroupIdxTotal(cfgOptGrpRepo); repoIdx++)
         {
-            result.pgVersion = archiveInfo.version;
-            result.pgSystemId = archiveInfo.systemId;
-            result.archiveId = strDup(archiveId);
-            result.archiveCipherPass = strDup(infoArchiveCipherPass(info));
+            TRY_BEGIN()
+            {
+                // Get the repo storage in case it is remote and encryption settings need to be pulled down
+                storageRepoIdx(repoIdx);
+
+                // Get cipher type
+                CipherType repoCipherType = cipherType(cfgOptionIdxStr(cfgOptRepoCipherType, repoIdx));
+
+                // Attempt to load the archive info file
+                InfoArchive *info = infoArchiveLoadFile(
+                    storageRepoIdx(repoIdx), INFO_ARCHIVE_PATH_FILE_STR, repoCipherType,
+                    cfgOptionIdxStrNull(cfgOptRepoCipherPass, repoIdx));
+
+                // Get archive id for the most recent version -- archive-push will only operate against the most recent version
+                String *archiveId = infoPgArchiveId(infoArchivePg(info), infoPgDataCurrentId(infoArchivePg(info)));
+                InfoPgData archiveInfo = infoPgData(infoArchivePg(info), infoPgDataCurrentId(infoArchivePg(info)));
+
+                // Ensure that stanza version and system identifier match pg_control when available or the other repos when
+                // pg_control is not available
+                if (pgPathSet || repoIdx > 0)
+                {
+                    if (result.pgVersion != archiveInfo.version || result.pgSystemId != archiveInfo.systemId)
+                    {
+                        THROW_FMT(
+                            ArchiveMismatchError,
+                            "%s version %s, system-id %" PRIu64 " do not match %s stanza version %s, system-id %" PRIu64
+                            "\nHINT: are you archiving to the correct stanza?",
+                            pgPathSet ? PG_NAME : strZ(strNewFmt("repo%u stanza", cfgOptionGroupIdxToKey(cfgOptGrpRepo, 0))),
+                            strZ(pgVersionToStr(result.pgVersion)), result.pgSystemId,
+                            strZ(strNewFmt("repo%u", cfgOptionGroupIdxToKey(cfgOptGrpRepo, repoIdx))),
+                            strZ(pgVersionToStr(archiveInfo.version)), archiveInfo.systemId);
+                    }
+                }
+
+                MEM_CONTEXT_PRIOR_BEGIN()
+                {
+                    result.pgVersion = archiveInfo.version;
+                    result.pgSystemId = archiveInfo.systemId;
+
+                    lstAdd(
+                        result.repoList,
+                        &(ArchivePushFileRepoData)
+                        {
+                            .repoIdx = repoIdx,
+                            .archiveId = strDup(archiveId),
+                            .cipherType = repoCipherType,
+                            .cipherPass = strDup(infoArchiveCipherPass(info)),
+                        });
+                }
+                MEM_CONTEXT_PRIOR_END();
+            }
+            CATCH_ANY()
+            {
+                strLstAdd(
+                    result.errorList,
+                    strNewFmt(
+                        "repo%u: [%s] %s", cfgOptionGroupIdxToKey(cfgOptGrpRepo, repoIdx), errorTypeName(errorType()),
+                        errorMessage()));
+            }
+            TRY_END();
         }
-        MEM_CONTEXT_PRIOR_END();
     }
     MEM_CONTEXT_TEMP_END();
 
-    FUNCTION_LOG_RETURN(ARCHIVE_PUSH_CHECK_RESULT, result);
+    // If no valid repos were found then error
+    if (lstEmpty(result.repoList))
+    {
+        ASSERT(strLstSize(result.errorList) > 0);
+
+        THROW_FMT(RepoInvalidError, UNABLE_TO_FIND_VALID_REPO_MSG ":\n%s", strZ(strLstJoin(result.errorList, "\n")));
+    }
+
+    FUNCTION_LOG_RETURN_STRUCT(result);
 }
 
 /**********************************************************************************************************************************/
@@ -284,10 +332,14 @@ cmdArchivePush(void)
 
             // pg1-path is not optional for async mode
             if (!cfgOptionTest(cfgOptPgPath))
-                THROW(OptionRequiredError, "'" CFGCMD_ARCHIVE_PUSH "' command in async mode requires option '" CFGOPT_PG1_PATH "'");
+            {
+                THROW_FMT(
+                    OptionRequiredError, "'" CFGCMD_ARCHIVE_PUSH "' command in async mode requires option '%s'",
+                    cfgOptionName(cfgOptPgPath));
+            }
 
             // Loop and wait for the WAL segment to be pushed
-            Wait *wait = waitNew((TimeMSec)(cfgOptionDbl(cfgOptArchiveTimeout) * MSEC_PER_SEC));
+            Wait *wait = waitNew(cfgOptionUInt64(cfgOptArchiveTimeout));
 
             do
             {
@@ -299,7 +351,9 @@ cmdArchivePush(void)
                 // forking the async process off more than once so track that as well.  Use an archive lock to prevent more than
                 // one async process being launched.
                 if (!pushed && !forked &&
-                    lockAcquire(cfgOptionStr(cfgOptLockPath), cfgOptionStr(cfgOptStanza), cfgLockType(), 0, false))
+                    lockAcquire(
+                        cfgOptionStr(cfgOptLockPath), cfgOptionStr(cfgOptStanza), cfgOptionStr(cfgOptExecId), cfgLockType(), 0,
+                        false))
                 {
                     // The async process should not output on the console at all
                     KeyValue *optionReplace = kvNew();
@@ -335,44 +389,39 @@ cmdArchivePush(void)
             if (!pushed)
             {
                 THROW_FMT(
-                    ArchiveTimeoutError, "unable to push WAL file '%s' to the archive asynchronously after %lg second(s)",
-                    strPtr(archiveFile), cfgOptionDbl(cfgOptArchiveTimeout));
+                    ArchiveTimeoutError, "unable to push WAL file '%s' to the archive asynchronously after %s second(s)",
+                    strZ(archiveFile), strZ(strNewDbl((double)cfgOptionInt64(cfgOptArchiveTimeout) / MSEC_PER_SEC)));
             }
 
             // Log success
-            LOG_INFO_FMT("pushed WAL file '%s' to the archive asynchronously", strPtr(archiveFile));
+            LOG_INFO_FMT("pushed WAL file '%s' to the archive asynchronously", strZ(archiveFile));
         }
         else
         {
-            // Get the repo storage in case it is remote and encryption settings need to be pulled down
-            storageRepo();
-
-            // Get archive info
-            ArchivePushCheckResult archiveInfo = archivePushCheck(
-                cfgOptionTest(cfgOptPgPath), cipherType(cfgOptionStr(cfgOptRepoCipherType)),
-                cfgOptionStrNull(cfgOptRepoCipherPass));
-
             // Check if the push queue has been exceeded
             if (cfgOptionTest(cfgOptArchivePushQueueMax) &&
                 archivePushDrop(strPath(walFile), archivePushReadyList(strPath(walFile))))
             {
-                LOG_WARN(strPtr(archivePushDropWarning(archiveFile, cfgOptionUInt64(cfgOptArchivePushQueueMax))));
+                LOG_WARN(strZ(archivePushDropWarning(archiveFile, cfgOptionUInt64(cfgOptArchivePushQueueMax))));
             }
             // Else push the file
             else
             {
+                // Check archive info for each repo
+                ArchivePushCheckResult archiveInfo = archivePushCheck(cfgOptionTest(cfgOptPgPath));
+
                 // Push the file to the archive
-                String *warning = archivePushFile(
-                    walFile, archiveInfo.archiveId, archiveInfo.pgVersion, archiveInfo.pgSystemId, archiveFile,
-                    cipherType(cfgOptionStr(cfgOptRepoCipherType)), archiveInfo.archiveCipherPass,
-                    compressTypeEnum(cfgOptionStr(cfgOptCompressType)), cfgOptionInt(cfgOptCompressLevel));
+                ArchivePushFileResult fileResult = archivePushFile(
+                    walFile, cfgOptionBool(cfgOptArchiveHeaderCheck), archiveInfo.pgVersion, archiveInfo.pgSystemId, archiveFile,
+                    compressTypeEnum(cfgOptionStr(cfgOptCompressType)), cfgOptionInt(cfgOptCompressLevel), archiveInfo.repoList,
+                    archiveInfo.errorList);
 
                 // If a warning was returned then log it
-                if (warning != NULL)
-                    LOG_WARN(strPtr(warning));
+                for (unsigned int warnIdx = 0; warnIdx < strLstSize(fileResult.warnList); warnIdx++)
+                    LOG_WARN(strZ(strLstGet(fileResult.warnList, warnIdx)));
 
                 // Log success
-                LOG_INFO_FMT("pushed WAL file '%s' to the archive", strPtr(archiveFile));
+                LOG_INFO_FMT("pushed WAL file '%s' to the archive", strZ(archiveFile));
             }
         }
     }
@@ -387,13 +436,13 @@ typedef struct ArchivePushAsyncData
     const String *walPath;                                          // Path to pg_wal/pg_xlog
     const StringList *walFileList;                                  // List of wal files to process
     unsigned int walFileIdx;                                        // Current index in the list to be processed
-    CipherType cipherType;                                          // Cipher type
     CompressType compressType;                                      // Type of compression for WAL segments
     int compressLevel;                                              // Compression level for wal files
     ArchivePushCheckResult archiveInfo;                             // Archive info
 } ArchivePushAsyncData;
 
-static ProtocolParallelJob *archivePushAsyncCallback(void *data, unsigned int clientIdx)
+static ProtocolParallelJob *
+archivePushAsyncCallback(void *data, unsigned int clientIdx)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM_P(VOID, data);
@@ -411,16 +460,27 @@ static ProtocolParallelJob *archivePushAsyncCallback(void *data, unsigned int cl
         const String *walFile = strLstGet(jobData->walFileList, jobData->walFileIdx);
         jobData->walFileIdx++;
 
-        ProtocolCommand *command = protocolCommandNew(PROTOCOL_COMMAND_ARCHIVE_PUSH_STR);
-        protocolCommandParamAdd(command, VARSTR(strNewFmt("%s/%s", strPtr(jobData->walPath), strPtr(walFile))));
-        protocolCommandParamAdd(command, VARSTR(jobData->archiveInfo.archiveId));
+        ProtocolCommand *command = protocolCommandNew(PROTOCOL_COMMAND_ARCHIVE_PUSH_FILE_STR);
+        protocolCommandParamAdd(command, VARSTR(strNewFmt("%s/%s", strZ(jobData->walPath), strZ(walFile))));
+        protocolCommandParamAdd(command, VARBOOL(cfgOptionBool(cfgOptArchiveHeaderCheck)));
         protocolCommandParamAdd(command, VARUINT(jobData->archiveInfo.pgVersion));
         protocolCommandParamAdd(command, VARUINT64(jobData->archiveInfo.pgSystemId));
         protocolCommandParamAdd(command, VARSTR(walFile));
-        protocolCommandParamAdd(command, VARUINT(jobData->cipherType));
-        protocolCommandParamAdd(command, VARSTR(jobData->archiveInfo.archiveCipherPass));
         protocolCommandParamAdd(command, VARUINT(jobData->compressType));
         protocolCommandParamAdd(command, VARINT(jobData->compressLevel));
+        protocolCommandParamAdd(command, varNewVarLst(varLstNewStrLst(jobData->archiveInfo.errorList)));
+        protocolCommandParamAdd(command, VARUINT(lstSize(jobData->archiveInfo.repoList)));
+
+        // Add data for each repo to push to
+        for (unsigned int repoListIdx = 0; repoListIdx < lstSize(jobData->archiveInfo.repoList); repoListIdx++)
+        {
+            ArchivePushFileRepoData *data = lstGet(jobData->archiveInfo.repoList, repoListIdx);
+
+            protocolCommandParamAdd(command, VARUINT(data->repoIdx));
+            protocolCommandParamAdd(command, VARSTR(data->archiveId));
+            protocolCommandParamAdd(command, VARUINT(data->cipherType));
+            protocolCommandParamAdd(command, VARSTR(data->cipherPass));
+        }
 
         FUNCTION_TEST_RETURN(protocolParallelJobNew(VARSTR(walFile), command));
     }
@@ -462,13 +522,13 @@ cmdArchivePushAsync(void)
             jobData.walFileList = archivePushProcessList(jobData.walPath);
 
             // The archive-push:async command should not have been called unless there are WAL files to process
-            if (strLstSize(jobData.walFileList) == 0)
+            if (strLstEmpty(jobData.walFileList))
                 THROW(AssertError, "no WAL files to process");
 
             LOG_INFO_FMT(
-                "push %u WAL file(s) to archive: %s%s", strLstSize(jobData.walFileList), strPtr(strLstGet(jobData.walFileList, 0)),
+                "push %u WAL file(s) to archive: %s%s", strLstSize(jobData.walFileList), strZ(strLstGet(jobData.walFileList, 0)),
                 strLstSize(jobData.walFileList) == 1 ?
-                    "" : strPtr(strNewFmt("...%s", strPtr(strLstGet(jobData.walFileList, strLstSize(jobData.walFileList) - 1)))));
+                    "" : strZ(strNewFmt("...%s", strZ(strLstGet(jobData.walFileList, strLstSize(jobData.walFileList) - 1)))));
 
             // Drop files if queue max has been exceeded
             if (cfgOptionTest(cfgOptArchivePushQueueMax) && archivePushDrop(jobData.walPath, jobData.walFileList))
@@ -479,28 +539,21 @@ cmdArchivePushAsync(void)
                     const String *warning = archivePushDropWarning(walFile, cfgOptionUInt64(cfgOptArchivePushQueueMax));
 
                     archiveAsyncStatusOkWrite(archiveModePush, walFile, warning);
-                    LOG_WARN(strPtr(warning));
+                    LOG_WARN(strZ(warning));
                 }
             }
             // Else continue processing
             else
             {
-                // Get the repo storage in case it is remote and encryption settings need to be pulled down
-                storageRepo();
-
-                // Get cipher type
-                jobData.cipherType = cipherType(cfgOptionStr(cfgOptRepoCipherType));
-
-                // Get archive info
-                jobData.archiveInfo = archivePushCheck(
-                    true, cipherType(cfgOptionStr(cfgOptRepoCipherType)), cfgOptionStrNull(cfgOptRepoCipherPass));
+                // Check archive info for each repo
+                jobData.archiveInfo = archivePushCheck(true);
 
                 // Create the parallel executor
                 ProtocolParallel *parallelExec = protocolParallelNew(
-                    (TimeMSec)(cfgOptionDbl(cfgOptProtocolTimeout) * MSEC_PER_SEC) / 2, archivePushAsyncCallback, &jobData);
+                    cfgOptionUInt64(cfgOptProtocolTimeout) / 2, archivePushAsyncCallback, &jobData);
 
                 for (unsigned int processIdx = 1; processIdx <= cfgOptionUInt(cfgOptProcessMax); processIdx++)
-                    protocolParallelClientAdd(parallelExec, protocolLocalGet(protocolStorageTypeRepo, 1, processIdx));
+                    protocolParallelClientAdd(parallelExec, protocolLocalGet(protocolStorageTypeRepo, 0, processIdx));
 
                 // Process jobs
                 do
@@ -519,16 +572,29 @@ cmdArchivePushAsync(void)
                         // The job was successful
                         if (protocolParallelJobErrorCode(job) == 0)
                         {
-                            LOG_DETAIL_PID_FMT(processId, "pushed WAL file '%s' to the archive", strPtr(walFile));
-                            archiveAsyncStatusOkWrite(archiveModePush, walFile, varStr(protocolParallelJobResult(job)));
+                            // Get job result
+                            const VariantList *fileResult = varVarLst(protocolParallelJobResult(job));
+
+                            // Output file warnings
+                            StringList *fileWarnList = strLstNewVarLst(varVarLst(varLstGet(fileResult, 0)));
+
+                            for (unsigned int warnIdx = 0; warnIdx < strLstSize(fileWarnList); warnIdx++)
+                                LOG_WARN_PID(processId, strZ(strLstGet(fileWarnList, warnIdx)));
+
+                            // Log success
+                            LOG_DETAIL_PID_FMT(processId, "pushed WAL file '%s' to the archive", strZ(walFile));
+
+                            // Write the status file
+                            archiveAsyncStatusOkWrite(
+                                archiveModePush, walFile, strLstEmpty(fileWarnList) ? NULL : strLstJoin(fileWarnList, "\n"));
                         }
                         // Else the job errored
                         else
                         {
                             LOG_WARN_PID_FMT(
                                 processId,
-                                "could not push WAL file '%s' to the archive (will be retried): [%d] %s", strPtr(walFile),
-                                protocolParallelJobErrorCode(job), strPtr(protocolParallelJobErrorMessage(job)));
+                                "could not push WAL file '%s' to the archive (will be retried): [%d] %s", strZ(walFile),
+                                protocolParallelJobErrorCode(job), strZ(protocolParallelJobErrorMessage(job)));
 
                             archiveAsyncStatusErrorWrite(
                                 archiveModePush, walFile, protocolParallelJobErrorCode(job), protocolParallelJobErrorMessage(job));
