@@ -7,9 +7,6 @@ Backup File
 
 #include "command/backup/file.h"
 #include "command/backup/pageChecksum.h"
-#include "common/compress/gzip/common.h"
-#include "common/compress/gzip/compress.h"
-#include "common/compress/gzip/decompress.h"
 #include "common/crypto/cipherBlock.h"
 #include "common/crypto/hash.h"
 #include "common/debug.h"
@@ -33,29 +30,29 @@ segmentNumber(const String *pgFile)
     FUNCTION_TEST_END();
 
     // Determine which segment number this is by checking for a numeric extension.  No extension means segment 0.
-    FUNCTION_TEST_RETURN(regExpMatchOne(STRDEF("\\.[0-9]+$"), pgFile) ? cvtZToUInt(strrchr(strPtr(pgFile), '.') + 1) : 0);
+    FUNCTION_TEST_RETURN(regExpMatchOne(STRDEF("\\.[0-9]+$"), pgFile) ? cvtZToUInt(strrchr(strZ(pgFile), '.') + 1) : 0);
 }
 
-/***********************************************************************************************************************************
-Copy a file from the PostgreSQL data directory to the repository
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 BackupFileResult
 backupFile(
-    const String *pgFile, bool pgFileIgnoreMissing, uint64_t pgFileSize, const String *pgFileChecksum, bool pgFileChecksumPage,
-    uint64_t pgFileChecksumPageLsnLimit, const String *repoFile, bool repoFileHasReference, bool repoFileCompress,
-    unsigned int repoFileCompressLevel, const String *backupLabel, bool delta, CipherType cipherType, const String *cipherPass)
+    const String *pgFile, bool pgFileIgnoreMissing, uint64_t pgFileSize, bool pgFileCopyExactSize, const String *pgFileChecksum,
+    bool pgFileChecksumPage, uint64_t pgFileChecksumPageLsnLimit, const String *repoFile, bool repoFileHasReference,
+    CompressType repoFileCompressType, int repoFileCompressLevel, const String *backupLabel, bool delta, CipherType cipherType,
+    const String *cipherPass)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
         FUNCTION_LOG_PARAM(STRING, pgFile);                         // Database file to copy to the repo
         FUNCTION_LOG_PARAM(BOOL, pgFileIgnoreMissing);              // Is it OK if the database file is missing?
         FUNCTION_LOG_PARAM(UINT64, pgFileSize);                     // Size of the database file
+        FUNCTION_LOG_PARAM(BOOL, pgFileCopyExactSize);              // Copy only pgFileSize bytes even if the file has grown
         FUNCTION_LOG_PARAM(STRING, pgFileChecksum);                 // Checksum to verify the database file
         FUNCTION_LOG_PARAM(BOOL, pgFileChecksumPage);               // Should page checksums be validated
         FUNCTION_LOG_PARAM(UINT64, pgFileChecksumPageLsnLimit);     // Upper LSN limit to which page checksums must be valid
         FUNCTION_LOG_PARAM(STRING, repoFile);                       // Destination in the repo to copy the pg file
         FUNCTION_LOG_PARAM(BOOL, repoFileHasReference);             // Does the repo file exist in a prior backup in the set?
-        FUNCTION_LOG_PARAM(BOOL, repoFileCompress);                 // Compress destination file
-        FUNCTION_LOG_PARAM(UINT, repoFileCompressLevel);            // Compression level for destination file
+        FUNCTION_LOG_PARAM(ENUM, repoFileCompressType);             // Compress type for repo file
+        FUNCTION_LOG_PARAM(INT,  repoFileCompressLevel);            // Compression level for repo file
         FUNCTION_LOG_PARAM(STRING, backupLabel);                    // Label of current backup
         FUNCTION_LOG_PARAM(BOOL, delta);                            // Is the delta option on?
         FUNCTION_LOG_PARAM(ENUM, cipherType);                       // Encryption type
@@ -74,7 +71,7 @@ backupFile(
     {
         // Generate complete repo path and add compression extension if needed
         const String *repoPathFile = strNewFmt(
-            STORAGE_REPO_BACKUP "/%s/%s%s", strPtr(backupLabel), strPtr(repoFile), repoFileCompress ? "." GZIP_EXT : "");
+            STORAGE_REPO_BACKUP "/%s/%s%s", strZ(backupLabel), strZ(repoFile), strZ(compressExtStr(repoFileCompressType)));
 
         // If checksum is defined then the file needs to be checked. If delta option then check the DB and possibly the repo, else
         // just check the repo.
@@ -87,8 +84,13 @@ backupFile(
             // recopy.
             if (delta)
             {
-                // Generate checksum/size for the pg file
-                IoRead *read = storageReadIo(storageNewReadP(storagePg(), pgFile, .ignoreMissing = pgFileIgnoreMissing));
+                // Generate checksum/size for the pg file. Only read as many bytes as passed in pgFileSize.  If the file has grown
+                // since the manifest was built we don't need to consider the extra bytes since they will be replayed from WAL
+                // during recovery.
+                IoRead *read = storageReadIo(
+                    storageNewReadP(
+                        storagePg(), pgFile, .ignoreMissing = pgFileIgnoreMissing,
+                        .limit = pgFileCopyExactSize ? VARUINT64(pgFileSize) : NULL));
                 ioFilterGroupAdd(ioReadFilterGroup(read), cryptoHashNew(HASH_TYPE_SHA1_STR));
                 ioFilterGroupAdd(ioReadFilterGroup(read), ioSizeNew());
 
@@ -148,8 +150,9 @@ backupFile(
                                 ioReadFilterGroup(read), cipherBlockNew(cipherModeDecrypt, cipherType, BUFSTR(cipherPass), NULL));
                         }
 
-                        if (repoFileCompress)
-                            ioFilterGroupAdd(ioReadFilterGroup(read), gzipDecompressNew(false));
+                        // Decompress the file if compressed
+                        if (repoFileCompressType != compressTypeNone)
+                            ioFilterGroupAdd(ioReadFilterGroup(read), decompressFilter(repoFileCompressType));
 
                         ioFilterGroupAdd(ioReadFilterGroup(read), cryptoHashNew(HASH_TYPE_SHA1_STR));
                         ioFilterGroupAdd(ioReadFilterGroup(read), ioSizeNew());
@@ -190,11 +193,14 @@ backupFile(
         if (result.backupCopyResult == backupCopyResultCopy || result.backupCopyResult == backupCopyResultReCopy)
         {
             // Is the file compressible during the copy?
-            bool compressible = !repoFileCompress && cipherType == cipherTypeNone;
+            bool compressible = repoFileCompressType == compressTypeNone && cipherType == cipherTypeNone;
 
-            // Setup pg file for read
+            // Setup pg file for read. Only read as many bytes as passed in pgFileSize.  If the file is growing it does no good to
+            // copy data past the end of the size recorded in the manifest since those blocks will need to be replayed from WAL
+            // during recovery.
             StorageRead *read = storageNewReadP(
-                storagePg(), pgFile, .ignoreMissing = pgFileIgnoreMissing, .compressible = compressible);
+                storagePg(), pgFile, .ignoreMissing = pgFileIgnoreMissing, .compressible = compressible,
+                .limit = pgFileCopyExactSize ? VARUINT64(pgFileSize) : NULL);
             ioFilterGroupAdd(ioReadFilterGroup(storageReadIo(read)), cryptoHashNew(HASH_TYPE_SHA1_STR));
             ioFilterGroupAdd(ioReadFilterGroup(storageReadIo(read)), ioSizeNew());
 
@@ -203,12 +209,15 @@ backupFile(
             {
                 ioFilterGroupAdd(
                     ioReadFilterGroup(storageReadIo(read)), pageChecksumNew(segmentNumber(pgFile), PG_SEGMENT_PAGE_DEFAULT,
-                    PG_PAGE_SIZE_DEFAULT, pgFileChecksumPageLsnLimit));
+                    pgFileChecksumPageLsnLimit));
             }
 
             // Add compression
-            if (repoFileCompress)
-                ioFilterGroupAdd(ioReadFilterGroup(storageReadIo(read)), gzipCompressNew((int)repoFileCompressLevel, false));
+            if (repoFileCompressType != compressTypeNone)
+            {
+                ioFilterGroupAdd(
+                    ioReadFilterGroup(storageReadIo(read)), compressFilter(repoFileCompressType, repoFileCompressLevel));
+            }
 
             // If there is a cipher then add the encrypt filter
             if (cipherType != cipherTypeNone)
@@ -263,5 +272,5 @@ backupFile(
     }
     MEM_CONTEXT_TEMP_END();
 
-    FUNCTION_LOG_RETURN(BACKUP_FILE_RESULT, result);
+    FUNCTION_LOG_RETURN_STRUCT(result);
 }
