@@ -15,9 +15,9 @@ Filter type constant
     STRING_DECLARE(PAGE_CHECKSUM_FILTER_TYPE_STR);
 
 /***********************************************************************************************************************************
-Constructor
+Constructors
 ***********************************************************************************************************************************/
-IoFilter *pageChecksumNew(unsigned int segmentNo, unsigned int segmentPageTotal, size_t pageSize, uint64_t lsnLimit);
+IoFilter *pageChecksumNew(unsigned int segmentNo, unsigned int segmentPageTotal, uint64_t lsnLimit);
 IoFilter *pageChecksumNewVar(const VariantList *paramList);
 
 #endif
