@@ -11,13 +11,19 @@ Backup Protocol Handler
 /***********************************************************************************************************************************
 Constants
 ***********************************************************************************************************************************/
-#define PROTOCOL_COMMAND_BACKUP_FILE                               "backupFile"
+#define PROTOCOL_COMMAND_BACKUP_FILE                                "backupFile"
     STRING_DECLARE(PROTOCOL_COMMAND_BACKUP_FILE_STR);
 
 /***********************************************************************************************************************************
 Functions
 ***********************************************************************************************************************************/
 // Process protocol requests
-bool backupProtocol(const String *command, const VariantList *paramList, ProtocolServer *server);
+void backupFileProtocol(const VariantList *paramList, ProtocolServer *server);
+
+/***********************************************************************************************************************************
+Protocol commands for ProtocolServerHandler arrays passed to protocolServerProcess()
+***********************************************************************************************************************************/
+#define PROTOCOL_SERVER_HANDLER_BACKUP_LIST                                                                                        \
+    {.command = PROTOCOL_COMMAND_BACKUP_FILE, .handler = backupFileProtocol},
 
 #endif
