@@ -9,9 +9,17 @@ Common Command Routines
 /***********************************************************************************************************************************
 Functions
 ***********************************************************************************************************************************/
+// Capture time at the very start of main so total time is more accurate
 void cmdInit(void);
 
-void cmdBegin(bool logOption);
+// Begin the command
+void cmdBegin(void);
+
+// Get the command options as a string. This is output in cmdBegin() if the log level is high enough but can also be used for
+// debugging or error reporting later on.
+const String *cmdOption(void);
+
+// End the command
 void cmdEnd(int code, const String *errorMessage);
 
 #endif
