@@ -7,6 +7,7 @@ Local Command
 /***********************************************************************************************************************************
 Functions
 ***********************************************************************************************************************************/
-void cmdLocal(int handleRead, int handleWrite);
+// Local command
+void cmdLocal(int fdRead, int fdWrite);
 
 #endif
