@@ -7,6 +7,7 @@ Remote Command
 /***********************************************************************************************************************************
 Functions
 ***********************************************************************************************************************************/
-void cmdRemote(int handleRead, int handleWrite);
+// Remote command
+void cmdRemote(int fdRead, int fdWrite);
 
 #endif
