@@ -6,7 +6,7 @@ Repository List Command
 #include <unistd.h>
 
 #include "common/debug.h"
-#include "common/io/handleWrite.h"
+#include "common/io/fdWrite.h"
 #include "common/log.h"
 #include "common/memContext.h"
 #include "common/regExp.h"
@@ -60,28 +60,20 @@ storageListRenderCallback(void *data, const StorageInfo *info)
         switch (info->type)
         {
             case storageTypeFile:
-            {
                 ioWrite(listData->write, BUFSTRDEF("file\""));
                 break;
-            }
 
             case storageTypeLink:
-            {
                 ioWrite(listData->write, BUFSTRDEF("link\""));
                 break;
-            }
 
             case storageTypePath:
-            {
                 ioWrite(listData->write, BUFSTRDEF("path\""));
                 break;
-            }
 
             case storageTypeSpecial:
-            {
                 ioWrite(listData->write, BUFSTRDEF("special\""));
                 break;
-            }
         }
 
         if (info->type == storageTypeFile)
@@ -91,7 +83,7 @@ storageListRenderCallback(void *data, const StorageInfo *info)
         }
 
         if (info->type == storageTypeLink)
-            ioWriteStr(listData->write, strNewFmt(",\"destination\":%s", strPtr(jsonFromStr(info->linkDestination))));
+            ioWriteStr(listData->write, strNewFmt(",\"destination\":%s", strZ(jsonFromStr(info->linkDestination))));
 
         ioWrite(listData->write, BRACER_BUF);
     }
@@ -194,7 +186,7 @@ cmdStorageList(void)
     {
         TRY_BEGIN()
         {
-            storageListRender(ioHandleWriteNew(STRDEF("stdout"), STDOUT_FILENO));
+            storageListRender(ioFdWriteNew(STRDEF("stdout"), STDOUT_FILENO, cfgOptionUInt64(cfgOptIoTimeout)));
         }
         // Ignore write errors because it's possible (even likely) that this output is being piped to something like head which
         // will exit when it gets what it needs and leave us writing to a broken pipe.  It would be better to just ignore the broken
