@@ -5,7 +5,6 @@ Stanza Commands Handler
 
 #include "command/check/common.h"
 #include "common/debug.h"
-#include "common/encode.h"
 #include "common/log.h"
 #include "config/config.h"
 #include "db/helper.h"
@@ -28,9 +27,8 @@ cipherPassGen(CipherType cipherType)
     {
         unsigned char buffer[48]; // 48 is the amount of entropy needed to get a 64 base key
         cryptoRandomBytes(buffer, sizeof(buffer));
-        char cipherPassSubChar[64];
-        encodeToStr(encodeBase64, buffer, sizeof(buffer), cipherPassSubChar);
-        result = strNew(cipherPassSubChar);
+
+        result = strNewEncode(encodeBase64, BUF(buffer, sizeof(buffer)));
     }
 
     FUNCTION_TEST_RETURN(result);
@@ -52,10 +50,10 @@ pgValidate(void)
             DbGetResult dbObject = dbGet(false, true, false);
 
             // Get the pgControl information from the pg*-path deemed to be the master
-            result = pgControlFromFile(storagePgId(dbObject.primaryId));
+            result = pgControlFromFile(storagePgIdx(dbObject.primaryIdx));
 
             // Check the user configured path and version against the database
-            checkDbConfig(result.version, dbObject.primaryId, dbObject.primary, false);
+            checkDbConfig(result.version, dbObject.primaryIdx, dbObject.primary, false);
         }
         // If the database is not online, assume that pg1 is the master
         else
