@@ -18,6 +18,12 @@ Constants
 Functions
 ***********************************************************************************************************************************/
 // Process protocol requests
-bool verifyProtocol(const String *command, const VariantList *paramList, ProtocolServer *server);
+void verifyFileProtocol(const VariantList *paramList, ProtocolServer *server);
+
+/***********************************************************************************************************************************
+Protocol commands for ProtocolServerHandler arrays passed to protocolServerProcess()
+***********************************************************************************************************************************/
+#define PROTOCOL_SERVER_HANDLER_VERIFY_LIST                                                                                        \
+    {.command = PROTOCOL_COMMAND_VERIFY_FILE, .handler = verifyFileProtocol},
 
 #endif
