@@ -14,7 +14,7 @@ Block Cipher
 #include "common/io/filter/filter.intern.h"
 #include "common/log.h"
 #include "common/memContext.h"
-#include "common/object.h"
+#include "common/type/object.h"
 
 /***********************************************************************************************************************************
 Filter type constant
@@ -77,7 +77,7 @@ Free cipher context
 ***********************************************************************************************************************************/
 OBJECT_DEFINE_FREE_RESOURCE_BEGIN(CIPHER_BLOCK, LOG, logLevelTrace)
 {
-    EVP_CIPHER_CTX_cleanup(this->cipherContext);
+    EVP_CIPHER_CTX_free(this->cipherContext);
 }
 OBJECT_DEFINE_FREE_RESOURCE_END(LOG);
 
@@ -203,13 +203,13 @@ cipherBlockProcessBlock(CipherBlock *this, const unsigned char *source, size_t s
     if (sourceSize > 0)
     {
         // Process the data
-        size_t destinationUpdateSize = 0;
+        int destinationUpdateSize = 0;
 
         cryptoError(
-            !EVP_CipherUpdate(this->cipherContext, destination, (int *)&destinationUpdateSize, source, (int)sourceSize),
+            !EVP_CipherUpdate(this->cipherContext, destination, &destinationUpdateSize, source, (int)sourceSize),
             "unable to process cipher");
 
-        destinationSize += destinationUpdateSize;
+        destinationSize += (size_t)destinationUpdateSize;
 
         // Note that data has been processed so flush is valid
         this->processDone = true;
@@ -234,18 +234,18 @@ cipherBlockFlush(CipherBlock *this, Buffer *destination)
     ASSERT(destination != NULL);
 
     // Actual destination size
-    size_t destinationSize = 0;
+    int destinationSize = 0;
 
     // If no header was processed then error
     if (!this->saltDone)
         THROW(CryptoError, "cipher header missing");
 
     // Only flush remaining data if some data was processed
-    if (!EVP_CipherFinal(this->cipherContext, bufRemainsPtr(destination), (int *)&destinationSize))
+    if (!EVP_CipherFinal(this->cipherContext, bufRemainsPtr(destination), &destinationSize))
         THROW(CryptoError, "unable to flush");
 
     // Return actual destination size
-    FUNCTION_LOG_RETURN(SIZE, destinationSize);
+    FUNCTION_LOG_RETURN(SIZE, (size_t)destinationSize);
 }
 
 /***********************************************************************************************************************************
@@ -267,7 +267,7 @@ cipherBlockProcess(THIS_VOID, const Buffer *source, Buffer *destination)
     ASSERT(bufRemains(destination) > 0);
 
     // Copy already buffered bytes
-    if (this->buffer != NULL && bufUsed(this->buffer) > 0)
+    if (this->buffer != NULL && !bufEmpty(this->buffer))
     {
         if (bufRemains(destination) >= bufUsed(this->buffer))
         {
@@ -289,7 +289,7 @@ cipherBlockProcess(THIS_VOID, const Buffer *source, Buffer *destination)
     }
     else
     {
-        ASSERT(this->buffer == NULL || bufUsed(this->buffer) == 0);
+        ASSERT(this->buffer == NULL || bufEmpty(this->buffer));
 
         // Determine how much space is required in the output buffer
         Buffer *outputActual = destination;
@@ -331,12 +331,15 @@ cipherBlockProcess(THIS_VOID, const Buffer *source, Buffer *destination)
             this->done = true;
         }
         else
-            destinationSizeActual = cipherBlockProcessBlock(this, bufPtr(source), bufUsed(source), bufRemainsPtr(outputActual));
+        {
+            destinationSizeActual = cipherBlockProcessBlock(
+                this, bufPtrConst(source), bufUsed(source), bufRemainsPtr(outputActual));
+        }
 
         bufUsedInc(outputActual, destinationSizeActual);
 
         // Copy from buffer to destination if needed
-        if (this->buffer != NULL && bufUsed(this->buffer) > 0)
+        if (this->buffer != NULL && !bufEmpty(this->buffer))
             cipherBlockProcess(this, source, destination);
     }
 
@@ -377,9 +380,7 @@ cipherBlockInputSame(const THIS_VOID)
     FUNCTION_TEST_RETURN(this->inputSame);
 }
 
-/***********************************************************************************************************************************
-New block encrypt/decrypt object
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 IoFilter *
 cipherBlockNew(CipherMode mode, CipherType cipherType, const Buffer *pass, const String *digestName)
 {
@@ -391,28 +392,28 @@ cipherBlockNew(CipherMode mode, CipherType cipherType, const Buffer *pass, const
     FUNCTION_LOG_END();
 
     ASSERT(pass != NULL);
-    ASSERT(bufSize(pass) > 0);
+    ASSERT(!bufEmpty(pass));
 
     // Init crypto subsystem
     cryptoInit();
 
     // Lookup cipher by name.  This means the ciphers passed in must exactly match a name expected by OpenSSL.  This is a good
     // thing since the name required by the openssl command-line tool will match what is used by pgBackRest.
-    const EVP_CIPHER *cipher = EVP_get_cipherbyname(strPtr(cipherTypeName(cipherType)));
+    const EVP_CIPHER *cipher = EVP_get_cipherbyname(strZ(cipherTypeName(cipherType)));
 
     if (!cipher)
-        THROW_FMT(AssertError, "unable to load cipher '%s'", strPtr(cipherTypeName(cipherType)));
+        THROW_FMT(AssertError, "unable to load cipher '%s'", strZ(cipherTypeName(cipherType)));
 
     // Lookup digest.  If not defined it will be set to sha1.
     const EVP_MD *digest = NULL;
 
     if (digestName)
-        digest = EVP_get_digestbyname(strPtr(digestName));
+        digest = EVP_get_digestbyname(strZ(digestName));
     else
         digest = EVP_sha1();
 
     if (!digest)
-        THROW_FMT(AssertError, "unable to load digest '%s'", strPtr(digestName));
+        THROW_FMT(AssertError, "unable to load digest '%s'", strZ(digestName));
 
     // Allocate memory to hold process state
     IoFilter *this = NULL;
@@ -432,7 +433,7 @@ cipherBlockNew(CipherMode mode, CipherType cipherType, const Buffer *pass, const
 
         // Store the passphrase
         driver->pass = memNew(driver->passSize);
-        memcpy(driver->pass, bufPtr(pass), driver->passSize);
+        memcpy(driver->pass, bufPtrConst(pass), driver->passSize);
 
         // Create param list
         VariantList *paramList = varLstNew();
@@ -461,9 +462,7 @@ cipherBlockNewVar(const VariantList *paramList)
         BUFSTR(varStr(varLstGet(paramList, 2))), varLstGet(paramList, 3) == NULL ? NULL : varStr(varLstGet(paramList, 3)));
 }
 
-/***********************************************************************************************************************************
-Helper function to add a block cipher to an io object
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 IoFilterGroup *
 cipherBlockFilterGroupAdd(IoFilterGroup *filterGroup, CipherType type, CipherMode mode, const String *pass)
 {
