@@ -114,9 +114,16 @@ FUNCTION_LOG_VOID() is provided as a shortcut for functions that have no paramet
 /***********************************************************************************************************************************
 Functions and macros to render various data types
 ***********************************************************************************************************************************/
+// Convert object to a zero-terminated string for logging
 size_t objToLog(const void *object, const char *objectName, char *buffer, size_t bufferSize);
+
+// Convert pointer to a zero-terminated string for logging
 size_t ptrToLog(const void *pointer, const char *pointerName, char *buffer, size_t bufferSize);
+
+// Convert zero-terminated string for logging
 size_t strzToLog(const char *string, char *buffer, size_t bufferSize);
+
+// Convert a type name to a zero-terminated string for logging
 size_t typeToLog(const char *typeName, char *buffer, size_t bufferSize);
 
 #define FUNCTION_LOG_BOOL_TYPE                                                                                                     \
@@ -262,6 +269,18 @@ Macros to return function results (or void)
 #define FUNCTION_LOG_RETURN_CONST_PP(typeMacroPrefix, result)                                                                      \
     FUNCTION_LOG_RETURN_BASE(const, typeMacroPrefix, **, result)
 
+#define FUNCTION_LOG_RETURN_STRUCT(result)                                                                                         \
+    do                                                                                                                             \
+    {                                                                                                                              \
+        STACK_TRACE_POP(false);                                                                                                    \
+                                                                                                                                   \
+        IF_LOG_ANY(FUNCTION_LOG_LEVEL())                                                                                           \
+            LOG_FMT(FUNCTION_LOG_LEVEL(), 0, "=> struct");                                                                         \
+                                                                                                                                   \
+        return result;                                                                                                             \
+    }                                                                                                                              \
+    while (0)
+
 #define FUNCTION_LOG_RETURN_VOID()                                                                                                 \
     do                                                                                                                             \
     {                                                                                                                              \
@@ -274,10 +293,18 @@ Macros to return function results (or void)
 /***********************************************************************************************************************************
 Function Test Macros
 
-In debug builds these macros will update the stack trace with function names and parameters but not log.  In production builds all
-test macros are compiled out (except for return statements).
+In debug builds these macros will update the stack trace with function names and parameters but will not log. In production builds
+all test macros are compiled out (except for return statements).
+
+Ignore DEBUG_TEST_TRACE_MACRO if NDEBUG is defined because the underlying functions that support the macros will not be present.
 ***********************************************************************************************************************************/
+#ifndef NDEBUG
 #ifdef DEBUG_TEST_TRACE
+    #define DEBUG_TEST_TRACE_MACRO
+#endif // DEBUG_TEST_TRACE
+#endif // NDEBUG
+
+#ifdef DEBUG_TEST_TRACE_MACRO
     #define FUNCTION_TEST_BEGIN()                                                                                                  \
         if (stackTraceTest())                                                                                                      \
         {                                                                                                                          \
@@ -322,6 +349,6 @@ test macros are compiled out (except for return statements).
     #define FUNCTION_TEST_RETURN(result)                                                                                           \
         return result
     #define FUNCTION_TEST_RETURN_VOID()
-#endif
+#endif // DEBUG_TEST_TRACE_MACRO
 
 #endif
