@@ -3,6 +3,7 @@ Error Handler
 ***********************************************************************************************************************************/
 #include "build.auto.h"
 
+#include <assert.h>
 #include <stdarg.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -25,6 +26,11 @@ struct ErrorType
 #define ERROR_DEFINE(code, name, parentType)                                                                                       \
     const ErrorType name = {code, #name, &parentType}
 
+// Define test error
+#ifndef NDEBUG
+    ERROR_DEFINE(1, TestError, RuntimeError);
+#endif
+
 // Include error type definitions
 #include "common/error.auto.c"
 
@@ -46,6 +52,10 @@ static struct
     // Array of jump buffers
     jmp_buf jumpList[ERROR_TRY_MAX];
 
+    // Handler list
+    const ErrorHandlerFunction *handlerList;
+    unsigned int handlerTotal;
+
     // State of each try
     int tryTotal;
 
@@ -82,18 +92,23 @@ static char messageBuffer[ERROR_MESSAGE_BUFFER_SIZE];
 static char messageBufferTemp[ERROR_MESSAGE_BUFFER_SIZE];
 static char stackTraceBuffer[ERROR_MESSAGE_BUFFER_SIZE];
 
-/***********************************************************************************************************************************
-Error type code
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
+void errorHandlerSet(ErrorHandlerFunction *list, unsigned int total)
+{
+    assert(total == 0 || list != NULL);
+
+    errorContext.handlerList = list;
+    errorContext.handlerTotal = total;
+}
+
+/**********************************************************************************************************************************/
 int
 errorTypeCode(const ErrorType *errorType)
 {
     return errorType->code;
 }
 
-/***********************************************************************************************************************************
-Get error type using a code
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 const ErrorType *
 errorTypeFromCode(int code)
 {
@@ -116,35 +131,27 @@ errorTypeFromCode(int code)
     return result;
 }
 
-/***********************************************************************************************************************************
-Error type name
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 const char *
 errorTypeName(const ErrorType *errorType)
 {
     return errorType->name;
 }
 
-/***********************************************************************************************************************************
-Error type parent
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 const ErrorType *
 errorTypeParent(const ErrorType *errorType)
 {
     return errorType->parentType;
 }
 
-/***********************************************************************************************************************************
-Get the depth of the current try statement (0 if none)
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 unsigned int errorTryDepth(void)
 {
     return (unsigned int)errorContext.tryTotal;
 }
 
-/***********************************************************************************************************************************
-Does the child error type extend the parent error type?
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 bool
 errorTypeExtends(const ErrorType *child, const ErrorType *parent)
 {
@@ -164,81 +171,63 @@ errorTypeExtends(const ErrorType *child, const ErrorType *parent)
     return false;
 }
 
-/***********************************************************************************************************************************
-Error type
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 const ErrorType *
 errorType(void)
 {
     return errorContext.error.errorType;
 }
 
-/***********************************************************************************************************************************
-Error code (pulled from error type)
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 int
 errorCode(void)
 {
     return errorTypeCode(errorType());
 }
 
-/***********************************************************************************************************************************
-Error filename
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 const char *
 errorFileName(void)
 {
     return errorContext.error.fileName;
 }
 
-/***********************************************************************************************************************************
-Error function name
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 const char *
 errorFunctionName(void)
 {
     return errorContext.error.functionName;
 }
 
-/***********************************************************************************************************************************
-Error file line number
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 int
 errorFileLine(void)
 {
     return errorContext.error.fileLine;
 }
 
-/***********************************************************************************************************************************
-Error message
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 const char *
 errorMessage(void)
 {
     return errorContext.error.message;
 }
 
-/***********************************************************************************************************************************
-Error name (pulled from error type)
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 const char *
 errorName(void)
 {
     return errorTypeName(errorType());
 }
 
-/***********************************************************************************************************************************
-Error stack trace
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 const char *
 errorStackTrace(void)
 {
     return errorContext.error.stackTrace;
 }
 
-/***********************************************************************************************************************************
-Is this error an instance of the error type?
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 bool
 errorInstanceOf(const ErrorType *errorTypeTest)
 {
@@ -254,18 +243,14 @@ errorInternalState(void)
     return errorContext.tryList[errorContext.tryTotal].state;
 }
 
-/***********************************************************************************************************************************
-True when in try state
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 bool
 errorInternalStateTry(void)
 {
     return errorInternalState() == errorStateTry;
 }
 
-/***********************************************************************************************************************************
-True when in catch state and the expected error matches
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 bool
 errorInternalStateCatch(const ErrorType *errorTypeCatch)
 {
@@ -275,27 +260,21 @@ errorInternalStateCatch(const ErrorType *errorTypeCatch)
     return false;
 }
 
-/***********************************************************************************************************************************
-True when in final state
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 bool
 errorInternalStateFinal(void)
 {
     return errorInternalState() == errorStateFinal;
 }
 
-/***********************************************************************************************************************************
-Return jump buffer for current try
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 jmp_buf *
 errorInternalJump(void)
 {
     return &errorContext.jumpList[errorContext.tryTotal - 1];
 }
 
-/***********************************************************************************************************************************
-Begin the try block
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 bool
 errorInternalTry(const char *fileName, const char *functionName, int fileLine)
 {
@@ -314,9 +293,7 @@ errorInternalTry(const char *fileName, const char *functionName, int fileLine)
     return true;
 }
 
-/***********************************************************************************************************************************
-Propagate the error up so it can be caught
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void
 errorInternalPropagate(void)
 {
@@ -335,9 +312,7 @@ errorInternalPropagate(void)
     exit(UnhandledError.code);
 }
 
-/***********************************************************************************************************************************
-Process the error through each try and state
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 bool
 errorInternalProcess(bool catch)
 {
@@ -349,7 +324,10 @@ errorInternalProcess(bool catch)
     }
     // Else if just entering error state clean up the stack
     else if (errorContext.tryList[errorContext.tryTotal].state == errorStateTry)
-        stackTraceClean(errorTryDepth());
+    {
+        for (unsigned int handlerIdx = 0; handlerIdx < errorContext.handlerTotal; handlerIdx++)
+            errorContext.handlerList[handlerIdx](errorTryDepth());
+    }
 
     // Increment the state
     errorContext.tryList[errorContext.tryTotal].state++;
@@ -376,9 +354,7 @@ errorInternalProcess(bool catch)
     return false;
 }
 
-/***********************************************************************************************************************************
-Throw an error
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void
 errorInternalThrow(const ErrorType *errorType, const char *fileName, const char *functionName, int fileLine, const char *message)
 {
@@ -420,24 +396,11 @@ errorInternalThrowFmt(
     errorInternalThrow(errorType, fileName, functionName, fileLine, messageBufferTemp);
 }
 
-/***********************************************************************************************************************************
-Throw a system error
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void
 errorInternalThrowSys(
-#ifdef DEBUG_COVERAGE
-    bool error,
-#else
-    int errNo,
-#endif
-    const ErrorType *errorType, const char *fileName, const char *functionName, int fileLine, const char *message)
+    int errNo, const ErrorType *errorType, const char *fileName, const char *functionName, int fileLine, const char *message)
 {
-#ifdef DEBUG_COVERAGE
-    if (error)
-    {
-        int errNo = errno;
-#endif
-
     // Format message with system message appended
     if (errNo == 0)
     {
@@ -448,27 +411,23 @@ errorInternalThrowSys(
         snprintf(messageBufferTemp, ERROR_MESSAGE_BUFFER_SIZE - 1, "%s: [%d] %s", message, errNo, strerror(errNo));
 
     errorInternalThrow(errorType, fileName, functionName, fileLine, messageBufferTemp);
+}
 
 #ifdef DEBUG_COVERAGE
-    }
-#endif
+void
+errorInternalThrowOnSys(
+    bool error, int errNo, const ErrorType *errorType, const char *fileName, const char *functionName, int fileLine,
+    const char *message)
+{
+    if (error)
+        errorInternalThrowSys(errNo, errorType, fileName, functionName, fileLine, message);
 }
+#endif
 
 void
 errorInternalThrowSysFmt(
-#ifdef DEBUG_COVERAGE
-    bool error,
-#else
-    int errNo,
-#endif
-    const ErrorType *errorType, const char *fileName, const char *functionName, int fileLine, const char *format, ...)
+    int errNo, const ErrorType *errorType, const char *fileName, const char *functionName, int fileLine, const char *format, ...)
 {
-#ifdef DEBUG_COVERAGE
-    if (error)
-    {
-        int errNo = errno;
-#endif
-
     // Format message
     va_list argument;
     va_start(argument, format);
@@ -480,8 +439,30 @@ errorInternalThrowSysFmt(
         snprintf(messageBufferTemp + messageSize, ERROR_MESSAGE_BUFFER_SIZE - 1 - messageSize, ": [%d] %s", errNo, strerror(errNo));
 
     errorInternalThrow(errorType, fileName, functionName, fileLine, messageBufferTemp);
+}
 
 #ifdef DEBUG_COVERAGE
+void
+errorInternalThrowOnSysFmt(
+    bool error, int errNo, const ErrorType *errorType, const char *fileName, const char *functionName, int fileLine,
+    const char *format, ...)
+{
+    if (error)
+    {
+        // Format message
+        va_list argument;
+        va_start(argument, format);
+        size_t messageSize = (size_t)vsnprintf(messageBufferTemp, ERROR_MESSAGE_BUFFER_SIZE - 1, format, argument);
+        va_end(argument);
+
+        // Append the system message
+        if (errNo != 0)
+        {
+            snprintf(
+                messageBufferTemp + messageSize, ERROR_MESSAGE_BUFFER_SIZE - 1 - messageSize, ": [%d] %s", errNo, strerror(errNo));
+        }
+
+        errorInternalThrow(errorType, fileName, functionName, fileLine, messageBufferTemp);
     }
-#endif
 }
+#endif
