@@ -13,12 +13,13 @@ Execute Process
 #include "common/debug.h"
 #include "common/log.h"
 #include "common/exec.h"
-#include "common/io/handleRead.h"
-#include "common/io/handleWrite.h"
+#include "common/fork.h"
+#include "common/io/fdRead.h"
+#include "common/io/fdWrite.h"
 #include "common/io/io.h"
 #include "common/io/read.intern.h"
 #include "common/io/write.intern.h"
-#include "common/object.h"
+#include "common/type/object.h"
 #include "common/wait.h"
 
 /***********************************************************************************************************************************
@@ -34,15 +35,15 @@ struct Exec
 
     pid_t processId;                                                // Process id of the child process
 
-    int handleRead;                                                 // Read handle
-    int handleWrite;                                                // Write handle
-    int handleError;                                                // Error handle
+    int fdRead;                                                     // Read file descriptor
+    int fdWrite;                                                    // Write file descriptor
+    int fdError;                                                    // Error file descriptor
 
-    IoRead *ioReadHandle;                                           // Handle read interface
-    IoWrite *ioWriteHandle;                                         // Handle write interface
+    IoRead *ioReadFd;                                               // File descriptor read interface
+    IoWrite *ioWriteFd;                                             // File descriptor write interface
 
-    IoRead *ioReadExec;                                             // Wrapper for handle read interface
-    IoWrite *ioWriteExec;                                           // Wrapper for handle write interface
+    IoRead *ioReadExec;                                             // Wrapper for file descriptor read interface
+    IoWrite *ioWriteExec;                                           // Wrapper for file descriptor write interface
 };
 
 OBJECT_DEFINE_FREE(EXEC);
@@ -71,14 +72,14 @@ other code.
     while (0);
 
 /***********************************************************************************************************************************
-Free exec handles and ensure process is shut down
+Free exec file descriptors and ensure process is shut down
 ***********************************************************************************************************************************/
 OBJECT_DEFINE_FREE_RESOURCE_BEGIN(EXEC, LOG, logLevelTrace)
 {
-    // Close the io handles
-    close(this->handleRead);
-    close(this->handleWrite);
-    close(this->handleError);
+    // Close file descriptors
+    close(this->fdRead);
+    close(this->fdWrite);
+    close(this->fdError);
 
     // Wait for the child to exit. We don't really care how it exits as long as it does.
     if (this->processId != 0)
@@ -98,16 +99,14 @@ OBJECT_DEFINE_FREE_RESOURCE_BEGIN(EXEC, LOG, logLevelTrace)
 
             // If the process did not exit then error -- else we may end up with a collection of zombie processes
             if (processResult == 0)
-                THROW_FMT(ExecuteError, "%s did not exit when expected", strPtr(this->name));
+                THROW_FMT(ExecuteError, "%s did not exit when expected", strZ(this->name));
         }
         MEM_CONTEXT_TEMP_END();
     }
 }
 OBJECT_DEFINE_FREE_RESOURCE_END(LOG);
 
-/***********************************************************************************************************************************
-New object
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 Exec *
 execNew(const String *command, const StringList *param, const String *name, TimeMSec timeout)
 {
@@ -177,18 +176,18 @@ execCheck(Exec *this)
         if (WIFEXITED(processStatus))
         {
             // Get data from stderr to help diagnose the problem
-            IoRead *ioReadError = ioHandleReadNew(strNewFmt("%s error", strPtr(this->name)), this->handleError, 0);
+            IoRead *ioReadError = ioFdReadNew(strNewFmt("%s error", strZ(this->name)), this->fdError, 0);
             ioReadOpen(ioReadError);
             String *errorStr = strTrim(strNewBuf(ioReadBuf(ioReadError)));
 
             // Throw the error with as much information as is available
             THROWP_FMT(
-                errorTypeFromCode(WEXITSTATUS(processStatus)), "%s terminated unexpectedly [%d]%s%s", strPtr(this->name),
-                WEXITSTATUS(processStatus), strSize(errorStr) > 0 ? ": " : "", strSize(errorStr) > 0 ? strPtr(errorStr) : "");
+                errorTypeFromCode(WEXITSTATUS(processStatus)), "%s terminated unexpectedly [%d]%s%s", strZ(this->name),
+                WEXITSTATUS(processStatus), strSize(errorStr) > 0 ? ": " : "", strSize(errorStr) > 0 ? strZ(errorStr) : "");
         }
 
         // If the process did not exit normally then it must have been a signal
-        THROW_FMT(ExecuteError, "%s terminated unexpectedly on signal %d", strPtr(this->name), WTERMSIG(processStatus));
+        THROW_FMT(ExecuteError, "%s terminated unexpectedly on signal %d", strZ(this->name), WTERMSIG(processStatus));
     }
 
     FUNCTION_LOG_RETURN_VOID();
@@ -215,7 +214,7 @@ execRead(THIS_VOID, Buffer *buffer, bool block)
 
     TRY_BEGIN()
     {
-        result = ioReadInterface(this->ioReadHandle)->read(ioReadDriver(this->ioReadHandle), buffer, block);
+        result = ioReadInterface(this->ioReadFd)->read(ioReadDriver(this->ioReadFd), buffer, block);
     }
     CATCH_ANY()
     {
@@ -245,8 +244,8 @@ execWrite(THIS_VOID, const Buffer *buffer)
 
     TRY_BEGIN()
     {
-        ioWrite(this->ioWriteHandle, buffer);
-        ioWriteFlush(this->ioWriteHandle);
+        ioWrite(this->ioWriteFd, buffer);
+        ioWriteFlush(this->ioWriteFd);
     }
     CATCH_ANY()
     {
@@ -273,17 +272,17 @@ execEof(THIS_VOID)
     ASSERT(this != NULL);
 
     // Check if the process is still running on eof
-    if (ioReadInterface(this->ioReadHandle)->eof(ioReadDriver(this->ioReadHandle)))
+    if (ioReadInterface(this->ioReadFd)->eof(ioReadDriver(this->ioReadFd)))
         execCheck(this);
 
     FUNCTION_LOG_RETURN(BOOL, false);
 }
 
 /***********************************************************************************************************************************
-Get the read handle
+Get the read file descriptor
 ***********************************************************************************************************************************/
 static int
-execHandleRead(const THIS_VOID)
+execFdRead(const THIS_VOID)
 {
     THIS(const Exec);
 
@@ -293,12 +292,10 @@ execHandleRead(const THIS_VOID)
 
     ASSERT(this != NULL);
 
-    FUNCTION_TEST_RETURN(this->handleRead);
+    FUNCTION_TEST_RETURN(this->fdRead);
 }
 
-/***********************************************************************************************************************************
-Execute command
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void
 execOpen(Exec *this)
 {
@@ -319,7 +316,7 @@ execOpen(Exec *this)
     THROW_ON_SYS_ERROR(pipe(pipeError) == -1, KernelError, "unable to create error pipe");
 
     // Fork the subprocess
-    this->processId = fork();
+    this->processId = forkSafe();
 
     // Exec command in the child process
     if (this->processId == 0)
@@ -337,44 +334,42 @@ execOpen(Exec *this)
         PIPE_DUP2(pipeError, 1, STDERR_FILENO);
 
         // Execute the binary.  This statement will not return if it is successful
-        execvp(strPtr(this->command), (char ** const)strLstPtr(this->param));
+        execvp(strZ(this->command), (char ** const)strLstPtr(this->param));
 
         // If we got here then there was an error.  We can't use a throw as we normally would because we have already shutdown
         // logging and we don't want to execute exit paths that might free parent resources which we still have references to.
-        fprintf(stderr, "unable to execute '%s': [%d] %s\n", strPtr(this->command), errno, strerror(errno));
+        fprintf(stderr, "unable to execute '%s': [%d] %s\n", strZ(this->command), errno, strerror(errno));
         exit(errorTypeCode(&ExecuteError));
     }
 
-    // Close the unused handles
+    // Close the unused file descriptors
     close(pipeRead[1]);
     close(pipeWrite[0]);
     close(pipeError[1]);
 
-    // Store the handles we'll use and need to close when the process terminates
-    this->handleRead = pipeRead[0];
-    this->handleWrite = pipeWrite[1];
-    this->handleError = pipeError[0];
+    // Store the file descriptors we'll use and need to close when the process terminates
+    this->fdRead = pipeRead[0];
+    this->fdWrite = pipeWrite[1];
+    this->fdError = pipeError[0];
 
-    // Assign handles to io interfaces
-    this->ioReadHandle = ioHandleReadNew(strNewFmt("%s read", strPtr(this->name)), this->handleRead, this->timeout);
-    this->ioWriteHandle = ioHandleWriteNew(strNewFmt("%s write", strPtr(this->name)), this->handleWrite);
-    ioWriteOpen(this->ioWriteHandle);
+    // Assign file descriptors to io interfaces
+    this->ioReadFd = ioFdReadNew(strNewFmt("%s read", strZ(this->name)), this->fdRead, this->timeout);
+    this->ioWriteFd = ioFdWriteNew(strNewFmt("%s write", strZ(this->name)), this->fdWrite, this->timeout);
+    ioWriteOpen(this->ioWriteFd);
 
     // Create wrapper interfaces that check process state
-    this->ioReadExec = ioReadNewP(this, .block = true, .read = execRead, .eof = execEof, .handle = execHandleRead);
+    this->ioReadExec = ioReadNewP(this, .block = true, .read = execRead, .eof = execEof, .fd = execFdRead);
     ioReadOpen(this->ioReadExec);
     this->ioWriteExec = ioWriteNewP(this, .write = execWrite);
     ioWriteOpen(this->ioWriteExec);
 
-    // Set a callback so the handles will get freed
+    // Set a callback so the file descriptors will get freed
     memContextCallbackSet(this->memContext, execFreeResource, this);
 
     FUNCTION_LOG_RETURN_VOID();
 }
 
-/***********************************************************************************************************************************
-Get read interface
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 IoRead *
 execIoRead(const Exec *this)
 {
@@ -387,9 +382,7 @@ execIoRead(const Exec *this)
     FUNCTION_TEST_RETURN(this->ioReadExec);
 }
 
-/***********************************************************************************************************************************
-Get write interface
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 IoWrite *
 execIoWrite(const Exec *this)
 {
@@ -402,9 +395,7 @@ execIoWrite(const Exec *this)
     FUNCTION_TEST_RETURN(this->ioWriteExec);
 }
 
-/***********************************************************************************************************************************
-Get the object mem context
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 MemContext *
 execMemContext(const Exec *this)
 {
