@@ -14,15 +14,16 @@ Exit Routines
 #include "common/log.h"
 #include "config/config.h"
 #include "protocol/helper.h"
+#include "version.h"
 
 /***********************************************************************************************************************************
 Return signal names
 ***********************************************************************************************************************************/
 static const char *
-exitSignalName(int signalType)
+exitSignalName(SignalType signalType)
 {
     FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_PARAM(INT, signalType);
+        FUNCTION_TEST_PARAM(ENUM, signalType);
     FUNCTION_TEST_END();
 
     const char *name = NULL;
@@ -30,22 +31,16 @@ exitSignalName(int signalType)
     switch (signalType)
     {
         case signalTypeHup:
-        {
             name = "HUP";
             break;
-        }
 
         case signalTypeInt:
-        {
             name = "INT";
             break;
-        }
 
         case signalTypeTerm:
-        {
             name = "TERM";
             break;
-        }
 
         case signalTypeNone:
             THROW(AssertError, "no name for signal none");
@@ -86,6 +81,26 @@ exitInit(void)
 }
 
 /**********************************************************************************************************************************/
+// Helper to provide details for error logging
+static String *
+exitErrorDetail(void)
+{
+    FUNCTION_TEST_VOID();
+
+    FUNCTION_TEST_RETURN(
+        strNewFmt(
+            "--------------------------------------------------------------------\n"
+            "If SUBMITTING AN ISSUE please provide the following information:\n"
+            "\n"
+            "version: " PROJECT_VERSION "\n"
+            "command: %s\n"
+            "options:%s\n"
+            "\n"
+            "stack trace:\n%s\n"
+            "--------------------------------------------------------------------",
+            strZ(cfgCommandRoleName()), strZ(cmdOption()), errorStackTrace()));
+}
+
 int
 exitSafe(int result, bool error, SignalType signalType)
 {
@@ -102,7 +117,7 @@ exitSafe(int result, bool error, SignalType signalType)
 
         // Assert errors always output a stack trace
         if (logLevel == logLevelAssert)
-            LOG_FMT(logLevel, errorCode(), "%s\nSTACK TRACE:\n%s", errorMessage(), errorStackTrace());
+            LOG_FMT(logLevel, errorCode(), "%s\n%s", errorMessage(), strZ(exitErrorDetail()));
         else
         {
             // Log just the error to non-debug levels
@@ -112,20 +127,15 @@ exitSafe(int result, bool error, SignalType signalType)
             if (logAny(logLevelDebug))
             {
                 LOG_INTERNAL_FMT(
-                    logLevel, logLevelDebug, LOG_LEVEL_MAX, 0, errorCode(), "%s\nSTACK TRACE:\n%s", errorMessage(),
-                    errorStackTrace());
+                    logLevel, logLevelDebug, LOG_LEVEL_MAX, 0, errorCode(), "%s\n%s", errorMessage(), strZ(exitErrorDetail()));
             }
         }
 
         result = errorCode();
     }
 
-    // Free protocol objects but ignore errors
-    TRY_BEGIN()
-    {
-        protocolFree();
-    }
-    TRY_END();
+    // Free protocol objects
+    protocolFree();
 
     // Log command end if a command is set
     if (cfgCommand() != cfgCmdNone)
