@@ -27,7 +27,8 @@ Functions
 // Move to a new parent mem context
 Ini *iniMove(Ini *this, MemContext *parentNew);
 
-// Parse ini from a string
+// Parse ini from a string. Comments are ignored and additional whitespace around sections, keys, and values is trimmed. Should be
+// used *only* to read user-generated config files, for code-generated info files see iniLoad().
 void iniParse(Ini *this, const String *content);
 
 // Set an ini value
@@ -62,9 +63,12 @@ void iniFree(Ini *this);
 /***********************************************************************************************************************************
 Helper Functions
 ***********************************************************************************************************************************/
-// Load an ini file and return data to a callback
+// Load an ini file and return data to a callback. Intended to read info files that were generated by code so do not have comments
+// or extraneous spaces, and where all values are valid JSON. This allows syntax characters such as [, =, #, and whitespace to be
+// used in keys.
 void iniLoad(
-    IoRead *read, void (*callbackFunction)(void *data, const String *section, const String *key, const String *value),
+    IoRead *read,
+    void (*callbackFunction)(void *data, const String *section, const String *key, const String *value, const Variant *valueVar),
     void *callbackData);
 
 /***********************************************************************************************************************************
