@@ -8,7 +8,7 @@ Buffer IO Read
 #include "common/io/read.intern.h"
 #include "common/log.h"
 #include "common/memContext.h"
-#include "common/object.h"
+#include "common/type/object.h"
 
 /***********************************************************************************************************************************
 Object type
@@ -84,9 +84,7 @@ ioBufferReadEof(THIS_VOID)
     FUNCTION_LOG_RETURN(BOOL, this->eof);
 }
 
-/***********************************************************************************************************************************
-New object
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 IoRead *
 ioBufferReadNew(const Buffer *buffer)
 {
