@@ -7,7 +7,7 @@ IO Filter Interface
 #include "common/io/filter/filter.intern.h"
 #include "common/log.h"
 #include "common/memContext.h"
-#include "common/object.h"
+#include "common/type/object.h"
 
 /***********************************************************************************************************************************
 Object type
@@ -27,8 +27,6 @@ OBJECT_DEFINE_MOVE(IO_FILTER);
 OBJECT_DEFINE_FREE(IO_FILTER);
 
 /***********************************************************************************************************************************
-New object
-
 Allocations will be in the memory context of the caller.
 ***********************************************************************************************************************************/
 IoFilter *
@@ -64,9 +62,7 @@ ioFilterNew(const String *type, void *driver, VariantList *paramList, IoFilterIn
     FUNCTION_LOG_RETURN(IO_FILTER, this);
 }
 
-/***********************************************************************************************************************************
-Filter input only (a result is expected)
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void
 ioFilterProcessIn(IoFilter *this, const Buffer *input)
 {
@@ -77,7 +73,7 @@ ioFilterProcessIn(IoFilter *this, const Buffer *input)
 
     ASSERT(this != NULL);
     ASSERT(this->interface.in != NULL);
-    CHECK(input == NULL || bufUsed(input) > 0);
+    CHECK(input == NULL || !bufEmpty(input));
     CHECK(!this->flushing || input == NULL);
 
     if (input == NULL)
@@ -88,9 +84,7 @@ ioFilterProcessIn(IoFilter *this, const Buffer *input)
     FUNCTION_TEST_RETURN_VOID();
 }
 
-/***********************************************************************************************************************************
-Filter input and produce output
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void
 ioFilterProcessInOut(IoFilter *this, const Buffer *input, Buffer *output)
 {
@@ -103,7 +97,7 @@ ioFilterProcessInOut(IoFilter *this, const Buffer *input, Buffer *output)
     ASSERT(this != NULL);
     ASSERT(output != NULL);
     ASSERT(this->interface.inOut != NULL);
-    CHECK(input == NULL || bufUsed(input) > 0);
+    CHECK(input == NULL || !bufEmpty(input));
     CHECK(!this->flushing || input == NULL);
 
     if (input == NULL && !this->flushing)
@@ -112,13 +106,11 @@ ioFilterProcessInOut(IoFilter *this, const Buffer *input, Buffer *output)
     if (!ioFilterDone(this))
         this->interface.inOut(this->driver, input, output);
 
-    CHECK(!ioFilterInputSame(this) || bufUsed(output) > 0);
+    CHECK(!ioFilterInputSame(this) || !bufEmpty(output));
     FUNCTION_TEST_RETURN_VOID();
 }
 
 /***********************************************************************************************************************************
-Is the filter done?
-
 If done is not defined by the filter then check inputSame.  If inputSame is true then the filter is not done.  Even if the filter
 is done the interface will not report done until the interface is flushing.
 ***********************************************************************************************************************************/
@@ -139,9 +131,7 @@ ioFilterDone(const IoFilter *this)
     FUNCTION_TEST_RETURN(result);
 }
 
-/***********************************************************************************************************************************
-Driver for the filter
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void *
 ioFilterDriver(IoFilter *this)
 {
@@ -154,11 +144,7 @@ ioFilterDriver(IoFilter *this)
     FUNCTION_TEST_RETURN(this->driver);
 }
 
-/***********************************************************************************************************************************
-Does the filter need the same input again?
-
-If the filter cannot get all its output into the output buffer then it may need access to the same input again.
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 bool
 ioFilterInputSame(const IoFilter *this)
 {
@@ -171,9 +157,7 @@ ioFilterInputSame(const IoFilter *this)
     FUNCTION_TEST_RETURN(this->interface.inputSame != NULL ? this->interface.inputSame(this->driver) : false);
 }
 
-/***********************************************************************************************************************************
-Interface for the filter
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 const IoFilterInterface *
 ioFilterInterface(const IoFilter *this)
 {
@@ -186,11 +170,7 @@ ioFilterInterface(const IoFilter *this)
     FUNCTION_TEST_RETURN(&this->interface);
 }
 
-/***********************************************************************************************************************************
-Does filter produce output?
-
-All In filters produce output.
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 bool
 ioFilterOutput(const IoFilter *this)
 {
@@ -203,9 +183,7 @@ ioFilterOutput(const IoFilter *this)
     FUNCTION_TEST_RETURN(this->interface.inOut != NULL);
 }
 
-/***********************************************************************************************************************************
-List of filter parameters
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 const VariantList *
 ioFilterParamList(const IoFilter *this)
 {
@@ -218,9 +196,7 @@ ioFilterParamList(const IoFilter *this)
     FUNCTION_TEST_RETURN(this->paramList);
 }
 
-/***********************************************************************************************************************************
-Get filter result
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 Variant *
 ioFilterResult(const IoFilter *this)
 {
@@ -233,11 +209,7 @@ ioFilterResult(const IoFilter *this)
     FUNCTION_TEST_RETURN(this->interface.result ? this->interface.result(this->driver) : NULL);
 }
 
-/***********************************************************************************************************************************
-Get filter type
-
-This name identifies the filter and is used when pulling results from the filter group.
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 const String *
 ioFilterType(const IoFilter *this)
 {
@@ -250,11 +222,9 @@ ioFilterType(const IoFilter *this)
     FUNCTION_TEST_RETURN(this->type);
 }
 
-/***********************************************************************************************************************************
-Render as string for logging
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 String *
 ioFilterToLog(const IoFilter *this)
 {
-    return strNewFmt("{type: %s}", strPtr(this->type));
+    return strNewFmt("{type: %s}", strZ(this->type));
 }
