@@ -1,7 +1,7 @@
 /***********************************************************************************************************************************
 IO Filter Interface
 
-Filters can modify an i/o stream (e.g. GzipCompress, GzipDecompress), generate a result (e.g. IoSize, CryptoHash), or even do both.
+Filters can modify an i/o stream (e.g. GzCompress, GzDecompress), generate a result (e.g. IoSize, CryptoHash), or even do both.
 
 A filter is created using a constructor implemented by each filter (e.g. ioBufferNew).  Filter processing is managed by
 IoFilterGroup so the only user facing functions are ioFilterResult() and ioFilterType().
@@ -23,9 +23,12 @@ typedef struct IoFilter IoFilter;
 #include "common/type/variant.h"
 
 /***********************************************************************************************************************************
-Getters
+Getters/Setters
 ***********************************************************************************************************************************/
+// Get filter result
 Variant *ioFilterResult(const IoFilter *this);
+
+// Identifies the filter and is used when pulling results from the filter group
 const String *ioFilterType(const IoFilter *this);
 
 /***********************************************************************************************************************************
