@@ -12,8 +12,8 @@ IO Filter Group
 #include "common/io/io.h"
 #include "common/log.h"
 #include "common/memContext.h"
-#include "common/object.h"
 #include "common/type/list.h"
+#include "common/type/object.h"
 
 /***********************************************************************************************************************************
 Filter and buffer structure
@@ -55,9 +55,7 @@ struct IoFilterGroup
 
 OBJECT_DEFINE_FREE(IO_FILTER_GROUP);
 
-/***********************************************************************************************************************************
-New Object
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 IoFilterGroup *
 ioFilterGroupNew(void)
 {
@@ -73,7 +71,7 @@ ioFilterGroupNew(void)
         {
             .memContext = memContextCurrent(),
             .done = false,
-            .filterList = lstNew(sizeof(IoFilterData)),
+            .filterList = lstNewP(sizeof(IoFilterData)),
         };
     }
     MEM_CONTEXT_NEW_END();
@@ -81,9 +79,7 @@ ioFilterGroupNew(void)
     FUNCTION_LOG_RETURN(IO_FILTER_GROUP, this);
 }
 
-/***********************************************************************************************************************************
-Add a filter
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 IoFilterGroup *
 ioFilterGroupAdd(IoFilterGroup *this, IoFilter *filter)
 {
@@ -106,9 +102,7 @@ ioFilterGroupAdd(IoFilterGroup *this, IoFilter *filter)
     FUNCTION_LOG_RETURN(IO_FILTER_GROUP, this);
 }
 
-/***********************************************************************************************************************************
-Insert a filter before an index
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 IoFilterGroup *
 ioFilterGroupInsert(IoFilterGroup *this, unsigned int listIdx, IoFilter *filter)
 {
@@ -147,9 +141,7 @@ ioFilterGroupGet(const IoFilterGroup *this, unsigned int filterIdx)
     FUNCTION_TEST_RETURN((IoFilterData *)lstGet(this->filterList, filterIdx));
 }
 
-/***********************************************************************************************************************************
-Clear filters
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 IoFilterGroup *
 ioFilterGroupClear(IoFilterGroup *this)
 {
@@ -169,9 +161,7 @@ ioFilterGroupClear(IoFilterGroup *this)
 }
 
 /***********************************************************************************************************************************
-Open filter group
-
-Setup the filter group and allocate any required buffers.
+Setup the filter group and allocate any required buffers
 ***********************************************************************************************************************************/
 void
 ioFilterGroupOpen(IoFilterGroup *this)
@@ -233,9 +223,7 @@ ioFilterGroupOpen(IoFilterGroup *this)
     FUNCTION_LOG_RETURN_VOID();
 }
 
-/***********************************************************************************************************************************
-Process filters
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void
 ioFilterGroupProcess(IoFilterGroup *this, const Buffer *input, Buffer *output)
 {
@@ -247,7 +235,7 @@ ioFilterGroupProcess(IoFilterGroup *this, const Buffer *input, Buffer *output)
 
     ASSERT(this != NULL);
     ASSERT(this->opened && !this->closed);
-    ASSERT(input == NULL || bufUsed(input) > 0);
+    ASSERT(input == NULL || !bufEmpty(input));
     ASSERT(!this->flushing || input == NULL);
     ASSERT(output != NULL);
     ASSERT(bufRemains(output) > 0);
@@ -361,9 +349,7 @@ ioFilterGroupProcess(IoFilterGroup *this, const Buffer *input, Buffer *output)
     FUNCTION_LOG_RETURN_VOID();
 }
 
-/***********************************************************************************************************************************
-Close filter group and gather results
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void
 ioFilterGroupClose(IoFilterGroup *this)
 {
@@ -403,9 +389,7 @@ ioFilterGroupClose(IoFilterGroup *this)
     FUNCTION_LOG_RETURN_VOID();
 }
 
-/***********************************************************************************************************************************
-Is the filter group done processing?
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 bool
 ioFilterGroupDone(const IoFilterGroup *this)
 {
@@ -419,11 +403,7 @@ ioFilterGroupDone(const IoFilterGroup *this)
     FUNCTION_TEST_RETURN(this->done);
 }
 
-/***********************************************************************************************************************************
-Should the same input be passed again?
-
-A buffer of input can produce multiple buffers of output, e.g. when a file containing all zeroes is being decompressed.
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 bool
 ioFilterGroupInputSame(const IoFilterGroup *this)
 {
@@ -437,9 +417,7 @@ ioFilterGroupInputSame(const IoFilterGroup *this)
     FUNCTION_TEST_RETURN(this->inputSame);
 }
 
-/***********************************************************************************************************************************
-Get all filters and parameters so they can be passed to a remote
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 Variant *
 ioFilterGroupParamAll(const IoFilterGroup *this)
 {
@@ -467,9 +445,7 @@ ioFilterGroupParamAll(const IoFilterGroup *this)
     FUNCTION_LOG_RETURN(VARIANT, varNewVarLst(result));
 }
 
-/***********************************************************************************************************************************
-Get filter results
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 const Variant *
 ioFilterGroupResult(const IoFilterGroup *this, const String *filterType)
 {
@@ -492,9 +468,7 @@ ioFilterGroupResult(const IoFilterGroup *this, const String *filterType)
     FUNCTION_LOG_RETURN_CONST(VARIANT, result);
 }
 
-/***********************************************************************************************************************************
-Get all filter results
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 const Variant *
 ioFilterGroupResultAll(const IoFilterGroup *this)
 {
@@ -508,9 +482,7 @@ ioFilterGroupResultAll(const IoFilterGroup *this)
     FUNCTION_LOG_RETURN_CONST(VARIANT, varNewKv(this->filterResult));
 }
 
-/***********************************************************************************************************************************
-Set all filter results
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void
 ioFilterGroupResultAllSet(IoFilterGroup *this, const Variant *filterResult)
 {
@@ -532,9 +504,7 @@ ioFilterGroupResultAllSet(IoFilterGroup *this, const Variant *filterResult)
     FUNCTION_LOG_RETURN_VOID();
 }
 
-/***********************************************************************************************************************************
-Return total number of filters
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 unsigned int
 ioFilterGroupSize(const IoFilterGroup *this)
 {
@@ -545,9 +515,7 @@ ioFilterGroupSize(const IoFilterGroup *this)
     FUNCTION_TEST_RETURN(lstSize(this->filterList));
 }
 
-/***********************************************************************************************************************************
-Render as string for logging
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 String *
 ioFilterGroupToLog(const IoFilterGroup *this)
 {
