@@ -10,7 +10,7 @@ IO Size Filter
 #include "common/io/filter/size.h"
 #include "common/log.h"
 #include "common/memContext.h"
-#include "common/object.h"
+#include "common/type/object.h"
 
 /***********************************************************************************************************************************
 Filter type constant
@@ -79,9 +79,7 @@ ioSizeResult(THIS_VOID)
     FUNCTION_LOG_RETURN(VARIANT, varNewUInt64(this->size));
 }
 
-/***********************************************************************************************************************************
-New object
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 IoFilter *
 ioSizeNew(void)
 {
