@@ -16,7 +16,7 @@ Filter type constant
     STRING_DECLARE(SIZE_FILTER_TYPE_STR);
 
 /***********************************************************************************************************************************
-Constructor
+Constructors
 ***********************************************************************************************************************************/
 IoFilter *ioSizeNew(void);
 
