@@ -22,7 +22,8 @@ struct IoRead
     IoReadInterface interface;                                      // Driver interface
     IoFilterGroup *filterGroup;                                     // IO filters
     Buffer *input;                                                  // Input buffer
-    Buffer *output;                                                 // Output buffer (holds extra data from line read)
+    Buffer *output;                                                 // Internal output buffer (extra output from buffered reads)
+    size_t outputPos;                                               // Current position in the internal output buffer
 
     bool eofAll;                                                    // Is the read done (read and filters complete)?
 
@@ -157,7 +158,7 @@ ioReadInternal(IoRead *this, Buffer *buffer, bool block)
             }
 
             // Process the input buffer (or flush if NULL)
-            if (this->input == NULL || bufUsed(this->input) > 0)
+            if (this->input == NULL || !bufEmpty(this->input))
                 ioFilterGroupProcess(this->filterGroup, this->input, buffer);
 
             // Stop if not blocking -- we don't need to fill the buffer as long as we got some data
@@ -191,18 +192,18 @@ ioRead(IoRead *this, Buffer *buffer)
     // Store size of remaining portion of buffer to calculate total read at the end
     size_t outputRemains = bufRemains(buffer);
 
-    // Use any data in the output buffer left over from a line read
-    if (this->output != NULL && bufUsed(this->output) > 0 && bufRemains(buffer) > 0)
+    // Copy any data in the internal output buffer
+    if (this->output != NULL && bufUsed(this->output) - this->outputPos > 0 && bufRemains(buffer) > 0)
     {
+        // Internal output buffer remains taking into account the position
+        size_t outputInternalRemains = bufUsed(this->output) - this->outputPos;
+
         // Determine how much data should be copied
-        size_t size = bufUsed(this->output) > bufRemains(buffer) ? bufRemains(buffer) : bufUsed(this->output);
+        size_t size = outputInternalRemains > bufRemains(buffer) ? bufRemains(buffer) : outputInternalRemains;
 
-        // Copy data to the user buffer
-        bufCatSub(buffer, this->output, 0, size);
-
-        // Remove copied data from the output buffer
-        memmove(bufPtr(this->output), bufPtr(this->output) + size, bufUsed(this->output) - size);
-        bufUsedSet(this->output, bufUsed(this->output) - size);
+        // Copy data to the output buffer
+        bufCatSub(buffer, this->output, this->outputPos, size);
+        this->outputPos += size;
     }
 
     // Read data
@@ -211,6 +212,72 @@ ioRead(IoRead *this, Buffer *buffer)
     FUNCTION_LOG_RETURN(SIZE, outputRemains - bufRemains(buffer));
 }
 
+/**********************************************************************************************************************************/
+size_t
+ioReadSmall(IoRead *this, Buffer *buffer)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(IO_READ, this);
+        FUNCTION_TEST_PARAM(BUFFER, buffer);
+    FUNCTION_TEST_END();
+
+    ASSERT(this != NULL);
+    ASSERT(buffer != NULL);
+    ASSERT(this->opened && !this->closed);
+
+    // Allocate the internal output buffer if it has not already been allocated
+    if (this->output == NULL)
+    {
+        MEM_CONTEXT_BEGIN(this->memContext)
+        {
+            this->output = bufNew(ioBufferSize());
+        }
+        MEM_CONTEXT_END();
+    }
+
+    // Store size of remaining portion of buffer to calculate total read at the end
+    size_t outputRemains = bufRemains(buffer);
+
+    do
+    {
+        // Internal output buffer remains taking into account the position
+        size_t outputInternalRemains = bufUsed(this->output) - this->outputPos;
+
+        // Use any data in the internal output buffer
+        if (outputInternalRemains > 0)
+        {
+            // Determine how much data should be copied
+            size_t size = outputInternalRemains > bufRemains(buffer) ? bufRemains(buffer) : outputInternalRemains;
+
+            // Copy data to the output buffer
+            bufCatSub(buffer, this->output, this->outputPos, size);
+            this->outputPos += size;
+        }
+
+        // If more data is required
+        if (!bufFull(buffer))
+        {
+            // If the data required is the same size as the internal output buffer then just read into the external buffer
+            if (bufRemains(buffer) >= bufSize(this->output))
+            {
+                ioReadInternal(this, buffer, true);
+            }
+            // Else read as much data as is available. If is not enough we will try again later.
+            else
+            {
+                // Clear the internal output buffer since all data was copied already
+                bufUsedZero(this->output);
+                this->outputPos = 0;
+
+                ioReadInternal(this, this->output, false);
+            }
+        }
+    }
+    while (!bufFull(buffer));
+
+    FUNCTION_TEST_RETURN(outputRemains - bufRemains(buffer));
+}
+
 /***********************************************************************************************************************************
 The entire string to search for must fit within a single buffer.
 ***********************************************************************************************************************************/
@@ -241,31 +308,47 @@ ioReadLineParam(IoRead *this, bool allowEof)
 
     do
     {
-        if (bufUsed(this->output) > 0)
+        // Internal output buffer remains taking into account the position
+        size_t outputInternalRemains = bufUsed(this->output) - this->outputPos;
+
+        if (outputInternalRemains > 0)
         {
+            // Internal output buffer pointer taking into account the position
+            char *outputPtr = (char *)bufPtr(this->output) + this->outputPos;
+
             // Search for a linefeed in the buffer
-            char *linefeed = memchr(bufPtr(this->output), '\n', bufUsed(this->output));
+            char *linefeed = memchr(outputPtr, '\n', outputInternalRemains);
 
             // A linefeed was found so get the string
             if (linefeed != NULL)
             {
                 // Get the string size
-                size_t size = (size_t)(linefeed - (char *)bufPtr(this->output) + 1);
+                size_t size = (size_t)(linefeed - outputPtr);
 
                 // Create the string
-                result = strNewN((char *)bufPtr(this->output), size - 1);
-
-                // Remove string from the output buffer
-                memmove(bufPtr(this->output), bufPtr(this->output) + size, bufUsed(this->output) - size);
-                bufUsedSet(this->output, bufUsed(this->output) - size);
+                result = strNewN(outputPtr, size);
+                this->outputPos += size + 1;
             }
         }
 
         // Read data if no linefeed was found in the existing buffer
         if (result == NULL)
         {
+            // If there is remaining data left in the internal output buffer then trim off the used data
+            if (outputInternalRemains > 0)
+            {
+                memmove(
+                    bufPtr(this->output), bufPtr(this->output) + (bufUsed(this->output) - outputInternalRemains),
+                    outputInternalRemains);
+            }
+
+            // Set used bytes and reset position
+            bufUsedSet(this->output, outputInternalRemains);
+            this->outputPos = 0;
+
+            // If the buffer is full then the linefeed (if it exists) is outside the buffer
             if (bufFull(this->output))
-                THROW_FMT(FileReadError, "unable to find line in %zu byte buffer", bufSize(this->output));
+                THROW_FMT(FileReadError, "unable to find line in %zu byte buffer", bufUsed(this->output));
 
             if (ioReadEof(this))
             {
@@ -294,6 +377,25 @@ ioReadLine(IoRead *this)
     FUNCTION_LOG_RETURN(STRING, ioReadLineParam(this, false));
 }
 
+/**********************************************************************************************************************************/
+bool
+ioReadReady(IoRead *this, IoReadReadyParam param)
+{
+    FUNCTION_LOG_BEGIN(logLevelTrace);
+        FUNCTION_LOG_PARAM(IO_READ, this);
+        FUNCTION_LOG_PARAM(BOOL, param.error);
+    FUNCTION_LOG_END();
+
+    ASSERT(this != NULL);
+
+    bool result = true;
+
+    if (this->interface.ready != NULL)
+        result = this->interface.ready(this->driver, param.error);
+
+    FUNCTION_LOG_RETURN(BOOL, result);
+}
+
 /**********************************************************************************************************************************/
 void
 ioReadClose(IoRead *this)
@@ -374,7 +476,7 @@ ioReadFilterGroup(const IoRead *this)
 
 /**********************************************************************************************************************************/
 int
-ioReadHandle(const IoRead *this)
+ioReadFd(const IoRead *this)
 {
     FUNCTION_LOG_BEGIN(logLevelTrace);
         FUNCTION_LOG_PARAM(IO_READ, this);
@@ -382,7 +484,7 @@ ioReadHandle(const IoRead *this)
 
     ASSERT(this != NULL);
 
-    FUNCTION_LOG_RETURN(INT, this->interface.handle == NULL ? -1 : this->interface.handle(this->driver));
+    FUNCTION_LOG_RETURN(INT, this->interface.fd == NULL ? -1 : this->interface.fd(this->driver));
 }
 
 /**********************************************************************************************************************************/
