@@ -10,7 +10,7 @@ Object type
 #include "common/io/read.h"
 
 /***********************************************************************************************************************************
-Constructor
+Constructors
 ***********************************************************************************************************************************/
 typedef struct IoReadInterface
 {
@@ -19,8 +19,12 @@ typedef struct IoReadInterface
     bool (*eof)(void *driver);
     void (*close)(void *driver);
     bool (*open)(void *driver);
-    int (*handle)(const void *driver);
+    int (*fd)(const void *driver);
     size_t (*read)(void *driver, Buffer *buffer, bool block);
+
+    // Are there bytes ready to read immediately? There are no guarantees on how much data is available to read but it must be at
+    // least one byte. Optionally error when read is not ready.
+    bool (*ready)(void *driver, bool error);
 } IoReadInterface;
 
 #define ioReadNewP(driver, ...)                                                                                                    \
@@ -29,9 +33,12 @@ typedef struct IoReadInterface
 IoRead *ioReadNew(void *driver, IoReadInterface interface);
 
 /***********************************************************************************************************************************
-Getters
+Getters/Setters
 ***********************************************************************************************************************************/
+// Driver for the read object
 void *ioReadDriver(IoRead *this);
+
+// Interface for the read object
 const IoReadInterface *ioReadInterface(const IoRead *this);
 
 /***********************************************************************************************************************************
