@@ -11,32 +11,62 @@ TLS Client
 #include "common/crypto/common.h"
 #include "common/debug.h"
 #include "common/log.h"
+#include "common/io/client.intern.h"
 #include "common/io/io.h"
 #include "common/io/tls/client.h"
-#include "common/io/tls/session.intern.h"
+#include "common/io/tls/session.h"
 #include "common/memContext.h"
+#include "common/stat.h"
 #include "common/type/object.h"
 #include "common/wait.h"
 
 /***********************************************************************************************************************************
-Statistics
+Io client type
 ***********************************************************************************************************************************/
-static TlsClientStat tlsClientStatLocal;
+STRING_EXTERN(IO_CLIENT_TLS_TYPE_STR,                               IO_CLIENT_TLS_TYPE);
+
+/***********************************************************************************************************************************
+Statistics constants
+***********************************************************************************************************************************/
+STRING_EXTERN(TLS_STAT_CLIENT_STR,                                  TLS_STAT_CLIENT);
+STRING_EXTERN(TLS_STAT_RETRY_STR,                                   TLS_STAT_RETRY);
+STRING_EXTERN(TLS_STAT_SESSION_STR,                                 TLS_STAT_SESSION);
 
 /***********************************************************************************************************************************
 Object type
 ***********************************************************************************************************************************/
-struct TlsClient
+#define TLS_CLIENT_TYPE                                             TlsClient
+#define TLS_CLIENT_PREFIX                                           tlsClient
+
+typedef struct TlsClient
 {
     MemContext *memContext;                                         // Mem context
+    const String *host;                                             // Host to use for peer verification
     TimeMSec timeout;                                               // Timeout for any i/o operation (connect, read, etc.)
     bool verifyPeer;                                                // Should the peer (server) certificate be verified?
-    SocketClient *socketClient;                                     // Socket client
+    IoClient *ioClient;                                             // Underlying client (usually a SocketClient)
 
     SSL_CTX *context;                                               // TLS context
-};
+} TlsClient;
 
-OBJECT_DEFINE_FREE(TLS_CLIENT);
+/***********************************************************************************************************************************
+Macros for function logging
+***********************************************************************************************************************************/
+static String *
+tlsClientToLog(const THIS_VOID)
+{
+    THIS(const TlsClient);
+
+    return strNewFmt(
+        "{ioClient: %s, timeout: %" PRIu64", verifyPeer: %s}",
+        memContextFreeing(this->memContext) ? NULL_Z : strZ(ioClientToLog(this->ioClient)), this->timeout,
+        cvtBoolToConstZ(this->verifyPeer));
+}
+
+#define FUNCTION_LOG_TLS_CLIENT_TYPE                                                                                               \
+    TlsClient *
+#define FUNCTION_LOG_TLS_CLIENT_FORMAT(value, buffer, bufferSize)                                                                  \
+    FUNCTION_LOG_STRING_OBJECT_FORMAT(value, tlsClientToLog, buffer, bufferSize)
 
 /***********************************************************************************************************************************
 Free connection
@@ -47,78 +77,6 @@ OBJECT_DEFINE_FREE_RESOURCE_BEGIN(TLS_CLIENT, LOG, logLevelTrace)
 }
 OBJECT_DEFINE_FREE_RESOURCE_END(LOG);
 
-/**********************************************************************************************************************************/
-TlsClient *
-tlsClientNew(SocketClient *socket, TimeMSec timeout, bool verifyPeer, const String *caFile, const String *caPath)
-{
-    FUNCTION_LOG_BEGIN(logLevelDebug)
-        FUNCTION_LOG_PARAM(SOCKET_CLIENT, socket);
-        FUNCTION_LOG_PARAM(TIME_MSEC, timeout);
-        FUNCTION_LOG_PARAM(BOOL, verifyPeer);
-        FUNCTION_LOG_PARAM(STRING, caFile);
-        FUNCTION_LOG_PARAM(STRING, caPath);
-    FUNCTION_LOG_END();
-
-    ASSERT(socket != NULL);
-
-    TlsClient *this = NULL;
-
-    MEM_CONTEXT_NEW_BEGIN("TlsClient")
-    {
-        this = memNew(sizeof(TlsClient));
-
-        *this = (TlsClient)
-        {
-            .memContext = MEM_CONTEXT_NEW(),
-            .socketClient = sckClientMove(socket, MEM_CONTEXT_NEW()),
-            .timeout = timeout,
-            .verifyPeer = verifyPeer,
-        };
-
-        // Setup TLS context
-        // -------------------------------------------------------------------------------------------------------------------------
-        cryptoInit();
-
-        // Select the TLS method to use.  To maintain compatibility with older versions of OpenSSL we need to use an SSL method,
-        // but SSL versions will be excluded in SSL_CTX_set_options().
-        const SSL_METHOD *method = SSLv23_method();
-        cryptoError(method == NULL, "unable to load TLS method");
-
-        // Create the TLS context
-        this->context = SSL_CTX_new(method);
-        cryptoError(this->context == NULL, "unable to create TLS context");
-
-        memContextCallbackSet(this->memContext, tlsClientFreeResource, this);
-
-        // Exclude SSL versions to only allow TLS and also disable compression
-        SSL_CTX_set_options(this->context, (long)(SSL_OP_ALL | SSL_OP_NO_SSLv2 | SSL_OP_NO_SSLv3 | SSL_OP_NO_COMPRESSION));
-
-        // Disable auto-retry to prevent SSL_read() from hanging
-        SSL_CTX_clear_mode(this->context, SSL_MODE_AUTO_RETRY);
-
-        // Set location of CA certificates if the server certificate will be verified
-        // -------------------------------------------------------------------------------------------------------------------------
-        if (this->verifyPeer)
-        {
-            // If the user specified a location
-            if (caFile != NULL || caPath != NULL)                                                                   // {vm_covered}
-            {
-                cryptoError(                                                                                        // {vm_covered}
-                    SSL_CTX_load_verify_locations(this->context, strPtrNull(caFile), strPtrNull(caPath)) != 1,      // {vm_covered}
-                    "unable to set user-defined CA certificate location");                                          // {vm_covered}
-            }
-            // Else use the defaults
-            else
-                cryptoError(SSL_CTX_set_default_verify_paths(this->context) != 1, "unable to set default CA certificate location");
-        }
-
-        tlsClientStatLocal.object++;
-    }
-    MEM_CONTEXT_NEW_END();
-
-    FUNCTION_LOG_RETURN(TLS_CLIENT, this);
-}
-
 /***********************************************************************************************************************************
 Convert an ASN1 string used in certificates to a String
 ***********************************************************************************************************************************/
@@ -160,13 +118,13 @@ tlsClientHostVerifyName(const String *host, const String *name)
     ASSERT(name != NULL);
 
     // Reject embedded nulls in certificate common or alternative name to prevent attacks like CVE-2009-4034
-    if (strlen(strPtr(name)) != strSize(name))
+    if (strlen(strZ(name)) != strSize(name))
         THROW(CryptoError, "TLS certificate name contains embedded null");
 
     bool result = false;
 
     // Try an exact match
-    if (strcasecmp(strPtr(name), strPtr(host)) == 0)                                                                // {vm_covered}
+    if (strcasecmp(strZ(name), strZ(host)) == 0)                                                                    // {vm_covered}
     {
         result = true;                                                                                              // {vm_covered}
     }
@@ -180,9 +138,9 @@ tlsClientHostVerifyName(const String *host, const String *name)
     //
     // This is roughly in line with RFC2818, but contrary to what most browsers appear to be implementing (point 3 being the
     // difference)
-    else if (strPtr(name)[0] == '*' && strPtr(name)[1] == '.' && strSize(name) > 2 &&                               // {vm_covered}
+    else if (strZ(name)[0] == '*' && strZ(name)[1] == '.' && strSize(name) > 2 &&                                   // {vm_covered}
              strSize(name) < strSize(host) &&                                                                       // {vm_covered}
-             strcasecmp(strPtr(name) + 1, strPtr(host) + strSize(host) - strSize(name) + 1) == 0 &&                 // {vm_covered}
+             strcasecmp(strZ(name) + 1, strZ(host) + strSize(host) - strSize(name) + 1) == 0 &&                     // {vm_covered}
              strChr(host, '.') >= (int)(strSize(host) - strSize(name)))                                             // {vm_covered}
     {
         result = true;                                                                                              // {vm_covered}
@@ -259,16 +217,18 @@ tlsClientHostVerify(const String *host, X509 *certificate)
 /***********************************************************************************************************************************
 Open connection if this is a new client or if the connection was closed by the server
 ***********************************************************************************************************************************/
-TlsSession *
-tlsClientOpen(TlsClient *this)
+static IoSession *
+tlsClientOpen(THIS_VOID)
 {
+    THIS(TlsClient);
+
     FUNCTION_LOG_BEGIN(logLevelTrace)
         FUNCTION_LOG_PARAM(TLS_CLIENT, this);
     FUNCTION_LOG_END();
 
     ASSERT(this != NULL);
 
-    TlsSession *result = NULL;
+    IoSession *result = NULL;
     SSL *session = NULL;
 
     MEM_CONTEXT_TEMP_BEGIN()
@@ -283,20 +243,18 @@ tlsClientOpen(TlsClient *this)
 
             TRY_BEGIN()
             {
-                // Open the socket session first since this is mostly likely to fail
-                SocketSession *socketSession = sckClientOpen(this->socketClient);
+                // Open the underlying session first since this is mostly likely to fail
+                IoSession *ioSession = ioClientOpen(this->ioClient);
 
                 // Create internal TLS session. If there is a failure before the TlsSession object is created there may be a leak
                 // of the TLS session but this is likely to result in program termination so it doesn't seem worth coding for.
                 cryptoError((session = SSL_new(this->context)) == NULL, "unable to create TLS session");
 
                 // Set server host name used for validation
-                cryptoError(
-                    SSL_set_tlsext_host_name(session, strPtr(sckClientHost(this->socketClient))) != 1,
-                    "unable to set TLS host name");
+                cryptoError(SSL_set_tlsext_host_name(session, strZ(this->host)) != 1, "unable to set TLS host name");
 
                 // Create the TLS session
-                result = tlsSessionNew(session, socketSession, this->timeout);
+                result = tlsSessionNew(session, ioSession, this->timeout);
             }
             CATCH_ANY()
             {
@@ -308,7 +266,7 @@ tlsClientOpen(TlsClient *this)
                     LOG_DEBUG_FMT("retry %s: %s", errorTypeName(errorType()), errorMessage());
                     retry = true;
 
-                    tlsClientStatLocal.retry++;
+                    statInc(TLS_STAT_RETRY_STR);
                 }
                 else
                     RETHROW();
@@ -317,11 +275,11 @@ tlsClientOpen(TlsClient *this)
         }
         while (retry);
 
-        tlsSessionMove(result, memContextPrior());
+        ioSessionMove(result, memContextPrior());
     }
     MEM_CONTEXT_TEMP_END();
 
-    tlsClientStatLocal.session++;
+    statInc(TLS_STAT_SESSION_STR);
 
     // Verify that the certificate presented by the server is valid
     if (this->verifyPeer)                                                                                           // {vm_covered}
@@ -332,14 +290,13 @@ tlsClientOpen(TlsClient *this)
         if (verifyResult != X509_V_OK)                                                                              // {vm_covered}
         {
             THROW_FMT(                                                                                              // {vm_covered}
-                CryptoError, "unable to verify certificate presented by '%s:%u': [%ld] %s",                         // {vm_covered}
-                strPtr(sckClientHost(this->socketClient)), sckClientPort(this->socketClient), verifyResult,         // {vm_covered}
-                X509_verify_cert_error_string(verifyResult));                                                       // {vm_covered}
+                CryptoError, "unable to verify certificate presented by '%s': [%ld] %s",                            // {vm_covered}
+                strZ(ioClientName(this->ioClient)), verifyResult, X509_verify_cert_error_string(verifyResult));     // {vm_covered}
         }
 
         // Verify that the hostname appears in the certificate
         X509 *certificate = SSL_get_peer_certificate(session);                                                      // {vm_covered}
-        bool nameResult = tlsClientHostVerify(sckClientHost(this->socketClient), certificate);                      // {vm_covered}
+        bool nameResult = tlsClientHostVerify(this->host, certificate);                                             // {vm_covered}
         X509_free(certificate);                                                                                     // {vm_covered}
 
         if (!nameResult)                                                                                            // {vm_covered}
@@ -347,27 +304,112 @@ tlsClientOpen(TlsClient *this)
             THROW_FMT(                                                                                              // {vm_covered}
                 CryptoError,                                                                                        // {vm_covered}
                 "unable to find hostname '%s' in certificate common name or subject alternative names",             // {vm_covered}
-                strPtr(sckClientHost(this->socketClient)));                                                         // {vm_covered}
+                strZ(this->host));                                                                                  // {vm_covered}
         }
     }
 
-    FUNCTION_LOG_RETURN(TLS_SESSION, result);
+    FUNCTION_LOG_RETURN(IO_SESSION, result);
 }
 
 /**********************************************************************************************************************************/
-String *
-tlsClientStatStr(void)
+static const String *
+tlsClientName(THIS_VOID)
 {
-    FUNCTION_TEST_VOID();
+    THIS(TlsClient);
 
-    String *result = NULL;
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(TLS_CLIENT, this);
+    FUNCTION_TEST_END();
 
-    if (tlsClientStatLocal.object > 0)
-    {
-        result = strNewFmt(
-            "tls statistics: objects %" PRIu64 ", sessions %" PRIu64 ", retries %" PRIu64, tlsClientStatLocal.object,
-            tlsClientStatLocal.session, tlsClientStatLocal.retry);
-    }
+    ASSERT(this != NULL);
 
-    FUNCTION_TEST_RETURN(result);
+    FUNCTION_TEST_RETURN(ioClientName(this->ioClient));
+}
+
+/**********************************************************************************************************************************/
+static const IoClientInterface tlsClientInterface =
+{
+    .type = &IO_CLIENT_TLS_TYPE_STR,
+    .name = tlsClientName,
+    .open = tlsClientOpen,
+    .toLog = tlsClientToLog,
+};
+
+IoClient *
+tlsClientNew(IoClient *ioClient, const String *host, TimeMSec timeout, bool verifyPeer, const String *caFile, const String *caPath)
+{
+    FUNCTION_LOG_BEGIN(logLevelDebug)
+        FUNCTION_LOG_PARAM(IO_CLIENT, ioClient);
+        FUNCTION_LOG_PARAM(STRING, host);
+        FUNCTION_LOG_PARAM(TIME_MSEC, timeout);
+        FUNCTION_LOG_PARAM(BOOL, verifyPeer);
+        FUNCTION_LOG_PARAM(STRING, caFile);
+        FUNCTION_LOG_PARAM(STRING, caPath);
+    FUNCTION_LOG_END();
+
+    ASSERT(ioClient != NULL);
+
+    IoClient *this = NULL;
+
+    MEM_CONTEXT_NEW_BEGIN("TlsClient")
+    {
+        TlsClient *driver = memNew(sizeof(TlsClient));
+
+        *driver = (TlsClient)
+        {
+            .memContext = MEM_CONTEXT_NEW(),
+            .ioClient = ioClientMove(ioClient, MEM_CONTEXT_NEW()),
+            .host = strDup(host),
+            .timeout = timeout,
+            .verifyPeer = verifyPeer,
+        };
+
+        // Setup TLS context
+        // -------------------------------------------------------------------------------------------------------------------------
+        cryptoInit();
+
+        // Select the TLS method to use.  To maintain compatibility with older versions of OpenSSL we need to use an SSL method,
+        // but SSL versions will be excluded in SSL_CTX_set_options().
+        const SSL_METHOD *method = SSLv23_method();
+        cryptoError(method == NULL, "unable to load TLS method");
+
+        // Create the TLS context
+        driver->context = SSL_CTX_new(method);
+        cryptoError(driver->context == NULL, "unable to create TLS context");
+
+        memContextCallbackSet(driver->memContext, tlsClientFreeResource, driver);
+
+        // Exclude SSL versions to only allow TLS and also disable compression
+        SSL_CTX_set_options(driver->context, (long)(SSL_OP_ALL | SSL_OP_NO_SSLv2 | SSL_OP_NO_SSLv3 | SSL_OP_NO_COMPRESSION));
+
+        // Disable auto-retry to prevent SSL_read() from hanging
+        SSL_CTX_clear_mode(driver->context, SSL_MODE_AUTO_RETRY);
+
+        // Set location of CA certificates if the server certificate will be verified
+        // -------------------------------------------------------------------------------------------------------------------------
+        if (driver->verifyPeer)
+        {
+            // If the user specified a location
+            if (caFile != NULL || caPath != NULL)                                                                   // {vm_covered}
+            {
+                cryptoError(                                                                                        // {vm_covered}
+                    SSL_CTX_load_verify_locations(driver->context, strZNull(caFile), strZNull(caPath)) != 1,        // {vm_covered}
+                    "unable to set user-defined CA certificate location");                                          // {vm_covered}
+            }
+            // Else use the defaults
+            else
+            {
+                cryptoError(
+                    SSL_CTX_set_default_verify_paths(driver->context) != 1, "unable to set default CA certificate location");
+            }
+        }
+
+        statInc(TLS_STAT_CLIENT_STR);
+
+        // Create client interface
+        this = ioClientNew(driver, &tlsClientInterface);
+    }
+    MEM_CONTEXT_NEW_END();
+
+    FUNCTION_LOG_RETURN(IO_CLIENT, this);
 }
