@@ -106,7 +106,7 @@ ioWrite(IoWrite *this, const Buffer *buffer)
     ASSERT(this->opened && !this->closed);
 
     // Only write if there is data to write
-    if (buffer != NULL && bufUsed(buffer) > 0)
+    if (buffer != NULL && !bufEmpty(buffer))
     {
         do
         {
@@ -143,6 +143,25 @@ ioWriteLine(IoWrite *this, const Buffer *buffer)
     FUNCTION_LOG_RETURN_VOID();
 }
 
+/**********************************************************************************************************************************/
+bool
+ioWriteReady(IoWrite *this, IoWriteReadyParam param)
+{
+    FUNCTION_LOG_BEGIN(logLevelTrace);
+        FUNCTION_LOG_PARAM(IO_WRITE, this);
+        FUNCTION_LOG_PARAM(BOOL, param.error);
+    FUNCTION_LOG_END();
+
+    ASSERT(this != NULL);
+
+    bool result = true;
+
+    if (this->interface.ready != NULL)
+        result = this->interface.ready(this->driver, param.error);
+
+    FUNCTION_LOG_RETURN(BOOL, result);
+}
+
 /**********************************************************************************************************************************/
 void
 ioWriteStr(IoWrite *this, const String *string)
@@ -190,7 +209,7 @@ ioWriteFlush(IoWrite *this)
     ASSERT(this->opened && !this->closed);
     ASSERT(!this->filterGroupSet);
 
-    if (bufUsed(this->output) > 0)
+    if (!bufEmpty(this->output))
     {
         this->interface.write(this->driver, this->output);
         bufUsedZero(this->output);
@@ -216,7 +235,7 @@ ioWriteClose(IoWrite *this)
         ioFilterGroupProcess(this->filterGroup, NULL, this->output);
 
         // Write data if the buffer is full or if this is the last buffer to be written
-        if (bufRemains(this->output) == 0 || (ioFilterGroupDone(this->filterGroup) && bufUsed(this->output) > 0))
+        if (bufRemains(this->output) == 0 || (ioFilterGroupDone(this->filterGroup) && !bufEmpty(this->output)))
         {
             this->interface.write(this->driver, this->output);
             bufUsedZero(this->output);
@@ -253,7 +272,7 @@ ioWriteFilterGroup(const IoWrite *this)
 
 /**********************************************************************************************************************************/
 int
-ioWriteHandle(const IoWrite *this)
+ioWriteFd(const IoWrite *this)
 {
     FUNCTION_LOG_BEGIN(logLevelTrace);
         FUNCTION_LOG_PARAM(IO_WRITE, this);
@@ -261,5 +280,5 @@ ioWriteHandle(const IoWrite *this)
 
     ASSERT(this != NULL);
 
-    FUNCTION_LOG_RETURN(INT, this->interface.handle == NULL ? -1 : this->interface.handle(this->driver));
+    FUNCTION_LOG_RETURN(INT, this->interface.fd == NULL ? -1 : this->interface.fd(this->driver));
 }
