@@ -23,11 +23,22 @@ Constants
 ***********************************************************************************************************************************/
 #define LOCK_FILE_EXT                                               ".lock"
 
+// Size of buffer used to load lock file
+#define LOCK_BUFFER_SIZE                                            128
+
 /***********************************************************************************************************************************
 Functions
 ***********************************************************************************************************************************/
-bool lockAcquire(const String *lockPath, const String *stanza, LockType lockType, TimeMSec lockTimeout, bool failOnNoLock);
+// Acquire a lock type. This will involve locking one or more files on disk depending on the lock type.  Most operations only take a
+// single lock (archive or backup), but the stanza commands all need to lock both.
+bool lockAcquire(
+    const String *lockPath, const String *stanza, const String *execId, LockType lockType, TimeMSec lockTimeout, bool failOnNoLock);
+
+// Clear the lock without releasing it.  This is used by a master process after it has spawned a child so the child can keep the
+// lock and the master process won't try to free it.
 bool lockClear(bool failOnNoLock);
+
+// Release a lock
 bool lockRelease(bool failOnNoLock);
 
 #endif
