@@ -13,18 +13,38 @@ Memory Context Manager
 /***********************************************************************************************************************************
 Memory context states
 ***********************************************************************************************************************************/
-typedef enum {memContextStateFree = 0, memContextStateFreeing, memContextStateActive} MemContextState;
+typedef enum
+{
+    memContextStateFree = 0,
+    memContextStateFreeing,
+    memContextStateActive
+} MemContextState;
 
 /***********************************************************************************************************************************
-Contains information about a memory allocation
+Contains information about a memory allocation. This header is placed at the beginning of every memory allocation returned to the
+user by memNew(), etc. The advantage is that when an allocation is passed back by the user we know the location of the allocation
+header by doing some pointer arithmetic. This is much faster than searching through a list.
 ***********************************************************************************************************************************/
 typedef struct MemContextAlloc
 {
-    bool active:1;                                                  // Is the allocation active?
+    unsigned int allocIdx:32;                                       // Index in the allocation list
     unsigned int size:32;                                           // Allocation size (4GB max)
-    void *buffer;                                                   // Allocated buffer
 } MemContextAlloc;
 
+// Get the allocation buffer pointer given the allocation header pointer
+#define MEM_CONTEXT_ALLOC_BUFFER(header)                            ((MemContextAlloc *)header + 1)
+
+// Get the allocation header pointer given the allocation buffer pointer
+#define MEM_CONTEXT_ALLOC_HEADER(buffer)                            ((MemContextAlloc *)buffer - 1)
+
+// Make sure the allocation is valid for the current memory context.  This check only works correctly if the allocation is valid but
+// belongs to another context.  Otherwise, there is likely to be a segfault.
+#define ASSERT_ALLOC_VALID(alloc)                                                                                                  \
+    ASSERT(                                                                                                                        \
+        alloc != NULL && (uintptr_t)alloc != (uintptr_t)-sizeof(MemContextAlloc) &&                                                \
+        alloc->allocIdx < memContextStack[memContextCurrentStackIdx].memContext->allocListSize &&                                  \
+        memContextStack[memContextCurrentStackIdx].memContext->allocList[alloc->allocIdx]);
+
 /***********************************************************************************************************************************
 Contains information about the memory context
 ***********************************************************************************************************************************/
@@ -40,7 +60,7 @@ struct MemContext
     unsigned int contextChildListSize;                              // Size of child context list (not the actual count of contexts)
     unsigned int contextChildFreeIdx;                               // Index of first free space in the context list
 
-    MemContextAlloc *allocList;                                     // List of memory allocations created in this context
+    MemContextAlloc **allocList;                                    // List of memory allocations created in this context
     unsigned int allocListSize;                                     // Size of alloc list (not the actual count of allocations)
     unsigned int allocFreeIdx;                                      // Index of first free space in the alloc list
 
@@ -57,11 +77,28 @@ generally used to allocate memory that exists for the life of the program.
 MemContext contextTop = {.state = memContextStateActive, .name = "TOP"};
 
 /***********************************************************************************************************************************
-Current context
-
-All memory allocations will be done from the current context.  Initialized to top context at execution start.
+Memory context stack types
 ***********************************************************************************************************************************/
-MemContext *contextCurrent = &contextTop;
+typedef enum
+{
+    memContextStackTypeSwitch = 0,                                  // Context can be switched to to allocate mem for new variables
+    memContextStackTypeNew,                                         // Context to be tracked for error handling - cannot switch to
+} MemContextStackType;
+
+/***********************************************************************************************************************************
+Mem context stack used to pop mem contexts and cleanup after an error
+***********************************************************************************************************************************/
+#define MEM_CONTEXT_STACK_MAX                                       128
+
+static struct MemContextStack
+{
+    MemContext *memContext;
+    MemContextStackType type;
+    unsigned int tryDepth;
+} memContextStack[MEM_CONTEXT_STACK_MAX] = {{.memContext = &contextTop}};
+
+static unsigned int memContextCurrentStackIdx = 0;
+static unsigned int memContextMaxStackIdx = 0;
 
 /***********************************************************************************************************************************
 Wrapper around malloc() with error handling
@@ -185,7 +222,7 @@ memContextNewIndex(MemContext *memContext, bool allowFree)
     // Try to find space for the new context
     for (; memContext->contextChildFreeIdx < memContext->contextChildListSize; memContext->contextChildFreeIdx++)
     {
-        if (!memContext->contextChildList[memContext->contextChildFreeIdx] ||
+        if (memContext->contextChildList[memContext->contextChildFreeIdx] == NULL ||
             (allowFree && memContext->contextChildList[memContext->contextChildFreeIdx]->state == memContextStateFree))
         {
             break;
@@ -222,9 +259,7 @@ memContextNewIndex(MemContext *memContext, bool allowFree)
     FUNCTION_TEST_RETURN(memContext->contextChildFreeIdx);
 }
 
-/***********************************************************************************************************************************
-Create a new memory context
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 MemContext *
 memContextNew(const char *name)
 {
@@ -238,6 +273,7 @@ memContextNew(const char *name)
     ASSERT(name[0] != '\0');
 
     // Find space for the new context
+    MemContext *contextCurrent = memContextStack[memContextCurrentStackIdx].memContext;
     unsigned int contextIdx = memContextNewIndex(contextCurrent, true);
 
     // If the context has not been allocated yet
@@ -250,7 +286,7 @@ memContextNew(const char *name)
     *this = (MemContext)
     {
         // Create initial space for allocations
-        .allocList = memAllocInternal(sizeof(MemContextAlloc) * MEM_CONTEXT_ALLOC_INITIAL_SIZE),
+        .allocList = memAllocPtrArrayInternal(MEM_CONTEXT_ALLOC_INITIAL_SIZE),
         .allocListSize = MEM_CONTEXT_ALLOC_INITIAL_SIZE,
 
         // Set the context name
@@ -264,20 +300,24 @@ memContextNew(const char *name)
         .contextParentIdx = contextIdx,
     };
 
-    // Initialize allocation list
-    for (unsigned int allocIdx = 0; allocIdx < MEM_CONTEXT_ALLOC_INITIAL_SIZE; allocIdx++)
-        this->allocList[allocIdx] = (MemContextAlloc){.active = false};
-
     // Possible free context must be in the next position
     contextCurrent->contextChildFreeIdx++;
 
+    // Add to the mem context stack so it will be automatically freed on error if memContextKeep() has not been called
+    memContextMaxStackIdx++;
+
+    memContextStack[memContextMaxStackIdx] = (struct MemContextStack)
+    {
+        .memContext = this,
+        .type = memContextStackTypeNew,
+        .tryDepth = errorTryDepth(),
+    };
+
     // Return context
     FUNCTION_TEST_RETURN(this);
 }
 
-/***********************************************************************************************************************************
-Register a callback to be called just before the context is freed
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void
 memContextCallbackSet(MemContext *this, void (*callbackFunction)(void *), void *callbackArgument)
 {
@@ -309,10 +349,7 @@ memContextCallbackSet(MemContext *this, void (*callbackFunction)(void *), void *
     FUNCTION_TEST_RETURN_VOID();
 }
 
-/***********************************************************************************************************************************
-Clear the mem context callback.  This is usually done in the object free method after resources have been freed but before
-memContextFree() is called.  The goal is to prevent the object free method from being called more than once.
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void
 memContextCallbackClear(MemContext *this)
 {
@@ -336,16 +373,20 @@ memContextCallbackClear(MemContext *this)
 }
 
 /***********************************************************************************************************************************
-Find an available allocation in the memory context
+Find an available slot in the memory context's allocation list and allocate memory
 ***********************************************************************************************************************************/
 static MemContextAlloc *
-memContextAllocFind(void)
+memContextAllocNew(size_t size)
 {
-    FUNCTION_TEST_VOID();
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(SIZE, size);
+    FUNCTION_TEST_END();
 
     // Find space for the new allocation
+    MemContext *contextCurrent = memContextStack[memContextCurrentStackIdx].memContext;
+
     for (; contextCurrent->allocFreeIdx < contextCurrent->allocListSize; contextCurrent->allocFreeIdx++)
-        if (!contextCurrent->allocList[contextCurrent->allocFreeIdx].active)
+        if (contextCurrent->allocList[contextCurrent->allocFreeIdx] == NULL)
             break;
 
     // If no space was found then allocate more
@@ -355,11 +396,7 @@ memContextAllocFind(void)
         if (contextCurrent->allocListSize == 0)
         {
             // Allocate memory before modifying anything else in case there is an error
-            contextCurrent->allocList = memAllocInternal(sizeof(MemContextAlloc) * MEM_CONTEXT_ALLOC_INITIAL_SIZE);
-
-            // Initialize allocations in list
-            for (unsigned int allocIdx = 0; allocIdx < MEM_CONTEXT_ALLOC_INITIAL_SIZE; allocIdx++)
-                contextCurrent->allocList[allocIdx] = (MemContextAlloc){.active = false};
+            contextCurrent->allocList = memAllocPtrArrayInternal(MEM_CONTEXT_ALLOC_INITIAL_SIZE);
 
             // Set new size
             contextCurrent->allocListSize = MEM_CONTEXT_ALLOC_INITIAL_SIZE;
@@ -370,48 +407,54 @@ memContextAllocFind(void)
             // Calculate new list size
             unsigned int allocListSizeNew = contextCurrent->allocListSize * 2;
 
-            // ReAllocate memory before modifying anything else in case there is an error
-            contextCurrent->allocList = memReAllocInternal(contextCurrent->allocList, sizeof(MemContextAlloc) * allocListSizeNew);
-
-            // Initialize new allocations in list
-            for (unsigned int allocIdx = contextCurrent->allocListSize; allocIdx < allocListSizeNew; allocIdx++)
-                contextCurrent->allocList[allocIdx] = (MemContextAlloc){.active = false};
+            // Reallocate memory before modifying anything else in case there is an error
+            contextCurrent->allocList = memReAllocPtrArrayInternal(
+                contextCurrent->allocList, contextCurrent->allocListSize, allocListSizeNew);
 
             // Set new size
             contextCurrent->allocListSize = allocListSizeNew;
         }
     }
 
+    // Create new allocation
+    MemContextAlloc *result = memAllocInternal(sizeof(MemContextAlloc) + size);
+
+    *result = (MemContextAlloc)
+    {
+        .allocIdx = contextCurrent->allocFreeIdx,
+        .size = (unsigned int)(sizeof(MemContextAlloc) + size),
+    };
+
+    // Set pointer in allocation list
+    contextCurrent->allocList[contextCurrent->allocFreeIdx] = result;
+
+    // Update free index to next location. This location may not actually be free but it is where the search should start next time.
     contextCurrent->allocFreeIdx++;
 
-    // Return buffer
-    FUNCTION_TEST_RETURN(&contextCurrent->allocList[contextCurrent->allocFreeIdx - 1]);
+    FUNCTION_TEST_RETURN(result);
 }
 
 /***********************************************************************************************************************************
-Find a memory allocation
+Resize memory that has already been allocated
 ***********************************************************************************************************************************/
-static unsigned int
-memFind(const void *buffer)
+static MemContextAlloc *
+memContextAllocResize(MemContextAlloc *alloc, size_t size)
 {
     FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_PARAM_P(VOID, buffer);
+        FUNCTION_TEST_PARAM_P(VOID, alloc);
+        FUNCTION_TEST_PARAM(SIZE, size);
     FUNCTION_TEST_END();
 
-    ASSERT(buffer != NULL);
+    ASSERT_ALLOC_VALID(alloc);
 
-    // Find memory allocation
-    unsigned int allocIdx;
+    // Resize the allocation
+    alloc = memReAllocInternal(alloc, sizeof(MemContextAlloc) + size);
+    alloc->size = (unsigned int)(sizeof(MemContextAlloc) + size);
 
-    for (allocIdx = 0; allocIdx < contextCurrent->allocListSize; allocIdx++)
-        if (contextCurrent->allocList[allocIdx].buffer == buffer && contextCurrent->allocList[allocIdx].active)
-            break;
+    // Update pointer in allocation list in case the realloc moved the allocation
+    memContextStack[memContextCurrentStackIdx].memContext->allocList[alloc->allocIdx] = alloc;
 
-    // Error if the buffer was not found
-    if (allocIdx == contextCurrent->allocListSize)
-        THROW(AssertError, "unable to find allocation");
-
-    FUNCTION_TEST_RETURN(allocIdx);
+    FUNCTION_TEST_RETURN(alloc);
 }
 
 /**********************************************************************************************************************************/
@@ -422,16 +465,7 @@ memNew(size_t size)
         FUNCTION_TEST_PARAM(SIZE, size);
     FUNCTION_TEST_END();
 
-    MemContextAlloc *alloc = memContextAllocFind();
-
-    *alloc = (MemContextAlloc)
-    {
-        .active = true,
-        .size = (unsigned int)size,
-        .buffer = memAllocInternal(size),
-    };
-
-    FUNCTION_TEST_RETURN(alloc->buffer);
+    FUNCTION_TEST_RETURN(MEM_CONTEXT_ALLOC_BUFFER(memContextAllocNew(size)));
 }
 
 /**********************************************************************************************************************************/
@@ -442,16 +476,14 @@ memNewPtrArray(size_t size)
         FUNCTION_TEST_PARAM(SIZE, size);
     FUNCTION_TEST_END();
 
-    MemContextAlloc *alloc = memContextAllocFind();
+    // Allocate pointer array
+    void **buffer = (void **)MEM_CONTEXT_ALLOC_BUFFER(memContextAllocNew(size * sizeof(void *)));
 
-    *alloc = (MemContextAlloc)
-    {
-        .active = true,
-        .size = (unsigned int)(size * sizeof(void *)),
-        .buffer = memAllocPtrArrayInternal(size),
-    };
+    // Set pointers to NULL
+    for (size_t ptrIdx = 0; ptrIdx < size; ptrIdx++)
+        buffer[ptrIdx] = NULL;
 
-    FUNCTION_TEST_RETURN(alloc->buffer);
+    FUNCTION_TEST_RETURN(buffer);
 }
 
 /**********************************************************************************************************************************/
@@ -463,16 +495,7 @@ memResize(const void *buffer, size_t size)
         FUNCTION_TEST_PARAM(SIZE, size);
     FUNCTION_TEST_END();
 
-    ASSERT(buffer != NULL);
-
-    // Find the allocation
-    MemContextAlloc *alloc = &(contextCurrent->allocList[memFind(buffer)]);
-
-    // Grow the buffer
-    alloc->buffer = memReAllocInternal(alloc->buffer, size);
-    alloc->size = (unsigned int)size;
-
-    FUNCTION_TEST_RETURN(alloc->buffer);
+    FUNCTION_TEST_RETURN(MEM_CONTEXT_ALLOC_BUFFER(memContextAllocResize(MEM_CONTEXT_ALLOC_HEADER(buffer), size)));
 }
 
 /**********************************************************************************************************************************/
@@ -483,28 +506,24 @@ memFree(void *buffer)
         FUNCTION_TEST_PARAM_P(VOID, buffer);
     FUNCTION_TEST_END();
 
-    ASSERT(buffer != NULL);
+    ASSERT_ALLOC_VALID(MEM_CONTEXT_ALLOC_HEADER(buffer));
 
-    // Find the allocation
-    unsigned int allocIdx = memFind(buffer);
-    MemContextAlloc *alloc = &(contextCurrent->allocList[allocIdx]);
-
-    // Free the buffer
-    memFreeInternal(alloc->buffer);
-    alloc->active = false;
+    // Get the allocation
+    MemContext *contextCurrent = memContextStack[memContextCurrentStackIdx].memContext;
+    MemContextAlloc *alloc = MEM_CONTEXT_ALLOC_HEADER(buffer);
 
     // If this allocation is before the current free allocation then make it the current free allocation
-    if (allocIdx < contextCurrent->allocFreeIdx)
-        contextCurrent->allocFreeIdx = allocIdx;
+    if (alloc->allocIdx < contextCurrent->allocFreeIdx)
+        contextCurrent->allocFreeIdx = alloc->allocIdx;
+
+    // Free the allocation
+    contextCurrent->allocList[alloc->allocIdx] = NULL;
+    memFreeInternal(alloc);
 
     FUNCTION_TEST_RETURN_VOID();
 }
 
-/***********************************************************************************************************************************
-Move a context to a new parent context
-
-This is generally used to move objects to a new context once they have been successfully created.
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void
 memContextMove(MemContext *this, MemContext *parentNew)
 {
@@ -548,10 +567,8 @@ memContextMove(MemContext *this, MemContext *parentNew)
     FUNCTION_TEST_RETURN_VOID();
 }
 
-/***********************************************************************************************************************************
-Switch to the specified context and return the old context
-***********************************************************************************************************************************/
-MemContext *
+/**********************************************************************************************************************************/
+void
 memContextSwitch(MemContext *this)
 {
     FUNCTION_TEST_BEGIN();
@@ -559,20 +576,101 @@ memContextSwitch(MemContext *this)
     FUNCTION_TEST_END();
 
     ASSERT(this != NULL);
+    ASSERT(memContextCurrentStackIdx < MEM_CONTEXT_STACK_MAX - 1);
 
     // Error if context is not active
     if (this->state != memContextStateActive)
         THROW(AssertError, "cannot switch to inactive context");
 
-    MemContext *memContextOld = contextCurrent;
-    contextCurrent = this;
+    memContextMaxStackIdx++;
+    memContextCurrentStackIdx = memContextMaxStackIdx;
 
-    FUNCTION_TEST_RETURN(memContextOld);
+    // Add memContext to the stack as a context that can be used for memory allocation
+    memContextStack[memContextCurrentStackIdx] = (struct MemContextStack)
+    {
+        .memContext = this,
+        .type = memContextStackTypeSwitch,
+        .tryDepth = errorTryDepth(),
+    };
+
+    FUNCTION_TEST_RETURN_VOID();
 }
 
-/***********************************************************************************************************************************
-Return the top context
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
+void
+memContextSwitchBack(void)
+{
+    FUNCTION_TEST_VOID();
+
+    ASSERT(memContextCurrentStackIdx > 0);
+
+    // Generate a detailed error to help with debugging
+#ifdef DEBUG
+    if (memContextStack[memContextMaxStackIdx].type == memContextStackTypeNew)
+    {
+        THROW_FMT(
+            AssertError, "current context expected but new context '%s' found",
+            memContextName(memContextStack[memContextMaxStackIdx].memContext));
+    }
+#endif
+
+    ASSERT(memContextCurrentStackIdx == memContextMaxStackIdx);
+
+    memContextMaxStackIdx--;
+    memContextCurrentStackIdx--;
+
+    // memContext of type New cannot be the current context so keep going until we find a memContext we can switch to as the current
+    // context
+    while (memContextStack[memContextCurrentStackIdx].type == memContextStackTypeNew)
+        memContextCurrentStackIdx--;
+
+    FUNCTION_TEST_RETURN_VOID();
+}
+
+/**********************************************************************************************************************************/
+void
+memContextKeep(void)
+{
+    FUNCTION_TEST_VOID();
+
+    // Generate a detailed error to help with debugging
+#ifdef DEBUG
+    if (memContextStack[memContextMaxStackIdx].type != memContextStackTypeNew)
+    {
+        THROW_FMT(
+            AssertError, "new context expected but current context '%s' found",
+            memContextName(memContextStack[memContextMaxStackIdx].memContext));
+    }
+#endif
+
+    memContextMaxStackIdx--;
+
+    FUNCTION_TEST_RETURN_VOID();
+}
+
+/**********************************************************************************************************************************/
+void
+memContextDiscard(void)
+{
+    FUNCTION_TEST_VOID();
+
+    // Generate a detailed error to help with debugging
+#ifdef DEBUG
+    if (memContextStack[memContextMaxStackIdx].type != memContextStackTypeNew)
+    {
+        THROW_FMT(
+            AssertError, "new context expected but current context '%s' found",
+            memContextName(memContextStack[memContextMaxStackIdx].memContext));
+    }
+#endif
+
+    memContextFree(memContextStack[memContextMaxStackIdx].memContext);
+    memContextMaxStackIdx--;
+
+    FUNCTION_TEST_RETURN_VOID();
+}
+
+/**********************************************************************************************************************************/
 MemContext *
 memContextTop(void)
 {
@@ -580,19 +678,28 @@ memContextTop(void)
     FUNCTION_TEST_RETURN(&contextTop);
 }
 
-/***********************************************************************************************************************************
-Return the current context
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 MemContext *
 memContextCurrent(void)
 {
     FUNCTION_TEST_VOID();
-    FUNCTION_TEST_RETURN(contextCurrent);
+    FUNCTION_TEST_RETURN(memContextStack[memContextCurrentStackIdx].memContext);
 }
 
-/***********************************************************************************************************************************
-Return the context name
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
+bool
+memContextFreeing(MemContext *this)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(MEM_CONTEXT, this);
+    FUNCTION_TEST_END();
+
+    ASSERT(this != NULL);
+
+    FUNCTION_TEST_RETURN(this->state == memContextStateFreeing);
+}
+
+/**********************************************************************************************************************************/
 const char *
 memContextName(MemContext *this)
 {
@@ -609,9 +716,86 @@ memContextName(MemContext *this)
     FUNCTION_TEST_RETURN(this->name);
 }
 
-/***********************************************************************************************************************************
-memContextFree - free all memory used by the context and all child contexts
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
+MemContext *
+memContextPrior(void)
+{
+    FUNCTION_TEST_VOID();
+
+    ASSERT(memContextCurrentStackIdx > 0);
+
+    unsigned int priorIdx = 1;
+
+    while (memContextStack[memContextCurrentStackIdx - priorIdx].type == memContextStackTypeNew)
+        priorIdx++;
+
+    FUNCTION_TEST_RETURN(memContextStack[memContextCurrentStackIdx - priorIdx].memContext);
+}
+
+/**********************************************************************************************************************************/
+size_t
+memContextSize(const MemContext *this)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(MEM_CONTEXT, this);
+    FUNCTION_TEST_END();
+
+    // Size of struct and child context/alloc arrays
+    size_t result =
+        sizeof(MemContext) + (this->contextChildListSize * sizeof(MemContext *)) +
+        (this->allocListSize * sizeof(MemContextAlloc *));
+
+    // Add child contexts
+    for (unsigned int contextIdx = 0; contextIdx < this->contextChildListSize; contextIdx++)
+    {
+        if (this->contextChildList[contextIdx])
+            result += memContextSize(this->contextChildList[contextIdx]);
+    }
+
+    // Add allocations
+    for (unsigned int allocIdx = 0; allocIdx < this->allocListSize; allocIdx++)
+    {
+        if (this->allocList[allocIdx] != NULL)
+            result += this->allocList[allocIdx]->size;
+    }
+
+    FUNCTION_TEST_RETURN(result);
+}
+
+/**********************************************************************************************************************************/
+void
+memContextClean(unsigned int tryDepth)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(UINT, tryDepth);
+    FUNCTION_TEST_END();
+
+    ASSERT(tryDepth > 0);
+
+    // Iterate through everything pushed to the stack since the last try
+    while (memContextStack[memContextMaxStackIdx].tryDepth >= tryDepth)
+    {
+        // Free memory contexts that were not kept
+        if (memContextStack[memContextMaxStackIdx].type == memContextStackTypeNew)
+        {
+            memContextFree(memContextStack[memContextMaxStackIdx].memContext);
+        }
+        // Else find the prior context and make it the current context
+        else
+        {
+            memContextCurrentStackIdx--;
+
+            while (memContextStack[memContextCurrentStackIdx].type == memContextStackTypeNew)
+                memContextCurrentStackIdx--;
+        }
+
+        memContextMaxStackIdx--;
+    }
+
+    FUNCTION_TEST_RETURN_VOID();
+}
+
+/**********************************************************************************************************************************/
 void
 memContextFree(MemContext *this)
 {
@@ -625,7 +809,7 @@ memContextFree(MemContext *this)
     if (this->state != memContextStateFreeing)
     {
         // Current context cannot be freed unless it is top (top is never really freed, just the stuff under it)
-        if (this == contextCurrent && this != &contextTop)
+        if (this == memContextStack[memContextCurrentStackIdx].memContext && this != &contextTop)
             THROW_FMT(AssertError, "cannot free current context '%s'", this->name);
 
         // Error if context is not active
@@ -673,12 +857,8 @@ memContextFree(MemContext *this)
         if (this->allocListSize > 0)
         {
             for (unsigned int allocIdx = 0; allocIdx < this->allocListSize; allocIdx++)
-            {
-                MemContextAlloc *alloc = &(this->allocList[allocIdx]);
-
-                if (alloc->active)
-                    memFreeInternal(alloc->buffer);
-            }
+                if (this->allocList[allocIdx] != NULL)
+                    memFreeInternal(this->allocList[allocIdx]);
 
             memFreeInternal(this->allocList);
             this->allocListSize = 0;
