@@ -15,17 +15,18 @@ typedef struct RegExp RegExp;
 #include "common/type/string.h"
 
 /***********************************************************************************************************************************
-Functions
+Constructors
 ***********************************************************************************************************************************/
 RegExp *regExpNew(const String *expression);
-bool regExpMatch(RegExp *this, const String *string);
-void regExpFree(RegExp *this);
-
-bool regExpMatchOne(const String *expression, const String *string);
-String *regExpPrefix(const String *expression);
 
 /***********************************************************************************************************************************
-Getters
+Functions
+***********************************************************************************************************************************/
+// Match on a regular expression
+bool regExpMatch(RegExp *this, const String *string);
+
+/***********************************************************************************************************************************
+Getters/Setters
 ***********************************************************************************************************************************/
 // Get pointer to the last match.  NULL if there was no match.
 const char *regExpMatchPtr(RegExp *this);
@@ -36,6 +37,22 @@ size_t regExpMatchSize(RegExp *this);
 // Get the last match as a String.  NULL if there was no match.
 String *regExpMatchStr(RegExp *this);
 
+/***********************************************************************************************************************************
+Helper functions
+***********************************************************************************************************************************/
+// Match a regular expression in one call for brevity
+bool regExpMatchOne(const String *expression, const String *string);
+
+// Return the common prefix of a regular expression, if it has one. The common prefix consists of fixed characters that must always
+// be found at the beginning of the string to be matched. Escaped characters will not be included in the prefix. If there is no
+// usable prefix then NULL is returned.
+String *regExpPrefix(const String *expression);
+
+/***********************************************************************************************************************************
+Destructor
+***********************************************************************************************************************************/
+void regExpFree(RegExp *this);
+
 /***********************************************************************************************************************************
 Macros for function logging
 ***********************************************************************************************************************************/
