@@ -14,9 +14,7 @@ Constants describing number of sub-units in an interval
 ***********************************************************************************************************************************/
 #define MSEC_PER_USEC                                               ((TimeMSec)1000)
 
-/***********************************************************************************************************************************
-Epoch time in milliseconds
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 TimeMSec
 timeMSec(void)
 {
@@ -28,9 +26,7 @@ timeMSec(void)
     FUNCTION_TEST_RETURN(((TimeMSec)currentTime.tv_sec * MSEC_PER_SEC) + (TimeMSec)currentTime.tv_usec / MSEC_PER_USEC);
 }
 
-/***********************************************************************************************************************************
-Sleep for specified milliseconds
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void
 sleepMSec(TimeMSec sleepMSec)
 {
@@ -40,7 +36,7 @@ sleepMSec(TimeMSec sleepMSec)
 
     struct timeval delay;
     delay.tv_sec = (time_t)(sleepMSec / MSEC_PER_SEC);
-    delay.tv_usec = (time_t)(sleepMSec % MSEC_PER_SEC * 1000);
+    delay.tv_usec = (suseconds_t)(sleepMSec % MSEC_PER_SEC * 1000);
     select(0, NULL, NULL, NULL, &delay);
 
     FUNCTION_TEST_RETURN_VOID();
