@@ -1,5 +1,5 @@
 /***********************************************************************************************************************************
-Convert Base Data Types
+Convert C Types
 ***********************************************************************************************************************************/
 #include "build.auto.h"
 
@@ -90,9 +90,7 @@ cvtZToUInt64Internal(const char *value, const char *type, int base)
     FUNCTION_TEST_RETURN(result);
 }
 
-/***********************************************************************************************************************************
-Convert boolean to zero-terminated string
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 size_t
 cvtBoolToZ(bool value, char *buffer, size_t bufferSize)
 {
@@ -112,17 +110,13 @@ cvtBoolToZ(bool value, char *buffer, size_t bufferSize)
     FUNCTION_TEST_RETURN(result);
 }
 
-// Since booleans only have two possible values we can return a const with the value.  This is useful when a boolean needs to be
-// output as part of a large string.
 const char *
 cvtBoolToConstZ(bool value)
 {
     return value ? TRUE_Z : FALSE_Z;
 }
 
-/***********************************************************************************************************************************
-Convert char to zero-terminated string
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 size_t
 cvtCharToZ(char value, char *buffer, size_t bufferSize)
 {
@@ -142,9 +136,7 @@ cvtCharToZ(char value, char *buffer, size_t bufferSize)
     FUNCTION_TEST_RETURN(result);
 }
 
-/***********************************************************************************************************************************
-Convert double to zero-terminated string and vice versa
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 size_t
 cvtDoubleToZ(double value, char *buffer, size_t bufferSize)
 {
@@ -206,9 +198,7 @@ cvtZToDouble(const char *value)
     FUNCTION_TEST_RETURN(result);
 }
 
-/***********************************************************************************************************************************
-Convert int to zero-terminated string and vice versa
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 size_t
 cvtIntToZ(int value, char *buffer, size_t bufferSize)
 {
@@ -257,9 +247,7 @@ cvtZToInt(const char *value)
     FUNCTION_TEST_RETURN(cvtZToIntBase(value, 10));
 }
 
-/***********************************************************************************************************************************
-Convert int64 to zero-terminated string and vice versa
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 size_t
 cvtInt64ToZ(int64_t value, char *buffer, size_t bufferSize)
 {
@@ -303,9 +291,7 @@ cvtZToInt64(const char *value)
     FUNCTION_TEST_RETURN(cvtZToInt64Base(value, 10));
 }
 
-/***********************************************************************************************************************************
-Convert mode to zero-terminated string
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 size_t
 cvtModeToZ(mode_t value, char *buffer, size_t bufferSize)
 {
@@ -334,12 +320,10 @@ cvtZToMode(const char *value)
 
     ASSERT(value != NULL);
 
-    FUNCTION_TEST_RETURN(cvtZToUIntBase(value, 8));
+    FUNCTION_TEST_RETURN((mode_t)cvtZToUIntBase(value, 8));
 }
 
-/***********************************************************************************************************************************
-Convert size to zero-terminated string
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 size_t
 cvtSizeToZ(size_t value, char *buffer, size_t bufferSize)
 {
@@ -359,9 +343,6 @@ cvtSizeToZ(size_t value, char *buffer, size_t bufferSize)
     FUNCTION_TEST_RETURN(result);
 }
 
-/***********************************************************************************************************************************
-Convert ssize to zero-terminated string
-***********************************************************************************************************************************/
 size_t
 cvtSSizeToZ(ssize_t value, char *buffer, size_t bufferSize)
 {
@@ -381,9 +362,7 @@ cvtSSizeToZ(ssize_t value, char *buffer, size_t bufferSize)
     FUNCTION_TEST_RETURN(result);
 }
 
-/***********************************************************************************************************************************
-Convert time_t to zero-terminated string
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 size_t
 cvtTimeToZ(time_t value, char *buffer, size_t bufferSize)
 {
@@ -403,9 +382,7 @@ cvtTimeToZ(time_t value, char *buffer, size_t bufferSize)
     FUNCTION_TEST_RETURN(result);
 }
 
-/***********************************************************************************************************************************
-Convert uint to zero-terminated string
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 size_t
 cvtUIntToZ(unsigned int value, char *buffer, size_t bufferSize)
 {
@@ -455,9 +432,7 @@ cvtZToUInt(const char *value)
     FUNCTION_TEST_RETURN(cvtZToUIntBase(value, 10));
 }
 
-/***********************************************************************************************************************************
-Convert uint64 to zero-terminated string and visa versa
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 size_t
 cvtUInt64ToZ(uint64_t value, char *buffer, size_t bufferSize)
 {
