@@ -10,7 +10,7 @@ List Handler
 
 #include "common/debug.h"
 #include "common/type/list.h"
-#include "common/object.h"
+#include "common/type/object.h"
 
 /***********************************************************************************************************************************
 Object type
@@ -22,28 +22,17 @@ struct List
     unsigned int listSize;
     unsigned int listSizeMax;
     SortOrder sortOrder;
-    unsigned char *list;
+    unsigned char *listAlloc;                                       // Pointer to memory allocated for the list
+    unsigned char *list;                                            // Pointer to the current start of the list
     ListComparator *comparator;
 };
 
 OBJECT_DEFINE_MOVE(LIST);
 OBJECT_DEFINE_FREE(LIST);
 
-/***********************************************************************************************************************************
-Create a new list
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 List *
-lstNew(size_t itemSize)
-{
-    FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_PARAM(SIZE, itemSize);
-    FUNCTION_TEST_END();
-
-    FUNCTION_TEST_RETURN(lstNewP(itemSize));
-}
-
-List *
-lstNewParam(size_t itemSize, ListParam param)
+lstNew(size_t itemSize, ListParam param)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(SIZE, itemSize);
@@ -70,9 +59,7 @@ lstNewParam(size_t itemSize, ListParam param)
     FUNCTION_TEST_RETURN(this);
 }
 
-/***********************************************************************************************************************************
-Add an item to the end of the list
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void *
 lstAdd(List *this, const void *item)
 {
@@ -87,9 +74,7 @@ lstAdd(List *this, const void *item)
     FUNCTION_TEST_RETURN(lstInsert(this, lstSize(this), item));
 }
 
-/***********************************************************************************************************************************
-Clear items from a list
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 List *
 lstClear(List *this)
 {
@@ -114,9 +99,7 @@ lstClear(List *this)
     FUNCTION_TEST_RETURN(this);
 }
 
-/***********************************************************************************************************************************
-Compare Strings ascending or structs with a String as the first member
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 int
 lstComparatorStr(const void *item1, const void *item2)
 {
@@ -142,9 +125,7 @@ lstComparatorDesc(const void *item1, const void *item2)
     return comparatorDescList->comparator(item2, item1);
 }
 
-/***********************************************************************************************************************************
-Get an item from the list
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void *
 lstGet(const List *this, unsigned int listIdx)
 {
@@ -163,9 +144,24 @@ lstGet(const List *this, unsigned int listIdx)
     FUNCTION_TEST_RETURN(this->list + (listIdx * this->itemSize));
 }
 
-/***********************************************************************************************************************************
-Does an item exist in the list?
-***********************************************************************************************************************************/
+void *
+lstGetLast(const List *this)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(LIST, this);
+    FUNCTION_TEST_END();
+
+    ASSERT(this != NULL);
+
+    // Ensure there are items in the list
+    if (this->listSize == 0)
+        THROW(AssertError, "cannot get last from list with no values");
+
+    // Return pointer to list item
+    FUNCTION_TEST_RETURN(lstGet(this, this->listSize - 1));
+}
+
+/**********************************************************************************************************************************/
 bool
 lstExists(const List *this, const void *item)
 {
@@ -180,9 +176,7 @@ lstExists(const List *this, const void *item)
     FUNCTION_TEST_RETURN(lstFind(this, item) != NULL);
 }
 
-/***********************************************************************************************************************************
-Find an item in the list
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void *
 lstFind(const List *this, const void *item)
 {
@@ -192,6 +186,7 @@ lstFind(const List *this, const void *item)
     FUNCTION_TEST_END();
 
     ASSERT(this != NULL);
+    ASSERT(this->comparator != NULL);
     ASSERT(item != NULL);
 
     if (this->sortOrder == sortOrderAsc)
@@ -247,9 +242,7 @@ lstFindDefault(const List *this, const void *item, void *itemDefault)
     FUNCTION_TEST_RETURN(result == NULL ? itemDefault : result);
 }
 
-/***********************************************************************************************************************************
-Get the index of a list item
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 unsigned int
 lstIdx(const List *this, const void *item)
 {
@@ -272,9 +265,7 @@ lstIdx(const List *this, const void *item)
     FUNCTION_TEST_RETURN((unsigned int)result);
 }
 
-/***********************************************************************************************************************************
-Insert an item into the list
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void *
 lstInsert(List *this, unsigned int listIdx, const void *item)
 {
@@ -304,13 +295,24 @@ lstInsert(List *this, unsigned int listIdx, const void *item)
                 this->listSizeMax *= 2;
                 this->list = memResize(this->list, this->listSizeMax * this->itemSize);
             }
+
+            this->listAlloc = this->list;
         }
         MEM_CONTEXT_END();
     }
+    // Else if there is space before the beginning of the list then move the list down
+    else if (
+        (this->list != this->listAlloc) &&
+        (this->listSize + ((uintptr_t)(this->list - this->listAlloc) / this->itemSize) == this->listSizeMax))
+    {
+        memmove(this->listAlloc, this->list, this->listSize * this->itemSize);
+        this->list = this->listAlloc;
+    }
 
-    // If not inserting at the end then move items down to make space
+    // Calculate the position where this item will be copied
     void *itemPtr = this->list + (listIdx * this->itemSize);
 
+    // If not inserting at the end then move items down to make space
     if (listIdx != lstSize(this))
         memmove(this->list + ((listIdx + 1) * this->itemSize), itemPtr, (lstSize(this) - listIdx) * this->itemSize);
 
@@ -322,25 +324,33 @@ lstInsert(List *this, unsigned int listIdx, const void *item)
     FUNCTION_TEST_RETURN(itemPtr);
 }
 
-/***********************************************************************************************************************************
-Remove an item from the list
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 List *
 lstRemoveIdx(List *this, unsigned int listIdx)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(LIST, this);
+        FUNCTION_TEST_PARAM(UINT, listIdx);
     FUNCTION_TEST_END();
 
     ASSERT(this != NULL);
     ASSERT(listIdx <= lstSize(this));
 
-    // Remove the item by moving the items after it down
+    // Decrement the list size
     this->listSize--;
 
-    memmove(
-        this->list + (listIdx * this->itemSize), this->list + ((listIdx + 1) * this->itemSize),
-        (lstSize(this) - listIdx) * this->itemSize);
+    // If this is the first item then move the list pointer up to avoid moving all the items
+    if (listIdx == 0)
+    {
+        this->list += this->itemSize;
+    }
+    // Else remove the item by moving the items after it down
+    else
+    {
+        memmove(
+            this->list + (listIdx * this->itemSize), this->list + ((listIdx + 1) * this->itemSize),
+            (lstSize(this) - listIdx) * this->itemSize);
+    }
 
     FUNCTION_TEST_RETURN(this);
 }
@@ -367,9 +377,22 @@ lstRemove(List *this, const void *item)
     FUNCTION_TEST_RETURN(false);
 }
 
-/***********************************************************************************************************************************
-Return the memory context for this list
-***********************************************************************************************************************************/
+List *
+lstRemoveLast(List *this)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(LIST, this);
+    FUNCTION_TEST_END();
+
+    ASSERT(this != NULL);
+
+    if (this->listSize == 0)
+        THROW(AssertError, "cannot remove last from list with no values");
+
+    FUNCTION_TEST_RETURN(lstRemoveIdx(this, this->listSize - 1));
+}
+
+/**********************************************************************************************************************************/
 MemContext *
 lstMemContext(const List *this)
 {
@@ -382,9 +405,7 @@ lstMemContext(const List *this)
     FUNCTION_TEST_RETURN(this->memContext);
 }
 
-/***********************************************************************************************************************************
-Return list size
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 unsigned int
 lstSize(const List *this)
 {
@@ -397,9 +418,7 @@ lstSize(const List *this)
     FUNCTION_TEST_RETURN(this->listSize);
 }
 
-/***********************************************************************************************************************************
-List sort
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 List *
 lstSort(List *this, SortOrder sortOrder)
 {
@@ -409,14 +428,13 @@ lstSort(List *this, SortOrder sortOrder)
     FUNCTION_TEST_END();
 
     ASSERT(this != NULL);
+    ASSERT(this->comparator != NULL);
 
     switch (sortOrder)
     {
         case sortOrderAsc:
-        {
             qsort(this->list, this->listSize, this->itemSize, this->comparator);
             break;
-        }
 
         case sortOrderDesc:
         {
@@ -436,9 +454,7 @@ lstSort(List *this, SortOrder sortOrder)
     FUNCTION_TEST_RETURN(this);
 }
 
-/***********************************************************************************************************************************
-Set a new comparator
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 List *
 lstComparatorSet(List *this, ListComparator *comparator)
 {
@@ -455,9 +471,7 @@ lstComparatorSet(List *this, ListComparator *comparator)
     FUNCTION_TEST_RETURN(this);
 }
 
-/***********************************************************************************************************************************
-Render as string for logging
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 String *
 lstToLog(const List *this)
 {
