@@ -18,7 +18,6 @@ typedef struct StringList StringList;
 Constructors
 ***********************************************************************************************************************************/
 StringList *strLstNew(void);
-StringList *strLstNewParam(ListComparator *comparator);
 
 // Split a string into a string list based on a delimiter
 StringList *strLstNewSplit(const String *string, const String *delimiter);
@@ -78,6 +77,13 @@ StringList *strLstRemoveIdx(StringList *this, unsigned int listIdx);
 // List size
 unsigned int strLstSize(const StringList *this);
 
+// Is the list empty?
+__attribute__((always_inline)) static inline bool
+strLstEmpty(const StringList *this)
+{
+    return strLstSize(this) == 0;
+}
+
 // List sort
 StringList *strLstSort(StringList *this, SortOrder sortOrder);
 
