@@ -41,13 +41,6 @@ typedef struct VariantBool
     MemContext *memContext;
 } VariantBool;
 
-typedef struct VariantDouble
-{
-    VARIANT_COMMON
-    VARIANT_DOUBLE_COMMON
-    MemContext *memContext;
-} VariantDouble;
-
 typedef struct VariantInt
 {
     VARIANT_COMMON
@@ -103,7 +96,6 @@ Variant type names
 static const char *const variantTypeName[] =
 {
     "bool",                                                         // varTypeBool
-    "double",                                                       // varTypeDouble,
     "int",                                                          // varTypeInt
     "int64",                                                        // varTypeInt64
     "KeyValue",                                                     // varTypeKeyValue
@@ -113,9 +105,7 @@ static const char *const variantTypeName[] =
     "VariantList",                                                  // varTypeVariantList
 };
 
-/***********************************************************************************************************************************
-Duplicate a variant
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 Variant *
 varDup(const Variant *this)
 {
@@ -130,28 +120,16 @@ varDup(const Variant *this)
         switch (this->type)
         {
             case varTypeBool:
-            {
                 result = varNewBool(varBool(this));
                 break;
-            }
-
-            case varTypeDouble:
-            {
-                result = varNewDbl(varDbl(this));
-                break;
-            }
 
             case varTypeInt:
-            {
                 result = varNewInt(varInt(this));
                 break;
-            }
 
             case varTypeInt64:
-            {
                 result = varNewInt64(varInt64(this));
                 break;
-            }
 
             case varTypeKeyValue:
             {
@@ -169,37 +147,27 @@ varDup(const Variant *this)
             }
 
             case varTypeString:
-            {
                 result = varNewStr(varStr(this));
                 break;
-            }
 
             case varTypeUInt:
-            {
                 result = varNewUInt(varUInt(this));
                 break;
-            }
 
             case varTypeUInt64:
-            {
                 result = varNewUInt64(varUInt64(this));
                 break;
-            }
 
             case varTypeVariantList:
-            {
                 result = varNewVarLst(varVarLst(this));
                 break;
-            }
         }
     }
 
     FUNCTION_TEST_RETURN(result);
 }
 
-/***********************************************************************************************************************************
-Test if variants are equal
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 bool
 varEq(const Variant *this1, const Variant *this2)
 {
@@ -219,46 +187,28 @@ varEq(const Variant *this1, const Variant *this2)
             switch (varType(this1))
             {
                 case varTypeBool:
-                {
                     result = varBool(this1) == varBool(this2);
                     break;
-                }
-
-                case varTypeDouble:
-                {
-                    result = varDbl(this1) == varDbl(this2);
-                    break;
-                }
 
                 case varTypeInt:
-                {
                     result = varInt(this1) == varInt(this2);
                     break;
-                }
 
                 case varTypeInt64:
-                {
                     result = varInt64(this1) == varInt64(this2);
                     break;
-                }
 
                 case varTypeString:
-                {
                     result = strEq(varStr(this1), varStr(this2));
                     break;
-                }
 
                 case varTypeUInt:
-                {
                     result = varUInt(this1) == varUInt(this2);
                     break;
-                }
 
                 case varTypeUInt64:
-                {
                     result = varUInt64(this1) == varUInt64(this2);
                     break;
-                }
 
                 default:
                     THROW_FMT(AssertError, "unable to test equality for %s", variantTypeName[this1->type]);
@@ -272,9 +222,7 @@ varEq(const Variant *this1, const Variant *this2)
     FUNCTION_TEST_RETURN(result);
 }
 
-/***********************************************************************************************************************************
-Get variant type
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 VariantType
 varType(const Variant *this)
 {
@@ -287,9 +235,7 @@ varType(const Variant *this)
     FUNCTION_TEST_RETURN(this->type);
 }
 
-/***********************************************************************************************************************************
-New bool variant
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 Variant *
 varNewBool(bool data)
 {
@@ -310,9 +256,7 @@ varNewBool(bool data)
     FUNCTION_TEST_RETURN((Variant *)this);
 }
 
-/***********************************************************************************************************************************
-Return bool
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 bool
 varBool(const Variant *this)
 {
@@ -326,9 +270,6 @@ varBool(const Variant *this)
     FUNCTION_TEST_RETURN(((VariantBool *)this)->data);
 }
 
-/***********************************************************************************************************************************
-Return bool regardless of variant type
-***********************************************************************************************************************************/
 bool
 varBoolForce(const Variant *this)
 {
@@ -364,7 +305,7 @@ varBoolForce(const Variant *this)
             };
 
             // Search for the string
-            const char *string = strPtr(varStr(this));
+            const char *string = strZ(varStr(this));
             unsigned int boolIdx;
 
             for (boolIdx = 0; boolIdx < sizeof(boolString) / sizeof(char *); boolIdx++)
@@ -396,113 +337,7 @@ varBoolForce(const Variant *this)
     FUNCTION_TEST_RETURN(result);
 }
 
-/***********************************************************************************************************************************
-New double variant
-***********************************************************************************************************************************/
-Variant *
-varNewDbl(double data)
-{
-    FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_PARAM(DOUBLE, data);
-    FUNCTION_TEST_END();
-
-    // Allocate memory for the variant and set the type and data
-    VariantDouble *this = memNew(sizeof(VariantDouble));
-
-    *this = (VariantDouble)
-    {
-        .memContext = memContextCurrent(),
-        .type = varTypeDouble,
-        .data = data,
-    };
-
-    FUNCTION_TEST_RETURN((Variant *)this);
-}
-
-/***********************************************************************************************************************************
-Return double
-***********************************************************************************************************************************/
-double
-varDbl(const Variant *this)
-{
-    FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_PARAM(VARIANT, this);
-    FUNCTION_TEST_END();
-
-    ASSERT(this != NULL);
-    ASSERT(this->type == varTypeDouble);
-
-    FUNCTION_TEST_RETURN(((VariantDouble *)this)->data);
-}
-
-/***********************************************************************************************************************************
-Return double regardless of variant type
-***********************************************************************************************************************************/
-double
-varDblForce(const Variant *this)
-{
-    FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_PARAM(VARIANT, this);
-    FUNCTION_TEST_END();
-
-    ASSERT(this != NULL);
-
-    double result = 0;
-
-    switch (this->type)
-    {
-        case varTypeBool:
-        {
-            result = varBool(this);
-            break;
-        }
-
-        case varTypeDouble:
-        {
-            result = varDbl(this);
-            break;
-        }
-
-        case varTypeInt:
-        {
-            result = varInt(this);
-            break;
-        }
-
-        case varTypeInt64:
-        {
-            result = (double)varInt64(this);
-            break;
-        }
-
-        case varTypeString:
-        {
-            result = cvtZToDouble(strPtr(varStr(this)));
-            break;
-        }
-
-        case varTypeUInt:
-        {
-            result = (double)varUInt(this);
-            break;
-        }
-
-        case varTypeUInt64:
-        {
-            result = (double)varUInt64(this);
-            break;
-        }
-
-        default:
-            THROW_FMT(AssertError, "unable to force %s to %s", variantTypeName[this->type], variantTypeName[varTypeDouble]);
-    }
-
-    FUNCTION_TEST_RETURN(result);
-}
-
-/***********************************************************************************************************************************
-New int variant
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 Variant *
 varNewInt(int data)
 {
@@ -523,9 +358,7 @@ varNewInt(int data)
     FUNCTION_TEST_RETURN((Variant *)this);
 }
 
-/***********************************************************************************************************************************
-Return int
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 int
 varInt(const Variant *this)
 {
@@ -539,9 +372,6 @@ varInt(const Variant *this)
     FUNCTION_TEST_RETURN(((VariantInt *)this)->data);
 }
 
-/***********************************************************************************************************************************
-Return int regardless of variant type
-***********************************************************************************************************************************/
 int
 varIntForce(const Variant *this)
 {
@@ -556,16 +386,12 @@ varIntForce(const Variant *this)
     switch (this->type)
     {
         case varTypeBool:
-        {
             result = varBool(this);
             break;
-        }
 
         case varTypeInt:
-        {
             result = varInt(this);
             break;
-        }
 
         case varTypeInt64:
         {
@@ -582,10 +408,8 @@ varIntForce(const Variant *this)
         }
 
         case varTypeString:
-        {
-            result = cvtZToInt(strPtr(varStr(this)));
+            result = cvtZToInt(strZ(varStr(this)));
             break;
-        }
 
         case varTypeUInt:
         {
@@ -622,9 +446,7 @@ varIntForce(const Variant *this)
     FUNCTION_TEST_RETURN(result);
 }
 
-/***********************************************************************************************************************************
-New int64 variant
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 Variant *
 varNewInt64(int64_t data)
 {
@@ -645,9 +467,7 @@ varNewInt64(int64_t data)
     FUNCTION_TEST_RETURN((Variant *)this);
 }
 
-/***********************************************************************************************************************************
-Return int64
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 int64_t
 varInt64(const Variant *this)
 {
@@ -661,9 +481,6 @@ varInt64(const Variant *this)
     FUNCTION_TEST_RETURN(((VariantInt64 *)this)->data);
 }
 
-/***********************************************************************************************************************************
-Return int64 regardless of variant type
-***********************************************************************************************************************************/
 int64_t
 varInt64Force(const Variant *this)
 {
@@ -678,35 +495,25 @@ varInt64Force(const Variant *this)
     switch (this->type)
     {
         case varTypeBool:
-        {
             result = varBool(this);
             break;
-        }
 
         case varTypeInt:
-        {
             result = (int64_t)varInt(this);
             break;
-        }
 
         case varTypeInt64:
-        {
             result = varInt64(this);
             break;
-        }
 
         case varTypeString:
-        {
-            result = cvtZToInt64(strPtr(varStr(this)));
+            result = cvtZToInt64(strZ(varStr(this)));
             break;
-        }
 
         case varTypeUInt:
-        {
             result = varUInt(this);
 
             break;
-        }
 
         case varTypeUInt64:
         {
@@ -732,9 +539,7 @@ varInt64Force(const Variant *this)
     FUNCTION_TEST_RETURN(result);
 }
 
-/***********************************************************************************************************************************
-New unsigned int variant
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 Variant *
 varNewUInt(unsigned int data)
 {
@@ -755,9 +560,7 @@ varNewUInt(unsigned int data)
     FUNCTION_TEST_RETURN((Variant *)this);
 }
 
-/***********************************************************************************************************************************
-Return unsigned int
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 unsigned int
 varUInt(const Variant *this)
 {
@@ -771,9 +574,6 @@ varUInt(const Variant *this)
     FUNCTION_TEST_RETURN(((VariantUInt *)this)->data);
 }
 
-/***********************************************************************************************************************************
-Return unsigned int regardless of variant type
-***********************************************************************************************************************************/
 unsigned int
 varUIntForce(const Variant *this)
 {
@@ -788,10 +588,8 @@ varUIntForce(const Variant *this)
     switch (this->type)
     {
         case varTypeBool:
-        {
             result = varBool(this);
             break;
-        }
 
         case varTypeInt:
         {
@@ -828,10 +626,8 @@ varUIntForce(const Variant *this)
         }
 
         case varTypeUInt:
-        {
             result = varUInt(this);
             break;
-        }
 
         case varTypeUInt64:
         {
@@ -851,10 +647,8 @@ varUIntForce(const Variant *this)
         }
 
         case varTypeString:
-        {
-            result = cvtZToUInt(strPtr(varStr(this)));
+            result = cvtZToUInt(strZ(varStr(this)));
             break;
-        }
 
         default:
             THROW_FMT(AssertError, "unable to force %s to %s", variantTypeName[this->type], variantTypeName[varTypeUInt]);
@@ -863,9 +657,7 @@ varUIntForce(const Variant *this)
     FUNCTION_TEST_RETURN(result);
 }
 
-/***********************************************************************************************************************************
-New uint64 variant
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 Variant *
 varNewUInt64(uint64_t data)
 {
@@ -886,9 +678,7 @@ varNewUInt64(uint64_t data)
     FUNCTION_TEST_RETURN((Variant *)this);
 }
 
-/***********************************************************************************************************************************
-Return int64
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 uint64_t
 varUInt64(const Variant *this)
 {
@@ -902,9 +692,6 @@ varUInt64(const Variant *this)
     FUNCTION_TEST_RETURN(((VariantUInt64 *)this)->data);
 }
 
-/***********************************************************************************************************************************
-Return uint64 regardless of variant type
-***********************************************************************************************************************************/
 uint64_t
 varUInt64Force(const Variant *this)
 {
@@ -919,10 +706,8 @@ varUInt64Force(const Variant *this)
     switch (this->type)
     {
         case varTypeBool:
-        {
             result = varBool(this);
             break;
-        }
 
         case varTypeInt:
         {
@@ -959,22 +744,16 @@ varUInt64Force(const Variant *this)
         }
 
         case varTypeString:
-        {
-            result = cvtZToUInt64(strPtr(varStr(this)));
+            result = cvtZToUInt64(strZ(varStr(this)));
             break;
-        }
 
         case varTypeUInt:
-        {
             result = varUInt(this);
             break;
-        }
 
         case varTypeUInt64:
-        {
             result = varUInt64(this);
             break;
-        }
 
         default:
             THROW_FMT(AssertError, "unable to force %s to %s", variantTypeName[this->type], variantTypeName[varTypeUInt64]);
@@ -983,11 +762,7 @@ varUInt64Force(const Variant *this)
     FUNCTION_TEST_RETURN(result);
 }
 
-/***********************************************************************************************************************************
-New key/value variant
-
-Note that the kv is not duped because it this a heavy-weight operation.  It is merely moved into the same MemContext as the Variant.
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 Variant *
 varNewKv(KeyValue *data)
 {
@@ -1010,9 +785,7 @@ varNewKv(KeyValue *data)
     FUNCTION_TEST_RETURN((Variant *)this);
 }
 
-/***********************************************************************************************************************************
-Return key/value
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 KeyValue *
 varKv(const Variant *this)
 {
@@ -1031,9 +804,7 @@ varKv(const Variant *this)
     FUNCTION_TEST_RETURN(result);
 }
 
-/***********************************************************************************************************************************
-New string variant
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 Variant *
 varNewStr(const String *data)
 {
@@ -1054,9 +825,6 @@ varNewStr(const String *data)
     FUNCTION_TEST_RETURN((Variant *)this);
 }
 
-/***********************************************************************************************************************************
-New string variant from a zero-terminated string
-***********************************************************************************************************************************/
 Variant *
 varNewStrZ(const char *data)
 {
@@ -1067,9 +835,7 @@ varNewStrZ(const char *data)
     FUNCTION_TEST_RETURN(varNewStr(data == NULL ? NULL : strNew(data)));
 }
 
-/***********************************************************************************************************************************
-Return string
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 const String *
 varStr(const Variant *this)
 {
@@ -1088,9 +854,6 @@ varStr(const Variant *this)
     FUNCTION_TEST_RETURN(result);
 }
 
-/***********************************************************************************************************************************
-Return string regardless of variant type
-***********************************************************************************************************************************/
 String *
 varStrForce(const Variant *this)
 {
@@ -1105,19 +868,8 @@ varStrForce(const Variant *this)
     switch (varType(this))
     {
         case varTypeBool:
-        {
             result = strNew(cvtBoolToConstZ(varBool(this)));
             break;
-        }
-
-        case varTypeDouble:
-        {
-            char working[CVT_BASE10_BUFFER_SIZE];
-
-            cvtDoubleToZ(varDbl(this), working, sizeof(working));
-            result = strNew(working);
-            break;
-        }
 
         case varTypeInt:
         {
@@ -1138,10 +890,8 @@ varStrForce(const Variant *this)
         }
 
         case varTypeString:
-        {
             result = strDup(varStr(this));
             break;
-        }
 
         case varTypeUInt:
         {
@@ -1168,9 +918,7 @@ varStrForce(const Variant *this)
     FUNCTION_TEST_RETURN(result);
 }
 
-/***********************************************************************************************************************************
-New variant list variant
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 Variant *
 varNewVarLst(const VariantList *data)
 {
@@ -1193,9 +941,7 @@ varNewVarLst(const VariantList *data)
     FUNCTION_TEST_RETURN((Variant *)this);
 }
 
-/***********************************************************************************************************************************
-Return key/value
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 VariantList *
 varVarLst(const Variant *this)
 {
@@ -1214,9 +960,7 @@ varVarLst(const Variant *this)
     FUNCTION_TEST_RETURN(result);
 }
 
-/***********************************************************************************************************************************
-Convert variant to a zero-terminated string for logging
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 String *
 varToLog(const Variant *this)
 {
@@ -1229,31 +973,24 @@ varToLog(const Variant *this)
         switch (varType(this))
         {
             case varTypeString:
-            {
                 result = strToLog(varStr(this));
                 break;
-            }
 
             case varTypeKeyValue:
-            {
                 result = strNew("{KeyValue}");
                 break;
-            }
 
             case varTypeVariantList:
-            {
                 result = strNew("{VariantList}");
                 break;
-            }
 
             case varTypeBool:
-            case varTypeDouble:
             case varTypeInt:
             case varTypeInt64:
             case varTypeUInt:
             case varTypeUInt64:
             {
-                result = strNewFmt("{%s}", strPtr(varStrForce(this)));
+                result = strNewFmt("{%s}", strZ(varStrForce(this)));
                 break;
             }
         }
@@ -1262,9 +999,7 @@ varToLog(const Variant *this)
     return result;
 }
 
-/***********************************************************************************************************************************
-Free variant
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void
 varFree(Variant *this)
 {
@@ -1279,61 +1014,39 @@ varFree(Variant *this)
         switch (this->type)
         {
             case varTypeBool:
-            {
                 memContext = ((VariantBool *)this)->memContext;
                 break;
-            }
-
-            case varTypeDouble:
-            {
-                memContext = ((VariantDouble *)this)->memContext;
-                break;
-            }
 
             case varTypeInt:
-            {
                 memContext = ((VariantInt *)this)->memContext;
                 break;
-            }
 
             case varTypeInt64:
-            {
                 memContext = ((VariantInt64 *)this)->memContext;
                 break;
-            }
 
             case varTypeKeyValue:
-            {
                 memContext = ((VariantKeyValue *)this)->memContext;
                 kvFree(((VariantKeyValue *)this)->data);
                 break;
-            }
 
             case varTypeString:
-            {
                 memContext = ((VariantString *)this)->memContext;
                 strFree(((VariantString *)this)->data);
                 break;
-            }
 
             case varTypeUInt:
-            {
                 memContext = ((VariantUInt *)this)->memContext;
                 break;
-            }
 
             case varTypeUInt64:
-            {
                 memContext = ((VariantUInt64 *)this)->memContext;
                 break;
-            }
 
             case varTypeVariantList:
-            {
                 memContext = ((VariantVariantList *)this)->memContext;
                 varLstFree(((VariantVariantList *)this)->data);
                 break;
-            }
         }
 
         MEM_CONTEXT_BEGIN(memContext)
