@@ -12,7 +12,7 @@ old context and then back. Below is a simplified example:
 
         MEM_CONTEXT_PRIOR_BEGIN() <--- switch to old context so creation of the variant from the string is in old context
         {
-            result = varNewUInt64(cvtZToUInt64(strPtr(resultStr))); <--- recreates variant from the string in the old context.
+            result = varNewUInt64(cvtZToUInt64(strZ(resultStr))); <--- recreates variant from the string in the old context.
         }
         MEM_CONTEXT_PRIOR_END(); <--- switch back to the temporary context
     }
@@ -34,7 +34,6 @@ Variant type
 typedef enum
 {
     varTypeBool,
-    varTypeDouble,
     varTypeInt,
     varTypeInt64,
     varTypeKeyValue,
@@ -52,7 +51,6 @@ typedef enum
 Constructors
 ***********************************************************************************************************************************/
 Variant *varNewBool(bool data);
-Variant *varNewDbl(double data);
 Variant *varNewInt(int data);
 Variant *varNewInt64(int64_t data);
 
@@ -83,9 +81,6 @@ Getters/Setters
 bool varBool(const Variant *this);
 bool varBoolForce(const Variant *this);
 
-double varDbl(const Variant *this);
-double varDblForce(const Variant *this);
-
 int varInt(const Variant *this);
 int varIntForce(const Variant *this);
 
@@ -128,15 +123,6 @@ typedef struct VariantBoolConst
     const VARIANT_BOOL_COMMON
 } VariantBoolConst;
 
-#define VARIANT_DOUBLE_COMMON                                                                                                      \
-    double data;                                                    /* Double data */
-
-typedef struct VariantDoubleConst
-{
-    VARIANT_COMMON
-    const VARIANT_DOUBLE_COMMON
-} VariantDoubleConst;
-
 #define VARIANT_INT_COMMON                                                                                                         \
     int data;                                                       /* Signed integer data */
 
@@ -196,10 +182,6 @@ By convention all variant constant identifiers are appended with _VAR.
 #define VARBOOL(dataParam)                                                                                                         \
     ((const Variant *)&(const VariantBoolConst){.type = varTypeBool, .data = dataParam})
 
-// Create a Double Variant constant inline from a double
-#define VARDBL(dataParam)                                                                                                          \
-    ((const Variant *)&(const VariantDoubleConst){.type = varTypeDouble, .data = dataParam})
-
 // Create an Int Variant constant inline from an int
 #define VARINT(dataParam)                                                                                                          \
     ((const Variant *)&(const VariantIntConst){.type = varTypeInt, .data = dataParam})
