@@ -6,7 +6,7 @@ Wait Handler
 #include "common/debug.h"
 #include "common/log.h"
 #include "common/memContext.h"
-#include "common/object.h"
+#include "common/type/object.h"
 #include "common/wait.h"
 
 /***********************************************************************************************************************************
@@ -16,16 +16,17 @@ struct Wait
 {
     MemContext *memContext;                                         // Context that contains the wait handler
     TimeMSec waitTime;                                              // Total time to wait (in usec)
+    TimeMSec remainTime;                                            // Wait time remaining (in usec)
     TimeMSec sleepTime;                                             // Next sleep time (in usec)
     TimeMSec sleepPrevTime;                                         // Previous time slept (in usec)
     TimeMSec beginTime;                                             // Time the wait began (in epoch usec)
 };
 
+OBJECT_DEFINE_GET(Remaining, const, WAIT, TimeMSec, remainTime);
+
 OBJECT_DEFINE_FREE(WAIT);
 
-/***********************************************************************************************************************************
-New wait handler
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 Wait *
 waitNew(TimeMSec waitTime)
 {
@@ -33,7 +34,7 @@ waitNew(TimeMSec waitTime)
         FUNCTION_LOG_PARAM(TIMEMSEC, waitTime);
     FUNCTION_LOG_END();
 
-    ASSERT(waitTime >= 100 && waitTime <= 999999000);
+    ASSERT(waitTime <= 999999000);
 
     // Allocate wait object
     Wait *this = NULL;
@@ -47,6 +48,7 @@ waitNew(TimeMSec waitTime)
         {
             .memContext = MEM_CONTEXT_NEW(),
             .waitTime = waitTime,
+            .remainTime = waitTime,
         };
 
         // Calculate first sleep time -- start with 1/10th of a second for anything >= 1 second
@@ -64,9 +66,7 @@ waitNew(TimeMSec waitTime)
     FUNCTION_LOG_RETURN(WAIT, this);
 }
 
-/***********************************************************************************************************************************
-Wait and return whether the caller has more time left
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 bool
 waitMore(Wait *this)
 {
@@ -100,6 +100,7 @@ waitMore(Wait *this)
             // Store new sleep times
             this->sleepPrevTime = this->sleepTime;
             this->sleepTime = sleepNextTime;
+            this->remainTime = this->waitTime - elapsedTime;
         }
         // Else set sleep to zero so next call will return false
         else
