@@ -5,18 +5,22 @@ Configuration Load
 
 #include <string.h>
 #include <sys/stat.h>
+#include <unistd.h>
 
 #include "command/command.h"
 #include "common/compress/helper.intern.h"
+#include "common/crypto/common.h"
 #include "common/memContext.h"
 #include "common/debug.h"
 #include "common/io/io.h"
 #include "common/io/socket/common.h"
 #include "common/lock.h"
 #include "common/log.h"
-#include "config/config.h"
+#include "config/config.intern.h"
 #include "config/load.h"
 #include "config/parse.h"
+#include "storage/cifs/storage.h"
+#include "storage/posix/storage.h"
 #include "storage/helper.h"
 
 /***********************************************************************************************************************************
@@ -35,15 +39,15 @@ cfgLoadLogSetting(void)
     unsigned int logProcessMax = 1;
 
     if (cfgOptionValid(cfgOptLogLevelConsole))
-        logLevelConsole = logLevelEnum(strPtr(cfgOptionStr(cfgOptLogLevelConsole)));
+        logLevelConsole = logLevelEnum(strZ(cfgOptionStr(cfgOptLogLevelConsole)));
 
     if (cfgOptionValid(cfgOptLogLevelStderr))
     {
-        logLevelStdErr = logLevelEnum(strPtr(cfgOptionStr(cfgOptLogLevelStderr)));
+        logLevelStdErr = logLevelEnum(strZ(cfgOptionStr(cfgOptLogLevelStderr)));
     }
 
     if (cfgOptionValid(cfgOptLogLevelFile))
-        logLevelFile = logLevelEnum(strPtr(cfgOptionStr(cfgOptLogLevelFile)));
+        logLevelFile = logLevelEnum(strZ(cfgOptionStr(cfgOptLogLevelFile)));
 
     if (cfgOptionValid(cfgOptLogTimestamp))
         logTimestamp = cfgOptionBool(cfgOptLogTimestamp);
@@ -64,39 +68,76 @@ cfgLoadUpdateOption(void)
 {
     FUNCTION_LOG_VOID(logLevelTrace);
 
+    // Make sure the repo option is set for the stanza-delete command when more than one repo is configured or the first configured
+    // repo is not key 1.
+    if (!cfgCommandHelp() && cfgOptionValid(cfgOptRepo) && cfgCommand() == cfgCmdStanzaDelete &&
+        !cfgOptionTest(cfgOptRepo) && (cfgOptionGroupIdxTotal(cfgOptGrpRepo) > 1 || cfgOptionGroupIdxToKey(cfgOptGrpRepo, 0) != 1))
+    {
+        THROW_FMT(
+            OptionRequiredError,
+            "%s command requires option: " CFGOPT_REPO "\n"
+            "HINT: this command requires a specific repository to operate on",
+            cfgCommandName(cfgCommand()));
+    }
+
+    // If there is more than one repo configured
+    if (cfgOptionGroupIdxTotal(cfgOptGrpRepo) > 1)
+    {
+        for (unsigned int optionIdx = 0; optionIdx < cfgOptionGroupIdxTotal(cfgOptGrpRepo); optionIdx++)
+        {
+            // If the repo is local and either posix or cifs
+            if (!(cfgOptionIdxTest(cfgOptRepoHost, optionIdx)) &&
+                (strEq(cfgOptionIdxStr(cfgOptRepoType, optionIdx), STORAGE_POSIX_TYPE_STR) ||
+                strEq(cfgOptionIdxStr(cfgOptRepoType, optionIdx), STORAGE_CIFS_TYPE_STR)))
+            {
+                // Ensure a local repo does not have the same path as another local repo of the same type
+                for (unsigned int repoIdx = 0; repoIdx < cfgOptionGroupIdxTotal(cfgOptGrpRepo); repoIdx++)
+                {
+                    if (optionIdx != repoIdx && !(cfgOptionIdxTest(cfgOptRepoHost, repoIdx)) &&
+                        strEq(cfgOptionIdxStr(cfgOptRepoType, optionIdx), cfgOptionIdxStr(cfgOptRepoType, repoIdx)) &&
+                        strEq(cfgOptionIdxStr(cfgOptRepoPath, optionIdx), cfgOptionIdxStr(cfgOptRepoPath, repoIdx)))
+                    {
+                        THROW_FMT(
+                            OptionInvalidValueError,
+                            "local repo%u and repo%u paths are both '%s' but must be different",
+                            cfgOptionGroupIdxToKey(cfgOptGrpRepo, optionIdx), cfgOptionGroupIdxToKey(cfgOptGrpRepo, repoIdx),
+                            strZ(cfgOptionIdxStr(cfgOptRepoPath, repoIdx)));
+                    }
+                }
+            }
+        }
+    }
+
     // Set default for repo-host-cmd
-    if (cfgOptionTest(cfgOptRepoHost) && cfgOptionSource(cfgOptRepoHostCmd) == cfgSourceDefault)
+    if (cfgOptionValid(cfgOptRepoHostCmd))
         cfgOptionDefaultSet(cfgOptRepoHostCmd, VARSTR(cfgExe()));
 
     // Set default for pg-host-cmd
     if (cfgOptionValid(cfgOptPgHostCmd))
-    {
-        for (unsigned int optionIdx = 0; optionIdx < cfgOptionIndexTotal(cfgOptPgHost); optionIdx++)
-        {
-            if (cfgOptionTest(cfgOptPgHost + optionIdx) && cfgOptionSource(cfgOptPgHostCmd + optionIdx) == cfgSourceDefault)
-                cfgOptionDefaultSet(cfgOptPgHostCmd + optionIdx, VARSTR(cfgExe()));
-        }
-    }
+        cfgOptionDefaultSet(cfgOptPgHostCmd, VARSTR(cfgExe()));
 
     // Protocol timeout should be greater than db timeout
     if (cfgOptionTest(cfgOptDbTimeout) && cfgOptionTest(cfgOptProtocolTimeout) &&
-        cfgOptionDbl(cfgOptProtocolTimeout) <= cfgOptionDbl(cfgOptDbTimeout))
+        cfgOptionInt64(cfgOptProtocolTimeout) <= cfgOptionInt64(cfgOptDbTimeout))
     {
         // If protocol-timeout is default then increase it to be greater than db-timeout
         if (cfgOptionSource(cfgOptProtocolTimeout) == cfgSourceDefault)
-            cfgOptionSet(cfgOptProtocolTimeout, cfgSourceDefault, VARDBL(cfgOptionDbl(cfgOptDbTimeout) + 30));
+        {
+            cfgOptionSet(
+                cfgOptProtocolTimeout, cfgSourceDefault, VARINT64(cfgOptionInt64(cfgOptDbTimeout) + (int64_t)(30 * MSEC_PER_SEC)));
+        }
         else if (cfgOptionSource(cfgOptDbTimeout) == cfgSourceDefault)
         {
-            double dbTimeout = cfgOptionDbl(cfgOptProtocolTimeout) - 30;
+            int64_t dbTimeout = cfgOptionInt64(cfgOptProtocolTimeout) - (int64_t)(30 * MSEC_PER_SEC);
 
             // Normally the protocol time will be greater than 45 seconds so db timeout can be at least 15 seconds
-            if (dbTimeout >= 15)
+            if (dbTimeout >= (int64_t)(15 * MSEC_PER_SEC))
             {
-                cfgOptionSet(cfgOptDbTimeout, cfgSourceDefault, VARDBL(dbTimeout));
+                cfgOptionSet(cfgOptDbTimeout, cfgSourceDefault, VARINT64(dbTimeout));
             }
             // But in some test cases the protocol timeout will be very small so make db timeout half of protocol timeout
             else
-                cfgOptionSet(cfgOptDbTimeout, cfgSourceDefault, VARDBL(cfgOptionDbl(cfgOptProtocolTimeout) / 2));
+                cfgOptionSet(cfgOptDbTimeout, cfgSourceDefault, VARINT64(cfgOptionInt64(cfgOptProtocolTimeout) / 2));
         }
         else
         {
@@ -104,8 +145,8 @@ cfgLoadUpdateOption(void)
                 OptionInvalidValueError,
                 "'%s' is not valid for '" CFGOPT_PROTOCOL_TIMEOUT "' option\nHINT '" CFGOPT_PROTOCOL_TIMEOUT "' option (%s)"
                     " should be greater than '" CFGOPT_DB_TIMEOUT "' option (%s).",
-                strPtr(varStrForce(cfgOption(cfgOptProtocolTimeout))),  strPtr(varStrForce(cfgOption(cfgOptProtocolTimeout))),
-                strPtr(varStrForce(cfgOption(cfgOptDbTimeout))));
+                strZ(varStrForce(cfgOption(cfgOptProtocolTimeout))),  strZ(varStrForce(cfgOption(cfgOptProtocolTimeout))),
+                strZ(varStrForce(cfgOption(cfgOptDbTimeout))));
         }
     }
 
@@ -114,9 +155,9 @@ cfgLoadUpdateOption(void)
     {
         bool pgHostFound = false;
 
-        for (unsigned int optionIdx = 0; optionIdx < cfgOptionIndexTotal(cfgOptPgHost); optionIdx++)
+        for (unsigned int optionIdx = 0; optionIdx < cfgOptionGroupIdxTotal(cfgOptGrpPg); optionIdx++)
         {
-            if (cfgOptionTest(cfgOptPgHost + optionIdx))
+            if (cfgOptionIdxTest(cfgOptPgHost, optionIdx))
             {
                 pgHostFound = true;
                 break;
@@ -126,28 +167,27 @@ cfgLoadUpdateOption(void)
         // If a pg-host was found, see if a repo-host is configured
         if (pgHostFound == true)
         {
-            for (unsigned int optionIdx = 0; optionIdx < cfgOptionIndexTotal(cfgOptRepoHost); optionIdx++)
+            for (unsigned int optionIdx = 0; optionIdx < cfgOptionGroupIdxTotal(cfgOptGrpRepo); optionIdx++)
             {
-                if (cfgOptionTest(cfgOptRepoHost + optionIdx))
+                if (cfgOptionIdxTest(cfgOptRepoHost, optionIdx))
                     THROW_FMT(ConfigError, "pg and repo hosts cannot both be configured as remote");
             }
         }
     }
 
     // Warn when repo-retention-full is not set on a configured repo
-    if (!cfgCommandHelp() && cfgOptionValid(cfgOptRepoRetentionFullType) && cfgCommandRole() == cfgCmdRoleDefault)
+    if (!cfgCommandHelp() && cfgOptionValid(cfgOptRepoRetentionFullType))
     {
-        for (unsigned int optionIdx = 0; optionIdx < cfgOptionIndexTotal(cfgOptRepoType); optionIdx++)
+        for (unsigned int optionIdx = 0; optionIdx < cfgOptionGroupIdxTotal(cfgOptGrpRepo); optionIdx++)
         {
-            // If the repo-type is defined, then see if corresponding retention-full is set
-            if (cfgOptionTest(cfgOptRepoType + optionIdx) && !(cfgOptionTest(cfgOptRepoRetentionFull + optionIdx)))
+            if (!(cfgOptionIdxTest(cfgOptRepoRetentionFull, optionIdx)))
             {
                 LOG_WARN_FMT(
                     "option '%s' is not set for '%s=%s', the repository may run out of space"
                     "\nHINT: to retain full backups indefinitely (without warning), set option '%s' to the maximum.",
-                    cfgOptionName(cfgOptRepoRetentionFull + optionIdx), cfgOptionName(cfgOptRepoRetentionFullType + optionIdx),
-                    strPtr(cfgOptionStr(cfgOptRepoRetentionFullType + optionIdx)),
-                    cfgOptionName(cfgOptRepoRetentionFull + optionIdx));
+                    cfgOptionIdxName(cfgOptRepoRetentionFull, optionIdx), cfgOptionIdxName(cfgOptRepoRetentionFullType, optionIdx),
+                    strZ(cfgOptionIdxStr(cfgOptRepoRetentionFullType, optionIdx)),
+                    cfgOptionIdxName(cfgOptRepoRetentionFull, optionIdx));
             }
         }
     }
@@ -156,50 +196,54 @@ cfgLoadUpdateOption(void)
     if (cfgOptionValid(cfgOptRepoRetentionArchive))
     {
         // For each possible repo, check and adjust the settings as appropriate
-        for (unsigned int optionIdx = 0; optionIdx < cfgOptionIndexTotal(cfgOptRepoType); optionIdx++)
+        for (unsigned int optionIdx = 0; optionIdx < cfgOptionGroupIdxTotal(cfgOptGrpRepo); optionIdx++)
         {
-            const String *archiveRetentionType = cfgOptionStr(cfgOptRepoRetentionArchiveType + optionIdx);
+            const String *archiveRetentionType = cfgOptionIdxStr(cfgOptRepoRetentionArchiveType, optionIdx);
 
             const String *msgArchiveOff = strNewFmt(
-                "WAL segments will not be expired: option '" CFGOPT_REPO1_RETENTION_ARCHIVE_TYPE "=%s' but",
-                strPtr(archiveRetentionType));
+                "WAL segments will not be expired: option '%s=%s' but", cfgOptionIdxName(cfgOptRepoRetentionArchiveType, optionIdx),
+                strZ(archiveRetentionType));
 
             // If the archive retention is not explicitly set then determine what it should be defaulted to
-            if (!cfgOptionTest(cfgOptRepoRetentionArchive + optionIdx))
+            if (!cfgOptionIdxTest(cfgOptRepoRetentionArchive, optionIdx))
             {
                 // If repo-retention-archive-type is default (full), then if repo-retention-full is set, set the
                 // repo-retention-archive to this value when retention-full-type is 'count', else ignore archiving. If
                 // retention-full-type is 'time' then the the expire command will default the archive retention accordingly.
                 if (strEqZ(archiveRetentionType, CFGOPTVAL_TMP_REPO_RETENTION_ARCHIVE_TYPE_FULL))
                 {
-                    if (strEqZ(cfgOptionStr(cfgOptRepoRetentionFullType + optionIdx), CFGOPTVAL_TMP_REPO_RETENTION_FULL_TYPE_COUNT)
-                        && cfgOptionTest(cfgOptRepoRetentionFull + optionIdx))
+                    if (strEqZ(
+                            cfgOptionIdxStr(cfgOptRepoRetentionFullType, optionIdx),
+                            CFGOPTVAL_TMP_REPO_RETENTION_FULL_TYPE_COUNT) &&
+                        cfgOptionIdxTest(cfgOptRepoRetentionFull, optionIdx))
                     {
-                        cfgOptionSet(cfgOptRepoRetentionArchive + optionIdx, cfgSourceDefault,
-                            VARUINT(cfgOptionUInt(cfgOptRepoRetentionFull + optionIdx)));
+                        cfgOptionIdxSet(cfgOptRepoRetentionArchive, optionIdx, cfgSourceDefault,
+                            VARUINT(cfgOptionIdxUInt(cfgOptRepoRetentionFull, optionIdx)));
                     }
                 }
                 else if (strEqZ(archiveRetentionType, CFGOPTVAL_TMP_REPO_RETENTION_ARCHIVE_TYPE_DIFF))
                 {
                     // if repo-retention-diff is set then user must have set it
-                    if (cfgOptionTest(cfgOptRepoRetentionDiff + optionIdx))
+                    if (cfgOptionIdxTest(cfgOptRepoRetentionDiff, optionIdx))
                     {
-                        cfgOptionSet(cfgOptRepoRetentionArchive + optionIdx, cfgSourceDefault,
-                            VARUINT(cfgOptionUInt(cfgOptRepoRetentionDiff + optionIdx)));
+                        cfgOptionIdxSet(cfgOptRepoRetentionArchive, optionIdx, cfgSourceDefault,
+                            VARUINT(cfgOptionIdxUInt(cfgOptRepoRetentionDiff, optionIdx)));
                     }
                     else
                     {
-                        LOG_WARN_FMT("%s neither option '%s' nor option '%s' is set", strPtr(msgArchiveOff),
-                            cfgOptionName(cfgOptRepoRetentionArchive + optionIdx),
-                            cfgOptionName(cfgOptRepoRetentionDiff + optionIdx));
+                        LOG_WARN_FMT(
+                            "%s neither option '%s' nor option '%s' is set", strZ(msgArchiveOff),
+                            cfgOptionIdxName(cfgOptRepoRetentionArchive, optionIdx),
+                            cfgOptionIdxName(cfgOptRepoRetentionDiff, optionIdx));
                     }
                 }
                 else
                 {
                     CHECK(strEqZ(archiveRetentionType, CFGOPTVAL_TMP_REPO_RETENTION_ARCHIVE_TYPE_INCR));
 
-                    LOG_WARN_FMT("%s option '%s' is not set", strPtr(msgArchiveOff),
-                        cfgOptionName(cfgOptRepoRetentionArchive + optionIdx));
+                    LOG_WARN_FMT(
+                        "%s option '%s' is not set", strZ(msgArchiveOff),
+                        cfgOptionIdxName(cfgOptRepoRetentionArchive, optionIdx));
                 }
             }
             else
@@ -208,30 +252,33 @@ cfgLoadUpdateOption(void)
                 // corresponding setting is UNDEF since UNDEF means backups will not be expired but they should be in the
                 // practice of setting this value even though expiring the archive itself is OK and will be performed.
                 if ((strEqZ(archiveRetentionType, CFGOPTVAL_TMP_REPO_RETENTION_ARCHIVE_TYPE_DIFF)) &&
-                    (!cfgOptionTest(cfgOptRepoRetentionDiff + optionIdx)))
+                    (!cfgOptionIdxTest(cfgOptRepoRetentionDiff, optionIdx)))
                 {
                     LOG_WARN_FMT("option '%s' is not set for '%s=%s'\n"
                         "HINT: to retain differential backups indefinitely (without warning), set option '%s' to the maximum.",
-                        cfgOptionName(cfgOptRepoRetentionDiff + optionIdx),
-                        cfgOptionName(cfgOptRepoRetentionArchiveType + optionIdx),
+                        cfgOptionIdxName(cfgOptRepoRetentionDiff, optionIdx),
+                        cfgOptionIdxName(cfgOptRepoRetentionArchiveType, optionIdx),
                         CFGOPTVAL_TMP_REPO_RETENTION_ARCHIVE_TYPE_DIFF,
-                        cfgOptionName(cfgOptRepoRetentionDiff + optionIdx));
+                        cfgOptionIdxName(cfgOptRepoRetentionDiff, optionIdx));
                 }
             }
         }
     }
 
-    // Error if an S3 bucket name contains dots
-    if (cfgOptionTest(cfgOptRepoS3Bucket) && cfgOptionBool(cfgOptRepoS3VerifyTls) &&
-        strChr(cfgOptionStr(cfgOptRepoS3Bucket), '.') != -1)
+    // For each possible repo, error if an S3 bucket name contains dots
+    for (unsigned int repoIdx = 0; repoIdx < cfgOptionGroupIdxTotal(cfgOptGrpRepo); repoIdx++)
     {
-        THROW_FMT(
-            OptionInvalidValueError,
-            "'%s' is not valid for option '" CFGOPT_REPO1_S3_BUCKET "'"
-                "\nHINT: RFC-2818 forbids dots in wildcard matches."
-                "\nHINT: TLS/SSL verification cannot proceed with this bucket name."
-                "\nHINT: remove dots from the bucket name.",
-            strPtr(cfgOptionStr(cfgOptRepoS3Bucket)));
+        if (cfgOptionIdxTest(cfgOptRepoS3Bucket, repoIdx) && cfgOptionIdxBool(cfgOptRepoStorageVerifyTls, repoIdx) &&
+            strChr(cfgOptionIdxStr(cfgOptRepoS3Bucket, repoIdx), '.') != -1)
+        {
+            THROW_FMT(
+                OptionInvalidValueError,
+                "'%s' is not valid for option '%s'"
+                    "\nHINT: RFC-2818 forbids dots in wildcard matches."
+                    "\nHINT: TLS/SSL verification cannot proceed with this bucket name."
+                    "\nHINT: remove dots from the bucket name.",
+                strZ(cfgOptionIdxStr(cfgOptRepoS3Bucket, repoIdx)), cfgOptionIdxName(cfgOptRepoS3Bucket, repoIdx));
+        }
     }
 
     // Check/update compress-type if compress is valid. There should be no references to the compress option outside this block.
@@ -253,7 +300,7 @@ cfgLoadUpdateOption(void)
         }
 
         // Now invalidate compress so it can't be used and won't be passed to child processes
-        cfgOptionValidSet(cfgOptCompress, false);
+        cfgOptionInvalidate(cfgOptCompress);
         cfgOptionSet(cfgOptCompress, cfgSourceDefault, NULL);
     }
 
@@ -282,8 +329,8 @@ cfgLoadLogFile(void)
         {
             // Construct log filename prefix
             String *logFile = strNewFmt(
-                "%s/%s-%s", strPtr(cfgOptionStr(cfgOptLogPath)),
-                cfgOptionTest(cfgOptStanza) ? strPtr(cfgOptionStr(cfgOptStanza)): "all", cfgCommandName(cfgCommand()));
+                "%s/%s-%s", strZ(cfgOptionStr(cfgOptLogPath)),
+                cfgOptionTest(cfgOptStanza) ? strZ(cfgOptionStr(cfgOptStanza)): "all", cfgCommandName(cfgCommand()));
 
             // ??? Append async for local/remote archive async commands.  It would be good to find a more generic way to do this in
             // case the async role is added to more commands.
@@ -295,7 +342,7 @@ cfgLoadLogFile(void)
 
             // Add command role if it is not default
             if (cfgCommandRole() != cfgCmdRoleDefault)
-                strCatFmt(logFile, "-%s", strPtr(cfgCommandRoleStr(cfgCommandRole())));
+                strCatFmt(logFile, "-%s", strZ(cfgCommandRoleStr(cfgCommandRole())));
 
             // Add process id if local or remote role
             if (cfgCommandRole() == cfgCmdRoleLocal || cfgCommandRole() == cfgCmdRoleRemote)
@@ -305,7 +352,7 @@ cfgLoadLogFile(void)
             strCatZ(logFile, ".log");
 
             // Attempt to open log file
-            if (!logFileSet(strPtr(logFile)))
+            if (!logFileSet(strZ(logFile)))
                 cfgOptionSet(cfgOptLogLevelFile, cfgSourceParam, varNewStrZ("off"));
         }
         MEM_CONTEXT_TEMP_END();
@@ -324,7 +371,7 @@ cfgLoad(unsigned int argListSize, const char *argList[])
     MEM_CONTEXT_TEMP_BEGIN()
     {
         // Parse config from command line and config file
-        configParse(argListSize, argList, true);
+        configParse(storageLocal(), argListSize, argList, true);
 
         // Initialize dry-run mode for storage when valid for the current command
         storageHelperDryRunInit(cfgOptionValid(cfgOptDryRun) && cfgOptionBool(cfgOptDryRun));
@@ -356,17 +403,32 @@ cfgLoad(unsigned int argListSize, const char *argList[])
 
             // Set IO timeout
             if (cfgOptionValid(cfgOptIoTimeout))
-                ioTimeoutMsSet((TimeMSec)(cfgOptionDbl(cfgOptIoTimeout) * MSEC_PER_SEC));
+                ioTimeoutMsSet(cfgOptionUInt64(cfgOptIoTimeout));
 
             // Open the log file if this command logs to a file
             cfgLoadLogFile();
 
+            // Create the exec-id used to identify all locals and remotes spawned by this process. This allows lock contention to be
+            // easily resolved and makes it easier to associate processes from various logs.
+            if (cfgOptionValid(cfgOptExecId) && !cfgOptionTest(cfgOptExecId))
+            {
+                // Generate some random bytes
+                uint32_t execRandom;
+                cryptoRandomBytes((unsigned char *)&execRandom, sizeof(execRandom));
+
+                // Format a string with the pid and the random bytes to serve as the exec id
+                cfgOptionSet(cfgOptExecId, cfgSourceParam, VARSTR(strNewFmt("%d-%08x", getpid(), execRandom)));
+            }
+
             // Begin the command
-            cmdBegin(true);
+            cmdBegin();
 
             // Acquire a lock if this command requires a lock
             if (cfgLockRequired() && !cfgCommandHelp())
-                lockAcquire(cfgOptionStr(cfgOptLockPath), cfgOptionStr(cfgOptStanza), cfgLockType(), 0, true);
+            {
+                lockAcquire(
+                    cfgOptionStr(cfgOptLockPath), cfgOptionStr(cfgOptStanza), cfgOptionStr(cfgOptExecId), cfgLockType(), 0, true);
+            }
 
             // Update options that have complex rules
             cfgLoadUpdateOption();
