@@ -11,9 +11,13 @@ Configuration Load
 /***********************************************************************************************************************************
 Functions
 ***********************************************************************************************************************************/
+// Load the configuration
 void cfgLoad(unsigned int argListSize, const char *argList[]);
-void cfgLoadLogSetting(void);
+
+// Attempt to set the log file and turn file logging off if the file cannot be opened
 void cfgLoadLogFile(void);
+
+// Update options that have complex rules
 void cfgLoadUpdateOption(void);
 
 #endif
