@@ -219,6 +219,19 @@ dbOpen(Db *this)
                 " (select setting from pg_catalog.pg_settings where name = 'archive_mode')::text,"
                 " (select setting from pg_catalog.pg_settings where name = 'archive_command')::text"));
 
+        // Check that none of the return values are null, which indicates the user cannot select some rows in pg_settings
+        for (unsigned int columnIdx = 0; columnIdx < varLstSize(row); columnIdx++)
+        {
+            if (varLstGet(row, columnIdx) == NULL)
+            {
+                THROW(
+                    DbQueryError,
+                    "unable to select some rows from pg_settings\n"
+                        "HINT: is the backup running as the postgres user?\n"
+                        "HINT: is the pg_read_all_settings role assigned for " PG_NAME " >= " PG_VERSION_10_STR "?");
+            }
+        }
+
         // Strip the minor version off since we don't need it.  In the future it might be a good idea to warn users when they are
         // running an old minor version.
         this->pgVersion = varUIntForce(varLstGet(row, 0)) / 100 * 100;
@@ -235,7 +248,7 @@ dbOpen(Db *this)
 
         // Set application name to help identify the backup session
         if (this->pgVersion >= PG_VERSION_APPLICATION_NAME)
-            dbExec(this, strNewFmt("set application_name = '%s'", strPtr(this->applicationName)));
+            dbExec(this, strNewFmt("set application_name = '%s'", strZ(this->applicationName)));
 
         // There is no need to have parallelism enabled in a backup session. In particular, 9.6 marks pg_stop_backup() as
         // parallel-safe but an error will be thrown if pg_stop_backup() is run in a worker.
@@ -262,7 +275,7 @@ dbBackupStartQuery(unsigned int pgVersion, bool startFast)
         "select lsn::text as lsn,\n"
         "       pg_catalog.pg_%sfile_name(lsn)::text as wal_segment_name\n"
         "  from pg_catalog.pg_start_backup('" PROJECT_NAME " backup started at ' || current_timestamp",
-        strPtr(pgWalName(pgVersion)));
+        strZ(pgWalName(pgVersion)));
 
     // Start backup after immediate checkpoint
     if (startFast)
@@ -283,11 +296,6 @@ dbBackupStartQuery(unsigned int pgVersion, bool startFast)
     FUNCTION_TEST_RETURN(result);
 }
 
-#define FUNCTION_LOG_DB_BACKUP_START_RESULT_TYPE                                                                                   \
-    DbBackupStartResult
-#define FUNCTION_LOG_DB_BACKUP_START_RESULT_FORMAT(value, buffer, bufferSize)                                                      \
-    objToLog(&value, "DbBackupStartResult", buffer, bufferSize)
-
 DbBackupStartResult
 dbBackupStart(Db *this, bool startFast, bool stopAuto)
 {
@@ -346,7 +354,7 @@ dbBackupStart(Db *this, bool startFast, bool stopAuto)
     }
     MEM_CONTEXT_TEMP_END();
 
-    FUNCTION_LOG_RETURN(DB_BACKUP_START_RESULT, result);
+    FUNCTION_LOG_RETURN_STRUCT(result);
 }
 /**********************************************************************************************************************************/
 // Helper to build stop backup query
@@ -361,7 +369,7 @@ dbBackupStopQuery(unsigned int pgVersion)
     String *result = strNewFmt(
         "select lsn::text as lsn,\n"
         "       pg_catalog.pg_%sfile_name(lsn)::text as wal_segment_name",
-        strPtr(pgWalName(pgVersion)));
+        strZ(pgWalName(pgVersion)));
 
     // For PostgreSQL >= 9.6 the backup label and tablespace map are returned from pg_stop_backup
     if (pgVersion >= PG_VERSION_96)
@@ -396,11 +404,6 @@ dbBackupStopQuery(unsigned int pgVersion)
     FUNCTION_TEST_RETURN(result);
 }
 
-#define FUNCTION_LOG_DB_BACKUP_STOP_RESULT_TYPE                                                                                   \
-    DbBackupStopResult
-#define FUNCTION_LOG_DB_BACKUP_STOP_RESULT_FORMAT(value, buffer, bufferSize)                                                      \
-    objToLog(&value, "DbBackupStopResult", buffer, bufferSize)
-
 DbBackupStopResult
 dbBackupStop(Db *this)
 {
@@ -439,7 +442,7 @@ dbBackupStop(Db *this)
     }
     MEM_CONTEXT_TEMP_END();
 
-    FUNCTION_LOG_RETURN(DB_BACKUP_STOP_RESULT, result);
+    FUNCTION_LOG_RETURN_STRUCT(result);
 }
 
 /**********************************************************************************************************************************/
@@ -493,9 +496,9 @@ dbReplayWait(Db *this, const String *targetLsn, TimeMSec timeout)
         // Loop until lsn has been reached or timeout
         Wait *wait = waitNew(timeout);
         bool targetReached = false;
-        const char *lsnName = strPtr(pgLsnName(dbPgVersion(this)));
+        const char *lsnName = strZ(pgLsnName(dbPgVersion(this)));
         const String *replayLsnFunction = strNewFmt(
-            "pg_catalog.pg_last_%s_replay_%s()", strPtr(pgWalName(dbPgVersion(this))), lsnName);
+            "pg_catalog.pg_last_%s_replay_%s()", strZ(pgWalName(dbPgVersion(this))), lsnName);
         const String *replayLsn = NULL;
 
         do
@@ -504,21 +507,22 @@ dbReplayWait(Db *this, const String *targetLsn, TimeMSec timeout)
             String *query = strNewFmt(
                 "select replayLsn::text,\n"
                 "       (replayLsn > '%s')::bool as targetReached",
-                strPtr(targetLsn));
+                strZ(targetLsn));
 
             if (replayLsn != NULL)
             {
                 strCatFmt(
                     query,
                     ",\n"
-                    "       (replayLsn > '%s')::bool as replayProgress", strPtr(replayLsn));
+                    "       (replayLsn > '%s')::bool as replayProgress",
+                    strZ(replayLsn));
             }
 
             strCatFmt(
                 query,
                 "\n"
                 "  from %s as replayLsn",
-                strPtr(replayLsnFunction));
+                strZ(replayLsnFunction));
 
             // Execute the query and get replayLsn
             VariantList *row = dbQueryRow(this, query);
@@ -532,7 +536,7 @@ dbReplayWait(Db *this, const String *targetLsn, TimeMSec timeout)
                     ArchiveTimeoutError,
                     "unable to query replay lsn on the standby using '%s'\n"
                     "HINT: Is this a standby?",
-                    strPtr(replayLsnFunction));
+                    strZ(replayLsnFunction));
             }
 
             targetReached = varBool(varLstGet(row, 1));
@@ -549,8 +553,8 @@ dbReplayWait(Db *this, const String *targetLsn, TimeMSec timeout)
         if (!targetReached)
         {
             THROW_FMT(
-                ArchiveTimeoutError, "timeout before standby replayed to %s - only reached %s", strPtr(targetLsn),
-                strPtr(replayLsn));
+                ArchiveTimeoutError, "timeout before standby replayed to %s - only reached %s", strZ(targetLsn),
+                strZ(replayLsn));
         }
 
         // Perform a checkpoint
@@ -568,7 +572,7 @@ dbReplayWait(Db *this, const String *targetLsn, TimeMSec timeout)
                 "select (checkpoint_%s > '%s')::bool as targetReached,\n"
                 "       checkpoint_%s::text as checkpointLsn\n"
                 "  from pg_catalog.pg_control_checkpoint()",
-                lsnName, strPtr(targetLsn), lsnName);
+                lsnName, strZ(targetLsn), lsnName);
 
             // Execute query
             VariantList *row = dbQueryRow(this, query);
@@ -579,7 +583,7 @@ dbReplayWait(Db *this, const String *targetLsn, TimeMSec timeout)
                 THROW_FMT(
                     ArchiveTimeoutError,
                     "the checkpoint lsn %s is less than the target lsn %s even though the replay lsn is %s",
-                    strPtr(varStr(varLstGet(row, 1))), strPtr(targetLsn), strPtr(replayLsn));
+                    strZ(varStr(varLstGet(row, 1))), strZ(targetLsn), strZ(replayLsn));
             }
         }
     }
@@ -631,7 +635,7 @@ dbWalSwitch(Db *this)
             dbQueryColumn(this, STRDEF("select pg_catalog.pg_create_restore_point('" PROJECT_NAME " Archive Check')::text"));
 
         // Request a WAL segment switch
-        const char *walName = strPtr(pgWalName(this->pgVersion));
+        const char *walName = strZ(pgWalName(this->pgVersion));
         const String *walFileName = varStr(
             dbQueryColumn(this, strNewFmt("select pg_catalog.pg_%sfile_name(pg_catalog.pg_switch_%s())::text", walName, walName)));
 
@@ -704,6 +708,6 @@ String *
 dbToLog(const Db *this)
 {
     return strNewFmt(
-        "{client: %s, remoteClient: %s}", this->client == NULL ? NULL_Z : strPtr(pgClientToLog(this->client)),
-        this->remoteClient == NULL ? NULL_Z : strPtr(protocolClientToLog(this->remoteClient)));
+        "{client: %s, remoteClient: %s}", this->client == NULL ? NULL_Z : strZ(pgClientToLog(this->client)),
+        this->remoteClient == NULL ? NULL_Z : strZ(protocolClientToLog(this->remoteClient)));
 }
