@@ -10,17 +10,15 @@ Database Helper
 #include "protocol/helper.h"
 #include "version.h"
 
-/***********************************************************************************************************************************
-Get specified cluster
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 static Db *
-dbGetId(unsigned int pgId)
+dbGetIdx(unsigned int pgIdx)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
-        FUNCTION_LOG_PARAM(UINT, pgId);
+        FUNCTION_LOG_PARAM(UINT, pgIdx);
     FUNCTION_LOG_END();
 
-    ASSERT(pgId > 0);
+    ASSERT(pgIdx < cfgOptionGroupIdxTotal(cfgOptGrpPg));
 
     Db *result = NULL;
 
@@ -28,16 +26,17 @@ dbGetId(unsigned int pgId)
     {
         const String *applicationName = strNewFmt(PROJECT_NAME " [%s]", cfgCommandName(cfgCommand()));
 
-        if (pgIsLocal(pgId))
+        if (pgIsLocal(pgIdx))
         {
             result = dbNew(
                 pgClientNew(
-                    cfgOptionStr(cfgOptPgSocketPath + pgId - 1), cfgOptionUInt(cfgOptPgPort + pgId - 1), PG_DB_POSTGRES_STR,
-                    cfgOptionStr(cfgOptPgUser + pgId - 1), (TimeMSec)(cfgOptionDbl(cfgOptDbTimeout) * MSEC_PER_SEC)),
+                    cfgOptionIdxStrNull(cfgOptPgSocketPath, pgIdx), cfgOptionIdxUInt(cfgOptPgPort, pgIdx),
+                    cfgOptionIdxStr(cfgOptPgDatabase, pgIdx), cfgOptionIdxStrNull(cfgOptPgUser, pgIdx),
+                    cfgOptionUInt64(cfgOptDbTimeout)),
                 NULL, applicationName);
         }
         else
-            result = dbNew(NULL, protocolRemoteGet(protocolStorageTypePg, pgId), applicationName);
+            result = dbNew(NULL, protocolRemoteGet(protocolStorageTypePg, pgIdx), applicationName);
 
         dbMove(result, memContextPrior());
     }
@@ -65,74 +64,73 @@ dbGet(bool primaryOnly, bool primaryRequired, bool standbyRequired)
     MEM_CONTEXT_TEMP_BEGIN()
     {
         // Loop through to look for primary and standby (if required)
-        for (unsigned int pgIdx = 0; pgIdx < cfgOptionIndexTotal(cfgOptPgPath); pgIdx++)
+        for (unsigned int pgIdx = 0; pgIdx < cfgOptionGroupIdxTotal(cfgOptGrpPg); pgIdx++)
         {
-            if (cfgOptionTest(cfgOptPgHost + pgIdx) || cfgOptionTest(cfgOptPgPath + pgIdx))
-            {
-                Db *db = NULL;
-                bool standby = false;
+            Db *db = NULL;
+            bool standby = false;
 
+            TRY_BEGIN()
+            {
+                db = dbGetIdx(pgIdx);
+
+                // This needs to be nested because db can be reset to NULL on an error in the outer try but we need the pointer
+                // to be able to free it.
                 TRY_BEGIN()
                 {
-                    db = dbGetId(pgIdx + 1);
-
-                    // This needs to be nested because db can be reset to NULL on an error in the outer try but we need the pointer
-                    // to be able to free it.
-                    TRY_BEGIN()
-                    {
-                        dbOpen(db);
-                        standby = dbIsStandby(db);
-                    }
-                    CATCH_ANY()
-                    {
-                        dbFree(db);
-                        RETHROW();
-                    }
-                    TRY_END();
+                    dbOpen(db);
+                    standby = dbIsStandby(db);
                 }
                 CATCH_ANY()
                 {
-                    LOG_WARN_FMT("unable to check pg-%u: [%s] %s", pgIdx + 1, errorTypeName(errorType()), errorMessage());
-                    db = NULL;
+                    dbFree(db);
+                    RETHROW();
                 }
                 TRY_END();
+            }
+            CATCH_ANY()
+            {
+                LOG_WARN_FMT(
+                    "unable to check pg-%u: [%s] %s", cfgOptionGroupIdxToKey(cfgOptGrpPg, pgIdx), errorTypeName(errorType()),
+                    errorMessage());
+                db = NULL;
+            }
+            TRY_END();
 
-                // Was the connection successful
-                if (db != NULL)
+            // Was the connection successful
+            if (db != NULL)
+            {
+                // Is this cluster a standby
+                if (standby)
                 {
-                    // Is this cluster a standby
-                    if (standby)
+                    // If a standby has not already been found then assign it
+                    if (result.standby == NULL && !primaryOnly)
                     {
-                        // If a standby has not already been found then assign it
-                        if (result.standbyId == 0 && !primaryOnly)
-                        {
-                            result.standbyId = pgIdx + 1;
-                            result.standby = db;
-                        }
-                        // Else close the connection since we don't need it
-                        else
-                            dbFree(db);
+                        result.standbyIdx = pgIdx;
+                        result.standby = db;
                     }
-                    // Else is a primary
+                    // Else close the connection since we don't need it
                     else
-                    {
-                        // Error if more than one primary was found
-                        if (result.primaryId != 0)
-                            THROW(DbConnectError, "more than one primary cluster found");
+                        dbFree(db);
+                }
+                // Else is a primary
+                else
+                {
+                    // Error if more than one primary was found
+                    if (result.primary != NULL)
+                        THROW(DbConnectError, "more than one primary cluster found");
 
-                        result.primaryId = pgIdx + 1;
-                        result.primary = db;
-                    }
+                    result.primaryIdx = pgIdx;
+                    result.primary = db;
                 }
             }
         }
 
         // Error if no primary was found
-        if (result.primaryId == 0 && primaryRequired)
+        if (result.primary == NULL && primaryRequired)
             THROW(DbConnectError, "unable to find primary cluster - cannot proceed");
 
         // Error if no standby was found
-        if (result.standbyId == 0 && standbyRequired)
+        if (result.standby == NULL && standbyRequired)
             THROW(DbConnectError, "unable to find standby cluster - cannot proceed");
 
         dbMove(result.primary, memContextPrior());
@@ -140,5 +138,5 @@ dbGet(bool primaryOnly, bool primaryRequired, bool standbyRequired)
     }
     MEM_CONTEXT_TEMP_END();
 
-    FUNCTION_LOG_RETURN(DB_GET_RESULT, result);
+    FUNCTION_LOG_RETURN_STRUCT(result);
 }
