@@ -12,8 +12,10 @@ Archive Info Handler
 #include "common/debug.h"
 #include "common/log.h"
 #include "common/ini.h"
+#include "common/io/bufferWrite.h"
+#include "common/io/io.h"
 #include "common/memContext.h"
-#include "common/object.h"
+#include "common/type/object.h"
 #include "info/infoArchive.h"
 #include "info/infoPg.h"
 #include "postgres/interface.h"
@@ -35,6 +37,7 @@ struct InfoArchive
     InfoPg *infoPg;                                                 // Contents of the DB data
 };
 
+OBJECT_DEFINE_MOVE(INFO_ARCHIVE);
 OBJECT_DEFINE_FREE(INFO_ARCHIVE);
 
 /***********************************************************************************************************************************
@@ -55,9 +58,7 @@ infoArchiveNewInternal(void)
     FUNCTION_TEST_RETURN(this);
 }
 
-/***********************************************************************************************************************************
-Create new object without loading it from a file
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 InfoArchive *
 infoArchiveNew(unsigned int pgVersion, uint64_t pgSystemId, const String *cipherPassSub)
 {
@@ -84,10 +85,8 @@ infoArchiveNew(unsigned int pgVersion, uint64_t pgSystemId, const String *cipher
     FUNCTION_LOG_RETURN(INFO_ARCHIVE, this);
 }
 
-/***********************************************************************************************************************************
-Create new object and load contents from a file
-***********************************************************************************************************************************/
-static InfoArchive *
+/**********************************************************************************************************************************/
+InfoArchive *
 infoArchiveNewLoad(IoRead *read)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
@@ -108,9 +107,7 @@ infoArchiveNewLoad(IoRead *read)
     FUNCTION_LOG_RETURN(INFO_ARCHIVE, this);
 }
 
-/***********************************************************************************************************************************
-Given a backrest history id and postgres systemId and version, return the archiveId of the best match
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 const String *
 infoArchiveIdHistoryMatch(
     const InfoArchive *this, const unsigned int historyId, const unsigned int pgVersion, const uint64_t pgSystemId)
@@ -161,7 +158,7 @@ infoArchiveIdHistoryMatch(
         THROW_FMT(
             ArchiveMismatchError,
             "unable to retrieve the archive id for database version '%s' and system-id '%" PRIu64 "'",
-            strPtr(pgVersionToStr(pgVersion)), pgSystemId);
+            strZ(pgVersionToStr(pgVersion)), pgSystemId);
     }
 
     FUNCTION_LOG_RETURN(STRING, archiveId);
@@ -190,9 +187,7 @@ infoArchiveSave(InfoArchive *this, IoWrite *write)
     FUNCTION_LOG_RETURN_VOID();
 }
 
-/***********************************************************************************************************************************
-Get the current archive id
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 const String *
 infoArchiveId(const InfoArchive *this)
 {
@@ -205,9 +200,7 @@ infoArchiveId(const InfoArchive *this)
     FUNCTION_TEST_RETURN(infoPgArchiveId(this->infoPg, infoPgDataCurrentId(this->infoPg)));
 }
 
-/***********************************************************************************************************************************
-Return the cipher passphrase
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 const String *
 infoArchiveCipherPass(const InfoArchive *this)
 {
@@ -220,9 +213,7 @@ infoArchiveCipherPass(const InfoArchive *this)
     FUNCTION_TEST_RETURN(infoPgCipherPass(this->infoPg));
 }
 
-/***********************************************************************************************************************************
-Get PostgreSQL info
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 InfoPg *
 infoArchivePg(const InfoArchive *this)
 {
@@ -235,9 +226,7 @@ infoArchivePg(const InfoArchive *this)
     FUNCTION_TEST_RETURN(this->infoPg);
 }
 
-/***********************************************************************************************************************************
-Set the infoPg data
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 InfoArchive *
 infoArchivePgSet(InfoArchive *this, unsigned int pgVersion, uint64_t pgSystemId)
 {
@@ -249,14 +238,12 @@ infoArchivePgSet(InfoArchive *this, unsigned int pgVersion, uint64_t pgSystemId)
 
     ASSERT(this != NULL);
 
-    this->infoPg = infoPgSet(this->infoPg, infoPgArchive, pgVersion, pgSystemId);
+    this->infoPg = infoPgSet(this->infoPg, infoPgArchive, pgVersion, pgSystemId, 0);
 
     FUNCTION_LOG_RETURN(INFO_ARCHIVE, this);
 }
 
-/***********************************************************************************************************************************
-Helper function to load archive info files
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 typedef struct InfoArchiveLoadFileData
 {
     MemContext *memContext;                                         // Mem context
@@ -283,7 +270,7 @@ infoArchiveLoadFileCallback(void *data, unsigned int try)
     if (try < 2)
     {
         // Construct filename based on try
-        const String *fileName = try == 0 ? loadData->fileName : strNewFmt("%s" INFO_COPY_EXT, strPtr(loadData->fileName));
+        const String *fileName = try == 0 ? loadData->fileName : strNewFmt("%s" INFO_COPY_EXT, strZ(loadData->fileName));
 
         // Attempt to load the file
         IoRead *read = storageReadIo(storageNewReadP(loadData->storage, fileName));
@@ -325,7 +312,7 @@ infoArchiveLoadFile(const Storage *storage, const String *fileName, CipherType c
 
     MEM_CONTEXT_TEMP_BEGIN()
     {
-        const char *fileNamePath = strPtr(storagePathP(storage, fileName));
+        const char *fileNamePath = strZ(storagePathP(storage, fileName));
 
         TRY_BEGIN()
         {
@@ -351,9 +338,7 @@ infoArchiveLoadFile(const Storage *storage, const String *fileName, CipherType c
     FUNCTION_LOG_RETURN(INFO_ARCHIVE, data.infoArchive);
 }
 
-/***********************************************************************************************************************************
-Helper function to save archive info files
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void
 infoArchiveSaveFile(
     InfoArchive *infoArchive, const Storage *storage, const String *fileName, CipherType cipherType, const String *cipherPass)
@@ -373,14 +358,15 @@ infoArchiveSaveFile(
 
     MEM_CONTEXT_TEMP_BEGIN()
     {
-        // Save the file
-        IoWrite *write = storageWriteIo(storageNewWriteP(storage, fileName));
+        // Write output into a buffer since it needs to be saved to storage twice
+        Buffer *buffer = bufNew(ioBufferSize());
+        IoWrite *write = ioBufferWriteNew(buffer);
         cipherBlockFilterGroupAdd(ioWriteFilterGroup(write), cipherType, cipherModeEncrypt, cipherPass);
         infoArchiveSave(infoArchive, write);
 
-        // Make a copy of the file
-        storageCopy(
-            storageNewReadP(storage, fileName), storageNewWriteP(storage, strNewFmt("%s" INFO_COPY_EXT, strPtr(fileName))));
+        // Save the file and make a copy
+        storagePutP(storageNewWriteP(storage, fileName), buffer);
+        storagePutP(storageNewWriteP(storage, strNewFmt("%s" INFO_COPY_EXT, strZ(fileName))), buffer);
     }
     MEM_CONTEXT_TEMP_END();
 
