@@ -12,6 +12,8 @@ Backup Info Handler
 #include "common/crypto/cipherBlock.h"
 #include "common/debug.h"
 #include "common/ini.h"
+#include "common/io/bufferWrite.h"
+#include "common/io/io.h"
 #include "common/log.h"
 #include "common/memContext.h"
 #include "common/regExp.h"
@@ -772,13 +774,15 @@ infoBackupSaveFile(
 
     MEM_CONTEXT_TEMP_BEGIN()
     {
-        // Save the file
-        IoWrite *write = storageWriteIo(storageNewWriteP(storage, fileName));
+        // Write output into a buffer since it needs to be saved to storage twice
+        Buffer *buffer = bufNew(ioBufferSize());
+        IoWrite *write = ioBufferWriteNew(buffer);
         cipherBlockFilterGroupAdd(ioWriteFilterGroup(write), cipherType, cipherModeEncrypt, cipherPass);
         infoBackupSave(infoBackup, write);
 
-        // Make a copy of the file
-        storageCopy(storageNewReadP(storage, fileName), storageNewWriteP(storage, strNewFmt("%s" INFO_COPY_EXT, strZ(fileName))));
+        // Save the file and make a copy
+        storagePutP(storageNewWriteP(storage, fileName), buffer);
+        storagePutP(storageNewWriteP(storage, strNewFmt("%s" INFO_COPY_EXT, strZ(fileName))), buffer);
     }
     MEM_CONTEXT_TEMP_END();
 
