@@ -64,7 +64,7 @@ infoPgNewInternal(InfoPgType type)
     {
         .memContext = memContextCurrent(),
         .type = type,
-        .history = lstNew(sizeof(InfoPgData)),
+        .history = lstNewP(sizeof(InfoPgData)),
     };
 
     FUNCTION_TEST_RETURN(this);
@@ -101,13 +101,13 @@ typedef struct InfoPgLoadData
 } InfoPgLoadData;
 
 static void
-infoPgLoadCallback(void *data, const String *section, const String *key, const String *value)
+infoPgLoadCallback(void *data, const String *section, const String *key, const Variant *value)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM_P(VOID, data);
         FUNCTION_TEST_PARAM(STRING, section);
         FUNCTION_TEST_PARAM(STRING, key);
-        FUNCTION_TEST_PARAM(STRING, value);
+        FUNCTION_TEST_PARAM(VARIANT, value);
     FUNCTION_TEST_END();
 
     ASSERT(data != NULL);
@@ -121,19 +121,20 @@ infoPgLoadCallback(void *data, const String *section, const String *key, const S
     if (strEq(section, INFO_SECTION_DB_STR))
     {
         if (strEq(key, INFO_KEY_DB_ID_STR))
-            loadData->currentId = jsonToUInt(value);
+            loadData->currentId = varUIntForce(value);
     }
     // Process db:history section
     else if (strEq(section, INFO_SECTION_DB_HISTORY_STR))
     {
-        // Load JSON loadData into a KeyValue
-        const KeyValue *pgDataKv = jsonToKv(value);
-
         // Get db values that are common to all info files
+        const KeyValue *pgDataKv = varKv(value);
+
         InfoPgData infoPgData =
         {
-            .id = cvtZToUInt(strPtr(key)),
+            .id = cvtZToUInt(strZ(key)),
             .version = pgVersionFromStr(varStr(kvGet(pgDataKv, INFO_KEY_DB_VERSION_VAR))),
+            .catalogVersion =
+                loadData->infoPg->type == infoPgBackup ? varUIntForce(kvGet(pgDataKv, INFO_KEY_DB_CATALOG_VERSION_VAR)) : 0,
 
             // This is different in archive.info due to a typo that can't be fixed without a format version bump
             .systemId = varUInt64Force(
@@ -184,7 +185,7 @@ infoPgNewLoad(IoRead *read, InfoPgType type, InfoLoadNewCallback *callbackFuncti
         this->info = infoNewLoad(read, infoPgLoadCallback, &loadData);
 
         // History must include at least one item or the file is corrupt
-        CHECK(lstSize(this->history) > 0);
+        CHECK(!lstEmpty(this->history));
 
         // If the current id was not found then the file is corrupt
         CHECK(loadData.currentId > 0);
@@ -224,13 +225,15 @@ infoPgAdd(InfoPg *this, const InfoPgData *infoPgData)
 
 /**********************************************************************************************************************************/
 InfoPg *
-infoPgSet(InfoPg *this, InfoPgType type, const unsigned int pgVersion, const uint64_t pgSystemId)
+infoPgSet(
+    InfoPg *this, InfoPgType type, const unsigned int pgVersion, const uint64_t pgSystemId, const unsigned int pgCatalogVersion)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
         FUNCTION_LOG_PARAM(INFO_PG, this);
         FUNCTION_LOG_PARAM(ENUM, type);
         FUNCTION_LOG_PARAM(UINT, pgVersion);
         FUNCTION_LOG_PARAM(UINT64, pgSystemId);
+        FUNCTION_LOG_PARAM(UINT, pgCatalogVersion);
     FUNCTION_LOG_END();
 
     ASSERT(this != NULL);
@@ -251,6 +254,9 @@ infoPgSet(InfoPg *this, InfoPgType type, const unsigned int pgVersion, const uin
 
             // This is different in archive.info due to a typo that can't be fixed without a format version bump
             .systemId = pgSystemId,
+
+            // Catalog version is only required for backup info to preserve the repo format
+            .catalogVersion = this->type == infoPgBackup ? pgCatalogVersion : 0,
         };
 
         // Add the pg data to the history list
@@ -295,8 +301,7 @@ infoPgSaveCallback(void *data, const String *sectionNext, InfoSave *infoSaveData
         if (saveData->infoPg->type == infoPgBackup)
         {
             infoSaveValue(
-                infoSaveData, INFO_SECTION_DB_STR, varStr(INFO_KEY_DB_CATALOG_VERSION_VAR),
-                jsonFromUInt(pgCatalogVersion(pgData.version)));
+                infoSaveData, INFO_SECTION_DB_STR, varStr(INFO_KEY_DB_CATALOG_VERSION_VAR), jsonFromUInt(pgData.catalogVersion));
             infoSaveValue(
                 infoSaveData, INFO_SECTION_DB_STR, varStr(INFO_KEY_DB_CONTROL_VERSION_VAR),
                 jsonFromUInt(pgControlVersion(pgData.version)));
@@ -326,7 +331,7 @@ infoPgSaveCallback(void *data, const String *sectionNext, InfoSave *infoSaveData
                 kvPut(pgDataKv, INFO_KEY_DB_SYSTEM_ID_VAR, VARUINT64(pgData.systemId));
 
                 // These need to be saved because older pgBackRest versions expect them
-                kvPut(pgDataKv, INFO_KEY_DB_CATALOG_VERSION_VAR, VARUINT(pgCatalogVersion(pgData.version)));
+                kvPut(pgDataKv, INFO_KEY_DB_CATALOG_VERSION_VAR, VARUINT(pgData.catalogVersion));
                 kvPut(pgDataKv, INFO_KEY_DB_CONTROL_VERSION_VAR, VARUINT(pgControlVersion(pgData.version)));
             }
             else
@@ -386,7 +391,7 @@ infoPgArchiveId(const InfoPg *this, unsigned int pgDataIdx)
 
     InfoPgData pgData = infoPgData(this, pgDataIdx);
 
-    FUNCTION_LOG_RETURN(STRING, strNewFmt("%s-%u", strPtr(pgVersionToStr(pgData.version)), pgData.id));
+    FUNCTION_LOG_RETURN(STRING, strNewFmt("%s-%u", strZ(pgVersionToStr(pgData.version)), pgData.id));
 }
 
 /**********************************************************************************************************************************/
@@ -413,7 +418,7 @@ infoPgData(const InfoPg *this, unsigned int pgDataIdx)
 
     ASSERT(this != NULL);
 
-    FUNCTION_LOG_RETURN(INFO_PG_DATA, *((InfoPgData *)lstGet(this->history, pgDataIdx)));
+    FUNCTION_LOG_RETURN(INFO_PG_DATA, *(InfoPgData *)lstGet(this->history, pgDataIdx));
 }
 
 /**********************************************************************************************************************************/
@@ -487,5 +492,7 @@ infoPgCurrentDataId(const InfoPg *this)
 String *
 infoPgDataToLog(const InfoPgData *this)
 {
-    return strNewFmt("{id: %u, version: %u, systemId: %" PRIu64 "}", this->id, this->version, this->systemId);
+    return strNewFmt(
+        "{id: %u, version: %u, systemId: %" PRIu64 ", catalogVersion: %u}", this->id, this->version, this->systemId,
+        this->catalogVersion);
 }
