@@ -11,6 +11,7 @@ nothing is missing or corrupt.  It is also useful for reporting, e.g. size of ba
 #define INFO_MANIFEST_H
 
 #include "command/backup/common.h"
+#include "common/compress/helper.h"
 #include "common/crypto/common.h"
 #include "common/type/variantList.h"
 
@@ -60,15 +61,16 @@ typedef struct ManifestData
     unsigned int pgId;                                              // PostgreSQL id in backup.info
     unsigned int pgVersion;                                         // PostgreSQL version
     uint64_t pgSystemId;                                            // PostgreSQL system identifier
+    unsigned int pgCatalogVersion;                                  // PostgreSQL catalog version
 
     bool backupOptionArchiveCheck;                                  // Will WAL segments be checked at the end of the backup?
     bool backupOptionArchiveCopy;                                   // Will WAL segments be copied to the backup?
     const Variant *backupOptionStandby;                             // Will the backup be performed from a standby?
     const Variant *backupOptionBufferSize;                          // Buffer size used for file/protocol operations
     const Variant *backupOptionChecksumPage;                        // Will page checksums be verified?
-    bool backupOptionCompress;                                      // Will compression be used for backup?
-    const Variant *backupOptionCompressLevel;                       // Level to use for compression
-    const Variant *backupOptionCompressLevelNetwork;                // Level to use for network compression
+    CompressType backupOptionCompressType;                          // Compression type used for the backup
+    const Variant *backupOptionCompressLevel;                       // Level used for compression (if type not none)
+    const Variant *backupOptionCompressLevelNetwork;                // Level used for network compression
     const Variant *backupOptionDelta;                               // Will a checksum delta be performed?
     bool backupOptionHardLink;                                      // Will hardlinks be created in the backup?
     bool backupOptionOnline;                                        // Will an online backup be performed?
@@ -151,8 +153,8 @@ Constructors
 ***********************************************************************************************************************************/
 // Build a new manifest for a PostgreSQL data directory
 Manifest *manifestNewBuild(
-    const Storage *storagePg, unsigned int pgVersion, bool online, bool checksumPage, const StringList *excludeList,
-    const VariantList *tablespaceList);
+    const Storage *storagePg, unsigned int pgVersion, unsigned int pgCatalogVersion, bool online, bool checksumPage,
+    const StringList *excludeList, const VariantList *tablespaceList);
 
 // Load a manifest from IO
 Manifest *manifestNewLoad(IoRead *read);
@@ -161,7 +163,7 @@ Manifest *manifestNewLoad(IoRead *read);
 Build functions
 ***********************************************************************************************************************************/
 // Validate the timestamps in the manifest given a copy start time, i.e. all times should be <= the copy start time
-void manifestBuildValidate(Manifest *this, bool delta, time_t copyStart, bool compress);
+void manifestBuildValidate(Manifest *this, bool delta, time_t copyStart, CompressType compressType);
 
 // Create a diff/incr backup by comparing to a previous backup manifest
 void manifestBuildIncr(Manifest *this, const Manifest *prior, BackupType type, const String *archiveStart);
@@ -176,8 +178,13 @@ void manifestBuildComplete(
 /***********************************************************************************************************************************
 Functions
 ***********************************************************************************************************************************/
+// Ensure that symlinks do not point to the same directory or a subdirectory of another link
 void manifestLinkCheck(const Manifest *this);
+
+// Move to a new parent mem context
 Manifest *manifestMove(Manifest *this, MemContext *parentNew);
+
+// Manifest save
 void manifestSave(Manifest *this, IoWrite *write);
 
 // Validate a completed manifest.  Use strict mode only when saving the manifest after a backup.
@@ -258,9 +265,15 @@ const ManifestData *manifestData(const Manifest *this);
 // Set backup label
 void manifestBackupLabelSet(Manifest *this, const String *backupLabel);
 
+/***********************************************************************************************************************************
+Destructor
+***********************************************************************************************************************************/
+void manifestFree(Manifest *this);
+
 /***********************************************************************************************************************************
 Helper functions
 ***********************************************************************************************************************************/
+// Load backup manifest
 Manifest *manifestLoadFile(const Storage *storage, const String *fileName, CipherType cipherType, const String *cipherPass);
 
 /***********************************************************************************************************************************
