@@ -28,9 +28,11 @@ Main
 #include "command/stanza/create.h"
 #include "command/stanza/delete.h"
 #include "command/stanza/upgrade.h"
+#include "command/verify/verify.h"
 #include "common/debug.h"
 #include "common/error.h"
 #include "common/exit.h"
+#include "common/stat.h"
 #include "config/config.h"
 #include "config/load.h"
 #include "postgres/interface.h"
@@ -40,6 +42,10 @@ Main
 int
 main(int argListSize, const char *argList[])
 {
+    // Set stack trace and mem context error cleanup handlers
+    static const ErrorHandlerFunction errorHandlerList[] = {stackTraceClean, memContextClean};
+    errorHandlerSet(errorHandlerList, sizeof(errorHandlerList) / sizeof(ErrorHandlerFunction));
+
 #ifdef WITH_BACKTRACE
     stackTraceInit(argList[0]);
 #endif
@@ -52,6 +58,9 @@ main(int argListSize, const char *argList[])
     // Initialize command with the start time
     cmdInit();
 
+    // Initialize statistics collector
+    statInit();
+
     volatile bool result = 0;
     volatile bool error = false;
 
@@ -124,7 +133,7 @@ main(int argListSize, const char *argList[])
                         cmdEnd(0, NULL);
                         cfgCommandSet(cfgCmdExpire, cfgCmdRoleDefault);
                         cfgLoadLogFile();
-                        cmdBegin(true);
+                        cmdBegin();
 
                         // Run expire
                         cmdExpire();
@@ -136,131 +145,105 @@ main(int argListSize, const char *argList[])
                 // Check command
                 // -----------------------------------------------------------------------------------------------------------------
                 case cfgCmdCheck:
-                {
                     cmdCheck();
                     break;
-                }
 
                 // Expire command
                 // -----------------------------------------------------------------------------------------------------------------
                 case cfgCmdExpire:
-                {
                     cmdExpire();
                     break;
-                }
 
                 // Help command
                 // -----------------------------------------------------------------------------------------------------------------
                 case cfgCmdHelp:
                 case cfgCmdNone:
-                {
                     THROW(AssertError, "'help' and 'none' commands should have been handled already");
-                }
 
                 // Info command
                 // -----------------------------------------------------------------------------------------------------------------
                 case cfgCmdInfo:
-                {
                     cmdInfo();
                     break;
-                }
 
                 // Repository create command
                 // -----------------------------------------------------------------------------------------------------------------
                 case cfgCmdRepoCreate:
-                {
                     cmdRepoCreate();
                     break;
-                }
 
                 // Repository get file command
                 // -----------------------------------------------------------------------------------------------------------------
                 case cfgCmdRepoGet:
-                {
                     result = cmdStorageGet();
                     break;
-                }
 
                 // Repository list paths/files command
                 // -----------------------------------------------------------------------------------------------------------------
                 case cfgCmdRepoLs:
-                {
                     cmdStorageList();
                     break;
-                }
 
                 // Repository put file command
                 // -----------------------------------------------------------------------------------------------------------------
                 case cfgCmdRepoPut:
-                {
                     cmdStoragePut();
                     break;
-                }
 
                 // Repository remove paths/files command
                 // -----------------------------------------------------------------------------------------------------------------
                 case cfgCmdRepoRm:
-                {
                     cmdStorageRemove();
                     break;
-                }
 
                 // Restore command
                 // -----------------------------------------------------------------------------------------------------------------
                 case cfgCmdRestore:
-                {
                     cmdRestore();
                     break;
-                }
 
                 // Stanza create command
                 // -----------------------------------------------------------------------------------------------------------------
                 case cfgCmdStanzaCreate:
-                {
                     cmdStanzaCreate();
                     break;
-                }
 
                 // Stanza delete command
                 // -----------------------------------------------------------------------------------------------------------------
                 case cfgCmdStanzaDelete:
-                {
                     cmdStanzaDelete();
                     break;
-                }
 
                 // Stanza upgrade command
                 // -----------------------------------------------------------------------------------------------------------------
                 case cfgCmdStanzaUpgrade:
-                {
                     cmdStanzaUpgrade();
                     break;
-                }
 
                 // Start command
                 // -----------------------------------------------------------------------------------------------------------------
                 case cfgCmdStart:
-                {
                     cmdStart();
                     break;
-                }
 
                 // Stop command
                 // -----------------------------------------------------------------------------------------------------------------
                 case cfgCmdStop:
-                {
                     cmdStop();
                     break;
-                }
+
+                // Verify command
+                // -----------------------------------------------------------------------------------------------------------------
+                case cfgCmdVerify:
+                    cmdVerify();
+                    break;
 
                 // Display version
                 // -----------------------------------------------------------------------------------------------------------------
                 case cfgCmdVersion:
-                {
                     printf(PROJECT_NAME " " PROJECT_VERSION "\n");
                     fflush(stdout);
                     break;
-                }
             }
         }
     }
