@@ -42,14 +42,6 @@ STRING_STATIC(PG_PATH_PGXACT_STR,                                   "pg_xact");
 STRING_STATIC(PG_NAME_LSN_STR,                                      "lsn");
 STRING_STATIC(PG_NAME_LOCATION_STR,                                 "location");
 
-/***********************************************************************************************************************************
-Define default wal segment size
-
-Before PostgreSQL 11 WAL segment size could only be changed at compile time and is not known to be well-tested, so only the default
-WAL segment size is supported for versions below 11.
-***********************************************************************************************************************************/
-#define PG_WAL_SEGMENT_SIZE_DEFAULT                                 ((unsigned int)(16 * 1024 * 1024))
-
 /***********************************************************************************************************************************
 Control file size.  The control file is actually 8192 bytes but only the first 512 bytes are used to prevent torn pages even on
 really old storage with 512-byte sectors.  This is true across all versions of PostgreSQL.
@@ -57,17 +49,6 @@ really old storage with 512-byte sectors.  This is true across all versions of P
 #define PG_CONTROL_SIZE                                             ((unsigned int)(8 * 1024))
 #define PG_CONTROL_DATA_SIZE                                        ((unsigned int)(512))
 
-/***********************************************************************************************************************************
-WAL header size.  It doesn't seem worth tracking the exact size of the WAL header across versions of PostgreSQL so just set it to
-something far larger needed but <= the minimum read size on just about any system.
-***********************************************************************************************************************************/
-#define PG_WAL_HEADER_SIZE                                          ((unsigned int)(512))
-
-/***********************************************************************************************************************************
-Name of default PostgreSQL database used for running all queries and commands
-***********************************************************************************************************************************/
-STRING_EXTERN(PG_DB_POSTGRES_STR,                                   PG_DB_POSTGRES);
-
 /***********************************************************************************************************************************
 PostgreSQL interface definitions
 
@@ -80,9 +61,6 @@ typedef struct PgInterface
     // Version of PostgreSQL supported by this interface
     unsigned int version;
 
-    // Get the catalog version for this version of PostgreSQL
-    uint32_t (*catalogVersion)(void);
-
     // Does pg_control match this version of PostgreSQL?
     bool (*controlIs)(const unsigned char *);
 
@@ -99,6 +77,8 @@ typedef struct PgInterface
     PgWal (*wal)(const unsigned char *);
 
 #ifdef DEBUG
+    // Catalog version for testing
+    unsigned int catalogVersion;
 
     // Create pg_control for testing
     void (*controlTest)(PgControl, unsigned char *);
@@ -113,8 +93,6 @@ static const PgInterface pgInterface[] =
     {
         .version = PG_VERSION_13,
 
-        .catalogVersion = pgInterfaceCatalogVersion130,
-
         .controlIs = pgInterfaceControlIs130,
         .control = pgInterfaceControl130,
         .controlVersion = pgInterfaceControlVersion130,
@@ -123,6 +101,8 @@ static const PgInterface pgInterface[] =
         .wal = pgInterfaceWal130,
 
 #ifdef DEBUG
+        .catalogVersion = 202007201,
+
         .controlTest = pgInterfaceControlTest130,
         .walTest = pgInterfaceWalTest130,
 #endif
@@ -130,8 +110,6 @@ static const PgInterface pgInterface[] =
     {
         .version = PG_VERSION_12,
 
-        .catalogVersion = pgInterfaceCatalogVersion120,
-
         .controlIs = pgInterfaceControlIs120,
         .control = pgInterfaceControl120,
         .controlVersion = pgInterfaceControlVersion120,
@@ -140,6 +118,8 @@ static const PgInterface pgInterface[] =
         .wal = pgInterfaceWal120,
 
 #ifdef DEBUG
+        .catalogVersion = 201909212,
+
         .controlTest = pgInterfaceControlTest120,
         .walTest = pgInterfaceWalTest120,
 #endif
@@ -147,8 +127,6 @@ static const PgInterface pgInterface[] =
     {
         .version = PG_VERSION_11,
 
-        .catalogVersion = pgInterfaceCatalogVersion110,
-
         .controlIs = pgInterfaceControlIs110,
         .control = pgInterfaceControl110,
         .controlVersion = pgInterfaceControlVersion110,
@@ -157,6 +135,8 @@ static const PgInterface pgInterface[] =
         .wal = pgInterfaceWal110,
 
 #ifdef DEBUG
+        .catalogVersion = 201809051,
+
         .controlTest = pgInterfaceControlTest110,
         .walTest = pgInterfaceWalTest110,
 #endif
@@ -164,8 +144,6 @@ static const PgInterface pgInterface[] =
     {
         .version = PG_VERSION_10,
 
-        .catalogVersion = pgInterfaceCatalogVersion100,
-
         .controlIs = pgInterfaceControlIs100,
         .control = pgInterfaceControl100,
         .controlVersion = pgInterfaceControlVersion100,
@@ -174,6 +152,8 @@ static const PgInterface pgInterface[] =
         .wal = pgInterfaceWal100,
 
 #ifdef DEBUG
+        .catalogVersion = 201707211,
+
         .controlTest = pgInterfaceControlTest100,
         .walTest = pgInterfaceWalTest100,
 #endif
@@ -181,8 +161,6 @@ static const PgInterface pgInterface[] =
     {
         .version = PG_VERSION_96,
 
-        .catalogVersion = pgInterfaceCatalogVersion096,
-
         .controlIs = pgInterfaceControlIs096,
         .control = pgInterfaceControl096,
         .controlVersion = pgInterfaceControlVersion096,
@@ -191,6 +169,8 @@ static const PgInterface pgInterface[] =
         .wal = pgInterfaceWal096,
 
 #ifdef DEBUG
+        .catalogVersion = 201608131,
+
         .controlTest = pgInterfaceControlTest096,
         .walTest = pgInterfaceWalTest096,
 #endif
@@ -198,8 +178,6 @@ static const PgInterface pgInterface[] =
     {
         .version = PG_VERSION_95,
 
-        .catalogVersion = pgInterfaceCatalogVersion095,
-
         .controlIs = pgInterfaceControlIs095,
         .control = pgInterfaceControl095,
         .controlVersion = pgInterfaceControlVersion095,
@@ -208,6 +186,8 @@ static const PgInterface pgInterface[] =
         .wal = pgInterfaceWal095,
 
 #ifdef DEBUG
+        .catalogVersion = 201510051,
+
         .controlTest = pgInterfaceControlTest095,
         .walTest = pgInterfaceWalTest095,
 #endif
@@ -215,8 +195,6 @@ static const PgInterface pgInterface[] =
     {
         .version = PG_VERSION_94,
 
-        .catalogVersion = pgInterfaceCatalogVersion094,
-
         .controlIs = pgInterfaceControlIs094,
         .control = pgInterfaceControl094,
         .controlVersion = pgInterfaceControlVersion094,
@@ -225,6 +203,8 @@ static const PgInterface pgInterface[] =
         .wal = pgInterfaceWal094,
 
 #ifdef DEBUG
+        .catalogVersion = 201409291,
+
         .controlTest = pgInterfaceControlTest094,
         .walTest = pgInterfaceWalTest094,
 #endif
@@ -232,8 +212,6 @@ static const PgInterface pgInterface[] =
     {
         .version = PG_VERSION_93,
 
-        .catalogVersion = pgInterfaceCatalogVersion093,
-
         .controlIs = pgInterfaceControlIs093,
         .control = pgInterfaceControl093,
         .controlVersion = pgInterfaceControlVersion093,
@@ -242,6 +220,8 @@ static const PgInterface pgInterface[] =
         .wal = pgInterfaceWal093,
 
 #ifdef DEBUG
+        .catalogVersion = 201306121,
+
         .controlTest = pgInterfaceControlTest093,
         .walTest = pgInterfaceWalTest093,
 #endif
@@ -249,8 +229,6 @@ static const PgInterface pgInterface[] =
     {
         .version = PG_VERSION_92,
 
-        .catalogVersion = pgInterfaceCatalogVersion092,
-
         .controlIs = pgInterfaceControlIs092,
         .control = pgInterfaceControl092,
         .controlVersion = pgInterfaceControlVersion092,
@@ -259,6 +237,8 @@ static const PgInterface pgInterface[] =
         .wal = pgInterfaceWal092,
 
 #ifdef DEBUG
+        .catalogVersion = 201204301,
+
         .controlTest = pgInterfaceControlTest092,
         .walTest = pgInterfaceWalTest092,
 #endif
@@ -266,8 +246,6 @@ static const PgInterface pgInterface[] =
     {
         .version = PG_VERSION_91,
 
-        .catalogVersion = pgInterfaceCatalogVersion091,
-
         .controlIs = pgInterfaceControlIs091,
         .control = pgInterfaceControl091,
         .controlVersion = pgInterfaceControlVersion091,
@@ -276,6 +254,8 @@ static const PgInterface pgInterface[] =
         .wal = pgInterfaceWal091,
 
 #ifdef DEBUG
+        .catalogVersion = 201105231,
+
         .controlTest = pgInterfaceControlTest091,
         .walTest = pgInterfaceWalTest091,
 #endif
@@ -283,8 +263,6 @@ static const PgInterface pgInterface[] =
     {
         .version = PG_VERSION_90,
 
-        .catalogVersion = pgInterfaceCatalogVersion090,
-
         .controlIs = pgInterfaceControlIs090,
         .control = pgInterfaceControl090,
         .controlVersion = pgInterfaceControlVersion090,
@@ -293,6 +271,8 @@ static const PgInterface pgInterface[] =
         .wal = pgInterfaceWal090,
 
 #ifdef DEBUG
+        .catalogVersion = 201008051,
+
         .controlTest = pgInterfaceControlTest090,
         .walTest = pgInterfaceWalTest090,
 #endif
@@ -300,8 +280,6 @@ static const PgInterface pgInterface[] =
     {
         .version = PG_VERSION_84,
 
-        .catalogVersion = pgInterfaceCatalogVersion084,
-
         .controlIs = pgInterfaceControlIs084,
         .control = pgInterfaceControl084,
         .controlVersion = pgInterfaceControlVersion084,
@@ -310,6 +288,8 @@ static const PgInterface pgInterface[] =
         .wal = pgInterfaceWal084,
 
 #ifdef DEBUG
+        .catalogVersion = 200904091,
+
         .controlTest = pgInterfaceControlTest084,
         .walTest = pgInterfaceWalTest084,
 #endif
@@ -317,8 +297,6 @@ static const PgInterface pgInterface[] =
     {
         .version = PG_VERSION_83,
 
-        .catalogVersion = pgInterfaceCatalogVersion083,
-
         .controlIs = pgInterfaceControlIs083,
         .control = pgInterfaceControl083,
         .controlVersion = pgInterfaceControlVersion083,
@@ -327,6 +305,8 @@ static const PgInterface pgInterface[] =
         .wal = pgInterfaceWal083,
 
 #ifdef DEBUG
+        .catalogVersion = 200711281,
+
         .controlTest = pgInterfaceControlTest083,
         .walTest = pgInterfaceWalTest083,
 #endif
@@ -375,17 +355,6 @@ pgInterfaceVersion(unsigned int pgVersion)
     FUNCTION_TEST_RETURN(result);
 }
 
-/**********************************************************************************************************************************/
-uint32_t
-pgCatalogVersion(unsigned int pgVersion)
-{
-    FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_PARAM(UINT, pgVersion);
-    FUNCTION_TEST_END();
-
-    FUNCTION_TEST_RETURN(pgInterfaceVersion(pgVersion)->catalogVersion());
-}
-
 /***********************************************************************************************************************************
 Check expected WAL segment size for older PostgreSQL versions
 ***********************************************************************************************************************************/
@@ -549,7 +518,7 @@ pgWalFromBuffer(const Buffer *walBuffer)
 }
 
 PgWal
-pgWalFromFile(const String *walFile)
+pgWalFromFile(const String *walFile, const Storage *storage)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
         FUNCTION_LOG_PARAM(STRING, walFile);
@@ -562,7 +531,7 @@ pgWalFromFile(const String *walFile)
     MEM_CONTEXT_TEMP_BEGIN()
     {
         // Read WAL segment header
-        Buffer *walBuffer = storageGetP(storageNewReadP(storageLocal(), walFile), .exactSize = PG_WAL_HEADER_SIZE);
+        Buffer *walBuffer = storageGetP(storageNewReadP(storage, walFile), .exactSize = PG_WAL_HEADER_SIZE);
 
         result = pgWalFromBuffer(walBuffer);
     }
@@ -573,10 +542,11 @@ pgWalFromFile(const String *walFile)
 
 /**********************************************************************************************************************************/
 String *
-pgTablespaceId(unsigned int pgVersion)
+pgTablespaceId(unsigned int pgVersion, unsigned int pgCatalogVersion)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(UINT, pgVersion);
+        FUNCTION_TEST_PARAM(UINT, pgCatalogVersion);
     FUNCTION_TEST_END();
 
     String *result = NULL;
@@ -589,7 +559,7 @@ pgTablespaceId(unsigned int pgVersion)
 
             MEM_CONTEXT_PRIOR_BEGIN()
             {
-                result = strNewFmt("PG_%s_%u", strPtr(pgVersionStr), pgCatalogVersion(pgVersion));
+                result = strNewFmt("PG_%s_%u", strZ(pgVersionStr), pgCatalogVersion);
             }
             MEM_CONTEXT_PRIOR_END();
         }
@@ -615,7 +585,7 @@ pgLsnFromStr(const String *lsn)
 
         CHECK(strLstSize(lsnPart) == 2);
 
-        result = (cvtZToUInt64Base(strPtr(strLstGet(lsnPart, 0)), 16) << 32) + cvtZToUInt64Base(strPtr(strLstGet(lsnPart, 1)), 16);
+        result = (cvtZToUInt64Base(strZ(strLstGet(lsnPart, 0)), 16) << 32) + cvtZToUInt64Base(strZ(strLstGet(lsnPart, 1)), 16);
     }
     MEM_CONTEXT_TEMP_END();
 
@@ -659,8 +629,8 @@ pgLsnFromWalSegment(const String *walSegment, unsigned int walSegmentSize)
     ASSERT(walSegmentSize > 0);
 
     FUNCTION_TEST_RETURN(
-        (cvtZToUInt64Base(strPtr(strSubN(walSegment, 8, 8)), 16) << 32) +
-        (cvtZToUInt64Base(strPtr(strSubN(walSegment, 16, 8)), 16) * walSegmentSize));
+        (cvtZToUInt64Base(strZ(strSubN(walSegment, 8, 8)), 16) << 32) +
+        (cvtZToUInt64Base(strZ(strSubN(walSegment, 16, 8)), 16) * walSegmentSize));
 }
 
 /**********************************************************************************************************************************/
@@ -772,6 +742,21 @@ pgXactPath(unsigned int pgVersion)
 /**********************************************************************************************************************************/
 #ifdef DEBUG
 
+unsigned int
+pgCatalogTestVersion(unsigned int pgVersion)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(UINT, pgVersion);
+    FUNCTION_TEST_END();
+
+    FUNCTION_TEST_RETURN(pgInterfaceVersion(pgVersion)->catalogVersion);
+}
+
+#endif
+
+/**********************************************************************************************************************************/
+#ifdef DEBUG
+
 Buffer *
 pgControlTestToBuffer(PgControl pgControl)
 {
@@ -782,6 +767,8 @@ pgControlTestToBuffer(PgControl pgControl)
     // Set defaults if values are not passed
     pgControl.pageSize = pgControl.pageSize == 0 ? PG_PAGE_SIZE_DEFAULT : pgControl.pageSize;
     pgControl.walSegmentSize = pgControl.walSegmentSize == 0 ? PG_WAL_SEGMENT_SIZE_DEFAULT : pgControl.walSegmentSize;
+    pgControl.catalogVersion = pgControl.catalogVersion == 0 ?
+        pgInterfaceVersion(pgControl.version)->catalogVersion : pgControl.catalogVersion;
 
     // Create the buffer and clear it
     Buffer *result = bufNew(PG_CONTROL_SIZE);
@@ -837,7 +824,7 @@ pgVersionFromStr(const String *version)
     {
         // If format is not number.number (9.4) or number only (10) then error
         if (!regExpMatchOne(STRDEF("^[0-9]+[.]*[0-9]+$"), version))
-            THROW_FMT(AssertError, "version %s format is invalid", strPtr(version));
+            THROW_FMT(AssertError, "version %s format is invalid", strZ(version));
 
         // If there is a dot set the major and minor versions, else just the major
         int idxStart = strChr(version, '.');
@@ -846,11 +833,11 @@ pgVersionFromStr(const String *version)
 
         if (idxStart != -1)
         {
-            major = cvtZToUInt(strPtr(strSubN(version, 0, (size_t)idxStart)));
-            minor = cvtZToUInt(strPtr(strSub(version, (size_t)idxStart + 1)));
+            major = cvtZToUInt(strZ(strSubN(version, 0, (size_t)idxStart)));
+            minor = cvtZToUInt(strZ(strSub(version, (size_t)idxStart + 1)));
         }
         else
-            major = cvtZToUInt(strPtr(version));
+            major = cvtZToUInt(strZ(version));
 
         // No check to see if valid/supported PG version is on purpose
         result = major * 10000 + minor * 100;
