@@ -1,37 +1,21 @@
 /***********************************************************************************************************************************
 PostgreSQL Version Interface
 
-Macros for building version-specific functions that interface with the types in version.auto.h.  Due to the way PostgreSQL types
+Macros for building version-specific functions that interface with the types in version.vendor.h.  Due to the way PostgreSQL types
 evolve over time, this seems to be the easiest way to extract information from them.
 
 These macros should be kept as simple as possible, with most of the logic contained in postgres/interface.c.
 
 Each version of PostgreSQL will need a vXXX.c file to contain the version-specific functions created by these macros.
 ***********************************************************************************************************************************/
-#ifndef POSTGRES_INTERFACE_IMPLEMENTATION_H
-#define POSTGRES_INTERFACE_IMPLEMENTATION_H
+#ifndef POSTGRES_INTERFACE_VERSIONINTERN_H
+#define POSTGRES_INTERFACE_VERSIONINTERN_H
 
 #include "common/debug.h"
 #include "postgres/interface/version.h"
 #include "postgres/version.h"
 
-#include "postgres/interface/version.auto.h"
-
-/***********************************************************************************************************************************
-Get the catalog version
-***********************************************************************************************************************************/
-#if PG_VERSION > PG_VERSION_MAX
-
-#elif PG_VERSION >= PG_VERSION_83
-
-#define PG_INTERFACE_CATALOG_VERSION(version)                                                                                      \
-    uint32_t                                                                                                                       \
-    pgInterfaceCatalogVersion##version(void)                                                                                       \
-    {                                                                                                                              \
-        return CATALOG_VERSION_NO;                                                                                                 \
-    }
-
-#endif
+#include "postgres/interface/version.vendor.h"
 
 /***********************************************************************************************************************************
 Determine if the supplied pg_control is for this version of PostgreSQL
@@ -40,6 +24,8 @@ Determine if the supplied pg_control is for this version of PostgreSQL
 
 #elif PG_VERSION >= PG_VERSION_83
 
+#ifdef CATALOG_VERSION_NO
+
 #define PG_INTERFACE_CONTROL_IS(version)                                                                                           \
     bool                                                                                                                           \
     pgInterfaceControlIs##version(const unsigned char *controlFile)                                                                \
@@ -51,6 +37,19 @@ Determine if the supplied pg_control is for this version of PostgreSQL
             ((ControlFileData *)controlFile)->catalog_version_no == CATALOG_VERSION_NO;                                            \
     }
 
+#else
+
+#define PG_INTERFACE_CONTROL_IS(version)                                                                                           \
+    bool                                                                                                                           \
+    pgInterfaceControlIs##version(const unsigned char *controlFile)                                                                \
+    {                                                                                                                              \
+        ASSERT(controlFile != NULL);                                                                                               \
+                                                                                                                                   \
+        return ((ControlFileData *)controlFile)->pg_control_version == PG_CONTROL_VERSION;                                         \
+    }
+
+#endif // CATALOG_VERSION_NO
+
 #endif
 
 /***********************************************************************************************************************************
@@ -70,6 +69,7 @@ Read the version specific pg_control into a general data structure
         return (PgControl)                                                                                                         \
         {                                                                                                                          \
             .systemId = ((ControlFileData *)controlFile)->system_identifier,                                                       \
+            .catalogVersion = ((ControlFileData *)controlFile)->catalog_version_no,                                                \
             .pageSize = ((ControlFileData *)controlFile)->blcksz,                                                                  \
             .walSegmentSize = ((ControlFileData *)controlFile)->xlog_seg_size,                                                     \
             .pageChecksum = ((ControlFileData *)controlFile)->data_checksum_version != 0,                                          \
@@ -88,6 +88,7 @@ Read the version specific pg_control into a general data structure
         return (PgControl)                                                                                                         \
         {                                                                                                                          \
             .systemId = ((ControlFileData *)controlFile)->system_identifier,                                                       \
+            .catalogVersion = ((ControlFileData *)controlFile)->catalog_version_no,                                                \
             .pageSize = ((ControlFileData *)controlFile)->blcksz,                                                                  \
             .walSegmentSize = ((ControlFileData *)controlFile)->xlog_seg_size,                                                     \
         };                                                                                                                         \
@@ -128,7 +129,7 @@ Create a pg_control file for testing
         {                                                                                                                          \
             .system_identifier = pgControl.systemId,                                                                               \
             .pg_control_version = PG_CONTROL_VERSION,                                                                              \
-            .catalog_version_no = CATALOG_VERSION_NO,                                                                              \
+            .catalog_version_no = pgControl.catalogVersion,                                                                        \
             .blcksz = pgControl.pageSize,                                                                                          \
             .xlog_seg_size = pgControl.walSegmentSize,                                                                             \
             .data_checksum_version = pgControl.pageChecksum,                                                                       \
@@ -148,7 +149,7 @@ Create a pg_control file for testing
         {                                                                                                                          \
             .system_identifier = pgControl.systemId,                                                                               \
             .pg_control_version = PG_CONTROL_VERSION,                                                                              \
-            .catalog_version_no = CATALOG_VERSION_NO,                                                                              \
+            .catalog_version_no = pgControl.catalogVersion,                                                                        \
             .blcksz = pgControl.pageSize,                                                                                          \
             .xlog_seg_size = pgControl.walSegmentSize,                                                                             \
         };                                                                                                                         \
@@ -191,6 +192,7 @@ Read the version specific WAL header into a general data structure
         return (PgWal)                                                                                                             \
         {                                                                                                                          \
             .systemId = ((XLogLongPageHeaderData *)walFile)->xlp_sysid,                                                            \
+            .size = ((XLogLongPageHeaderData *)walFile)->xlp_seg_size,                                                             \
         };                                                                                                                         \
     }
 
@@ -210,6 +212,7 @@ Create a WAL file file for testing
         ((XLogLongPageHeaderData *)buffer)->std.xlp_magic = XLOG_PAGE_MAGIC;                                                       \
         ((XLogLongPageHeaderData *)buffer)->std.xlp_info = XLP_LONG_HEADER;                                                        \
         ((XLogLongPageHeaderData *)buffer)->xlp_sysid = pgWal.systemId;                                                            \
+        ((XLogLongPageHeaderData *)buffer)->xlp_seg_size = pgWal.size;                                                             \
     }
 
 #endif
@@ -218,7 +221,6 @@ Create a WAL file file for testing
 Call all macros with a single macro to make the vXXX.c files as simple as possible
 ***********************************************************************************************************************************/
 #define PG_INTERFACE_BASE(version)                                                                                                 \
-    PG_INTERFACE_CATALOG_VERSION(version)                                                                                          \
     PG_INTERFACE_CONTROL_IS(version)                                                                                               \
     PG_INTERFACE_CONTROL(version)                                                                                                  \
     PG_INTERFACE_CONTROL_VERSION(version)                                                                                          \
