@@ -29,23 +29,36 @@ Constants
 /***********************************************************************************************************************************
 Functions
 ***********************************************************************************************************************************/
+// Send keepalives to all remotes
 void protocolKeepAlive(void);
+
+// Local protocol client
 ProtocolClient *protocolLocalGet(ProtocolStorageType protocolStorageType, unsigned int hostId, unsigned int protocolId);
+
+// Free (shutdown) a local
+void protocolLocalFree(unsigned int protocolId);
+
+// Remote protocol client
 ProtocolClient *protocolRemoteGet(ProtocolStorageType protocolStorageType, unsigned int hostId);
 
 // Free (shutdown) a remote
 void protocolRemoteFree(unsigned int hostId);
 
 /***********************************************************************************************************************************
-Getters
+Getters/Setters
 ***********************************************************************************************************************************/
-bool pgIsLocal(unsigned int hostId);
+// Is pg local?
+bool pgIsLocal(unsigned int pgIdx);
 
 // Error if PostgreSQL is not local, i.e. pg-host is set
 void pgIsLocalVerify(void);
 
-bool repoIsLocal(void);
+// Is the repository local?
+bool repoIsLocal(unsigned int repoIdx);
+
+// Error if the repository is not local
 void repoIsLocalVerify(void);
+void repoIsLocalVerifyIdx(unsigned int repoIdx);
 
 // Get enum/string for protocol storage type
 ProtocolStorageType protocolStorageTypeEnum(const String *type);
