@@ -9,11 +9,12 @@ Protocol Parallel Executor
 #include "common/debug.h"
 #include "common/log.h"
 #include "common/memContext.h"
-#include "common/object.h"
 #include "common/type/json.h"
 #include "common/type/keyValue.h"
 #include "common/type/list.h"
+#include "common/type/object.h"
 #include "protocol/command.h"
+#include "protocol/helper.h"
 #include "protocol/parallel.h"
 
 /***********************************************************************************************************************************
@@ -36,9 +37,7 @@ struct ProtocolParallel
 
 OBJECT_DEFINE_FREE(PROTOCOL_PARALLEL);
 
-/***********************************************************************************************************************************
-Create object
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 ProtocolParallel *
 protocolParallelNew(TimeMSec timeout, ParallelJobCallback *callbackFunction, void *callbackData)
 {
@@ -63,8 +62,8 @@ protocolParallelNew(TimeMSec timeout, ParallelJobCallback *callbackFunction, voi
             .timeout = timeout,
             .callbackFunction = callbackFunction,
             .callbackData = callbackData,
-            .clientList = lstNew(sizeof(ProtocolClient *)),
-            .jobList = lstNew(sizeof(ProtocolParallelJob *)),
+            .clientList = lstNewP(sizeof(ProtocolClient *)),
+            .jobList = lstNewP(sizeof(ProtocolParallelJob *)),
             .state = protocolParallelJobStatePending,
         };
     }
@@ -73,9 +72,7 @@ protocolParallelNew(TimeMSec timeout, ParallelJobCallback *callbackFunction, voi
     FUNCTION_LOG_RETURN(PROTOCOL_PARALLEL, this);
 }
 
-/***********************************************************************************************************************************
-Add client
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void
 protocolParallelClientAdd(ProtocolParallel *this, ProtocolClient *client)
 {
@@ -88,17 +85,15 @@ protocolParallelClientAdd(ProtocolParallel *this, ProtocolClient *client)
     ASSERT(client != NULL);
     ASSERT(this->state == protocolParallelJobStatePending);
 
-    if (ioReadHandle(protocolClientIoRead(client)) == -1)
-        THROW(AssertError, "client with read handle is required");
+    if (ioReadFd(protocolClientIoRead(client)) == -1)
+        THROW(AssertError, "client with read fd is required");
 
     lstAdd(this->clientList, &client);
 
     FUNCTION_LOG_RETURN_VOID();
 }
 
-/***********************************************************************************************************************************
-Process jobs
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 unsigned int
 protocolParallelProcess(ProtocolParallel *this)
 {
@@ -126,7 +121,7 @@ protocolParallelProcess(ProtocolParallel *this)
     // Initialize the file descriptor set used for select
     fd_set selectSet;
     FD_ZERO(&selectSet);
-    int handleMax = -1;
+    int fdMax = -1;
 
     // Find clients that are running jobs
     unsigned int clientRunningTotal = 0;
@@ -135,11 +130,11 @@ protocolParallelProcess(ProtocolParallel *this)
     {
         if (this->clientJobList[clientIdx] != NULL)
         {
-            int handle = ioReadHandle(protocolClientIoRead(*(ProtocolClient **)lstGet(this->clientList, clientIdx)));
-            FD_SET((unsigned int)handle, &selectSet);
+            int fd = ioReadFd(protocolClientIoRead(*(ProtocolClient **)lstGet(this->clientList, clientIdx)));
+            FD_SET((unsigned int)fd, &selectSet);
 
-            // Find the max file handle needed for select()
-            MAX_ASSIGN(handleMax, handle);
+            // Find the max file descriptor needed for select()
+            MAX_ASSIGN(fdMax, fd);
 
             clientRunningTotal++;
         }
@@ -151,10 +146,10 @@ protocolParallelProcess(ProtocolParallel *this)
         // Initialize timeout struct used for select.  Recreate this structure each time since Linux (at least) will modify it.
         struct timeval timeoutSelect;
         timeoutSelect.tv_sec = (time_t)(this->timeout / MSEC_PER_SEC);
-        timeoutSelect.tv_usec = (time_t)(this->timeout % MSEC_PER_SEC * 1000);
+        timeoutSelect.tv_usec = (suseconds_t)(this->timeout % MSEC_PER_SEC * 1000);
 
         // Determine if there is data to be read
-        int completed = select(handleMax + 1, &selectSet, NULL, NULL, &timeoutSelect);
+        int completed = select(fdMax + 1, &selectSet, NULL, NULL, &timeoutSelect);
         THROW_ON_SYS_ERROR(completed == -1, AssertError, "unable to select from parallel client(s)");
 
         // If any jobs have completed then get the results
@@ -166,7 +161,7 @@ protocolParallelProcess(ProtocolParallel *this)
 
                 if (job != NULL &&
                     FD_ISSET(
-                        (unsigned int)ioReadHandle(protocolClientIoRead(*(ProtocolClient **)lstGet(this->clientList, clientIdx))),
+                        (unsigned int)ioReadFd(protocolClientIoRead(*(ProtocolClient **)lstGet(this->clientList, clientIdx))),
                         &selectSet))
                 {
                     MEM_CONTEXT_TEMP_BEGIN()
@@ -223,15 +218,16 @@ protocolParallelProcess(ProtocolParallel *this)
                 protocolParallelJobStateSet(job, protocolParallelJobStateRunning);
                 this->clientJobList[clientIdx] = job;
             }
+            // Else no more jobs for this client so free it
+            else
+                protocolLocalFree(clientIdx + 1);
         }
     }
 
     FUNCTION_LOG_RETURN(UINT, result);
 }
 
-/***********************************************************************************************************************************
-Get a completed job result
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 ProtocolParallelJob *
 protocolParallelResult(ProtocolParallel *this)
 {
@@ -257,29 +253,28 @@ protocolParallelResult(ProtocolParallel *this)
         }
     }
 
-    // If all jobs have been returned then we are done
-    if (lstSize(this->jobList) == 0)
-        this->state = protocolParallelJobStateDone;
-
     FUNCTION_LOG_RETURN(PROTOCOL_PARALLEL_JOB, result);
 }
 
-/***********************************************************************************************************************************
-Process jobs
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 bool
-protocolParallelDone(const ProtocolParallel *this)
+protocolParallelDone(ProtocolParallel *this)
 {
     FUNCTION_LOG_BEGIN(logLevelTrace);
         FUNCTION_LOG_PARAM(PROTOCOL_PARALLEL, this);
     FUNCTION_LOG_END();
 
+    ASSERT(this != NULL);
+    ASSERT(this->state != protocolParallelJobStatePending);
+
+    // If there are no jobs left then we are done
+    if (this->state != protocolParallelJobStateDone && lstEmpty(this->jobList))
+        this->state = protocolParallelJobStateDone;
+
     FUNCTION_LOG_RETURN(BOOL, this->state == protocolParallelJobStateDone);
 }
 
-/***********************************************************************************************************************************
-Render as string for logging
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 String *
 protocolParallelToLog(const ProtocolParallel *this)
 {
