@@ -16,29 +16,53 @@ typedef struct ProtocolServer ProtocolServer;
 #include "common/io/write.h"
 
 /***********************************************************************************************************************************
-Protocol process handler type
+Protocol command handler type and structure
+
+An array of this struct must be passed to protocolServerProcess() for the server to process commands. Each command handler should
+implement a single command, as defined by the command string.
 ***********************************************************************************************************************************/
-typedef bool (*ProtocolServerProcessHandler)(const String *command, const VariantList *paramList, ProtocolServer *server);
+typedef void (*ProtocolServerCommandHandler)(const VariantList *paramList, ProtocolServer *server);
+
+typedef struct ProtocolServerHandler
+{
+    const char *const command;
+    ProtocolServerCommandHandler handler;
+} ProtocolServerHandler;
+
+#define PROTOCOL_SERVER_HANDLER_LIST_SIZE(list)                     (sizeof(list) / sizeof(ProtocolServerHandler))
 
 /***********************************************************************************************************************************
-Constructor
+Constructors
 ***********************************************************************************************************************************/
 ProtocolServer *protocolServerNew(const String *name, const String *service, IoRead *read, IoWrite *write);
 
 /***********************************************************************************************************************************
 Functions
 ***********************************************************************************************************************************/
+// Return an error
 void protocolServerError(ProtocolServer *this, int code, const String *message, const String *stack);
-void protocolServerProcess(ProtocolServer *this);
+
+// Process requests
+void protocolServerProcess(
+    ProtocolServer *this, const VariantList *retryInterval, const ProtocolServerHandler *const handlerList,
+    const unsigned int handlerListSize);
+
+// Respond to request with output if provided
 void protocolServerResponse(ProtocolServer *this, const Variant *output);
-void protocolServerHandlerAdd(ProtocolServer *this, ProtocolServerProcessHandler handler);
+
+// Move to a new parent mem context
 ProtocolServer *protocolServerMove(ProtocolServer *this, MemContext *parentNew);
+
+// Write a line
 void protocolServerWriteLine(const ProtocolServer *this, const String *line);
 
 /***********************************************************************************************************************************
-Getters
+Getters/Setters
 ***********************************************************************************************************************************/
+// Read interface
 IoRead *protocolServerIoRead(const ProtocolServer *this);
+
+// Write interface
 IoWrite *protocolServerIoWrite(const ProtocolServer *this);
 
 /***********************************************************************************************************************************
