@@ -13,6 +13,7 @@ Storage Helper
 #include "protocol/helper.h"
 #include "storage/azure/storage.h"
 #include "storage/cifs/storage.h"
+#include "storage/gcs/storage.h"
 #include "storage/posix/storage.h"
 #include "storage/remote/storage.h"
 #include "storage/s3/storage.h"
@@ -348,11 +349,12 @@ storageRepoGet(unsigned int repoIdx, bool write)
             STORAGE_MODE_FILE_DEFAULT, STORAGE_MODE_PATH_DEFAULT, write, storageRepoPathExpression,
             protocolRemoteGet(protocolStorageTypeRepo, repoIdx), cfgOptionUInt(cfgOptCompressLevelNetwork));
     }
-    // Use Azure storage
+    // Use local storage
     else
     {
         const String *type = cfgOptionIdxStr(cfgOptRepoType, repoIdx);
 
+        // Use Azure storage
         if (strEqZ(type, STORAGE_AZURE_TYPE))
         {
             result = storageAzureNew(
@@ -361,10 +363,10 @@ storageRepoGet(unsigned int repoIdx, bool write)
                 strEqZ(cfgOptionIdxStr(cfgOptRepoAzureKeyType, repoIdx), STORAGE_AZURE_KEY_TYPE_SHARED) ?
                     storageAzureKeyTypeShared : storageAzureKeyTypeSas,
                 cfgOptionIdxStr(cfgOptRepoAzureKey, repoIdx), STORAGE_AZURE_BLOCKSIZE_MIN,
-                cfgOptionIdxStrNull(cfgOptRepoAzureHost, repoIdx), cfgOptionIdxStr(cfgOptRepoAzureEndpoint, repoIdx),
-                cfgOptionIdxUInt(cfgOptRepoAzurePort, repoIdx), ioTimeoutMs(), cfgOptionIdxBool(cfgOptRepoAzureVerifyTls, repoIdx),
-                cfgOptionIdxStrNull(cfgOptRepoAzureCaFile, repoIdx),
-                cfgOptionIdxStrNull(cfgOptRepoAzureCaPath, repoIdx));
+                cfgOptionIdxStrNull(cfgOptRepoStorageHost, repoIdx), cfgOptionIdxStr(cfgOptRepoAzureEndpoint, repoIdx),
+                cfgOptionIdxUInt(cfgOptRepoStoragePort, repoIdx), ioTimeoutMs(),
+                cfgOptionIdxBool(cfgOptRepoStorageVerifyTls, repoIdx), cfgOptionIdxStrNull(cfgOptRepoStorageCaFile, repoIdx),
+                cfgOptionIdxStrNull(cfgOptRepoStorageCaPath, repoIdx));
         }
         // Use CIFS storage
         else if (strEqZ(type, STORAGE_CIFS_TYPE))
@@ -373,6 +375,19 @@ storageRepoGet(unsigned int repoIdx, bool write)
                 cfgOptionIdxStr(cfgOptRepoPath, repoIdx), STORAGE_MODE_FILE_DEFAULT, STORAGE_MODE_PATH_DEFAULT, write,
                 storageRepoPathExpression);
         }
+        // Use GCS storage
+        else if (strEqZ(type, STORAGE_GCS_TYPE))
+        {
+            result = storageGcsNew(
+                cfgOptionIdxStr(cfgOptRepoPath, repoIdx), write, storageRepoPathExpression,
+                cfgOptionIdxStr(cfgOptRepoGcsBucket, repoIdx),
+                strEqZ(cfgOptionIdxStr(cfgOptRepoGcsKeyType, repoIdx), STORAGE_GCS_KEY_TYPE_SERVICE) ?
+                    storageGcsKeyTypeService : storageGcsKeyTypeToken,
+                cfgOptionIdxStr(cfgOptRepoGcsKey, repoIdx), STORAGE_GCS_CHUNKSIZE_DEFAULT,
+                cfgOptionIdxStr(cfgOptRepoGcsEndpoint, repoIdx), ioTimeoutMs(),
+                cfgOptionIdxBool(cfgOptRepoStorageVerifyTls, repoIdx),
+                cfgOptionIdxStrNull(cfgOptRepoStorageCaFile, repoIdx), cfgOptionIdxStrNull(cfgOptRepoStorageCaPath, repoIdx));
+        }
         // Use Posix storage
         else if (strEqZ(type, STORAGE_POSIX_TYPE))
         {
@@ -386,15 +401,15 @@ storageRepoGet(unsigned int repoIdx, bool write)
             CHECK(strEqZ(type, STORAGE_S3_TYPE));
 
             // Set the default port
-            unsigned int port = cfgOptionIdxUInt(cfgOptRepoS3Port, repoIdx);
+            unsigned int port = cfgOptionIdxUInt(cfgOptRepoStoragePort, repoIdx);
 
             // Extract port from the endpoint and host if it is present
             const String *endPoint = cfgOptionIdxHostPort(cfgOptRepoS3Endpoint, repoIdx, &port);
-            const String *host = cfgOptionIdxHostPort(cfgOptRepoS3Host, repoIdx, &port);
+            const String *host = cfgOptionIdxHostPort(cfgOptRepoStorageHost, repoIdx, &port);
 
             // If the port option was set explicitly then use it in preference to appended ports
-            if (cfgOptionIdxSource(cfgOptRepoS3Port, repoIdx) != cfgSourceDefault)
-                port = cfgOptionIdxUInt(cfgOptRepoS3Port, repoIdx);
+            if (cfgOptionIdxSource(cfgOptRepoStoragePort, repoIdx) != cfgSourceDefault)
+                port = cfgOptionIdxUInt(cfgOptRepoStoragePort, repoIdx);
 
             result = storageS3New(
                 cfgOptionIdxStr(cfgOptRepoPath, repoIdx), write, storageRepoPathExpression,
@@ -406,8 +421,8 @@ storageRepoGet(unsigned int repoIdx, bool write)
                     storageS3KeyTypeShared : storageS3KeyTypeAuto,
                 cfgOptionIdxStrNull(cfgOptRepoS3Key, repoIdx), cfgOptionIdxStrNull(cfgOptRepoS3KeySecret, repoIdx),
                 cfgOptionIdxStrNull(cfgOptRepoS3Token, repoIdx), cfgOptionIdxStrNull(cfgOptRepoS3Role, repoIdx),
-                STORAGE_S3_PARTSIZE_MIN, host, port, ioTimeoutMs(), cfgOptionIdxBool(cfgOptRepoS3VerifyTls, repoIdx),
-                cfgOptionIdxStrNull(cfgOptRepoS3CaFile, repoIdx), cfgOptionIdxStrNull(cfgOptRepoS3CaPath, repoIdx));
+                STORAGE_S3_PARTSIZE_MIN, host, port, ioTimeoutMs(), cfgOptionIdxBool(cfgOptRepoStorageVerifyTls, repoIdx),
+                cfgOptionIdxStrNull(cfgOptRepoStorageCaFile, repoIdx), cfgOptionIdxStrNull(cfgOptRepoStorageCaPath, repoIdx));
         }
     }
 
