@@ -10,7 +10,7 @@ Posix Storage Read
 #include "common/io/read.intern.h"
 #include "common/log.h"
 #include "common/memContext.h"
-#include "common/object.h"
+#include "common/type/object.h"
 #include "storage/posix/read.h"
 #include "storage/posix/storage.intern.h"
 #include "storage/read.intern.h"
@@ -27,7 +27,9 @@ typedef struct StorageReadPosix
     StorageReadInterface interface;                                 // Interface
     StoragePosix *storage;                                          // Storage that created this object
 
-    int handle;
+    int fd;                                                         // File descriptor
+    uint64_t current;                                               // Current bytes read from file
+    uint64_t limit;                                                 // Limit bytes to be read from file (UINT64_MAX for no limit)
     bool eof;
 } StorageReadPosix;
 
@@ -40,12 +42,12 @@ Macros for function logging
     objToLog(value, "StorageReadPosix", buffer, bufferSize)
 
 /***********************************************************************************************************************************
-Close the file handle
+Close file descriptor
 ***********************************************************************************************************************************/
 OBJECT_DEFINE_FREE_RESOURCE_BEGIN(STORAGE_READ_POSIX, LOG, logLevelTrace)
 {
-    if (this->handle != -1)
-        THROW_ON_SYS_ERROR_FMT(close(this->handle) == -1, FileCloseError, STORAGE_ERROR_READ_CLOSE, strPtr(this->interface.name));
+    if (this->fd != -1)
+        THROW_ON_SYS_ERROR_FMT(close(this->fd) == -1, FileCloseError, STORAGE_ERROR_READ_CLOSE, strZ(this->interface.name));
 }
 OBJECT_DEFINE_FREE_RESOURCE_END(LOG);
 
@@ -62,26 +64,27 @@ storageReadPosixOpen(THIS_VOID)
     FUNCTION_LOG_END();
 
     ASSERT(this != NULL);
-    ASSERT(this->handle == -1);
+    ASSERT(this->fd == -1);
 
     bool result = false;
 
     // Open the file
-    this->handle = open(strPtr(this->interface.name), O_RDONLY, 0);
+    this->fd = open(strZ(this->interface.name), O_RDONLY, 0);
 
     // Handle errors
-    if (this->handle == -1)
+    if (this->fd == -1)
     {
-        if (errno == ENOENT)
+        if (errno == ENOENT)                                                                                        // {vm_covered}
         {
             if (!this->interface.ignoreMissing)
-                THROW_FMT(FileMissingError, STORAGE_ERROR_READ_MISSING, strPtr(this->interface.name));
+                THROW_FMT(FileMissingError, STORAGE_ERROR_READ_MISSING, strZ(this->interface.name));
         }
         else
-            THROW_SYS_ERROR_FMT(FileOpenError, STORAGE_ERROR_READ_OPEN, strPtr(this->interface.name));
+            THROW_SYS_ERROR_FMT(FileOpenError, STORAGE_ERROR_READ_OPEN, strZ(this->interface.name));                // {vm_covered}
     }
-    // On success set free callback to ensure file handle is freed
-    if (this->handle != -1)
+
+    // On success set free callback to ensure the file descriptor is freed
+    if (this->fd != -1)
     {
         memContextCallbackSet(this->memContext, storageReadPosixFreeResource, this);
         result = true;
@@ -104,7 +107,7 @@ storageReadPosix(THIS_VOID, Buffer *buffer, bool block)
         FUNCTION_LOG_PARAM(BOOL, block);
     FUNCTION_LOG_END();
 
-    ASSERT(this != NULL && this->handle != -1);
+    ASSERT(this != NULL && this->fd != -1);
     ASSERT(buffer != NULL && !bufFull(buffer));
 
     // Read if EOF has not been reached
@@ -112,20 +115,26 @@ storageReadPosix(THIS_VOID, Buffer *buffer, bool block)
 
     if (!this->eof)
     {
-        // Read and handle errors
+        // Determine expected bytes to read. If remaining size in the buffer would exceed the limit then reduce the expected read.
         size_t expectedBytes = bufRemains(buffer);
-        actualBytes = read(this->handle, bufRemainsPtr(buffer), expectedBytes);
+
+        if (this->current + expectedBytes > this->limit)
+            expectedBytes = (size_t)(this->limit - this->current);
+
+        // Read from file
+        actualBytes = read(this->fd, bufRemainsPtr(buffer), expectedBytes);
 
         // Error occurred during read
         if (actualBytes == -1)
-            THROW_SYS_ERROR_FMT(FileReadError, "unable to read '%s'", strPtr(this->interface.name));
+            THROW_SYS_ERROR_FMT(FileReadError, "unable to read '%s'", strZ(this->interface.name));
 
         // Update amount of buffer used
         bufUsedInc(buffer, (size_t)actualBytes);
+        this->current += (uint64_t)actualBytes;
 
-        // If less data than expected was read then EOF.  The file may not actually be EOF but we are not concerned with files that
-        // are growing.  Just read up to the point where the file is being extended.
-        if ((size_t)actualBytes != expectedBytes)
+        // If less data than expected was read or the limit has been reached then EOF.  The file may not actually be EOF but we are
+        // not concerned with files that are growing.  Just read up to the point where the file is being extended.
+        if ((size_t)actualBytes != expectedBytes || this->current == this->limit)
             this->eof = true;
     }
 
@@ -146,9 +155,9 @@ storageReadPosixClose(THIS_VOID)
 
     ASSERT(this != NULL);
 
-    storageReadPosixFreeResource(this);
     memContextCallbackClear(this->memContext);
-    this->handle = -1;
+    storageReadPosixFreeResource(this);
+    this->fd = -1;
 
     FUNCTION_LOG_RETURN_VOID();
 }
@@ -171,10 +180,10 @@ storageReadPosixEof(THIS_VOID)
 }
 
 /***********************************************************************************************************************************
-Get handle (file descriptor)
+Get file descriptor
 ***********************************************************************************************************************************/
 static int
-storageReadPosixHandle(const THIS_VOID)
+storageReadPosixFd(const THIS_VOID)
 {
     THIS(const StorageReadPosix);
 
@@ -184,18 +193,17 @@ storageReadPosixHandle(const THIS_VOID)
 
     ASSERT(this != NULL);
 
-    FUNCTION_TEST_RETURN(this->handle);
+    FUNCTION_TEST_RETURN(this->fd);
 }
 
-/***********************************************************************************************************************************
-New object
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 StorageRead *
-storageReadPosixNew(StoragePosix *storage, const String *name, bool ignoreMissing)
+storageReadPosixNew(StoragePosix *storage, const String *name, bool ignoreMissing, const Variant *limit)
 {
     FUNCTION_LOG_BEGIN(logLevelTrace);
         FUNCTION_LOG_PARAM(STRING, name);
         FUNCTION_LOG_PARAM(BOOL, ignoreMissing);
+        FUNCTION_LOG_PARAM(VARIANT, limit);
     FUNCTION_LOG_END();
 
     ASSERT(name != NULL);
@@ -210,19 +218,25 @@ storageReadPosixNew(StoragePosix *storage, const String *name, bool ignoreMissin
         {
             .memContext = MEM_CONTEXT_NEW(),
             .storage = storage,
-            .handle = -1,
+            .fd = -1,
+
+            // Rather than enable/disable limit checking just use a big number when there is no limit.  We can feel pretty confident
+            // that no files will be > UINT64_MAX in size. This is a copy of the interface limit but it simplifies the code during
+            // read so it seems worthwhile.
+            .limit = limit == NULL ? UINT64_MAX : varUInt64(limit),
 
             .interface = (StorageReadInterface)
             {
                 .type = STORAGE_POSIX_TYPE_STR,
                 .name = strDup(name),
                 .ignoreMissing = ignoreMissing,
+                .limit = varDup(limit),
 
                 .ioInterface = (IoReadInterface)
                 {
                     .close = storageReadPosixClose,
                     .eof = storageReadPosixEof,
-                    .handle = storageReadPosixHandle,
+                    .fd = storageReadPosixFd,
                     .open = storageReadPosixOpen,
                     .read = storageReadPosix,
                 },
