@@ -8,23 +8,19 @@ Storage Read Interface Internal
 #include "storage/read.h"
 
 /***********************************************************************************************************************************
-Constructor
+Constructors
 ***********************************************************************************************************************************/
 typedef struct StorageReadInterface
 {
-    const String * type;
-    const String * name;
+    const String *type;
+    const String *name;
     bool compressible;                                              // Is this file compressible?
     unsigned int compressLevel;                                     // Level to use for compression
     bool ignoreMissing;
+    const Variant *limit;                                           // Limit how many bytes are read (NULL for no limit)
     IoReadInterface ioInterface;
 } StorageReadInterface;
 
 StorageRead *storageReadNew(void *driver, const StorageReadInterface *interface);
 
-/***********************************************************************************************************************************
-Constructor
-***********************************************************************************************************************************/
-void *storageRead(const StorageRead *this);
-
 #endif
