@@ -45,7 +45,7 @@ Local variables
 static struct
 {
     MemContext *memContext;                                         // Mem context
-    RegExp *blockRegExp;                                            // Regular expression to check block messages
+    void *driver;                                                   // Storage driver used for requests
 } storageRemoteProtocolLocal;
 
 /***********************************************************************************************************************************
@@ -83,56 +83,17 @@ storageRemoteFilterGroup(IoFilterGroup *filterGroup, const Variant *filterList)
         else if (strEq(filterKey, SIZE_FILTER_TYPE_STR))
             ioFilterGroupAdd(filterGroup, ioSizeNew());
         else
-            THROW_FMT(AssertError, "unable to add filter '%s'", strPtr(filterKey));
+            THROW_FMT(AssertError, "unable to add filter '%s'", strZ(filterKey));
     }
 
     FUNCTION_TEST_RETURN_VOID();
 }
 
 /***********************************************************************************************************************************
-Write storage info into the protocol
+Callback to write info list into the protocol
 ***********************************************************************************************************************************/
-// Helper to write storage type into the protocol
-static void
-storageRemoteInfoWriteType(ProtocolServer *server, StorageType type)
-{
-    FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_PARAM(PROTOCOL_SERVER, server);
-        FUNCTION_TEST_PARAM(ENUM, type);
-    FUNCTION_TEST_END();
-
-    switch (type)
-    {
-        case storageTypeFile:
-        {
-            protocolServerWriteLine(server, STRDEF("f"));
-            break;
-        }
-
-        case storageTypePath:
-        {
-            protocolServerWriteLine(server, STRDEF("p"));
-            break;
-        }
-
-        case storageTypeLink:
-        {
-            protocolServerWriteLine(server, STRDEF("l"));
-            break;
-        }
-
-        case storageTypeSpecial:
-        {
-            protocolServerWriteLine(server, STRDEF("s"));
-            break;
-        }
-    }
-
-    FUNCTION_TEST_RETURN_VOID();
-}
-
-// Helper to write storage info into the protocol.  This function is not called unless the info exists so no need to write exists
-// or check for level == storageInfoLevelExists.
+// Helper to write storage info into the protocol. This function is not called unless the info exists so no need to write exists or
+// check for level == storageInfoLevelExists.
 static void
 storageRemoteInfoWrite(ProtocolServer *server, const StorageInfo *info)
 {
@@ -141,7 +102,7 @@ storageRemoteInfoWrite(ProtocolServer *server, const StorageInfo *info)
         FUNCTION_TEST_PARAM(STORAGE_INFO, info);
     FUNCTION_TEST_END();
 
-    storageRemoteInfoWriteType(server, info->type);
+    protocolServerWriteLine(server, jsonFromUInt(info->type));
     protocolServerWriteLine(server, jsonFromInt64(info->timeModified));
 
     if (info->type == storageTypeFile)
@@ -162,9 +123,6 @@ storageRemoteInfoWrite(ProtocolServer *server, const StorageInfo *info)
     FUNCTION_TEST_RETURN_VOID();
 }
 
-/***********************************************************************************************************************************
-Callback to write info list into the protocol
-***********************************************************************************************************************************/
 static void
 storageRemoteProtocolInfoListCallback(void *server, const StorageInfo *info)
 {
@@ -180,197 +138,351 @@ storageRemoteProtocolInfoListCallback(void *server, const StorageInfo *info)
 }
 
 /**********************************************************************************************************************************/
-bool
-storageRemoteProtocol(const String *command, const VariantList *paramList, ProtocolServer *server)
+void
+storageRemoteFeatureProtocol(const VariantList *paramList, ProtocolServer *server)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
-        FUNCTION_LOG_PARAM(STRING, command);
         FUNCTION_LOG_PARAM(VARIANT_LIST, paramList);
         FUNCTION_LOG_PARAM(PROTOCOL_SERVER, server);
     FUNCTION_LOG_END();
 
-    ASSERT(command != NULL);
-
-    // Determine which storage should be used
-    const Storage *storage = protocolStorageTypeEnum(
-        cfgOptionStr(cfgOptRemoteType)) == protocolStorageTypeRepo ? storageRepo() : storagePg();
-    StorageInterface interface = storageInterface(storage);
-    void *driver = storageDriver(storage);
-
-    // Attempt to satisfy the request -- we may get requests that are meant for other handlers
-    bool found = true;
+    ASSERT(paramList == NULL);
+    ASSERT(server != NULL);
 
     MEM_CONTEXT_TEMP_BEGIN()
     {
-        if (strEq(command, PROTOCOL_COMMAND_STORAGE_FEATURE_STR))
+        // Get storage based on remote type
+        const Storage *storage =
+            protocolStorageTypeEnum(cfgOptionStr(cfgOptRemoteType)) == protocolStorageTypeRepo ?
+                storageRepoWrite() : storagePgWrite();
+
+        // Store local variables in the server context
+        if (storageRemoteProtocolLocal.memContext == NULL)
         {
-            protocolServerWriteLine(server, jsonFromStr(storagePathP(storage, NULL)));
-            protocolServerWriteLine(server, jsonFromUInt64(interface.feature));
-
-            protocolServerResponse(server, NULL);
-        }
-        else if (strEq(command, PROTOCOL_COMMAND_STORAGE_INFO_STR))
-        {
-            StorageInfo info = storageInterfaceInfoP(
-                driver, varStr(varLstGet(paramList, 0)), (StorageInfoLevel)varUIntForce(varLstGet(paramList, 1)),
-                .followLink = varBool(varLstGet(paramList, 2)));
-
-            protocolServerResponse(server, VARBOOL(info.exists));
-
-            if (info.exists)
+            MEM_CONTEXT_PRIOR_BEGIN()
             {
-                storageRemoteInfoWrite(server, &info);
-                protocolServerResponse(server, NULL);
+                MEM_CONTEXT_NEW_BEGIN("StorageRemoteProtocol")
+                {
+                    storageRemoteProtocolLocal.memContext = memContextCurrent();
+                    storageRemoteProtocolLocal.driver = storageDriver(storage);
+                }
+                MEM_CONTEXT_NEW_END();
             }
+            MEM_CONTEXT_PRIOR_END();
         }
-        else if (strEq(command, PROTOCOL_COMMAND_STORAGE_INFO_LIST_STR))
-        {
-            bool result = storageInterfaceInfoListP(
-                driver, varStr(varLstGet(paramList, 0)), (StorageInfoLevel)varUIntForce(varLstGet(paramList, 1)),
-                storageRemoteProtocolInfoListCallback, server);
 
-            protocolServerWriteLine(server, NULL);
-            protocolServerResponse(server, VARBOOL(result));
-        }
-        else if (strEq(command, PROTOCOL_COMMAND_STORAGE_OPEN_READ_STR))
-        {
-            // Create the read object
-            IoRead *fileRead = storageReadIo(
-                storageInterfaceNewReadP(
-                    driver, varStr(varLstGet(paramList, 0)), varBool(varLstGet(paramList, 1)), .limit = varLstGet(paramList, 2)));
+        // Return storage features
+        protocolServerWriteLine(server, jsonFromStr(storagePathP(storage, NULL)));
+        protocolServerWriteLine(server, jsonFromUInt64(storageInterface(storage).feature));
 
-            // Set filter group based on passed filters
-            storageRemoteFilterGroup(ioReadFilterGroup(fileRead), varLstGet(paramList, 3));
-
-            // Check if the file exists
-            bool exists = ioReadOpen(fileRead);
-            protocolServerResponse(server, VARBOOL(exists));
-
-            // Transfer the file if it exists
-            if (exists)
-            {
-                Buffer *buffer = bufNew(ioBufferSize());
-
-                // Write file out to protocol layer
-                do
-                {
-                    ioRead(fileRead, buffer);
-
-                    if (bufUsed(buffer) > 0)
-                    {
-                        ioWriteStrLine(protocolServerIoWrite(server), strNewFmt(PROTOCOL_BLOCK_HEADER "%zu", bufUsed(buffer)));
-                        ioWrite(protocolServerIoWrite(server), buffer);
-                        ioWriteFlush(protocolServerIoWrite(server));
-
-                        bufUsedZero(buffer);
-                    }
-                }
-                while (!ioReadEof(fileRead));
-
-                ioReadClose(fileRead);
-
-                // Write a zero block to show file is complete
-                ioWriteLine(protocolServerIoWrite(server), BUFSTRDEF(PROTOCOL_BLOCK_HEADER "0"));
-                ioWriteFlush(protocolServerIoWrite(server));
-
-                // Push filter results
-                protocolServerResponse(server, ioFilterGroupResultAll(ioReadFilterGroup(fileRead)));
-            }
-        }
-        else if (strEq(command, PROTOCOL_COMMAND_STORAGE_OPEN_WRITE_STR))
-        {
-            // Create the write object
-            IoWrite *fileWrite = storageWriteIo(
-                storageInterfaceNewWriteP(
-                    driver, varStr(varLstGet(paramList, 0)), .modeFile = varUIntForce(varLstGet(paramList, 1)),
-                    .modePath = varUIntForce(varLstGet(paramList, 2)), .user = varStr(varLstGet(paramList, 3)),
-                    .group = varStr(varLstGet(paramList, 4)), .timeModified = (time_t)varUInt64Force(varLstGet(paramList, 5)),
-                    .createPath = varBool(varLstGet(paramList, 6)), .syncFile = varBool(varLstGet(paramList, 7)),
-                    .syncPath = varBool(varLstGet(paramList, 8)), .atomic = varBool(varLstGet(paramList, 9))));
-
-            // Set filter group based on passed filters
-            storageRemoteFilterGroup(ioWriteFilterGroup(fileWrite), varLstGet(paramList, 10));
-
-            // Open file
-            ioWriteOpen(fileWrite);
-            protocolServerResponse(server, NULL);
-
-            // Write data
-            Buffer *buffer = bufNew(ioBufferSize());
-            ssize_t remaining;
-
-            do
-            {
-                // How much data is remaining to write?
-                remaining = storageRemoteProtocolBlockSize(ioReadLine(protocolServerIoRead(server)));
-
-                // Write data
-                if (remaining > 0)
-                {
-                    size_t bytesToCopy = (size_t)remaining;
-
-                    do
-                    {
-                        if (bytesToCopy < bufSize(buffer))
-                            bufLimitSet(buffer, bytesToCopy);
-
-                        bytesToCopy -= ioRead(protocolServerIoRead(server), buffer);
-                        ioWrite(fileWrite, buffer);
-
-                        bufUsedZero(buffer);
-                        bufLimitClear(buffer);
-                    }
-                    while (bytesToCopy > 0);
-                }
-                // Close when all data has been written
-                else if (remaining == 0)
-                {
-                    ioWriteClose(fileWrite);
-
-                    // Push filter results
-                    protocolServerResponse(server, ioFilterGroupResultAll(ioWriteFilterGroup(fileWrite)));
-                }
-                // Write was aborted so free the file
-                else
-                {
-                    ioWriteFree(fileWrite);
-                    protocolServerResponse(server, NULL);
-                }
-            }
-            while (remaining > 0);
-
-        }
-        else if (strEq(command, PROTOCOL_COMMAND_STORAGE_PATH_CREATE_STR))
-        {
-            storageInterfacePathCreateP(
-                driver, varStr(varLstGet(paramList, 0)), varBool(varLstGet(paramList, 1)), varBool(varLstGet(paramList, 2)),
-                varUIntForce(varLstGet(paramList, 3)));
-
-            protocolServerResponse(server, NULL);
-        }
-        else if (strEq(command, PROTOCOL_COMMAND_STORAGE_PATH_REMOVE_STR))
-        {
-            protocolServerResponse(server,
-                VARBOOL(storageInterfacePathRemoveP(driver, varStr(varLstGet(paramList, 0)), varBool(varLstGet(paramList, 1)))));
-        }
-        else if (strEq(command, PROTOCOL_COMMAND_STORAGE_PATH_SYNC_STR))
-        {
-            storageInterfacePathSyncP(driver, varStr(varLstGet(paramList, 0)));
-
-            protocolServerResponse(server, NULL);
-        }
-        else if (strEq(command, PROTOCOL_COMMAND_STORAGE_REMOVE_STR))
-        {
-            storageInterfaceRemoveP(driver, varStr(varLstGet(paramList, 0)), .errorOnMissing = varBool(varLstGet(paramList, 1)));
-
-            protocolServerResponse(server, NULL);
-        }
-        else
-            found = false;
+        protocolServerResponse(server, NULL);
     }
     MEM_CONTEXT_TEMP_END();
 
-    FUNCTION_LOG_RETURN(BOOL, found);
+    FUNCTION_TEST_RETURN_VOID();
+}
+
+/**********************************************************************************************************************************/
+void
+storageRemoteInfoProtocol(const VariantList *paramList, ProtocolServer *server)
+{
+    FUNCTION_LOG_BEGIN(logLevelDebug);
+        FUNCTION_LOG_PARAM(VARIANT_LIST, paramList);
+        FUNCTION_LOG_PARAM(PROTOCOL_SERVER, server);
+    FUNCTION_LOG_END();
+
+    ASSERT(paramList != NULL);
+    ASSERT(server != NULL);
+    ASSERT(storageRemoteProtocolLocal.driver != NULL);
+
+    MEM_CONTEXT_TEMP_BEGIN()
+    {
+        StorageInfo info = storageInterfaceInfoP(
+            storageRemoteProtocolLocal.driver, varStr(varLstGet(paramList, 0)),
+            (StorageInfoLevel)varUIntForce(varLstGet(paramList, 1)), .followLink = varBool(varLstGet(paramList, 2)));
+
+        protocolServerResponse(server, VARBOOL(info.exists));
+
+        if (info.exists)
+        {
+            storageRemoteInfoWrite(server, &info);
+            protocolServerResponse(server, NULL);
+        }
+    }
+    MEM_CONTEXT_TEMP_END();
+
+    FUNCTION_TEST_RETURN_VOID();
+}
+
+/**********************************************************************************************************************************/
+void
+storageRemoteInfoListProtocol(const VariantList *paramList, ProtocolServer *server)
+{
+    FUNCTION_LOG_BEGIN(logLevelDebug);
+        FUNCTION_LOG_PARAM(VARIANT_LIST, paramList);
+        FUNCTION_LOG_PARAM(PROTOCOL_SERVER, server);
+    FUNCTION_LOG_END();
+
+    ASSERT(paramList != NULL);
+    ASSERT(server != NULL);
+    ASSERT(storageRemoteProtocolLocal.driver != NULL);
+
+    MEM_CONTEXT_TEMP_BEGIN()
+    {
+        bool result = storageInterfaceInfoListP(
+            storageRemoteProtocolLocal.driver, varStr(varLstGet(paramList, 0)),
+            (StorageInfoLevel)varUIntForce(varLstGet(paramList, 1)), storageRemoteProtocolInfoListCallback, server);
+
+        protocolServerWriteLine(server, NULL);
+        protocolServerResponse(server, VARBOOL(result));
+    }
+    MEM_CONTEXT_TEMP_END();
+
+    FUNCTION_TEST_RETURN_VOID();
+}
+
+/**********************************************************************************************************************************/
+void
+storageRemoteOpenReadProtocol(const VariantList *paramList, ProtocolServer *server)
+{
+    FUNCTION_LOG_BEGIN(logLevelDebug);
+        FUNCTION_LOG_PARAM(VARIANT_LIST, paramList);
+        FUNCTION_LOG_PARAM(PROTOCOL_SERVER, server);
+    FUNCTION_LOG_END();
+
+    ASSERT(paramList != NULL);
+    ASSERT(server != NULL);
+    ASSERT(storageRemoteProtocolLocal.driver != NULL);
+
+    MEM_CONTEXT_TEMP_BEGIN()
+    {
+        // Create the read object
+        IoRead *fileRead = storageReadIo(
+            storageInterfaceNewReadP(
+                storageRemoteProtocolLocal.driver, varStr(varLstGet(paramList, 0)), varBool(varLstGet(paramList, 1)),
+                .limit = varLstGet(paramList, 2)));
+
+        // Set filter group based on passed filters
+        storageRemoteFilterGroup(ioReadFilterGroup(fileRead), varLstGet(paramList, 3));
+
+        // Check if the file exists
+        bool exists = ioReadOpen(fileRead);
+        protocolServerResponse(server, VARBOOL(exists));
+
+        // Transfer the file if it exists
+        if (exists)
+        {
+            Buffer *buffer = bufNew(ioBufferSize());
+
+            // Write file out to protocol layer
+            do
+            {
+                ioRead(fileRead, buffer);
+
+                if (!bufEmpty(buffer))
+                {
+                    ioWriteStrLine(protocolServerIoWrite(server), strNewFmt(PROTOCOL_BLOCK_HEADER "%zu", bufUsed(buffer)));
+                    ioWrite(protocolServerIoWrite(server), buffer);
+                    ioWriteFlush(protocolServerIoWrite(server));
+
+                    bufUsedZero(buffer);
+                }
+            }
+            while (!ioReadEof(fileRead));
+
+            ioReadClose(fileRead);
+
+            // Write a zero block to show file is complete
+            ioWriteLine(protocolServerIoWrite(server), BUFSTRDEF(PROTOCOL_BLOCK_HEADER "0"));
+            ioWriteFlush(protocolServerIoWrite(server));
+
+            // Push filter results
+            protocolServerResponse(server, ioFilterGroupResultAll(ioReadFilterGroup(fileRead)));
+        }
+    }
+    MEM_CONTEXT_TEMP_END();
+
+    FUNCTION_TEST_RETURN_VOID();
+}
+
+/**********************************************************************************************************************************/
+void
+storageRemoteOpenWriteProtocol(const VariantList *paramList, ProtocolServer *server)
+{
+    FUNCTION_LOG_BEGIN(logLevelDebug);
+        FUNCTION_LOG_PARAM(VARIANT_LIST, paramList);
+        FUNCTION_LOG_PARAM(PROTOCOL_SERVER, server);
+    FUNCTION_LOG_END();
+
+    ASSERT(paramList != NULL);
+    ASSERT(server != NULL);
+    ASSERT(storageRemoteProtocolLocal.driver != NULL);
+
+    MEM_CONTEXT_TEMP_BEGIN()
+    {
+        // Create the write object
+        IoWrite *fileWrite = storageWriteIo(
+            storageInterfaceNewWriteP(
+                storageRemoteProtocolLocal.driver, varStr(varLstGet(paramList, 0)),
+                .modeFile = (mode_t)varUIntForce(varLstGet(paramList, 1)),
+                .modePath = (mode_t)varUIntForce(varLstGet(paramList, 2)), .user = varStr(varLstGet(paramList, 3)),
+                .group = varStr(varLstGet(paramList, 4)), .timeModified = (time_t)varUInt64Force(varLstGet(paramList, 5)),
+                .createPath = varBool(varLstGet(paramList, 6)), .syncFile = varBool(varLstGet(paramList, 7)),
+                .syncPath = varBool(varLstGet(paramList, 8)), .atomic = varBool(varLstGet(paramList, 9))));
+
+        // Set filter group based on passed filters
+        storageRemoteFilterGroup(ioWriteFilterGroup(fileWrite), varLstGet(paramList, 10));
+
+        // Open file
+        ioWriteOpen(fileWrite);
+        protocolServerResponse(server, NULL);
+
+        // Write data
+        Buffer *buffer = bufNew(ioBufferSize());
+        ssize_t remaining;
+
+        do
+        {
+            // How much data is remaining to write?
+            remaining = storageRemoteProtocolBlockSize(ioReadLine(protocolServerIoRead(server)));
+
+            // Write data
+            if (remaining > 0)
+            {
+                size_t bytesToCopy = (size_t)remaining;
+
+                do
+                {
+                    if (bytesToCopy < bufSize(buffer))
+                        bufLimitSet(buffer, bytesToCopy);
+
+                    bytesToCopy -= ioRead(protocolServerIoRead(server), buffer);
+                    ioWrite(fileWrite, buffer);
+
+                    bufUsedZero(buffer);
+                    bufLimitClear(buffer);
+                }
+                while (bytesToCopy > 0);
+            }
+            // Close when all data has been written
+            else if (remaining == 0)
+            {
+                ioWriteClose(fileWrite);
+
+                // Push filter results
+                protocolServerResponse(server, ioFilterGroupResultAll(ioWriteFilterGroup(fileWrite)));
+            }
+            // Write was aborted so free the file
+            else
+            {
+                ioWriteFree(fileWrite);
+                protocolServerResponse(server, NULL);
+            }
+        }
+        while (remaining > 0);
+    }
+    MEM_CONTEXT_TEMP_END();
+
+    FUNCTION_TEST_RETURN_VOID();
+}
+
+/**********************************************************************************************************************************/
+void
+storageRemotePathCreateProtocol(const VariantList *paramList, ProtocolServer *server)
+{
+    FUNCTION_LOG_BEGIN(logLevelDebug);
+        FUNCTION_LOG_PARAM(VARIANT_LIST, paramList);
+        FUNCTION_LOG_PARAM(PROTOCOL_SERVER, server);
+    FUNCTION_LOG_END();
+
+    ASSERT(paramList != NULL);
+    ASSERT(server != NULL);
+    ASSERT(storageRemoteProtocolLocal.driver != NULL);
+
+    MEM_CONTEXT_TEMP_BEGIN()
+    {
+        storageInterfacePathCreateP(
+            storageRemoteProtocolLocal.driver, varStr(varLstGet(paramList, 0)), varBool(varLstGet(paramList, 1)),
+            varBool(varLstGet(paramList, 2)), (mode_t)varUIntForce(varLstGet(paramList, 3)));
+
+        protocolServerResponse(server, NULL);
+    }
+    MEM_CONTEXT_TEMP_END();
+
+    FUNCTION_TEST_RETURN_VOID();
+}
+
+/**********************************************************************************************************************************/
+void
+storageRemotePathRemoveProtocol(const VariantList *paramList, ProtocolServer *server)
+{
+    FUNCTION_LOG_BEGIN(logLevelDebug);
+        FUNCTION_LOG_PARAM(VARIANT_LIST, paramList);
+        FUNCTION_LOG_PARAM(PROTOCOL_SERVER, server);
+    FUNCTION_LOG_END();
+
+    ASSERT(paramList != NULL);
+    ASSERT(server != NULL);
+    ASSERT(storageRemoteProtocolLocal.driver != NULL);
+
+    MEM_CONTEXT_TEMP_BEGIN()
+    {
+        protocolServerResponse(
+            server,
+            VARBOOL(
+                storageInterfacePathRemoveP(
+                    storageRemoteProtocolLocal.driver, varStr(varLstGet(paramList, 0)), varBool(varLstGet(paramList, 1)))));
+    }
+    MEM_CONTEXT_TEMP_END();
+
+    FUNCTION_TEST_RETURN_VOID();
+}
+
+/**********************************************************************************************************************************/
+void
+storageRemotePathSyncProtocol(const VariantList *paramList, ProtocolServer *server)
+{
+    FUNCTION_LOG_BEGIN(logLevelDebug);
+        FUNCTION_LOG_PARAM(VARIANT_LIST, paramList);
+        FUNCTION_LOG_PARAM(PROTOCOL_SERVER, server);
+    FUNCTION_LOG_END();
+
+    ASSERT(paramList != NULL);
+    ASSERT(server != NULL);
+    ASSERT(storageRemoteProtocolLocal.driver != NULL);
+
+    MEM_CONTEXT_TEMP_BEGIN()
+    {
+        storageInterfacePathSyncP(storageRemoteProtocolLocal.driver, varStr(varLstGet(paramList, 0)));
+        protocolServerResponse(server, NULL);
+    }
+    MEM_CONTEXT_TEMP_END();
+
+    FUNCTION_TEST_RETURN_VOID();
+}
+
+/**********************************************************************************************************************************/
+void
+storageRemoteRemoveProtocol(const VariantList *paramList, ProtocolServer *server)
+{
+    FUNCTION_LOG_BEGIN(logLevelDebug);
+        FUNCTION_LOG_PARAM(VARIANT_LIST, paramList);
+        FUNCTION_LOG_PARAM(PROTOCOL_SERVER, server);
+    FUNCTION_LOG_END();
+
+    ASSERT(paramList != NULL);
+    ASSERT(server != NULL);
+    ASSERT(storageRemoteProtocolLocal.driver != NULL);
+
+    MEM_CONTEXT_TEMP_BEGIN()
+    {
+        storageInterfaceRemoveP(
+            storageRemoteProtocolLocal.driver, varStr(varLstGet(paramList, 0)), .errorOnMissing = varBool(varLstGet(paramList, 1)));
+        protocolServerResponse(server, NULL);
+    }
+    MEM_CONTEXT_TEMP_END();
+
+    FUNCTION_LOG_RETURN_VOID();
 }
 
 /**********************************************************************************************************************************/
@@ -383,24 +495,22 @@ storageRemoteProtocolBlockSize(const String *message)
 
     ASSERT(message != NULL);
 
+    // Regular expression to check block messages
+    static RegExp *blockRegExp = NULL;
+
     // Create block regular expression if it has not been created yet
-    if (storageRemoteProtocolLocal.memContext == NULL)
+    if (blockRegExp == NULL)
     {
         MEM_CONTEXT_BEGIN(memContextTop())
         {
-            MEM_CONTEXT_NEW_BEGIN("StorageRemoteFileReadLocal")
-            {
-                storageRemoteProtocolLocal.memContext = memContextCurrent();
-                storageRemoteProtocolLocal.blockRegExp = regExpNew(BLOCK_REG_EXP_STR);
-            }
-            MEM_CONTEXT_NEW_END();
+            blockRegExp = regExpNew(BLOCK_REG_EXP_STR);
         }
         MEM_CONTEXT_END();
     }
 
     // Validate the header block size message
-    if (!regExpMatch(storageRemoteProtocolLocal.blockRegExp, message))
-        THROW_FMT(ProtocolError, "'%s' is not a valid block size message", strPtr(message));
+    if (!regExpMatch(blockRegExp, message))
+        THROW_FMT(ProtocolError, "'%s' is not a valid block size message", strZ(message));
 
-    FUNCTION_LOG_RETURN(SSIZE, (ssize_t)cvtZToInt(strPtr(message) + sizeof(PROTOCOL_BLOCK_HEADER) - 1));
+    FUNCTION_LOG_RETURN(SSIZE, (ssize_t)cvtZToInt(strZ(message) + sizeof(PROTOCOL_BLOCK_HEADER) - 1));
 }
