@@ -6,8 +6,8 @@ Remote Storage
 #include "common/debug.h"
 #include "common/log.h"
 #include "common/memContext.h"
-#include "common/object.h"
 #include "common/type/json.h"
+#include "common/type/object.h"
 #include "storage/remote/protocol.h"
 #include "storage/remote/read.h"
 #include "storage/remote/storage.intern.h"
@@ -30,61 +30,6 @@ struct StorageRemote
 };
 
 /**********************************************************************************************************************************/
-static bool
-storageRemoteExists(THIS_VOID, const String *file, StorageInterfaceExistsParam param)
-{
-    THIS(StorageRemote);
-
-    FUNCTION_LOG_BEGIN(logLevelDebug);
-        FUNCTION_LOG_PARAM(STORAGE_REMOTE, this);
-        FUNCTION_LOG_PARAM(STRING, file);
-        (void)param;                                                // No parameters are used
-    FUNCTION_LOG_END();
-
-    ASSERT(this != NULL);
-    ASSERT(file != NULL);
-
-    bool result = false;
-
-    MEM_CONTEXT_TEMP_BEGIN()
-    {
-        ProtocolCommand *command = protocolCommandNew(PROTOCOL_COMMAND_STORAGE_EXISTS_STR);
-        protocolCommandParamAdd(command, VARSTR(file));
-
-        result = varBool(protocolClientExecute(this->client, command, true));
-    }
-    MEM_CONTEXT_TEMP_END();
-
-    FUNCTION_LOG_RETURN(BOOL, result);
-}
-
-/**********************************************************************************************************************************/
-// Helper to convert protocol storage type to an enum
-static StorageType
-storageRemoteInfoParseType(const char type)
-{
-    FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_PARAM(CHAR, type);
-    FUNCTION_TEST_END();
-
-    switch (type)
-    {
-        case 'f':
-            FUNCTION_TEST_RETURN(storageTypeFile);
-
-        case 'p':
-            FUNCTION_TEST_RETURN(storageTypePath);
-
-        case 'l':
-            FUNCTION_TEST_RETURN(storageTypeLink);
-
-        case 's':
-            FUNCTION_TEST_RETURN(storageTypeSpecial);
-    }
-
-    THROW_FMT(AssertError, "unknown storage type '%c'", type);
-}
-
 // Helper to parse storage info from the protocol output
 static void
 storageRemoteInfoParse(ProtocolClient *client, StorageInfo *info)
@@ -94,63 +39,64 @@ storageRemoteInfoParse(ProtocolClient *client, StorageInfo *info)
         FUNCTION_TEST_PARAM(STORAGE_INFO, info);
     FUNCTION_TEST_END();
 
-    info->type = storageRemoteInfoParseType(strPtr(protocolClientReadLine(client))[0]);
-    info->userId = jsonToUInt(protocolClientReadLine(client));
-    info->user = jsonToStr(protocolClientReadLine(client));
-    info->groupId = jsonToUInt(protocolClientReadLine(client));
-    info->group = jsonToStr(protocolClientReadLine(client));
-    info->mode = jsonToUInt(protocolClientReadLine(client));
+    info->type = jsonToUInt(protocolClientReadLine(client));
     info->timeModified = (time_t)jsonToUInt64(protocolClientReadLine(client));
 
     if (info->type == storageTypeFile)
         info->size = jsonToUInt64(protocolClientReadLine(client));
 
-    if (info->type == storageTypeLink)
-        info->linkDestination = jsonToStr(protocolClientReadLine(client));
+    if (info->level >= storageInfoLevelDetail)
+    {
+        info->userId = jsonToUInt(protocolClientReadLine(client));
+        info->user = jsonToStr(protocolClientReadLine(client));
+        info->groupId = jsonToUInt(protocolClientReadLine(client));
+        info->group = jsonToStr(protocolClientReadLine(client));
+        info->mode = (mode_t)jsonToUInt(protocolClientReadLine(client));
+
+        if (info->type == storageTypeLink)
+            info->linkDestination = jsonToStr(protocolClientReadLine(client));
+    }
 
     FUNCTION_TEST_RETURN_VOID();
 }
 
 static StorageInfo
-storageRemoteInfo(THIS_VOID, const String *file, StorageInterfaceInfoParam param)
+storageRemoteInfo(THIS_VOID, const String *file, StorageInfoLevel level, StorageInterfaceInfoParam param)
 {
     THIS(StorageRemote);
 
     FUNCTION_LOG_BEGIN(logLevelDebug);
         FUNCTION_LOG_PARAM(STORAGE_REMOTE, this);
         FUNCTION_LOG_PARAM(STRING, file);
+        FUNCTION_LOG_PARAM(ENUM, level);
         FUNCTION_LOG_PARAM(BOOL, param.followLink);
     FUNCTION_LOG_END();
 
     ASSERT(this != NULL);
 
-    StorageInfo result = {.exists = false};
+    StorageInfo result = {.level = level};
 
     MEM_CONTEXT_TEMP_BEGIN()
     {
         ProtocolCommand *command = protocolCommandNew(PROTOCOL_COMMAND_STORAGE_INFO_STR);
         protocolCommandParamAdd(command, VARSTR(file));
+        protocolCommandParamAdd(command, VARUINT(level));
         protocolCommandParamAdd(command, VARBOOL(param.followLink));
 
         result.exists = varBool(protocolClientExecute(this->client, command, true));
 
         if (result.exists)
         {
-            // Read info from protocol
-            storageRemoteInfoParse(this->client, &result);
-
-            // Acknowledge command completed
-            protocolClientReadOutput(this->client, false);
-
-            // Duplicate strings into the prior context
+            // Read info from protocol into prior context
             MEM_CONTEXT_PRIOR_BEGIN()
             {
                 result.name = strDup(result.name);
-                result.linkDestination = strDup(result.linkDestination);
-                result.user = strDup(result.user);
-                result.group = strDup(result.group);
+                storageRemoteInfoParse(this->client, &result);
             }
             MEM_CONTEXT_PRIOR_END();
+
+            // Acknowledge command completed
+            protocolClientReadOutput(this->client, false);
         }
     }
     MEM_CONTEXT_TEMP_END();
@@ -161,13 +107,15 @@ storageRemoteInfo(THIS_VOID, const String *file, StorageInterfaceInfoParam param
 /**********************************************************************************************************************************/
 static bool
 storageRemoteInfoList(
-    THIS_VOID, const String *path, StorageInfoListCallback callback, void *callbackData, StorageInterfaceInfoListParam param)
+    THIS_VOID, const String *path, StorageInfoLevel level, StorageInfoListCallback callback, void *callbackData,
+    StorageInterfaceInfoListParam param)
 {
     THIS(StorageRemote);
 
     FUNCTION_LOG_BEGIN(logLevelTrace);
         FUNCTION_LOG_PARAM(STORAGE_REMOTE, this);
         FUNCTION_LOG_PARAM(STRING, path);
+        FUNCTION_LOG_PARAM(ENUM, level);
         FUNCTION_LOG_PARAM(FUNCTIONP, callback);
         FUNCTION_LOG_PARAM_P(VOID, callbackData);
         (void)param;                                                // No parameters are used
@@ -183,24 +131,32 @@ storageRemoteInfoList(
     {
         ProtocolCommand *command = protocolCommandNew(PROTOCOL_COMMAND_STORAGE_INFO_LIST_STR);
         protocolCommandParamAdd(command, VARSTR(path));
+        protocolCommandParamAdd(command, VARUINT(level));
 
         // Send command
         protocolClientWriteCommand(this->client, command);
 
         // Read list.  The list ends when there is a blank line -- this is safe even for file systems that allow blank filenames
         // since the filename is json-encoded so will always include quotes.
-        const String *name = protocolClientReadLine(this->client);
-
-        while (strSize(name) != 0)
+        MEM_CONTEXT_TEMP_RESET_BEGIN()
         {
-            StorageInfo info = {.exists = true, .name = jsonToStr(name)};
+            const String *name = protocolClientReadLine(this->client);
 
-            storageRemoteInfoParse(this->client, &info);
-            callback(callbackData, &info);
+            while (strSize(name) != 0)
+            {
+                StorageInfo info = {.exists = true, .level = level, .name = jsonToStr(name)};
 
-            // Read the next item
-            name = protocolClientReadLine(this->client);
+                storageRemoteInfoParse(this->client, &info);
+                callback(callbackData, &info);
+
+                // Reset the memory context occasionally so we don't use too much memory or slow down processing
+                MEM_CONTEXT_TEMP_RESET(1000);
+
+                // Read the next item
+                name = protocolClientReadLine(this->client);
+            }
         }
+        MEM_CONTEXT_TEMP_END();
 
         // Acknowledge command completed
         result = varBool(protocolClientReadOutput(this->client, true));
@@ -210,36 +166,6 @@ storageRemoteInfoList(
     FUNCTION_LOG_RETURN(BOOL, result);
 }
 
-/**********************************************************************************************************************************/
-static StringList *
-storageRemoteList(THIS_VOID, const String *path, StorageInterfaceListParam param)
-{
-    THIS(StorageRemote);
-
-    FUNCTION_LOG_BEGIN(logLevelDebug);
-        FUNCTION_LOG_PARAM(STORAGE_REMOTE, this);
-        FUNCTION_LOG_PARAM(STRING, path);
-        FUNCTION_LOG_PARAM(STRING, param.expression);
-    FUNCTION_LOG_END();
-
-    ASSERT(this != NULL);
-    ASSERT(path != NULL);
-
-    StringList *result = NULL;
-
-    MEM_CONTEXT_TEMP_BEGIN()
-    {
-        ProtocolCommand *command = protocolCommandNew(PROTOCOL_COMMAND_STORAGE_LIST_STR);
-        protocolCommandParamAdd(command, VARSTR(path));
-        protocolCommandParamAdd(command, VARSTR(param.expression));
-
-        result = strLstMove(strLstNewVarLst(varVarLst(protocolClientExecute(this->client, command, true))), memContextPrior());
-    }
-    MEM_CONTEXT_TEMP_END();
-
-    FUNCTION_LOG_RETURN(STRING_LIST, result);
-}
-
 /**********************************************************************************************************************************/
 static StorageRead *
 storageRemoteNewRead(THIS_VOID, const String *file, bool ignoreMissing, StorageInterfaceNewReadParam param)
@@ -251,6 +177,7 @@ storageRemoteNewRead(THIS_VOID, const String *file, bool ignoreMissing, StorageI
         FUNCTION_LOG_PARAM(STRING, file);
         FUNCTION_LOG_PARAM(BOOL, ignoreMissing);
         FUNCTION_LOG_PARAM(BOOL, param.compressible);
+        FUNCTION_LOG_PARAM(VARIANT, param.limit);
     FUNCTION_LOG_END();
 
     ASSERT(this != NULL);
@@ -259,7 +186,8 @@ storageRemoteNewRead(THIS_VOID, const String *file, bool ignoreMissing, StorageI
     FUNCTION_LOG_RETURN(
         STORAGE_READ,
         storageReadRemoteNew(
-            this, this->client, file, ignoreMissing, this->compressLevel > 0 ? param.compressible : false, this->compressLevel));
+            this, this->client, file, ignoreMissing, this->compressLevel > 0 ? param.compressible : false, this->compressLevel,
+            param.limit));
 }
 
 /**********************************************************************************************************************************/
@@ -329,35 +257,6 @@ storageRemotePathCreate(
     FUNCTION_LOG_RETURN_VOID();
 }
 
-/**********************************************************************************************************************************/
-static bool
-storageRemotePathExists(THIS_VOID, const String *path, StorageInterfacePathExistsParam param)
-{
-    THIS(StorageRemote);
-
-    FUNCTION_LOG_BEGIN(logLevelDebug);
-        FUNCTION_LOG_PARAM(STORAGE_REMOTE, this);
-        FUNCTION_LOG_PARAM(STRING, path);
-        (void)param;                                                // No parameters are used
-    FUNCTION_LOG_END();
-
-    ASSERT(this != NULL);
-    ASSERT(path != NULL);
-
-    bool result = false;
-
-    MEM_CONTEXT_TEMP_BEGIN()
-    {
-        ProtocolCommand *command = protocolCommandNew(PROTOCOL_COMMAND_STORAGE_PATH_EXISTS_STR);
-        protocolCommandParamAdd(command, VARSTR(path));
-
-        result = varBool(protocolClientExecute(this->client, command, true));
-    }
-    MEM_CONTEXT_TEMP_END();
-
-    FUNCTION_LOG_RETURN(BOOL, result);
-}
-
 /**********************************************************************************************************************************/
 static bool
 storageRemotePathRemove(THIS_VOID, const String *path, bool recurse, StorageInterfacePathRemoveParam param)
@@ -444,19 +343,14 @@ storageRemoteRemove(THIS_VOID, const String *file, StorageInterfaceRemoveParam p
     FUNCTION_LOG_RETURN_VOID();
 }
 
-/***********************************************************************************************************************************
-New object
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 static const StorageInterface storageInterfaceRemote =
 {
-    .exists = storageRemoteExists,
     .info = storageRemoteInfo,
     .infoList = storageRemoteInfoList,
-    .list = storageRemoteList,
     .newRead = storageRemoteNewRead,
     .newWrite = storageRemoteNewWrite,
     .pathCreate = storageRemotePathCreate,
-    .pathExists = storageRemotePathExists,
     .pathRemove = storageRemotePathRemove,
     .pathSync = storageRemotePathSync,
     .remove = storageRemoteRemove,
