@@ -12,6 +12,18 @@ Storage type
 #define STORAGE_S3_TYPE                                             "s3"
     STRING_DECLARE(STORAGE_S3_TYPE_STR);
 
+/***********************************************************************************************************************************
+Key type
+***********************************************************************************************************************************/
+typedef enum
+{
+    storageS3KeyTypeShared,
+    storageS3KeyTypeAuto,
+} StorageS3KeyType;
+
+#define STORAGE_S3_KEY_TYPE_SHARED                                  "shared"
+#define STORAGE_S3_KEY_TYPE_AUTO                                    "auto"
+
 /***********************************************************************************************************************************
 URI style
 ***********************************************************************************************************************************/
@@ -27,17 +39,15 @@ typedef enum
 /***********************************************************************************************************************************
 Defaults
 ***********************************************************************************************************************************/
-#define STORAGE_S3_TIMEOUT_DEFAULT                                  60000
 #define STORAGE_S3_PARTSIZE_MIN                                     ((size_t)5 * 1024 * 1024)
-#define STORAGE_S3_DELETE_MAX                                       1000
 
 /***********************************************************************************************************************************
-Constructor
+Constructors
 ***********************************************************************************************************************************/
 Storage *storageS3New(
     const String *path, bool write, StoragePathExpressionCallback pathExpressionFunction, const String *bucket,
-    const String *endPoint, StorageS3UriStyle uriStyle, const String *region, const String *accessKey,
-    const String *secretAccessKey, const String *securityToken, size_t partSize, unsigned int deleteMax, const String *host,
+    const String *endPoint, StorageS3UriStyle uriStyle, const String *region, StorageS3KeyType keyType, const String *accessKey,
+    const String *secretAccessKey, const String *securityToken, const String *credRole, size_t partSize, const String *host,
     unsigned int port, TimeMSec timeout, bool verifyPeer, const String *caFile, const String *caPath);
 
 #endif
