@@ -27,8 +27,8 @@ sub codeCountScan
     my $strBasePath = shift;
 
     # Load YAML
-    require YAML::Any;
-    YAML::Any->import(qw(Load Dump));
+    require YAML::XS;
+    YAML::XS->import(qw(Load Dump));
 
     my $hCodeCount = {};
 
@@ -64,7 +64,7 @@ sub codeCountScan
                  $strFile =~ '^test/expect/' ||
                  $strFile =~ '^test/patch/' ||
                  $strFile =~ '^test/result/' ||
-                 $strFile eq 'test/scratch.txt' ||
+                 $strFile =~ '^test/scratch' ||
                  $strFile =~ '^test/src/valgrind\.suppress\.' ||
                  $strFile eq 'test/src/lcov.conf');
 
