@@ -11,16 +11,22 @@ use warnings FATAL => qw(all);
 use Carp qw(confess);
 use English '-no_match_vars';
 
+use Digest::SHA qw(sha1_hex);
 use Exporter qw(import);
     our @EXPORT = qw();
 use File::Basename qw(dirname);
 
-use pgBackRest::Common::Log;
-use pgBackRest::Common::String;
-use pgBackRest::Version;
+use pgBackRestDoc::Common::Log;
+use pgBackRestDoc::Common::String;
+use pgBackRestDoc::Html::DocHtmlBuilder;
+use pgBackRestDoc::Html::DocHtmlElement;
+use pgBackRestDoc::ProjectInfo;
 
-use BackRestDoc::Html::DocHtmlBuilder;
-use BackRestDoc::Html::DocHtmlElement;
+use pgBackRestTest::Common::ContainerTest;
+use pgBackRestTest::Common::DefineTest;
+use pgBackRestTest::Common::ExecuteTest;
+use pgBackRestTest::Common::ListTest;
+use pgBackRestTest::Common::RunTest;
 
 ####################################################################################################################################
 # Generate an lcov configuration file
@@ -29,12 +35,14 @@ sub coverageLCovConfigGenerate
 {
     my $oStorage = shift;
     my $strOutFile = shift;
+    my $bContainer = shift;
     my $bCoverageSummary = shift;
 
     my $strBranchFilter =
         'OBJECT_DEFINE_[A-Z0-9_]+\(|\s{4}[A-Z][A-Z0-9_]+\([^\?]*\)|\s{4}(ASSERT|assert|switch\s)\(|\{\+{0,1}' .
         ($bCoverageSummary ? 'uncoverable_branch' : 'uncover(ed|able)_branch');
-    my $strLineFilter = '\{\+{0,1}uncover' . ($bCoverageSummary ? 'able' : '(ed|able)') . '[^_]';
+    my $strLineFilter =
+        '\{\+{0,1}' . ($bCoverageSummary ? 'uncoverable' : '(uncover(ed|able)' . ($bContainer ? '' : '|vm_covered') . ')') . '[^_]';
 
     my $strConfig =
         "# LCOV Settings\n" .
@@ -66,12 +74,338 @@ sub coverageLCovConfigGenerate
 
 push @EXPORT, qw(coverageLCovConfigGenerate);
 
+####################################################################################################################################
+# Extract coverage using gcov
+####################################################################################################################################
+sub coverageExtract
+{
+    my $oStorage = shift;
+    my $strModule = shift;
+    my $strTest = shift;
+    my $bContainer = shift;
+    my $bSummary = shift;
+    my $strContainerImage = shift;
+    my $strWorkPath = shift;
+    my $strWorkTmpPath = shift;
+    my $strWorkUnitPath = shift;
+    my $strTestResultCoveragePath = shift . '/coverage';
+
+    # Coverage summary must be run in a container
+    if ($bSummary && !$bContainer)
+    {
+        confess &log(ERROR, "coverage summary must be run on containers for full coverage");
+    }
+
+    # Generate a list of files to cover
+    my $hTestCoverage = (testDefModuleTest($strModule, $strTest))->{&TESTDEF_COVERAGE};
+
+    my @stryCoveredModule;
+
+    foreach my $strModule (sort(keys(%{$hTestCoverage})))
+    {
+        push (@stryCoveredModule, $strModule);
+    }
+
+    push(@stryCoveredModule, "module/${strModule}/" . testRunName($strTest, false) . 'Test');
+
+    # Generate coverage reports for the modules
+    my $strLCovConf = "${strTestResultCoveragePath}/raw/lcov.conf";
+    coverageLCovConfigGenerate($oStorage, $strLCovConf, $bContainer, $bSummary);
+
+    my $strLCovExe = "lcov --config-file=${strLCovConf}";
+    my $strLCovOut = "${strWorkUnitPath}/test.lcov";
+    my $strLCovOutTmp = "${strWorkUnitPath}/test.tmp.lcov";
+
+    executeTest(
+        (defined($strContainerImage) ? 'docker exec -i -u ' . TEST_USER . " ${strContainerImage} " : '') .
+        "${strLCovExe} --capture --directory=${strWorkUnitPath} --o=${strLCovOut}");
+
+    # Generate coverage report for each module
+    foreach my $strCoveredModule (@stryCoveredModule)
+    {
+        my $strModuleName = testRunName($strCoveredModule, false);
+        my $strModuleOutName = $strModuleName;
+        my $bTest = false;
+
+        if ($strModuleOutName =~ /^module/mg)
+        {
+            $strModuleOutName =~ s/^module/test/mg;
+            $bTest = true;
+        }
+
+        # Generate lcov reports
+        my $strModulePath =
+            "${strWorkPath}/repo/" .
+            (${strModuleOutName} =~ /^test\// ?
+                'test/src/module/' . substr(${strModuleOutName}, 5) : "src/${strModuleOutName}");
+        my $strLCovFile = "${strTestResultCoveragePath}/raw/${strModuleOutName}.lcov";
+        my $strLCovTotal = "${strWorkTmpPath}/all.lcov";
+
+        executeTest(
+            "${strLCovExe}" . ($bTest ? ' --rc lcov_branch_coverage=0' : '') . " --extract=${strLCovOut} */${strModuleName}.c" .
+                " --o=${strLCovOutTmp}");
+
+        # Combine with prior run if there was one
+        if ($oStorage->exists($strLCovFile))
+        {
+            my $strCoverage = ${$oStorage->get($strLCovOutTmp)};
+            $strCoverage =~ s/^SF\:.*$/SF:$strModulePath\.c/mg;
+            $oStorage->put($strLCovOutTmp, $strCoverage);
+
+            executeTest("${strLCovExe} --add-tracefile=${strLCovOutTmp} --add-tracefile=${strLCovFile} --o=${strLCovOutTmp}");
+        }
+
+        # Update source file
+        my $strCoverage = ${$oStorage->get($strLCovOutTmp)};
+
+        if (defined($strCoverage))
+        {
+            if (!$bTest && $hTestCoverage->{$strCoveredModule} eq TESTDEF_COVERAGE_NOCODE)
+            {
+                confess &log(ERROR, "module '${strCoveredModule}' is marked 'no code' but has code");
+            }
+
+            # Get coverage info
+            my $iTotalLines = (split(':', ($strCoverage =~ m/^LF:.*$/mg)[0]))[1] + 0;
+            my $iCoveredLines = (split(':', ($strCoverage =~ m/^LH:.*$/mg)[0]))[1] + 0;
+
+            my $iTotalBranches = 0;
+            my $iCoveredBranches = 0;
+
+            if ($strCoverage =~ /^BRF\:/mg && $strCoverage =~ /^BRH\:/mg)
+            {
+                # If this isn't here the statements below fail -- huh?
+                my @match = $strCoverage =~ m/^BRF\:.*$/mg;
+
+                $iTotalBranches = (split(':', ($strCoverage =~ m/^BRF:.*$/mg)[0]))[1] + 0;
+                $iCoveredBranches = (split(':', ($strCoverage =~ m/^BRH:.*$/mg)[0]))[1] + 0;
+            }
+
+            # Report coverage if this is not a test or if the test does not have complete coverage
+            if (!$bTest || $iTotalLines != $iCoveredLines || $iTotalBranches != $iCoveredBranches)
+            {
+                # Fix source file name
+                $strCoverage =~ s/^SF\:.*$/SF:$strModulePath\.c/mg;
+
+                $oStorage->put($oStorage->openWrite($strLCovFile, {bPathCreate => true}), $strCoverage);
+
+                if ($oStorage->exists($strLCovTotal))
+                {
+                    executeTest("${strLCovExe} --add-tracefile=${strLCovFile} --add-tracefile=${strLCovTotal} --o=${strLCovTotal}");
+                }
+                else
+                {
+                    $oStorage->copy($strLCovFile, $strLCovTotal)
+                }
+            }
+            else
+            {
+                $oStorage->remove($strLCovFile);
+            }
+        }
+        else
+        {
+            if ($hTestCoverage->{$strCoveredModule} ne TESTDEF_COVERAGE_NOCODE)
+            {
+                confess &log(ERROR, "module '${strCoveredModule}' is marked 'code' but has no code");
+            }
+        }
+    }
+}
+
+push @EXPORT, qw(coverageExtract);
+
+####################################################################################################################################
+# Validate converage and generate reports
+####################################################################################################################################
+sub coverageValidateAndGenerate
+{
+    my $oyTestRun = shift;
+    my $oStorage = shift;
+    my $bCoverageReport = shift;
+    my $bCoverageSummary = shift;
+    my $strWorkPath = shift;
+    my $strWorkTmpPath = shift;
+    my $strTestResultCoveragePath = shift . '/coverage';
+    my $strTestResultSummaryPath = shift;
+
+    my $result = 0;
+
+    # Determine which modules were covered (only check coverage if all tests were successful)
+    #-----------------------------------------------------------------------------------------------------------------------
+    my $hModuleTest;                                        # Everything that was run
+
+    # Build a hash of all modules, tests, and runs that were executed
+    foreach my $hTestRun (@{$oyTestRun})
+    {
+        # Get coverage for the module
+        my $strModule = $hTestRun->{&TEST_MODULE};
+        my $hModule = testDefModule($strModule);
+
+        # Get coverage for the test
+        my $strTest = $hTestRun->{&TEST_NAME};
+        my $hTest = testDefModuleTest($strModule, $strTest);
+
+        # If no tests are listed it means all of them were run
+        if (@{$hTestRun->{&TEST_RUN}} == 0)
+        {
+            $hModuleTest->{$strModule}{$strTest} = true;
+        }
+    }
+
+    # Now compare against code modules that should have full coverage
+    my $hCoverageList = testDefCoverageList();
+    my $hCoverageType = testDefCoverageType();
+    my $hCoverageActual;
+
+    foreach my $strCodeModule (sort(keys(%{$hCoverageList})))
+    {
+        if (@{$hCoverageList->{$strCodeModule}} > 0)
+        {
+            my $iCoverageTotal = 0;
+
+            foreach my $hTest (@{$hCoverageList->{$strCodeModule}})
+            {
+                if (!defined($hModuleTest->{$hTest->{strModule}}{$hTest->{strTest}}))
+                {
+                    next;
+                }
+
+                $iCoverageTotal++;
+            }
+
+            if (@{$hCoverageList->{$strCodeModule}} == $iCoverageTotal)
+            {
+                $hCoverageActual->{testRunName($strCodeModule, false)} = $hCoverageType->{$strCodeModule};
+            }
+        }
+    }
+
+    if (keys(%{$hCoverageActual}) == 0)
+    {
+        &log(INFO, 'no code modules had all tests run required for coverage');
+    }
+
+    # Generate C coverage report
+    #---------------------------------------------------------------------------------------------------------------------------
+    my $strLCovFile = "${strWorkTmpPath}/all.lcov";
+
+    if ($oStorage->exists($strLCovFile))
+    {
+        foreach my $strCodeModule (sort(keys(%{$hCoverageActual})))
+        {
+            my $strCoverageFile = $strCodeModule;
+            $strCoverageFile =~ s/^module/test/mg;
+            $strCoverageFile = "${strTestResultCoveragePath}/raw/${strCoverageFile}.lcov";
+
+            my $strCoverage = $oStorage->get($oStorage->openRead($strCoverageFile, {bIgnoreMissing => true}));
+
+            if (defined($strCoverage) && defined($$strCoverage))
+            {
+                my $iTotalLines = (split(':', ($$strCoverage =~ m/^LF\:.*$/mg)[0]))[1] + 0;
+                my $iCoveredLines = (split(':', ($$strCoverage =~ m/^LH\:.*$/mg)[0]))[1] + 0;
+
+                my $iTotalBranches = 0;
+                my $iCoveredBranches = 0;
+
+                if ($$strCoverage =~ /^BRF\:/mg && $$strCoverage =~ /^BRH\:/mg)
+                {
+                    # If this isn't here the statements below fail -- huh?
+                    my @match = $$strCoverage =~ m/^BRF\:.*$/mg;
+
+                    $iTotalBranches = (split(':', ($$strCoverage =~ m/^BRF\:.*$/mg)[0]))[1] + 0;
+                    $iCoveredBranches = (split(':', ($$strCoverage =~ m/^BRH\:.*$/mg)[0]))[1] + 0;
+                }
+
+                # Generate detail if there is missing coverage
+                my $strDetail = undef;
+
+                if ($iCoveredLines != $iTotalLines)
+                {
+                    $strDetail .= "$iCoveredLines/$iTotalLines lines";
+                }
+
+                if ($iTotalBranches != $iCoveredBranches)
+                {
+                    $strDetail .= (defined($strDetail) ? ', ' : '') . "$iCoveredBranches/$iTotalBranches branches";
+                }
+
+                if (defined($strDetail))
+                {
+                    &log(ERROR, "c module ${strCodeModule} is not fully covered ($strDetail)");
+                    $result++;
+                }
+            }
+        }
+
+        if ($result == 0)
+        {
+            &log(INFO, "tested modules have full coverage");
+        }
+
+        if ($bCoverageReport)
+        {
+            &log(INFO, 'writing C coverage report');
+
+            executeTest(
+                "genhtml ${strLCovFile} --config-file=${strTestResultCoveragePath}/raw/lcov.conf" .
+                    " --prefix=${strWorkPath}/repo" .
+                    " --output-directory=${strTestResultCoveragePath}/lcov");
+
+            coverageGenerate(
+                $oStorage, "${strWorkPath}/repo", "${strTestResultCoveragePath}/raw", "${strTestResultCoveragePath}/coverage.html");
+        }
+
+        if ($bCoverageSummary)
+        {
+            &log(INFO, 'writing C coverage summary report');
+
+            coverageDocSummaryGenerate(
+                $oStorage, "${strTestResultCoveragePath}/raw", "${strTestResultSummaryPath}/metric-coverage-report.auto.xml");
+        }
+    }
+
+    # Remove coverage report when no coverage or no report to avoid confusion from looking at an old report
+    if (!$bCoverageReport || !$oStorage->exists($strLCovFile))
+    {
+        executeTest("rm -rf ${strTestResultCoveragePath}");
+    }
+
+    return $result;
+}
+
+push @EXPORT, qw(coverageValidateAndGenerate);
+
 ####################################################################################################################################
 # Generate a C coverage report
 ####################################################################################################################################
+# Helper to get the function for the current line
+sub coverageGenerateFunction
+{
+    my $rhFile = shift;
+    my $iCurrentLine = shift;
+
+    my $rhFunction;
+
+    foreach my $iFunctionLine (sort(keys(%{$rhFile->{function}})))
+    {
+        last if $iCurrentLine < $iFunctionLine;
+
+        $rhFunction = $rhFile->{function}{$iFunctionLine};
+    }
+
+    if (!defined($rhFunction))
+    {
+        confess &log(ERROR, "function not found at line ${iCurrentLine}");
+    }
+
+    return $rhFunction;
+}
+
 sub coverageGenerate
 {
     my $oStorage = shift;
+    my $strBasePath = shift;
     my $strCoveragePath = shift;
     my $strOutFile = shift;
 
@@ -88,8 +422,7 @@ sub coverageGenerate
             my $strCoverage = ${$oStorage->get("${strCoveragePath}/${strFileCov}")};
 
             # Show that the file is part of the coverage report even if there is no missing coverage
-            my $strFile = substr($strFileCov, 0, length($strFileCov) - 5) . '.c';
-            $rhCoverage->{$strFile} = undef;
+            my $strFile;
 
             my $iBranchLine = -1;
             my $iBranch = undef;
@@ -98,8 +431,24 @@ sub coverageGenerate
 
             foreach my $strLine (split("\n", $strCoverage))
             {
+                # Get source file name
+                if ($strLine =~ /^SF\:/)
+                {
+                    $strFile = substr($strLine, 3);
+                    $rhCoverage->{$strFile} = undef;
+
+                    # Generate a random anchor so new reports will not show links as already followed.  This is also an easy way
+                    # to create valid, disambiguos links.
+                    $rhCoverage->{$strFile}{anchor} = sha1_hex(rand(16));
+                }
+                # Mark functions as initially covered
+                if ($strLine =~ /^FN\:/)
+                {
+                    my ($strLineBegin) = split("\,", substr($strLine, 3));
+                    $rhCoverage->{$strFile}{function}{sprintf("%09d", $strLineBegin - 1)}{covered} = true;
+                }
                 # Check branch coverage
-                if ($strLine =~ /^BRDA\:/)
+                elsif ($strLine =~ /^BRDA\:/)
                 {
                     my @stryData = split("\,", substr($strLine, 5));
 
@@ -112,8 +461,8 @@ sub coverageGenerate
 
                     if ($iBranchLine != $stryData[0])
                     {
-                        $iBranchLine = $stryData[0];
-                        $iBranch = $stryData[1];
+                        $iBranchLine = $stryData[0] + 0;
+                        $iBranch = $stryData[1] + 0;
                         $iBranchIdx = 0;
                         $iBranchPart = 0;
                     }
@@ -121,10 +470,10 @@ sub coverageGenerate
                     {
                         if ($iBranchPart != 1)
                         {
-                            confess &log(ERROR, "line ${iBranchLine}, branch ${iBranch} does not have two parts");
+                            confess &log(ERROR, "line ${iBranchLine}, branch ${iBranch} does not have at least two parts");
                         }
 
-                        $iBranch = $stryData[1];
+                        $iBranch = $stryData[1] + 0;
                         $iBranchIdx++;
                         $iBranchPart = 0;
                     }
@@ -135,6 +484,12 @@ sub coverageGenerate
 
                     $rhCoverage->{$strFile}{line}{$strBranchLine}{branch}{$iBranchIdx}{$iBranchPart} =
                         $stryData[3] eq '-' || $stryData[3] eq '0' ? false : true;
+
+                    # If the branch is uncovered then the function is uncovered
+                    if (!$rhCoverage->{$strFile}{line}{$strBranchLine}{branch}{$iBranchIdx}{$iBranchPart})
+                    {
+                        coverageGenerateFunction($rhCoverage->{$strFile}, $strBranchLine)->{covered} = false;
+                    }
                 }
 
                 # Check line coverage
@@ -147,104 +502,77 @@ sub coverageGenerate
                         confess &log(ERROR, "'${strLine}' should have two fields");
                     }
 
-                    my $strBranchLine = sprintf("%09d", $stryData[0]);
+                    my $strStatementLine = sprintf("%09d", $stryData[0]);
 
+                    # If the statement is uncovered then the function is uncovered
                     if ($stryData[1] eq '0')
                     {
-                        $rhCoverage->{$strFile}{line}{$strBranchLine}{statement} = 0;
+                        $rhCoverage->{$strFile}{line}{$strStatementLine}{statement} = 0;
+                        coverageGenerateFunction($rhCoverage->{$strFile}, $strStatementLine)->{covered} = false;
                     }
                 }
             }
         }
     }
 
-    # Remove branch coverage on lines that are completely covered
+    # Report on the entire function if any branches/lines in the function are uncovered
     foreach my $strFile (sort(keys(%{$rhCoverage})))
     {
-        foreach my $iLine (sort(keys(%{$rhCoverage->{$strFile}{line}})))
-        {
-            if (defined($rhCoverage->{$strFile}{line}{$iLine}{branch}))
-            {
-                # We'll assume the line is completely covered
-                my $bCovered = true;
+        my $bFileCovered = true;
 
-                foreach my $iBranch (sort(keys(%{$rhCoverage->{$strFile}{line}{$iLine}{branch}})))
-                {
-                    foreach my $iBranchPart (sort(keys(%{$rhCoverage->{$strFile}{line}{$iLine}{branch}{$iBranch}})))
-                    {
-                        if (!$rhCoverage->{$strFile}{line}{$iLine}{branch}{$iBranch}{$iBranchPart})
-                        {
-                            $bCovered = false;
-                        }
-                    }
-                }
-
-                if ($bCovered)
-                {
-                    # &log(WARN, "removed branch coverage for ${strFile} line ${iLine}");
-                    if (defined($rhCoverage->{$strFile}{line}{$iLine}{statement}))
-                    {
-                        delete($rhCoverage->{$strFile}{line}{$iLine}{branch});
-                    }
-                    else
-                    {
-                        delete($rhCoverage->{$strFile}{line}{$iLine});
-                    }
-                }
-            }
-        }
-    }
-
-    # Remove line when no lines are uncovered
-    foreach my $strFile (sort(keys(%{$rhCoverage})))
-    {
-        my $bCovered = true;
-
-        foreach my $iLine (sort(keys(%{$rhCoverage->{$strFile}{line}})))
-        {
-            $bCovered = false;
-            last;
-        }
-
-        if ($bCovered)
-        {
-            delete($rhCoverage->{$strFile}{line});
-        }
-    }
-
-    # Report on the entire function if any lines in the function are uncovered
-    foreach my $strFile (sort(keys(%{$rhCoverage})))
-    {
+        # Proceed if there is some coverage data
         if (defined($rhCoverage->{$strFile}{line}))
         {
-            my $strC = ${$oStorage->get("${strCoveragePath}/${strFile}")};
-            my @stryC = split("\n", $strC);
+            my @stryC = split("\n", ${$oStorage->get($strFile)});
+            my $bInUncoveredFunction = false;
 
-            foreach my $iLine (sort(keys(%{$rhCoverage->{$strFile}{line}})))
+            # Iterate every line in the C file
+            for (my $iLineIdx = 0; $iLineIdx < @stryC; $iLineIdx++)
             {
-                # Run back to the beginning of the function comment
-                for (my $iLineIdx = $iLine; $iLineIdx >= 0; $iLineIdx--)
-                {
-                    if (!defined($rhCoverage->{$strFile}{line}{sprintf("%09d", $iLineIdx)}))
-                    {
-                        $rhCoverage->{$strFile}{line}{sprintf("%09d", $iLineIdx)} = undef;
-                    }
+                my $iLine = sprintf("%09d", $iLineIdx + 1);
 
-                    last if ($stryC[$iLineIdx - 1] =~ '^\/\*');
+                # If not in an uncovered function see if this line is the start of an uncovered function
+                if (!$bInUncoveredFunction)
+                {
+                    $bInUncoveredFunction =
+                        defined($rhCoverage->{$strFile}{function}{$iLine}) && !$rhCoverage->{$strFile}{function}{$iLine}{covered};
+
+                    # If any function is uncovered then the file is uncovered
+                    if ($bInUncoveredFunction)
+                    {
+                        $bFileCovered = false;
+                    }
                 }
 
-                # Run forward to the end of the function
-                for (my $iLineIdx = $iLine; $iLineIdx < @stryC; $iLineIdx++)
+                # If not in an uncovered function remove coverage
+                if (!$bInUncoveredFunction)
                 {
-                    if (!defined($rhCoverage->{$strFile}{line}{sprintf("%09d", $iLineIdx)}))
+                    delete($rhCoverage->{$strFile}{line}{$iLine});
+                }
+                # Else in an uncovered function
+                else
+                {
+                    # If there is no coverage for this line define it so it will show up on the report
+                    if (!defined($rhCoverage->{$strFile}{line}{$iLine}))
                     {
-                        $rhCoverage->{$strFile}{line}{sprintf("%09d", $iLineIdx)} = undef;
+                        $rhCoverage->{$strFile}{line}{$iLine} = undef;
                     }
 
-                    last if ($stryC[$iLineIdx - 1] eq '}');
+                    # Stop processing at the function end brace. This depends on the file being formated correctly, but worst case
+                    # is we run on a display the entire file rather than just uncovered functions.
+                    if ($stryC[$iLineIdx] =~ '^\}')
+                    {
+                        $bInUncoveredFunction = false;
+                    }
                 }
             }
         }
+
+        # Remove coverage info when file is fully covered
+        if ($bFileCovered)
+        {
+            delete($rhCoverage->{$strFile}{line});
+        }
     }
 
     # Build html
@@ -253,7 +581,7 @@ sub coverageGenerate
     my $strGray = '#555555';
     my $strDarkGray = '#333333';
 
-    my $oHtml = new BackRestDoc::Html::DocHtmlBuilder(
+    my $oHtml = new pgBackRestDoc::Html::DocHtmlBuilder(
         PROJECT_NAME, $strTitle,
         undef, undef, undef,
         true, true,
@@ -424,11 +752,13 @@ sub coverageGenerate
         "    color: white;\n" .
         "}\n");
 
+    # File list title
     $oHtml->bodyGet()->addNew(HTML_DIV, 'title', {strContent => $strTitle});
 
     # Build the file list table
+    $oHtml->bodyGet()->addNew(HTML_DIV, 'list-table-caption');
+
     my $oTable = $oHtml->bodyGet()->addNew(HTML_TABLE, 'list-table');
-    $oTable->addNew(HTML_DIV, 'list-table-caption');
 
     my $oHeader = $oTable->addNew(HTML_TR, 'list-table-header');
     $oHeader->addNew(HTML_TH, 'list-table-header-file', {strContent => 'FILE'});
@@ -436,25 +766,43 @@ sub coverageGenerate
     foreach my $strFile (sort(keys(%{$rhCoverage})))
     {
         my $oRow = $oTable->addNew(HTML_TR, 'list-table-row-' . (defined($rhCoverage->{$strFile}{line}) ? 'uncovered' : 'covered'));
-        $oRow->addNew(HTML_TD, 'list-table-row-file', {strContent => $strFile});
+        my $strFileDisplay = substr($strFile, length($strBasePath) + 1);
+
+        # Link only created when file is uncovered
+        if (defined($rhCoverage->{$strFile}{line}))
+        {
+            $oRow->addNew(HTML_TD, 'list-table-row-file')->addNew(
+                HTML_A, undef, {strContent => $strFileDisplay, strRef => '#' . $rhCoverage->{$strFile}{anchor}});
+        }
+        # Else just show the file name
+        else
+        {
+            $oRow->addNew(HTML_TD, 'list-table-row-file', {strContent => $strFileDisplay});
+        }
     }
 
     # Report on files that are missing coverage
     foreach my $strFile (sort(keys(%{$rhCoverage})))
     {
+        my $strFileDisplay = substr($strFile, length($strBasePath) + 1);
+
         if (defined($rhCoverage->{$strFile}{line}))
         {
+            # Anchor only created when file is uncovered
+            $oHtml->bodyGet()->addNew(HTML_A, undef, {strId => $rhCoverage->{$strFile}{anchor}});
+
+            # Report table caption, i.e. the uncovered file name
+            $oHtml->bodyGet()->addNew(HTML_DIV, 'report-table-caption', {strContent => $strFileDisplay});
+
             # Build the file report table
             $oTable = $oHtml->bodyGet()->addNew(HTML_TABLE, 'report-table');
 
-            $oTable->addNew(HTML_DIV, 'report-table-caption', {strContent => "${strFile}"});
-
             $oHeader = $oTable->addNew(HTML_TR, 'report-table-header');
             $oHeader->addNew(HTML_TH, 'report-table-header-line', {strContent => 'LINE'});
             $oHeader->addNew(HTML_TH, 'report-table-header-branch', {strContent => 'BRANCH'});
             $oHeader->addNew(HTML_TH, 'report-table-header-code', {strContent => 'CODE'});
 
-            my $strC = ${$oStorage->get("${strCoveragePath}/${strFile}")};
+            my $strC = ${$oStorage->get($strFile)};
             my @stryC = split("\n", $strC);
             my $iLastLine = undef;
 
@@ -474,46 +822,47 @@ sub coverageGenerate
                 my $strBranch;
 
                 # Show missing branch coverage
-                if (defined($rhCoverage->{$strFile}{line}{$strLine}{branch}) &&
-                    !defined($rhCoverage->{$strFile}{line}{$strLine}{statement}))
-                {
-                    my $iBranchIdx = 0;
+                my $bBranchCovered = true;
 
+                if (defined($rhCoverage->{$strFile}{line}{$strLine}{branch}))
+                {
                     foreach my $iBranch (sort(keys(%{$rhCoverage->{$strFile}{line}{$strLine}{branch}})))
                     {
-                        $strBranch .=
-                            '[' .
-                            ($rhCoverage->{$strFile}{line}{$strLine}{branch}{$iBranch}{0} ?
-                                '+' : '-') .
-                            ' ' .
-                            ($rhCoverage->{$strFile}{line}{$strLine}{branch}{$iBranch}{1} ?
-                                '+' : '-') .
-                            ']';
+                        $strBranch .= '[';
 
-                        if ($iBranchIdx == 1)
+                        my $bBranchPartFirst = true;
+
+                        foreach my $iBranchPart (sort(keys(%{$rhCoverage->{$strFile}{line}{$strLine}{branch}{$iBranch}})))
                         {
-                            $strBranch .= '<br/>';
-                            $iBranchIdx = 0;
-                        }
-                        else
-                        {
-                            $strBranch .= ' ';
-                            $iBranchIdx++;
+                            if (!$bBranchPartFirst)
+                            {
+                                $strBranch .= ' ';
+                            }
+
+                            if ($rhCoverage->{$strFile}{line}{$strLine}{branch}{$iBranch}{$iBranchPart})
+                            {
+                                $strBranch .= '+';
+                            }
+                            else
+                            {
+                                $strBranch .= '-';
+                                $bBranchCovered = false;
+                            }
+
+                            $bBranchPartFirst = false;
                         }
+
+                        $strBranch .= ']';
                     }
                 }
 
                 $oRow->addNew(
-                    HTML_TD, 'report-table-row-branch' . (defined($strBranch) ? '-uncovered' : ''),
-                    {strContent => $strBranch});
+                    HTML_TD, 'report-table-row-branch' . (!$bBranchCovered ? '-uncovered' : ''), {strContent => $strBranch});
 
                 # Color code based on coverage
-                my $bUncovered =
-                    defined($rhCoverage->{$strFile}{line}{$strLine}{branch}) ||
-                    defined($rhCoverage->{$strFile}{line}{$strLine}{statement});
-
                 $oRow->addNew(
-                    HTML_TD, 'report-table-row-code' . ($bUncovered ? '-uncovered' : ''),
+                    HTML_TD,
+                    'report-table-row-code' . (defined($rhCoverage->{$strFile}{line}{$strLine}{statement}) ? '-uncovered' : ''),
                     {bPre => true, strContent => $stryC[$strLine - 1]});
             }
         }
