@@ -39,22 +39,27 @@ use constant TESTDEF_TEST                                           => 'test';
 
 use constant TESTDEF_DB                                             => 'db';
     push @EXPORT, qw(TESTDEF_DB);
+use constant TESTDEF_DEPEND                                         => 'depend';
 use constant TESTDEF_CONTAINER                                      => 'container';
     push @EXPORT, qw(TESTDEF_CONTAINER);
 use constant TESTDEF_CONTAINER_REQUIRED                             => 'containerReq';
     push @EXPORT, qw(TESTDEF_CONTAINER_REQUIRED);
 use constant TESTDEF_COVERAGE                                       => 'coverage';
     push @EXPORT, qw(TESTDEF_COVERAGE);
+use constant TESTDEF_CORE                                           => 'core';
+    push @EXPORT, qw(TESTDEF_CORE);
 use constant TESTDEF_EXPECT                                         => 'expect';
     push @EXPORT, qw(TESTDEF_EXPECT);
 use constant TESTDEF_C                                              => 'c';
     push @EXPORT, qw(TESTDEF_C);
 use constant TESTDEF_DEFINE                                         => 'define';
     push @EXPORT, qw(TESTDEF_DEFINE);
-use constant TESTDEF_DEFINE_TEST                                    => 'define-test';
-    push @EXPORT, qw(TESTDEF_DEFINE_TEST);
+use constant TESTDEF_FEATURE                                        => 'feature';
+    push @EXPORT, qw(TESTDEF_FEATURE);
 use constant TESTDEF_DEBUG_UNIT_SUPPRESS                            => 'debugUnitSuppress';
     push @EXPORT, qw(TESTDEF_DEBUG_UNIT_SUPPRESS);
+use constant TESTDEF_HARNESS                                        => 'harness';
+    push @EXPORT, qw(TESTDEF_HARNESS);
 use constant TESTDEF_INCLUDE                                        => 'include';
     push @EXPORT, qw(TESTDEF_INCLUDE);
 use constant TESTDEF_INDIVIDUAL                                     => 'individual';
@@ -70,8 +75,6 @@ use constant TESTDEF_VM                                             => 'vm';
 
 use constant TESTDEF_COVERAGE_FULL                                  => 'full';
     push @EXPORT, qw(TESTDEF_COVERAGE_FULL);
-use constant TESTDEF_COVERAGE_PARTIAL                               => 'partial';
-    push @EXPORT, qw(TESTDEF_COVERAGE_PARTIAL);
 use constant TESTDEF_COVERAGE_NOCODE                                => 'noCode';
     push @EXPORT, qw(TESTDEF_COVERAGE_NOCODE);
 
@@ -94,6 +97,15 @@ sub testDefLoad
 
     my $hTestDef = Load($strDefineYaml);
 
+    # Keep a list of all harnesses added so far. These will make up the harness list for subsequent tests.
+    my @stryHarnessFile = ();
+
+    # Keep a list of all modules added for coverage so far. These will make up the core list for subsequent tests.
+    my @stryCoreFile = ();
+
+    # Keep a list of modules that are test before this one so we know what is available
+    my $strTestDefine = '';
+
     # Iterate each test type
     foreach my $strModuleType (TESTDEF_UNIT, TESTDEF_INTEGRATION, TESTDEF_PERFORMANCE)
     {
@@ -128,7 +140,7 @@ sub testDefLoad
 
                 # Resolve variables that can be set in the module or the test
                 foreach my $strVar (
-                    TESTDEF_DEFINE, TESTDEF_DEFINE_TEST, TESTDEF_DEBUG_UNIT_SUPPRESS, TESTDEF_DB, TESTDEF_BIN_REQ, TESTDEF_VM,
+                    TESTDEF_DEFINE, TESTDEF_DEBUG_UNIT_SUPPRESS, TESTDEF_DB, TESTDEF_BIN_REQ, TESTDEF_VM,
                     TESTDEF_CONTAINER_REQUIRED)
                 {
                     $hTestDefHash->{$strModule}{$strTest}{$strVar} = coalesce(
@@ -150,6 +162,44 @@ sub testDefLoad
                 $hTestDefHash->{$strModule}{$strTest}{&TESTDEF_CONTAINER} = $bContainer;
                 $hTestDefHash->{$strModule}{$strTest}{&TESTDEF_INDIVIDUAL} = $bIndividual;
 
+                if (!$hTestDefHash->{$strModule}{$strTest}{&TESTDEF_INTEGRATION})
+                {
+                    # Add depends to core files
+                    if (defined($hModuleTest->{&TESTDEF_DEPEND}))
+                    {
+                        foreach my $strDepend (@{$hModuleTest->{&TESTDEF_DEPEND}})
+                        {
+                            if (!grep(/$strDepend/i, @stryCoreFile))
+                            {
+                                push(@stryCoreFile, $strDepend);
+                            }
+                        }
+                    }
+
+                    # Add core files
+                    push(@{$hTestDefHash->{$strModule}{$strTest}{&TESTDEF_CORE}}, @stryCoreFile);
+
+                    # Add harness files
+                    if (defined($hModuleTest->{&TESTDEF_HARNESS}))
+                    {
+                        push(@stryHarnessFile, $hModuleTest->{&TESTDEF_HARNESS});
+                    }
+
+                    push(@{$hTestDefHash->{$strModule}{$strTest}{&TESTDEF_HARNESS}}, @stryHarnessFile);
+
+                    # Add test defines
+                    $hTestDefHash->{$strModule}{$strTest}{&TESTDEF_FEATURE} =
+                        (defined($hModuleTest->{&TESTDEF_FEATURE}) ?
+                            "-DHRN_INTEST_" . uc($hModuleTest->{&TESTDEF_FEATURE}) . ' ' : '') .
+                        $strTestDefine;
+
+                    if (defined($hModuleTest->{&TESTDEF_FEATURE}))
+                    {
+                        $strTestDefine .=
+                            ($strTestDefine eq '' ? '' : ' ') . "-DHRN_FEATURE_" . uc($hModuleTest->{&TESTDEF_FEATURE});
+                    }
+                }
+
                 # Set test count
                 $hTestDefHash->{$strModule}{$strTest}{&TESTDEF_TOTAL} = $hModuleTest->{&TESTDEF_TOTAL};
 
@@ -161,36 +211,52 @@ sub testDefLoad
                     $hModuleTest->{&TESTDEF_COVERAGE}{$strTestFile} = TESTDEF_COVERAGE_FULL;
                 }
 
-                # Concatenate coverage for modules and tests
-                foreach my $hCoverage ($hModule->{&TESTDEF_COVERAGE}, $hModuleTest->{&TESTDEF_COVERAGE})
+                # Concatenate coverage for tests
+                foreach my $xCodeModule (@{$hModuleTest->{&TESTDEF_COVERAGE}})
                 {
-                    foreach my $strCodeModule (sort(keys(%{$hCoverage})))
+                    my $strCodeModule = undef;
+                    my $strCoverage = undef;
+
+                    if (ref($xCodeModule))
                     {
-                        if (defined($hTestDefHash->{$strModule}{$strTest}{&TESTDEF_COVERAGE}{$strCodeModule}))
-                        {
-                            confess &log(ASSERT,
-                                "${strCodeModule} is defined for coverage in both module ${strModule} and test ${strTest}");
-                        }
+                        $strCodeModule = (keys(%{$xCodeModule}))[0];
+                        $strCoverage = $xCodeModule->{$strCodeModule};
+                    }
+                    else
+                    {
+                        $strCodeModule = $xCodeModule;
+                        $strCoverage = TESTDEF_COVERAGE_FULL;
+                    }
 
-                        $hTestDefHash->{$strModule}{$strTest}{&TESTDEF_COVERAGE}{$strCodeModule} = $hCoverage->{$strCodeModule};
+                    $hTestDefHash->{$strModule}{$strTest}{&TESTDEF_COVERAGE}{$strCodeModule} = $strCoverage;
 
-                        # Build coverage type hash and make sure coverage type does not change
-                        if (!defined($hCoverageType->{$strCodeModule}))
-                        {
-                            $hCoverageType->{$strCodeModule} = $hCoverage->{$strCodeModule};
-                        }
-                        elsif ($hCoverageType->{$strCodeModule} ne $hCoverage->{$strCodeModule})
-                        {
-                            confess &log(ASSERT, "cannot mix coverage types for ${strCodeModule}");
-                        }
+                    # Build coverage type hash and make sure coverage type does not change
+                    if (!defined($hCoverageType->{$strCodeModule}))
+                    {
+                        $hCoverageType->{$strCodeModule} = $strCoverage;
+                    }
+                    elsif ($hCoverageType->{$strCodeModule} ne $strCoverage)
+                    {
+                        confess &log(ASSERT, "cannot mix coverage types for ${strCodeModule}");
+                    }
 
-                        # Add to coverage list
-                        push(@{$hCoverageList->{$strCodeModule}}, {strModule=> $strModule, strTest => $strTest});
+                    # Add to coverage list
+                    push(@{$hCoverageList->{$strCodeModule}}, {strModule=> $strModule, strTest => $strTest});
+
+                    # Check if this module is already in the core list
+                    if (!$hTestDefHash->{$strModule}{$strTest}{&TESTDEF_INTEGRATION} && !grep(/^$strCodeModule$/i, @stryCoreFile))
+                    {
+                        push(@stryCoreFile, $strCodeModule);
                     }
                 }
 
                 # Set include list
-                $hTestDefHash->{$strModule}{$strTest}{&TESTDEF_INCLUDE} = $hModuleTest->{&TESTDEF_INCLUDE};
+                @{$hTestDefHash->{$strModule}{$strTest}{&TESTDEF_INCLUDE}} = ();
+
+                if (defined($hModuleTest->{&TESTDEF_INCLUDE}))
+                {
+                    push(@{$hTestDefHash->{$strModule}{$strTest}{&TESTDEF_INCLUDE}}, @{$hModuleTest->{&TESTDEF_INCLUDE}});
+                }
             }
 
             $hModuleTest->{$strModule} = \@stryModuleTest;
