@@ -16,14 +16,14 @@ use Exporter qw(import);
     our @EXPORT = qw();
 use File::Basename qw(dirname);
 
-use pgBackRest::Common::Log;
-use pgBackRest::Protocol::Storage::Helper;
-use pgBackRest::Version;
+use pgBackRestDoc::Common::Log;
+use pgBackRestDoc::ProjectInfo;
 
 use pgBackRestTest::Common::ContainerTest;
 use pgBackRestTest::Common::ExecuteTest;
 use pgBackRestTest::Common::JobTest;
 use pgBackRestTest::Common::RunTest;
+use pgBackRestTest::Common::StorageRepo;
 use pgBackRestTest::Common::VmTest;
 
 ####################################################################################################################################
@@ -31,12 +31,16 @@ use pgBackRestTest::Common::VmTest;
 ####################################################################################################################################
 use constant HOST_BASE                                              => 'base';
     push @EXPORT, qw(HOST_BASE);
-use constant HOST_DB_MASTER                                         => 'db-master';
-    push @EXPORT, qw(HOST_DB_MASTER);
+use constant HOST_DB_PRIMARY                                        => 'db-primary';
+    push @EXPORT, qw(HOST_DB_PRIMARY);
 use constant HOST_DB_STANDBY                                        => 'db-standby';
     push @EXPORT, qw(HOST_DB_STANDBY);
 use constant HOST_BACKUP                                            => 'backup';
     push @EXPORT, qw(HOST_BACKUP);
+use constant HOST_GCS                                               => 'gcs';
+    push @EXPORT, qw(HOST_GCS);
+use constant HOST_AZURE                                             => 'azure';
+    push @EXPORT, qw(HOST_AZURE);
 use constant HOST_S3                                                => 's3-server';
     push @EXPORT, qw(HOST_S3);
 
@@ -66,12 +70,12 @@ sub new
 
     # Create the host
     my $strProjectPath = dirname(dirname(abs_path($0)));
+    my $strBinPath = dirname(dirname($strTestPath)) . '/bin/' . testRunGet()->vm() . '/' . PROJECT_EXE;
     my $strContainer = 'test-' . testRunGet()->vmId() . "-$strName";
 
     my $self = $class->SUPER::new(
         $strName, $strContainer, $$oParam{strImage}, $$oParam{strUser}, testRunGet()->vm(),
-        ["${strProjectPath}:${strProjectPath}", "${strTestPath}:${strTestPath}"
-        ,dirname(dirname($strTestPath)) . '/cover_db:' . dirname(dirname($strTestPath)) . '/cover_db']);
+        ["${strProjectPath}:${strProjectPath}", "${strTestPath}:${strTestPath}", "${strBinPath}:${strBinPath}:ro"]);
     bless $self, $class;
 
     # Set test path
@@ -80,9 +84,6 @@ sub new
     # Set permissions on the test path
     $self->executeSimple('chown -R ' . $self->userGet() . ':'. TEST_GROUP . ' ' . $self->testPath(), undef, 'root');
 
-    # Install bin and Perl C Library
-    jobInstallC(testRunGet()->basePath(), $self->{strOS}, $strContainer);
-
     # Return from function and log return values if any
     return logDebugReturn
     (
