@@ -13,22 +13,21 @@ use Carp qw(confess);
 
 use File::Basename qw(dirname);
 
-use pgBackRest::Archive::Info;
-use pgBackRest::Backup::Info;
-use pgBackRest::DbVersion;
-use pgBackRest::Common::Exception;
-use pgBackRest::Common::Ini;
-use pgBackRest::Common::Log;
-use pgBackRest::Common::Wait;
-use pgBackRest::Config::Config;
-use pgBackRest::Manifest;
-use pgBackRest::Protocol::Storage::Helper;
-use pgBackRest::Storage::Helper;
+use pgBackRestDoc::Common::Exception;
+use pgBackRestDoc::Common::Ini;
+use pgBackRestDoc::Common::Log;
 
+use pgBackRestTest::Env::ArchiveInfo;
+use pgBackRestTest::Env::BackupInfo;
 use pgBackRestTest::Env::HostEnvTest;
+use pgBackRestTest::Env::Host::HostBackupTest;
+use pgBackRestTest::Env::Manifest;
+use pgBackRestTest::Common::DbVersion;
 use pgBackRestTest::Common::ExecuteTest;
 use pgBackRestTest::Common::RunTest;
+use pgBackRestTest::Common::StorageRepo;
 use pgBackRestTest::Common::VmTest;
+use pgBackRestTest::Common::Wait;
 
 ####################################################################################################################################
 # run
@@ -44,14 +43,12 @@ sub run
 
     foreach my $rhRun
     (
-        {vm => VM1, remote => false, s3 => false, encrypt => false, compress =>  true, error => 0},
-        {vm => VM1, remote =>  true, s3 =>  true, encrypt =>  true, compress => false, error => 1},
-        {vm => VM2, remote => false, s3 =>  true, encrypt => false, compress => false, error => 0},
-        {vm => VM2, remote =>  true, s3 => false, encrypt =>  true, compress =>  true, error => 0},
-        {vm => VM3, remote => false, s3 => false, encrypt =>  true, compress => false, error => 0},
-        {vm => VM3, remote =>  true, s3 =>  true, encrypt => false, compress =>  true, error => 1},
-        {vm => VM4, remote => false, s3 =>  true, encrypt =>  true, compress =>  true, error => 0},
-        {vm => VM4, remote =>  true, s3 => false, encrypt => false, compress => false, error => 0},
+        {vm => VM2, remote => false, storage =>    S3, encrypt => false, compress =>  NONE, error => 0},
+        {vm => VM2, remote =>  true, storage => POSIX, encrypt =>  true, compress =>  NONE, error => 0},
+        {vm => VM3, remote => false, storage =>   GCS, encrypt =>  true, compress =>   BZ2, error => 0},
+        {vm => VM3, remote =>  true, storage => AZURE, encrypt => false, compress =>   LZ4, error => 1},
+        {vm => VM4, remote => false, storage =>    S3, encrypt =>  true, compress =>  NONE, error => 0},
+        {vm => VM4, remote =>  true, storage =>   GCS, encrypt => false, compress =>   ZST, error => 0},
     )
     {
         # Only run tests for this vm
@@ -59,43 +56,44 @@ sub run
 
         # Increment the run, log, and decide whether this unit test should be run
         my $bRemote = $rhRun->{remote};
-        my $bS3 = $rhRun->{s3};
+        my $strStorage = $rhRun->{storage};
         my $bEncrypt = $rhRun->{encrypt};
-        my $bCompress = $rhRun->{compress};
+        my $strCompressType = $rhRun->{compress};
         my $iError = $rhRun->{error};
 
         # Increment the run, log, and decide whether this unit test should be run
-        if (!$self->begin("rmt ${bRemote}, cmp ${bCompress}, error " . ($iError ? 'connect' : 'version') . ", s3 ${bS3}, " .
-            "enc ${bEncrypt}")) {next}
+        if (!$self->begin(
+                "rmt ${bRemote}, cmp ${strCompressType}, error " . ($iError ? 'connect' : 'version') .
+                    ", storage ${strStorage}, enc ${bEncrypt}")) {next}
 
         # Create hosts, file object, and config
-        my ($oHostDbMaster, $oHostDbStandby, $oHostBackup, $oHostS3) = $self->setup(
-            true, $self->expect(), {bHostBackup => $bRemote, bCompress => $bCompress, bArchiveAsync => true, bS3 => $bS3,
-            bRepoEncrypt => $bEncrypt});
+        my ($oHostDbPrimary, $oHostDbStandby, $oHostBackup) = $self->setup(
+            true, $self->expect(), {bHostBackup => $bRemote, strCompressType => $strCompressType, bArchiveAsync => true,
+            strStorage => $strStorage, bRepoEncrypt => $bEncrypt});
 
         # Create compression extension
-        my $strCompressExt = $bCompress ? qw{.} . COMPRESS_EXT : '';
+        my $strCompressExt = $strCompressType ne NONE ? ".${strCompressType}" : '';
 
         # Create the wal path
-        my $strWalPath = $oHostDbMaster->dbBasePath() . '/pg_xlog';
+        my $strWalPath = $oHostDbPrimary->dbBasePath() . '/pg_xlog';
         storageTest()->pathCreate($strWalPath, {bCreateParent => true});
 
         # Create the test path for pg_control and generate pg_control for stanza-create
-        storageTest()->pathCreate($oHostDbMaster->dbBasePath() . '/' . DB_PATH_GLOBAL, {bCreateParent => true});
-        $self->controlGenerate($oHostDbMaster->dbBasePath(), PG_VERSION_94);
+        storageTest()->pathCreate($oHostDbPrimary->dbBasePath() . '/' . DB_PATH_GLOBAL, {bCreateParent => true});
+        $self->controlGenerate($oHostDbPrimary->dbBasePath(), PG_VERSION_94);
 
         # Create the archive info file
-        $oHostBackup->stanzaCreate('create required data for stanza', {strOptionalParam => '--no-' . cfgOptionName(CFGOPT_ONLINE)});
+        $oHostBackup->stanzaCreate('create required data for stanza', {strOptionalParam => '--no-online'});
 
         # Push a WAL segment
         &log(INFO, '    push first WAL');
-        $oHostDbMaster->archivePush($strWalPath, $strWalTestFile, 1);
+        $oHostDbPrimary->archivePush($strWalPath, $strWalTestFile, 1);
 
         # Break the database version of the archive info file
         if ($iError == 0)
         {
             $oHostBackup->infoMunge(
-                storageRepo()->pathGet(STORAGE_REPO_ARCHIVE . qw{/} . ARCHIVE_INFO_FILE),
+                $oHostBackup->repoArchivePath(ARCHIVE_INFO_FILE),
                 {&INFO_ARCHIVE_SECTION_DB => {&INFO_ARCHIVE_KEY_DB_VERSION => '8.0'},
                  &INFO_ARCHIVE_SECTION_DB_HISTORY => {1 => {&INFO_ARCHIVE_KEY_DB_VERSION => '8.0'}}});
         }
@@ -103,38 +101,36 @@ sub run
         # Push two more segments with errors to exceed archive-push-queue-max
         &log(INFO, '    push second WAL');
 
-        $oHostDbMaster->archivePush(
-            $strWalPath, $strWalTestFile, 2, $iError ? ERROR_UNKNOWN : ERROR_ARCHIVE_MISMATCH);
+        $oHostDbPrimary->archivePush(
+            $strWalPath, $strWalTestFile, 2, ERROR_REPO_INVALID, undef, $iError ? '--repo1-host=bogus' : undef);
 
         &log(INFO, '    push third WAL');
 
-        $oHostDbMaster->archivePush(
-            $strWalPath, $strWalTestFile, 3, $iError ? ERROR_UNKNOWN : ERROR_ARCHIVE_MISMATCH);
+        $oHostDbPrimary->archivePush(
+            $strWalPath, $strWalTestFile, 3, ERROR_REPO_INVALID, undef, $iError ? '--repo1-host=bogus' : undef);
 
         # Now this segment will get dropped
         &log(INFO, '    push fourth WAL');
 
-        $oHostDbMaster->archivePush($strWalPath, $strWalTestFile, 4, undef, undef, '--repo1-host=bogus');
+        $oHostDbPrimary->archivePush($strWalPath, $strWalTestFile, 4, undef, undef, '--repo1-host=bogus');
 
         # Fix the database version
         if ($iError == 0)
         {
-            $oHostBackup->infoRestore(storageRepo()->pathGet(STORAGE_REPO_ARCHIVE . qw{/} . ARCHIVE_INFO_FILE));
+            $oHostBackup->infoRestore($oHostBackup->repoArchivePath(ARCHIVE_INFO_FILE));
         }
 
         #---------------------------------------------------------------------------------------------------------------------------
         $self->testResult(
-            sub {storageRepo()->list(
-                STORAGE_REPO_ARCHIVE . qw{/} . PG_VERSION_94 . '-1/0000000100000001')},
+            sub {storageRepo()->list($oHostBackup->repoArchivePath(PG_VERSION_94 . '-1/0000000100000001'))},
             "000000010000000100000001-${strWalHash}${strCompressExt}",
             'segment 2-4 not pushed', {iWaitSeconds => 5});
 
         #---------------------------------------------------------------------------------------------------------------------------
-        $oHostDbMaster->archivePush($strWalPath, $strWalTestFile, 5);
+        $oHostDbPrimary->archivePush($strWalPath, $strWalTestFile, 5);
 
         $self->testResult(
-            sub {storageRepo()->list(
-                STORAGE_REPO_ARCHIVE . qw{/} . PG_VERSION_94 . '-1/0000000100000001')},
+            sub {storageRepo()->list($oHostBackup->repoArchivePath(PG_VERSION_94 . '-1/0000000100000001'))},
             "(000000010000000100000001-${strWalHash}${strCompressExt}, " .
                 "000000010000000100000005-${strWalHash}${strCompressExt})",
             'segment 5 is pushed', {iWaitSeconds => 5});
