@@ -38,8 +38,6 @@ There should not be any code outside the HARNESS_FORK_CHILD_BEGIN/END() and HARN
 #include <sys/wait.h>
 #include <unistd.h>
 
-#include <common/fork.h>
-
 #include <common/harnessLog.h>
 
 /***********************************************************************************************************************************
@@ -62,47 +60,47 @@ Return the process index of the child (i.e. the index in the total)
 /***********************************************************************************************************************************
 Return the id of the child process, 0 if in the child process
 ***********************************************************************************************************************************/
-#define HARNESS_FORK_PROCESS_ID(processIdx)                                                                                         \
+#define HARNESS_FORK_PROCESS_ID(processIdx)                                                                                        \
     HARNESS_FORK_processIdList[processIdx]
 
 /***********************************************************************************************************************************
 Return the pipe for the child process
 ***********************************************************************************************************************************/
-#define HARNESS_FORK_PIPE(processIdx)                                                                                               \
+#define HARNESS_FORK_PIPE(processIdx)                                                                                              \
     HARNESS_FORK_pipe[processIdx]
 
 /***********************************************************************************************************************************
 Is the pipe required for this child process?
 ***********************************************************************************************************************************/
-#define HARNESS_FORK_PIPE_REQUIRED(processIdx)                                                                                      \
+#define HARNESS_FORK_PIPE_REQUIRED(processIdx)                                                                                     \
     HARNESS_FORK_pipeRequired[processIdx]
 
 /***********************************************************************************************************************************
-Get read/write pipe handles
+Get read/write pipe file descriptors
 ***********************************************************************************************************************************/
-#define HARNESS_FORK_CHILD_READ_PROCESS(processIdx)                                                                                 \
+#define HARNESS_FORK_CHILD_READ_PROCESS(processIdx)                                                                                \
     HARNESS_FORK_PIPE(processIdx)[1][0]
 
 #define HARNESS_FORK_CHILD_READ()                                                                                                  \
     HARNESS_FORK_CHILD_READ_PROCESS(HARNESS_FORK_PROCESS_IDX())
 
-#define HARNESS_FORK_CHILD_WRITE_PROCESS(processIdx)                                                                                \
+#define HARNESS_FORK_CHILD_WRITE_PROCESS(processIdx)                                                                               \
     HARNESS_FORK_PIPE(processIdx)[0][1]
 
 #define HARNESS_FORK_CHILD_WRITE()                                                                                                 \
     HARNESS_FORK_CHILD_WRITE_PROCESS(HARNESS_FORK_PROCESS_IDX())
 
-#define HARNESS_FORK_PARENT_READ_PROCESS(processIdx)                                                                                \
+#define HARNESS_FORK_PARENT_READ_PROCESS(processIdx)                                                                               \
     HARNESS_FORK_PIPE(processIdx)[0][0]
 
-#define HARNESS_FORK_PARENT_WRITE_PROCESS(processIdx)                                                                               \
+#define HARNESS_FORK_PARENT_WRITE_PROCESS(processIdx)                                                                              \
     HARNESS_FORK_PIPE(processIdx)[1][1]
 
 /***********************************************************************************************************************************
 At the end of the HARNESS_FORK block the parent will wait for the child to exit.  By default an exit code of 0 is expected but that
 can be modified when the child begins.
 ***********************************************************************************************************************************/
-#define HARNESS_FORK_CHILD_EXPECTED_EXIT_STATUS(processIdx)                                                                         \
+#define HARNESS_FORK_CHILD_EXPECTED_EXIT_STATUS(processIdx)                                                                        \
     HARNESS_FORK_expectedExitStatus[processIdx]
 
 /***********************************************************************************************************************************
@@ -137,7 +135,7 @@ Create a child process
                 "unable to create write pipe for child process %u", HARNESS_FORK_PROCESS_TOTAL());                                 \
         }                                                                                                                          \
                                                                                                                                    \
-        HARNESS_FORK_PROCESS_ID(HARNESS_FORK_PROCESS_TOTAL()) = forkSafe();                                                        \
+        HARNESS_FORK_PROCESS_ID(HARNESS_FORK_PROCESS_TOTAL()) = fork();                                                            \
                                                                                                                                    \
         if (HARNESS_FORK_PROCESS_ID(HARNESS_FORK_PROCESS_TOTAL()) == 0)                                                            \
         {                                                                                                                          \
@@ -205,7 +203,11 @@ End the fork block and check exit status for all child processes
                 THROW_SYS_ERROR_FMT(AssertError, "unable to find child process %u", processIdx);                                   \
                                                                                                                                    \
             if (WEXITSTATUS(processStatus) != HARNESS_FORK_CHILD_EXPECTED_EXIT_STATUS(processIdx))                                 \
-                THROW_FMT(AssertError, "child %u exited with error %d", processIdx, WEXITSTATUS(processStatus));                   \
+            {                                                                                                                      \
+                THROW_FMT(                                                                                                         \
+                    AssertError, "child %u exited with error %d but expected %d", processIdx, WEXITSTATUS(processStatus),          \
+                    HARNESS_FORK_CHILD_EXPECTED_EXIT_STATUS(processIdx));                                                          \
+            }                                                                                                                      \
         }                                                                                                                          \
     }                                                                                                                              \
     while (0)
