@@ -5,27 +5,9 @@ Test Common Functions and Definitions for Backup and Expire Commands
 #include "common/regExp.h"
 #include "common/type/json.h"
 #include "postgres/interface.h"
+#include "postgres/interface/static.vendor.h"
 #include "storage/posix/storage.h"
 
-/***********************************************************************************************************************************
-Need these structures to mock up test data
-***********************************************************************************************************************************/
-typedef struct
-{
-    uint32_t walid;                                                 // high bits
-    uint32_t xrecoff;                                               // low bits
-} PageWalRecPtr;
-
-typedef struct PageHeaderData
-{
-    // LSN is member of *any* block, not only page-organized ones
-    PageWalRecPtr pd_lsn;                                           // Lsn for last change to this page
-    uint16_t pd_checksum;                                           // checksum
-    uint16_t pd_flags;                                              // flag bits, see below
-    uint16_t pd_lower;                                              // offset to start of free space
-    uint16_t pd_upper;                                              // offset to end of free space
-} PageHeaderData;
-
 /***********************************************************************************************************************************
 Test Run
 ***********************************************************************************************************************************/
@@ -131,7 +113,7 @@ testRun(void)
         *(PageHeaderData *)(bufPtr(buffer) + (PG_PAGE_SIZE_DEFAULT * 0x02)) = (PageHeaderData){.pd_upper = 0};
 
         IoWrite *write = ioBufferWriteNew(bufferOut);
-        ioFilterGroupAdd(ioWriteFilterGroup(write), pageChecksumNew(0, PG_SEGMENT_PAGE_DEFAULT, PG_PAGE_SIZE_DEFAULT, 0));
+        ioFilterGroupAdd(ioWriteFilterGroup(write), pageChecksumNew(0, PG_SEGMENT_PAGE_DEFAULT, 0));
         ioWriteOpen(write);
         ioWrite(write, buffer);
         ioWriteClose(write);
@@ -140,6 +122,40 @@ testRun(void)
             jsonFromVar(ioFilterGroupResult(ioWriteFilterGroup(write), PAGE_CHECKSUM_FILTER_TYPE_STR)),
             "{\"align\":true,\"valid\":true}", "all zero pages");
 
+        // Single valid page
+        // -------------------------------------------------------------------------------------------------------------------------
+        buffer = bufNew(PG_PAGE_SIZE_DEFAULT * 1);
+        bufUsedSet(buffer, bufSize(buffer));
+        memset(bufPtr(buffer), 0, bufSize(buffer));
+
+        // Page 0 has good checksum
+        *(PageHeaderData *)(bufPtr(buffer) + (PG_PAGE_SIZE_DEFAULT * 0x00)) = (PageHeaderData)
+        {
+            .pd_upper = 0x01,
+            .pd_lsn = (PageXLogRecPtr)
+            {
+                .xlogid = 0xF0F0F0F0,
+                .xrecoff = 0xF0F0F0F0,
+            },
+        };
+
+        ((PageHeaderData *)(bufPtr(buffer) + (PG_PAGE_SIZE_DEFAULT * 0x00)))->pd_checksum = pgPageChecksum(
+            bufPtr(buffer) + (PG_PAGE_SIZE_DEFAULT * 0x00), 0);
+
+        write = ioBufferWriteNew(bufferOut);
+
+        ioFilterGroupAdd(
+            ioWriteFilterGroup(write),
+            pageChecksumNewVar(varVarLst(jsonToVar(
+                strNewFmt("[0,%u,%" PRIu64 "]", PG_SEGMENT_PAGE_DEFAULT, (uint64_t)0xFACEFACE00000000)))));
+        ioWriteOpen(write);
+        ioWrite(write, buffer);
+        ioWriteClose(write);
+
+        TEST_RESULT_STR_Z(
+            jsonFromVar(ioFilterGroupResult(ioWriteFilterGroup(write), PAGE_CHECKSUM_FILTER_TYPE_STR)),
+            "{\"align\":true,\"valid\":true}", "single valid page");
+
         // Single checksum error
         // -------------------------------------------------------------------------------------------------------------------------
         buffer = bufNew(PG_PAGE_SIZE_DEFAULT * 1);
@@ -150,9 +166,9 @@ testRun(void)
         *(PageHeaderData *)(bufPtr(buffer) + (PG_PAGE_SIZE_DEFAULT * 0x00)) = (PageHeaderData)
         {
             .pd_upper = 0x01,
-            .pd_lsn = (PageWalRecPtr)
+            .pd_lsn = (PageXLogRecPtr)
             {
-                .walid = 0xF0F0F0F0,
+                .xlogid = 0xF0F0F0F0,
                 .xrecoff = 0xF0F0F0F0,
             },
         };
@@ -161,10 +177,8 @@ testRun(void)
 
         ioFilterGroupAdd(
             ioWriteFilterGroup(write),
-            pageChecksumNewVar(
-                varVarLst(
-                    jsonToVar(
-                        strNewFmt("[0,%u,%u,%" PRIu64 "]", PG_SEGMENT_PAGE_DEFAULT, PG_PAGE_SIZE_DEFAULT, 0xFACEFACE00000000)))));
+            pageChecksumNewVar(varVarLst(jsonToVar(
+                strNewFmt("[0,%u,%" PRIu64 "]", PG_SEGMENT_PAGE_DEFAULT, (uint64_t)0xFACEFACE00000000)))));
         ioWriteOpen(write);
         ioWrite(write, buffer);
         ioWriteClose(write);
@@ -183,9 +197,9 @@ testRun(void)
         *(PageHeaderData *)(bufPtr(buffer) + (PG_PAGE_SIZE_DEFAULT * 0x00)) = (PageHeaderData)
         {
             .pd_upper = 0x01,
-            .pd_lsn = (PageWalRecPtr)
+            .pd_lsn = (PageXLogRecPtr)
             {
-                .walid = 0xF0F0F0F0,
+                .xlogid = 0xF0F0F0F0,
                 .xrecoff = 0xF0F0F0F0,
             },
         };
@@ -194,9 +208,9 @@ testRun(void)
         *(PageHeaderData *)(bufPtr(buffer) + (PG_PAGE_SIZE_DEFAULT * 0x01)) = (PageHeaderData)
         {
             .pd_upper = 0x01,
-            .pd_lsn = (PageWalRecPtr)
+            .pd_lsn = (PageXLogRecPtr)
             {
-                .walid = 0xFACEFACE,
+                .xlogid = 0xFACEFACE,
                 .xrecoff = 0x00000000,
             },
         };
@@ -205,7 +219,7 @@ testRun(void)
         *(PageHeaderData *)(bufPtr(buffer) + (PG_PAGE_SIZE_DEFAULT * 0x02)) = (PageHeaderData)
         {
             .pd_upper = 0x01,
-            .pd_lsn = (PageWalRecPtr)
+            .pd_lsn = (PageXLogRecPtr)
             {
                 .xrecoff = 0x2,
             },
@@ -215,7 +229,7 @@ testRun(void)
         *(PageHeaderData *)(bufPtr(buffer) + (PG_PAGE_SIZE_DEFAULT * 0x03)) = (PageHeaderData)
         {
             .pd_upper = 0x01,
-            .pd_lsn = (PageWalRecPtr)
+            .pd_lsn = (PageXLogRecPtr)
             {
                 .xrecoff = 0x3,
             },
@@ -225,7 +239,7 @@ testRun(void)
         *(PageHeaderData *)(bufPtr(buffer) + (PG_PAGE_SIZE_DEFAULT * 0x04)) = (PageHeaderData)
         {
             .pd_upper = 0x01,
-            .pd_lsn = (PageWalRecPtr)
+            .pd_lsn = (PageXLogRecPtr)
             {
                 .xrecoff = 0x4,
             },
@@ -238,7 +252,7 @@ testRun(void)
         *(PageHeaderData *)(bufPtr(buffer) + (PG_PAGE_SIZE_DEFAULT * 0x06)) = (PageHeaderData)
         {
             .pd_upper = 0x01,
-            .pd_lsn = (PageWalRecPtr)
+            .pd_lsn = (PageXLogRecPtr)
             {
                 .xrecoff = 0x6,
             },
@@ -248,15 +262,14 @@ testRun(void)
         *(PageHeaderData *)(bufPtr(buffer) + (PG_PAGE_SIZE_DEFAULT * 0x07)) = (PageHeaderData)
         {
             .pd_upper = 0x01,
-            .pd_lsn = (PageWalRecPtr)
+            .pd_lsn = (PageXLogRecPtr)
             {
                 .xrecoff = 0x7,
             },
         };
 
         write = ioBufferWriteNew(bufferOut);
-        ioFilterGroupAdd(
-            ioWriteFilterGroup(write), pageChecksumNew(0, PG_SEGMENT_PAGE_DEFAULT, PG_PAGE_SIZE_DEFAULT, 0xFACEFACE00000000));
+        ioFilterGroupAdd(ioWriteFilterGroup(write), pageChecksumNew(0, PG_SEGMENT_PAGE_DEFAULT, 0xFACEFACE00000000));
         ioWriteOpen(write);
         ioWrite(write, buffer);
         ioWriteClose(write);
@@ -274,8 +287,7 @@ testRun(void)
         *(PageHeaderData *)(bufPtr(buffer) + (PG_PAGE_SIZE_DEFAULT * 0x00)) = (PageHeaderData){.pd_upper = 0};
 
         write = ioBufferWriteNew(bufferOut);
-        ioFilterGroupAdd(
-            ioWriteFilterGroup(write), pageChecksumNew(0, PG_SEGMENT_PAGE_DEFAULT, PG_PAGE_SIZE_DEFAULT, 0xFACEFACE00000000));
+        ioFilterGroupAdd(ioWriteFilterGroup(write), pageChecksumNew(0, PG_SEGMENT_PAGE_DEFAULT, 0xFACEFACE00000000));
         ioWriteOpen(write);
         ioWrite(write, buffer);
         ioWriteClose(write);
@@ -293,8 +305,7 @@ testRun(void)
         *(PageHeaderData *)(bufPtr(buffer) + (PG_PAGE_SIZE_DEFAULT * 0x00)) = (PageHeaderData){.pd_upper = 0};
 
         write = ioBufferWriteNew(bufferOut);
-        ioFilterGroupAdd(
-            ioWriteFilterGroup(write), pageChecksumNew(0, PG_SEGMENT_PAGE_DEFAULT, PG_PAGE_SIZE_DEFAULT, 0xFACEFACE00000000));
+        ioFilterGroupAdd(ioWriteFilterGroup(write), pageChecksumNew(0, PG_SEGMENT_PAGE_DEFAULT, 0xFACEFACE00000000));
         ioWriteOpen(write);
         ioWrite(write, buffer);
         TEST_ERROR(ioWrite(write, buffer), AssertError, "should not be possible to see two misaligned pages in a row");
@@ -313,5 +324,5 @@ testRun(void)
         TEST_RESULT_STR_Z(backupTypeStr(backupTypeIncr), "incr", "backup type str incr");
     }
 
-    FUNCTION_HARNESS_RESULT_VOID();
+    FUNCTION_HARNESS_RETURN_VOID();
 }
