@@ -120,11 +120,11 @@ testRun(void)
         testFunction1(99, false, NULL, NULL, NULL, 1.17, 0755);
 
         harnessLogResult(
-            "P00  DEBUG:     test/module/common/debugOnTest::testFunction1: (paramInt: 99, paramBool: false, paramBoolP: null"
-                ", paramBoolPP: null, paramVoidP: null, paramDouble: 1.17, paramMode: 0755)\n"
-            "P00  TRACE:         test/module/common/debugOnTest::testFunction2: (void)\n"
-            "P00  TRACE:         test/module/common/debugOnTest::testFunction2: => void\n"
-            "P00  DEBUG:     test/module/common/debugOnTest::testFunction1: => 1");
+            "P00  DEBUG:     " TEST_PGB_PATH "/test/src/module/common/debugOnTest::testFunction1: (paramInt: 99, paramBool: false,"
+                " paramBoolP: null, paramBoolPP: null, paramVoidP: null, paramDouble: 1.17, paramMode: 0755)\n"
+            "P00  TRACE:         " TEST_PGB_PATH "/test/src/module/common/debugOnTest::testFunction2: (void)\n"
+            "P00  TRACE:         " TEST_PGB_PATH "/test/src/module/common/debugOnTest::testFunction2: => void\n"
+            "P00  DEBUG:     " TEST_PGB_PATH "/test/src/module/common/debugOnTest::testFunction1: => 1");
 
         // -------------------------------------------------------------------------------------------------------------------------
         bool testBool = true;
@@ -135,11 +135,11 @@ testRun(void)
         testFunction1(99, false, testBoolP, testBoolPP, testVoidP, 1.17, 0755);
 
         harnessLogResult(
-            "P00  DEBUG:     test/module/common/debugOnTest::testFunction1: (paramInt: 99, paramBool: false, paramBoolP: *true"
-                ", paramBoolPP: **true, paramVoidP: null, paramDouble: 1.17, paramMode: 0755)\n"
-            "P00  TRACE:         test/module/common/debugOnTest::testFunction2: (void)\n"
-            "P00  TRACE:         test/module/common/debugOnTest::testFunction2: => void\n"
-            "P00  DEBUG:     test/module/common/debugOnTest::testFunction1: => 1");
+            "P00  DEBUG:     " TEST_PGB_PATH "/test/src/module/common/debugOnTest::testFunction1: (paramInt: 99, paramBool: false,"
+                " paramBoolP: *true, paramBoolPP: **true, paramVoidP: null, paramDouble: 1.17, paramMode: 0755)\n"
+            "P00  TRACE:         " TEST_PGB_PATH "/test/src/module/common/debugOnTest::testFunction2: (void)\n"
+            "P00  TRACE:         " TEST_PGB_PATH "/test/src/module/common/debugOnTest::testFunction2: => void\n"
+            "P00  DEBUG:     " TEST_PGB_PATH "/test/src/module/common/debugOnTest::testFunction1: => 1");
 
         testBoolP = NULL;
         testVoidP = (void *)1;
@@ -147,11 +147,11 @@ testRun(void)
         testFunction1(99, false, testBoolP, testBoolPP, testVoidP, 1.17, 0755);
 
         harnessLogResult(
-            "P00  DEBUG:     test/module/common/debugOnTest::testFunction1: (paramInt: 99, paramBool: false, paramBoolP: null"
-                ", paramBoolPP: *null, paramVoidP: *void, paramDouble: 1.17, paramMode: 0755)\n"
-            "P00  TRACE:         test/module/common/debugOnTest::testFunction2: (void)\n"
-            "P00  TRACE:         test/module/common/debugOnTest::testFunction2: => void\n"
-            "P00  DEBUG:     test/module/common/debugOnTest::testFunction1: => 1");
+            "P00  DEBUG:     " TEST_PGB_PATH "/test/src/module/common/debugOnTest::testFunction1: (paramInt: 99, paramBool: false,"
+                " paramBoolP: null, paramBoolPP: *null, paramVoidP: *void, paramDouble: 1.17, paramMode: 0755)\n"
+            "P00  TRACE:         " TEST_PGB_PATH "/test/src/module/common/debugOnTest::testFunction2: (void)\n"
+            "P00  TRACE:         " TEST_PGB_PATH "/test/src/module/common/debugOnTest::testFunction2: => void\n"
+            "P00  DEBUG:     " TEST_PGB_PATH "/test/src/module/common/debugOnTest::testFunction1: => 1");
 
         // -------------------------------------------------------------------------------------------------------------------------
         harnessLogLevelReset();
@@ -160,5 +160,5 @@ testRun(void)
         harnessLogResult("");
     }
 
-    FUNCTION_HARNESS_RESULT_VOID();
+    FUNCTION_HARNESS_RETURN_VOID();
 }
