@@ -108,5 +108,5 @@ testRun(void)
         TEST_RESULT_VOID(execFree(exec), "sleep exited as expected");
     }
 
-    FUNCTION_HARNESS_RESULT_VOID();
+    FUNCTION_HARNESS_RETURN_VOID();
 }
