@@ -173,6 +173,101 @@ testRun(void)
         TEST_RESULT_VOID(httpQueryFree(query), "free");
     }
 
+    // *****************************************************************************************************************************
+    if (testBegin("HttpUrl"))
+    {
+        HttpUrl *url = NULL;
+
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("invalid url");
+
+        TEST_ERROR(httpUrlNewParseP(STRDEF("ftp://" BOGUS_STR)), FormatError, "invalid URL 'ftp://BOGUS'");
+
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("HttpProtocolTypeStr");
+
+        TEST_RESULT_STR_Z(httpProtocolTypeStr(httpProtocolTypeHttp), "http", "check http");
+        TEST_RESULT_STR_Z(httpProtocolTypeStr(httpProtocolTypeAny), NULL, "check any");
+
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("simple http");
+
+        TEST_ASSIGN(url, httpUrlNewParseP(STRDEF("http://test"), .type = httpProtocolTypeHttp), "new");
+        TEST_RESULT_STR_Z(httpUrl(url), "http://test", "check url");
+        TEST_RESULT_STR_Z(httpUrlHost(url), "test", "check host");
+        TEST_RESULT_STR_Z(httpUrlPath(url), "/", "check path");
+        TEST_RESULT_UINT(httpUrlPort(url), 80, "check port");
+        TEST_RESULT_UINT(httpUrlProtocolType(url), httpProtocolTypeHttp, "check protocol");
+        TEST_RESULT_STR_Z(httpUrlToLog(url), "{http://test:80/}", "check log");
+
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("host and port");
+
+        TEST_ASSIGN(url, httpUrlNewParseP(STRDEF("gcs:4443"), .type = httpProtocolTypeHttps), "new");
+        TEST_RESULT_STR_Z(httpUrl(url), "gcs:4443", "check url");
+        TEST_RESULT_STR_Z(httpUrlHost(url), "gcs", "check host");
+        TEST_RESULT_STR_Z(httpUrlPath(url), "/", "check path");
+        TEST_RESULT_UINT(httpUrlPort(url), 4443, "check port");
+        TEST_RESULT_UINT(httpUrlProtocolType(url), httpProtocolTypeHttps, "check protocol");
+        TEST_RESULT_STR_Z(httpUrlToLog(url), "{https://gcs:4443/}", "check log");
+
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("http but expected https");
+
+        TEST_ERROR(
+            httpUrlNewParseP(STRDEF("http://test"), .type = httpProtocolTypeHttps), FormatError,
+            "expected protocol 'https' in URL 'http://test'");
+
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("https with port and path");
+
+        TEST_ASSIGN(url, httpUrlNewParseP(STRDEF("https://test.com:445/path")), "new");
+        TEST_RESULT_STR_Z(httpUrl(url), "https://test.com:445/path", "check url");
+        TEST_RESULT_STR_Z(httpUrlHost(url), "test.com", "check host");
+        TEST_RESULT_STR_Z(httpUrlPath(url), "/path", "check path");
+        TEST_RESULT_UINT(httpUrlPort(url), 445, "check port");
+        TEST_RESULT_UINT(httpUrlProtocolType(url), httpProtocolTypeHttps, "check protocol");
+        TEST_RESULT_STR_Z(httpUrlToLog(url), "{https://test.com:445/path}", "check log");
+
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("host only");
+
+        TEST_ASSIGN(url, httpUrlNewParseP(STRDEF("test.com"), .type = httpProtocolTypeHttps), "new");
+        TEST_RESULT_STR_Z(httpUrl(url), "test.com", "check url");
+        TEST_RESULT_STR_Z(httpUrlHost(url), "test.com", "check host");
+        TEST_RESULT_STR_Z(httpUrlPath(url), "/", "check path");
+        TEST_RESULT_UINT(httpUrlPort(url), 443, "check port");
+        TEST_RESULT_UINT(httpUrlProtocolType(url), httpProtocolTypeHttps, "check protocol");
+        TEST_RESULT_STR_Z(httpUrlToLog(url), "{https://test.com:443/}", "check log");
+
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("IPv6");
+
+        TEST_ASSIGN(url, httpUrlNewParseP(STRDEF("http://[2001:db8::ff00:42:8329]:81"), .type = httpProtocolTypeHttp), "new");
+        TEST_RESULT_STR_Z(httpUrl(url), "http://[2001:db8::ff00:42:8329]:81", "check url");
+        TEST_RESULT_STR_Z(httpUrlHost(url), "2001:db8::ff00:42:8329", "check host");
+        TEST_RESULT_STR_Z(httpUrlPath(url), "/", "check path");
+        TEST_RESULT_UINT(httpUrlPort(url), 81, "check port");
+        TEST_RESULT_UINT(httpUrlProtocolType(url), httpProtocolTypeHttp, "check protocol");
+        TEST_RESULT_STR_Z(httpUrlToLog(url), "{http://[2001:db8::ff00:42:8329]:81/}", "check log");
+
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("IPv6 no port");
+
+        TEST_ASSIGN(url, httpUrlNewParseP(STRDEF("http://[2001:db8::ff00:42:8329]/url"), .type = httpProtocolTypeHttp), "new");
+        TEST_RESULT_STR_Z(httpUrl(url), "http://[2001:db8::ff00:42:8329]/url", "check url");
+        TEST_RESULT_STR_Z(httpUrlHost(url), "2001:db8::ff00:42:8329", "check host");
+        TEST_RESULT_STR_Z(httpUrlPath(url), "/url", "check path");
+        TEST_RESULT_UINT(httpUrlPort(url), 80, "check port");
+        TEST_RESULT_UINT(httpUrlProtocolType(url), httpProtocolTypeHttp, "check protocol");
+        TEST_RESULT_STR_Z(httpUrlToLog(url), "{http://[2001:db8::ff00:42:8329]:80/url}", "check log");
+
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("free");
+
+        TEST_RESULT_VOID(httpUrlFree(url), "free");
+    }
+
     // *****************************************************************************************************************************
     if (testBegin("HttpClient"))
     {
@@ -392,7 +487,7 @@ testRun(void)
                 MEM_CONTEXT_TEMP_END();
 
                 TEST_RESULT_STR_Z(httpRequestVerb(request), "GET", "check request verb");
-                TEST_RESULT_STR_Z(httpRequestUri(request), "/", "check request uri");
+                TEST_RESULT_STR_Z(httpRequestPath(request), "/", "check request path");
                 TEST_RESULT_STR_Z(
                     httpQueryRenderP(httpRequestQuery(request)), "name=%2Fpath%2FA%20Z.txt&type=test", "check request query");
                 TEST_RESULT_PTR_NE(httpRequestHeader(request), NULL, "check request headers");
@@ -489,7 +584,7 @@ testRun(void)
                 TEST_ERROR(
                     httpRequestError(request, response), ProtocolError,
                     "HTTP request failed with 404 (Not Found):\n"
-                    "*** URI/Query ***:\n"
+                    "*** Path/Query ***:\n"
                     "/");
 
                 // -----------------------------------------------------------------------------------------------------------------
@@ -520,7 +615,7 @@ testRun(void)
                 TEST_ERROR(
                     httpRequestError(request, response), ProtocolError,
                     "HTTP request failed with 403:\n"
-                    "*** URI/Query ***:\n"
+                    "*** Path/Query ***:\n"
                     "/?a=b\n"
                     "*** Request Headers ***:\n"
                     "hdr1: 1\n"
@@ -546,7 +641,7 @@ testRun(void)
                     response,
                     httpRequestResponse(
                         httpRequestNewP(
-                            client, strNew("GET"), strNew("/path/file 1.txt"),
+                            client, strNew("GET"), httpUriEncode(strNew("/path/file 1.txt"), true),
                             .header = httpHeaderAdd(httpHeaderNew(NULL), strNew("content-length"), strNew("30")),
                             .content = BUFSTRDEF("012345678901234567890123456789")), true),
                     "request");
@@ -570,7 +665,9 @@ testRun(void)
                 hrnServerScriptReplyZ(http, "HTTP/1.1 200 OK\r\ncontent-length:32\r\n\r\n01234567890123456789012345678901");
 
                 TEST_ASSIGN(
-                    response, httpRequestResponse(httpRequestNewP(client, strNew("GET"), strNew("/path/file 1.txt")), true),
+                    response,
+                    httpRequestResponse(
+                        httpRequestNewP(client, strNew("GET"), httpUriEncode(strNew("/path/file 1.txt"), true)), true),
                     "request");
                 TEST_RESULT_STR_Z(strNewBuf(httpResponseContent(response)),  "01234567890123456789012345678901", "check response");
                 TEST_RESULT_UINT(httpResponseRead(response, bufNew(1), true), 0, "call internal read to check eof");
@@ -584,7 +681,9 @@ testRun(void)
                 hrnServerScriptClose(http);
 
                 TEST_ASSIGN(
-                    response, httpRequestResponse(httpRequestNewP(client, strNew("GET"), strNew("/path/file 1.txt")), false),
+                    response,
+                    httpRequestResponse(
+                        httpRequestNewP(client, strNew("GET"), httpUriEncode(strNew("/path/file 1.txt"), true)), false),
                     "request");
                 TEST_RESULT_PTR_NE(response->session, NULL, "session is busy");
                 TEST_ERROR(ioRead(httpResponseIoRead(response), bufNew(32)), FileReadError, "unexpected EOF reading HTTP content");
@@ -628,5 +727,5 @@ testRun(void)
         TEST_RESULT_BOOL(varLstEmpty(kvKeyList(statToKv())), false, "check");
     }
 
-    FUNCTION_HARNESS_RESULT_VOID();
+    FUNCTION_HARNESS_RETURN_VOID();
 }
