@@ -679,5 +679,5 @@ testRun(void)
         TRY_END();
     }
 
-    FUNCTION_HARNESS_RESULT_VOID();
+    FUNCTION_HARNESS_RETURN_VOID();
 }
