@@ -420,5 +420,5 @@ testRun(void)
 
     memContextFree(memContextTop());
 
-    FUNCTION_HARNESS_RESULT_VOID();
+    FUNCTION_HARNESS_RETURN_VOID();
 }
