@@ -13,19 +13,39 @@ testRun(void)
     // *****************************************************************************************************************************
     if (testBegin("regExpNew(), regExpMatch(), and regExpFree()"))
     {
-        // Error message varies based on the libc version
+        // Error message varies based on the libc version/OS
         TRY_BEGIN()
         {
+            // Older libc
             TEST_ERROR(regExpNew(strNew("[[[")), FormatError, "Unmatched [ or [^");
         }
         CATCH(TestError)
         {
-            TEST_ERROR(regExpNew(strNew("[[[")), FormatError, "Unmatched [, [^, [:, [., or [=");
+            TRY_BEGIN()
+            {
+                // Newer libc
+                TEST_ERROR(regExpNew(strNew("[[[")), FormatError, "Unmatched [, [^, [:, [., or [=");
+            }
+            CATCH(TestError)
+            {
+                // MacOS
+                TEST_ERROR(regExpNew(strNew("[[[")), FormatError, "brackets ([ ]) not balanced");
+            }
+            TRY_END();
         }
         TRY_END();
 
-
-        TEST_ERROR(regExpErrorCheck(REG_BADBR), FormatError, "Invalid content of \\{\\}");
+        TRY_BEGIN()
+        {
+            // libc
+            TEST_ERROR(regExpErrorCheck(REG_BADBR), FormatError, "Invalid content of \\{\\}");
+        }
+        CATCH(TestError)
+        {
+            // MacOS
+            TEST_ERROR(regExpErrorCheck(REG_BADBR), FormatError, "invalid repetition count(s)");
+        }
+        TRY_END();
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("new regexp");
@@ -38,7 +58,7 @@ testRun(void)
 
         const String *string = STRDEF("abcdef");
         TEST_RESULT_BOOL(regExpMatch(regExp, string), true, "match regexp");
-        TEST_RESULT_PTR(regExpMatchPtr(regExp), strPtr(string), "check ptr");
+        TEST_RESULT_PTR(regExpMatchPtr(regExp), strZ(string), "check ptr");
         TEST_RESULT_UINT(regExpMatchSize(regExp), 3, "check size");
         TEST_RESULT_STR_Z(regExpMatchStr(regExp), "abc", "check str");
 
@@ -91,5 +111,5 @@ testRun(void)
         TEST_RESULT_BOOL(regExpMatchOne(strNew("^abc"), strNew("bcdef")), false, "no match regexp");
     }
 
-    FUNCTION_HARNESS_RESULT_VOID();
+    FUNCTION_HARNESS_RETURN_VOID();
 }
