@@ -11,7 +11,7 @@ testRun(void)
     FUNCTION_HARNESS_VOID();
 
     // *****************************************************************************************************************************
-    if (testBegin("bufNew(), bufNewC, bufNewUseC, bufMove(), bufSize(), bufPtr(), and bufFree()"))
+    if (testBegin("bufNew*(), bufMove(), bufSize(), bufSizeAlloc(), bufPtr(), and bufFree()"))
     {
         Buffer *buffer = NULL;
 
@@ -23,16 +23,12 @@ testRun(void)
         MEM_CONTEXT_TEMP_END();
 
         TEST_RESULT_PTR(bufPtr(buffer), buffer->buffer, "buffer pointer");
-        TEST_RESULT_INT(bufSize(buffer), 256, "buffer size");
+        TEST_RESULT_UINT(bufSize(buffer), 256, "buffer size");
+        TEST_RESULT_UINT(bufSizeAlloc(buffer), 256, "buffer allocation size");
 
         TEST_ASSIGN(buffer, bufNewC("TEST-STR", sizeof("TEST-STR") - 1), "new buffer from string");
         TEST_RESULT_BOOL(memcmp(bufPtr(buffer), "TEST-STR", 8) == 0, true, "check buffer");
 
-
-        TEST_ASSIGN(buffer, bufNewUseC((void *)"FIXED-BUFFER", sizeof("FIXED-BUFFER")), "new fixed buffer from string");
-        TEST_RESULT_BOOL(memcmp(bufPtr(buffer), "FIXED-BUFFER", 12) == 0, true, "check buffer");
-        TEST_ERROR(bufResize(buffer, 999), AssertError, "fixed size buffer cannot be resized");
-
         TEST_RESULT_VOID(bufFree(buffer), "free buffer");
         TEST_RESULT_VOID(bufFree(bufNew(0)), "free empty buffer");
 
@@ -43,6 +39,11 @@ testRun(void)
 
         TEST_ASSIGN(buffer, bufNewC(cBuffer, sizeof(cBuffer)), "create from c buffer");
         TEST_RESULT_BOOL(memcmp(bufPtr(buffer), cBuffer, sizeof(cBuffer)) == 0, true, "check buffer");
+
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("bufNewDecode()");
+
+        TEST_RESULT_STR_Z(strNewBuf(bufNewDecode(encodeBase64, STRDEF("eno="))), "zz", "decode base64");
     }
 
     // *****************************************************************************************************************************
@@ -52,9 +53,9 @@ testRun(void)
         unsigned char *bufferPtr = NULL;
 
         TEST_ASSIGN(buffer, bufNew(0), "new zero buffer");
-        TEST_RESULT_INT(bufSize(buffer), 0, "check size");
+        TEST_RESULT_UINT(bufSize(buffer), 0, "check size");
         TEST_RESULT_PTR(bufResize(buffer, 256), buffer, "resize buffer");
-        TEST_RESULT_INT(bufSize(buffer), 256, "check size");
+        TEST_RESULT_UINT(bufSize(buffer), 256, "check size");
         TEST_RESULT_VOID(bufUsedSet(buffer, 256), "set used size");
         TEST_RESULT_BOOL(bufFull(buffer), true, "check buffer full");
 
@@ -67,10 +68,10 @@ testRun(void)
         // Increase buffer size
         TEST_ASSIGN(bufferPtr, bufPtr(bufResize(buffer, 512)), "increase buffer size");
         TEST_ASSIGN(bufferPtr, bufPtr(bufResize(buffer, 512)), "set to same size");
-        TEST_RESULT_INT(bufSize(buffer), 512, "check size");
-        TEST_RESULT_INT(bufUsed(buffer), 256, "check used size");
+        TEST_RESULT_UINT(bufSize(buffer), 512, "check size");
+        TEST_RESULT_UINT(bufUsed(buffer), 256, "check used size");
         TEST_RESULT_BOOL(bufFull(buffer), false, "check buffer not full");
-        TEST_RESULT_INT(bufRemains(buffer), 256, "check remaining buffer space");
+        TEST_RESULT_UINT(bufRemains(buffer), 256, "check remaining buffer space");
         TEST_RESULT_PTR(bufRemainsPtr(buffer), bufPtr(buffer) + 256, "check remaining buffer space pointer");
         TEST_RESULT_VOID(bufUsedInc(buffer, 256), "set used size");
         TEST_RESULT_BOOL(bufFull(buffer), true, "check buffer full");
@@ -85,7 +86,7 @@ testRun(void)
 
         // Decrease buffer size
         TEST_ASSIGN(bufferPtr, bufPtr(bufResize(buffer, 128)), "decrease buffer size");
-        TEST_RESULT_INT(bufSize(buffer), 128, "check size");
+        TEST_RESULT_UINT(bufSize(buffer), 128, "check size");
 
         // Test that no bytes have changed in the original data
         sameTotal = 0;
@@ -95,24 +96,30 @@ testRun(void)
 
         TEST_RESULT_INT(sameTotal, 128, "original bytes match");
 
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("error when used > new limit");
+
+        TEST_ERROR(bufLimitSet(buffer, 64), AssertError, "assertion 'limit >= this->used' failed");
+        TEST_RESULT_VOID(bufUsedSet(buffer, 64), "set used");
+
         // Use limits to change size reporting
         TEST_RESULT_VOID(bufLimitSet(buffer, 64), "set limit");
-        TEST_RESULT_INT(bufSize(buffer), 64, "    check limited size");
+        TEST_RESULT_UINT(bufSize(buffer), 64, "    check limited size");
         TEST_RESULT_VOID(bufLimitClear(buffer), "    clear limit");
-        TEST_RESULT_INT(bufSize(buffer), 128, "    check unlimited size");
+        TEST_RESULT_UINT(bufSize(buffer), 128, "    check unlimited size");
 
         // Resize to zero buffer
         TEST_RESULT_VOID(bufUsedZero(buffer), "set used to 0");
-        TEST_RESULT_INT(bufUsed(buffer), 0, "check used is zero");
+        TEST_RESULT_UINT(bufUsed(buffer), 0, "check used is zero");
 
         TEST_RESULT_VOID(bufLimitSet(buffer, 64), "set limit to make sure it gets reduced with the resize");
         TEST_RESULT_VOID(bufResize(buffer, 32), "decrease size to 32");
-        TEST_RESULT_INT(bufSize(buffer), 32, "check size");
+        TEST_RESULT_UINT(bufSize(buffer), 32, "check size");
         TEST_RESULT_VOID(bufLimitSet(buffer, 0), "set limit so that it won't need to be resized");
         TEST_RESULT_VOID(bufResize(buffer, 0), "decrease size to zero");
-        TEST_RESULT_INT(bufSize(buffer), 0, "check size");
+        TEST_RESULT_UINT(bufSize(buffer), 0, "check size");
         TEST_RESULT_VOID(bufResize(buffer, 0), "decrease size to zero again");
-        TEST_RESULT_INT(bufSize(buffer), 0, "check size");
+        TEST_RESULT_UINT(bufSize(buffer), 0, "check size");
     }
 
     // *****************************************************************************************************************************
@@ -149,11 +156,11 @@ testRun(void)
     if (testBegin("bufToLog()"))
     {
         Buffer *buffer = bufNew(100);
-        TEST_RESULT_STR_Z(bufToLog(buffer), "{used: 0, size: 100, limit: <off>}", "buf to log");
+        TEST_RESULT_STR_Z(bufToLog(buffer), "{used: 0, size: 100}", "buf to log");
 
         bufLimitSet(buffer, 50);
-        TEST_RESULT_STR_Z(bufToLog(buffer), "{used: 0, size: 100, limit: 50}", "buf to log");
+        TEST_RESULT_STR_Z(bufToLog(buffer), "{used: 0, size: 50, sizeAlloc: 100}", "buf to log");
     }
 
-    FUNCTION_HARNESS_RESULT_VOID();
+    FUNCTION_HARNESS_RETURN_VOID();
 }
