@@ -210,5 +210,5 @@ testRun(void)
             CHECK(*(int *)lstFind(list, &listIdx) == listIdx);
     }
 
-    FUNCTION_HARNESS_RESULT_VOID();
+    FUNCTION_HARNESS_RETURN_VOID();
 }
