@@ -23,5 +23,5 @@ testRun(void)
         assert(!false);
     }
 
-    FUNCTION_HARNESS_RESULT_VOID();
+    FUNCTION_HARNESS_RETURN_VOID();
 }
