@@ -75,5 +75,5 @@ testRun(void)
             "exec restore -> restore");
     }
 
-    FUNCTION_HARNESS_RESULT_VOID();
+    FUNCTION_HARNESS_RETURN_VOID();
 }
