@@ -33,16 +33,22 @@ testRun(void)
             "db-version=\"9.4\"\n"
             "\n"
             "[ignore-section]\n"
-            "key1=value1\n"
+            "key1=\"value1\"\n"
             "\n"
             "[db:history]\n"
             "1={\"db-catalog-version\":201409291,\"db-control-version\":942,\"db-system-id\":6569239123849665679,"
                 "\"db-version\":\"9.4\"}\n"
         );
 
-        // Load to make sure ignore-section is ignored
-        InfoBackup *infoBackup;
-        TEST_ASSIGN(infoBackup, infoBackupNewLoad(ioBufferReadNew(contentLoad)), "    new backup info");
+        InfoBackup *infoBackup = NULL;
+
+        // Load and test move function then make sure ignore-section is ignored
+        MEM_CONTEXT_TEMP_BEGIN()
+        {
+            TEST_ASSIGN(infoBackup, infoBackupNewLoad(ioBufferReadNew(contentLoad)), "new backup info");
+            TEST_RESULT_VOID(infoBackupMove(infoBackup, memContextPrior()), "    move info");
+        }
+        MEM_CONTEXT_TEMP_END();
 
         // Save to verify with new created info backup
         Buffer *contentSave = bufNew(0);
@@ -53,7 +59,7 @@ testRun(void)
         Buffer *contentCompare = bufNew(0);
 
         TEST_ASSIGN(
-            infoBackup, infoBackupNew(PG_VERSION_94, 6569239123849665679, NULL),
+            infoBackup, infoBackupNew(PG_VERSION_94, 6569239123849665679, pgCatalogTestVersion(PG_VERSION_94), NULL),
             "infoBackupNew() - no cipher sub");
         TEST_RESULT_VOID(infoBackupSave(infoBackup, ioBufferWriteNew(contentCompare)), "    save backup info from new");
         TEST_RESULT_STR(strNewBuf(contentCompare), strNewBuf(contentSave), "   check save");
@@ -68,7 +74,8 @@ testRun(void)
         TEST_ASSIGN(
             infoBackup,
             infoBackupNew(
-                PG_VERSION_10, 6569239123849665999, strNew("zWa/6Xtp-IVZC5444yXB+cgFDFl7MxGlgkZSaoPvTGirhPygu4jOKOXf9LO4vjfO")),
+                PG_VERSION_10, 6569239123849665999, pgCatalogTestVersion(PG_VERSION_10),
+                strNew("zWa/6Xtp-IVZC5444yXB+cgFDFl7MxGlgkZSaoPvTGirhPygu4jOKOXf9LO4vjfO")),
             "infoBackupNew() - cipher sub");
 
         contentSave = bufNew(0);
@@ -85,11 +92,14 @@ testRun(void)
         // Add pg info
         // -------------------------------------------------------------------------------------------------------------------------
         InfoPgData infoPgData = {0};
-        TEST_RESULT_VOID(infoBackupPgSet(infoBackup, PG_VERSION_94, 6569239123849665679), "add another infoPg");
+        TEST_RESULT_VOID(
+            infoBackupPgSet(infoBackup, PG_VERSION_94, 6569239123849665679, pgCatalogTestVersion(PG_VERSION_94)),
+            "add another infoPg");
         TEST_RESULT_INT(infoPgDataTotal(infoBackup->infoPg), 2, "    history incremented");
         TEST_ASSIGN(infoPgData, infoPgDataCurrent(infoBackup->infoPg), "    get current infoPgData");
         TEST_RESULT_INT(infoPgData.version, PG_VERSION_94, "    version set");
         TEST_RESULT_UINT(infoPgData.systemId, 6569239123849665679, "    systemId set");
+        TEST_RESULT_UINT(infoPgData.catalogVersion, 201409291, "    catalogVersion set");
 
         // Free
         //--------------------------------------------------------------------------------------------------------------------------
@@ -193,30 +203,29 @@ testRun(void)
 
         // infoBackupDataLabelList and infoBackupDataDelete
         // -------------------------------------------------------------------------------------------------------------------------
-        TEST_RESULT_STR_Z(
-            strLstJoin(strLstSort(infoBackupDataLabelList(infoBackup, NULL), sortOrderAsc), ", "),
-            "20161219-212741F, 20161219-212741F_20161219-212803D, 20161219-212741F_20161219-212918I",
+        TEST_RESULT_STRLST_Z(
+            strLstSort(infoBackupDataLabelList(infoBackup, NULL), sortOrderAsc),
+            "20161219-212741F\n20161219-212741F_20161219-212803D\n20161219-212741F_20161219-212918I\n",
             "infoBackupDataLabelList without expression");
-        TEST_RESULT_STR_Z(
-            strLstJoin(
-                strLstSort(
-                    infoBackupDataLabelList(
-                        infoBackup, backupRegExpP(.full = true, .differential = true, .incremental = true)), sortOrderAsc), ", "),
-            "20161219-212741F, 20161219-212741F_20161219-212803D, 20161219-212741F_20161219-212918I",
+        TEST_RESULT_STRLST_Z(
+            strLstSort(
+                infoBackupDataLabelList(
+                    infoBackup, backupRegExpP(.full = true, .differential = true, .incremental = true)), sortOrderAsc),
+            "20161219-212741F\n20161219-212741F_20161219-212803D\n20161219-212741F_20161219-212918I\n",
             "infoBackupDataLabelList with expression");
-        TEST_RESULT_STR_Z(
-            strLstJoin(infoBackupDataLabelList(infoBackup, backupRegExpP(.full=true)), ", "), "20161219-212741F", "  full=true");
-        TEST_RESULT_STR_Z(
-            strLstJoin(infoBackupDataLabelList(infoBackup, backupRegExpP(.differential=true)), ", "),
-            "20161219-212741F_20161219-212803D", "differential=true");
-        TEST_RESULT_STR_Z(
-            strLstJoin(infoBackupDataLabelList(infoBackup, backupRegExpP(.incremental=true)), ", "),
-            "20161219-212741F_20161219-212918I", "incremental=true");
+        TEST_RESULT_STRLST_Z(
+            infoBackupDataLabelList(infoBackup, backupRegExpP(.full=true)), "20161219-212741F\n", "  full=true");
+        TEST_RESULT_STRLST_Z(
+            infoBackupDataLabelList(infoBackup, backupRegExpP(.differential=true)), "20161219-212741F_20161219-212803D\n",
+            "differential=true");
+        TEST_RESULT_STRLST_Z(
+            infoBackupDataLabelList(infoBackup, backupRegExpP(.incremental=true)), "20161219-212741F_20161219-212918I\n",
+            "incremental=true");
 
         TEST_RESULT_VOID(infoBackupDataDelete(infoBackup, strNew("20161219-212741F_20161219-212918I")), "delete a backup");
-        TEST_RESULT_STR_Z(
-            strLstJoin(strLstSort(infoBackupDataLabelList(infoBackup, NULL), sortOrderAsc), ", "),
-            "20161219-212741F, 20161219-212741F_20161219-212803D", "  backup deleted");
+        TEST_RESULT_STRLST_Z(
+            strLstSort(infoBackupDataLabelList(infoBackup, NULL), sortOrderAsc),
+            "20161219-212741F\n20161219-212741F_20161219-212803D\n", "  backup deleted");
 
         TEST_RESULT_VOID(infoBackupDataDelete(infoBackup, strNew("20161219-212741F_20161219-212803D")), "delete all backups");
         TEST_RESULT_VOID(infoBackupDataDelete(infoBackup, strNew("20161219-212741F")), "  deleted");
@@ -415,9 +424,9 @@ testRun(void)
         TEST_RESULT_STR_Z(backupData.backupArchiveStop, "000000030000028500000090", "archive stop set");
         TEST_RESULT_STR_Z(backupData.backupType, "diff", "backup type set");
         TEST_RESULT_STR_Z(backupData.backupPrior, "20190818-084502F", "backup prior set");
-        TEST_RESULT_STR_Z(
-            strLstJoin(backupData.backupReference, ", "),
-            "20190818-084502F, 20190818-084502F_20190819-084506D, 20190818-084502F_20190819-084506I",
+        TEST_RESULT_STRLST_Z(
+            backupData.backupReference,
+            "20190818-084502F\n20190818-084502F_20190819-084506D\n20190818-084502F_20190819-084506I\n",
             "backup reference set and ordered");
         TEST_RESULT_BOOL(backupData.optionArchiveCheck, true, "option archive check");
         TEST_RESULT_BOOL(backupData.optionArchiveCopy, true, "option archive copy");
@@ -437,7 +446,7 @@ testRun(void)
         // Load configuration to set repo-path and stanza
         StringList *argList = strLstNew();
         strLstAddZ(argList, "--stanza=db");
-        strLstAddZ(argList, "--" CFGOPT_PG1_PATH "=/path/to/pg");
+        hrnCfgArgRawZ(argList, cfgOptPgPath, "/path/to/pg");
         strLstAdd(argList, strNewFmt("--repo-path=%s", testPath()));
         harnessCfgLoad(cfgCmdArchiveGet, argList);
 
@@ -677,19 +686,19 @@ testRun(void)
             storagePathCreateP(storageRepoWrite(), strNew(STORAGE_REPO_BACKUP "/20190818-084502F")),
             "create backup on disk that is in current but no manifest");
 
-        TEST_RESULT_STR_Z(
-            strLstJoin(
-                strLstSort(
-                    storageListP(
-                        storageRepo(), STORAGE_REPO_BACKUP_STR,
-                        .expression = backupRegExpP(.full = true, .differential = true, .incremental = true)),
-                    sortOrderAsc),
-                ", "),
-            "20190818-084444F, 20190818-084502F, 20190818-084502F_20190820-084502I, 20190818-084555F, 20190818-084666F, "
-            "20190818-084777F, 20190923-164324F", "confirm backups on disk");
+        TEST_RESULT_STRLST_Z(
+            strLstSort(
+                storageListP(
+                    storageRepo(), STORAGE_REPO_BACKUP_STR,
+                    .expression = backupRegExpP(.full = true, .differential = true, .incremental = true)),
+                sortOrderAsc),
+            "20190818-084444F\n20190818-084502F\n20190818-084502F_20190820-084502I\n20190818-084555F\n20190818-084666F\n"
+            "20190818-084777F\n20190923-164324F\n", "confirm backups on disk");
 
         // With the infoBackup from above, upgrade the DB so there a 2 histories then save to disk
-        TEST_ASSIGN(infoBackup, infoBackupPgSet(infoBackup, PG_VERSION_11, 6739907367085689196), "upgrade db");
+        TEST_ASSIGN(
+            infoBackup, infoBackupPgSet(infoBackup, PG_VERSION_11, 6739907367085689196, pgCatalogTestVersion(PG_VERSION_11)),
+            "upgrade db");
         TEST_RESULT_VOID(
             infoBackupSaveFile(infoBackup, storageRepoWrite(), INFO_BACKUP_PATH_FILE_STR, cipherTypeNone, NULL),
             "save backup info");
@@ -793,9 +802,9 @@ testRun(void)
         TEST_ASSIGN(
             infoBackup, infoBackupLoadFileReconstruct(storageRepo(), INFO_BACKUP_PATH_FILE_STR, cipherTypeNone, NULL),
             "reconstruct");
-        TEST_RESULT_STR_Z(
-            strLstJoin(infoBackupDataLabelList(infoBackup, NULL), ", "),
-            "20190818-084444F, 20190818-084444F_20190924-084502D, 20190923-164324F",
+        TEST_RESULT_STRLST_Z(
+            infoBackupDataLabelList(infoBackup, NULL),
+            "20190818-084444F\n20190818-084444F_20190924-084502D\n20190923-164324F\n",
             "previously ignored pgId=1 manifest copy-only now added before existing, and add dependent found");
         harnessLogResult(
             "P00   WARN: backup '20190818-084444F' found in repository added to backup.info\n"
@@ -817,7 +826,7 @@ testRun(void)
             "HINT: has a stanza-create been performed?",
             testPath(), testPath(), testPath(), testPath());
 
-        InfoBackup *infoBackup = infoBackupNew(PG_VERSION_10, 6569239123849665999, NULL);
+        InfoBackup *infoBackup = infoBackupNew(PG_VERSION_10, 6569239123849665999, pgCatalogTestVersion(PG_VERSION_10), NULL);
         TEST_RESULT_VOID(
             infoBackupSaveFile(infoBackup, storageTest, STRDEF(INFO_BACKUP_FILE), cipherTypeNone, NULL), "save backup info");
 
@@ -913,27 +922,26 @@ testRun(void)
 
         TEST_ASSIGN(
             dependencyList, infoBackupDataDependentList(infoBackup, STRDEF("20200317-181625F")), "full");
-        TEST_RESULT_STR_Z(
-            strLstJoin(dependencyList, ", "),
-            "20200317-181625F, 20200317-181625F_20200317-182239D, 20200317-181625F_20200317-182300D, "
-            "20200317-181625F_20200317-182324I, 20200317-181625F_20200317-182340I, 20200317-181625F_20200317-182340D",
+        TEST_RESULT_STRLST_Z(
+            dependencyList,
+            "20200317-181625F\n20200317-181625F_20200317-182239D\n20200317-181625F_20200317-182300D\n"
+                "20200317-181625F_20200317-182324I\n20200317-181625F_20200317-182340I\n20200317-181625F_20200317-182340D\n",
             "all dependents");
 
         TEST_ASSIGN(
             dependencyList, infoBackupDataDependentList(infoBackup, STRDEF("20200317-181416F")), "full");
-        TEST_RESULT_STR_Z(strLstJoin(dependencyList, ", "), "20200317-181416F", "no dependents");
+        TEST_RESULT_STRLST_Z(dependencyList, "20200317-181416F\n", "no dependents");
 
         TEST_ASSIGN(
             dependencyList, infoBackupDataDependentList(infoBackup, STRDEF("20200317-181625F_20200317-182300D")), "diff");
-        TEST_RESULT_STR_Z(
-            strLstJoin(dependencyList, ", "),
-            "20200317-181625F_20200317-182300D, 20200317-181625F_20200317-182324I, 20200317-181625F_20200317-182340I",
+        TEST_RESULT_STRLST_Z(
+            dependencyList,
+            "20200317-181625F_20200317-182300D\n20200317-181625F_20200317-182324I\n20200317-181625F_20200317-182340I\n",
             "all dependents");
 
         TEST_ASSIGN(
             dependencyList, infoBackupDataDependentList(infoBackup, STRDEF("20200317-181625F_20200317-182324I")), "incr");
-        TEST_RESULT_STR_Z(
-            strLstJoin(dependencyList, ", "), "20200317-181625F_20200317-182324I, 20200317-181625F_20200317-182340I",
-            "all dependents");
+        TEST_RESULT_STRLST_Z(
+            dependencyList, "20200317-181625F_20200317-182324I\n20200317-181625F_20200317-182340I\n", "all dependents");
     }
 }
