@@ -9,6 +9,7 @@ stress testing as needed.
 ***********************************************************************************************************************************/
 #include "common/harnessConfig.h"
 #include "common/harnessFork.h"
+#include "common/harnessStorage.h"
 
 #include "common/crypto/hash.h"
 #include "common/compress/gz/compress.h"
@@ -17,66 +18,14 @@ stress testing as needed.
 #include "common/io/filter/sink.h"
 #include "common/io/bufferRead.h"
 #include "common/io/bufferWrite.h"
-#include "common/io/handleRead.h"
-#include "common/io/handleWrite.h"
+#include "common/io/fdRead.h"
+#include "common/io/fdWrite.h"
 #include "common/io/io.h"
 #include "common/type/object.h"
 #include "protocol/client.h"
 #include "protocol/server.h"
 #include "storage/posix/storage.h"
 #include "storage/remote/protocol.h"
-#include "storage/storage.intern.h"
-
-/***********************************************************************************************************************************
-Dummy functions and interface for constructing test drivers
-***********************************************************************************************************************************/
-static StorageInfo
-storageTestDummyInfo(THIS_VOID, const String *file, StorageInfoLevel level, StorageInterfaceInfoParam param)
-{
-    (void)thisVoid; (void)file; (void)level; (void)param; return (StorageInfo){.exists = false};
-}
-
-static bool
-storageTestDummyInfoList(
-    THIS_VOID, const String *path, StorageInfoLevel level, StorageInfoListCallback callback, void *callbackData,
-    StorageInterfaceInfoListParam param)
-{
-    (void)thisVoid; (void)path; (void)level; (void)callback; (void)callbackData; (void)param; return false;
-}
-
-static StorageRead *
-storageTestDummyNewRead(THIS_VOID, const String *file, bool ignoreMissing, StorageInterfaceNewReadParam param)
-{
-    (void)thisVoid; (void)file; (void)ignoreMissing; (void)param; return NULL;
-}
-
-static StorageWrite *
-storageTestDummyNewWrite(THIS_VOID, const String *file, StorageInterfaceNewWriteParam param)
-{
-    (void)thisVoid; (void)file; (void)param; return NULL;
-}
-
-static bool
-storageTestDummyPathRemove(THIS_VOID, const String *path, bool recurse, StorageInterfacePathRemoveParam param)
-{
-    (void)thisVoid; (void)path; (void)recurse; (void)param; return false;
-}
-
-static void
-storageTestDummyRemove(THIS_VOID, const String *file, StorageInterfaceRemoveParam param)
-{
-    (void)thisVoid; (void)file; (void)param;
-}
-
-static const StorageInterface storageInterfaceTestDummy =
-{
-    .info = storageTestDummyInfo,
-    .infoList = storageTestDummyInfoList,
-    .newRead = storageTestDummyNewRead,
-    .newWrite = storageTestDummyNewWrite,
-    .pathRemove = storageTestDummyPathRemove,
-    .remove = storageTestDummyRemove,
-};
 
 /***********************************************************************************************************************************
 Dummy callback functions
@@ -114,7 +63,7 @@ storageTestPerfInfoList(
         {
             for (uint64_t fileIdx = 0; fileIdx < this->fileTotal; fileIdx++)
             {
-                callback(callbackData, &(StorageInfo){.exists = true});
+                callback(callbackData, &(StorageInfo){.exists = true, .name = STRDEF("name")});
                 MEM_CONTEXT_TEMP_RESET(1000);
             }
         }
@@ -218,17 +167,20 @@ testRun(void)
 
                 driver.interface.infoList = storageTestPerfInfoList;
 
-                storageHelper.storageRepo = storageNew(STRDEF("TEST"), STRDEF("/"), 0, 0, false, NULL, &driver, driver.interface);
+                storageHelper.storageRepo = memNew(sizeof(Storage *));
+                storageHelper.storageRepo[0] = storageNew(
+                    STRDEF("TEST"), STRDEF("/"), 0, 0, false, NULL, &driver, driver.interface);
 
                 // Setup handler for remote storage protocol
-                IoRead *read = ioHandleReadNew(strNew("storage server read"), HARNESS_FORK_CHILD_READ(), 60000);
+                IoRead *read = ioFdReadNew(strNew("storage server read"), HARNESS_FORK_CHILD_READ(), 60000);
                 ioReadOpen(read);
-                IoWrite *write = ioHandleWriteNew(strNew("storage server write"), HARNESS_FORK_CHILD_WRITE());
+                IoWrite *write = ioFdWriteNew(strNew("storage server write"), HARNESS_FORK_CHILD_WRITE(), 1000);
                 ioWriteOpen(write);
 
                 ProtocolServer *server = protocolServerNew(strNew("storage test server"), strNew("test"), read, write);
-                protocolServerHandlerAdd(server, storageRemoteProtocol);
-                protocolServerProcess(server, NULL);
+
+                static const ProtocolServerHandler commandHandler[] = {PROTOCOL_SERVER_HANDLER_STORAGE_REMOTE_LIST};
+                protocolServerProcess(server, NULL, commandHandler, PROTOCOL_SERVER_HANDLER_LIST_SIZE(commandHandler));
 
             }
             HARNESS_FORK_CHILD_END();
@@ -236,9 +188,9 @@ testRun(void)
             HARNESS_FORK_PARENT_BEGIN()
             {
                 // Create client
-                IoRead *read = ioHandleReadNew(strNew("storage client read"), HARNESS_FORK_PARENT_READ_PROCESS(0), 60000);
+                IoRead *read = ioFdReadNew(strNew("storage client read"), HARNESS_FORK_PARENT_READ_PROCESS(0), 60000);
                 ioReadOpen(read);
-                IoWrite *write = ioHandleWriteNew(strNew("storage client write"), HARNESS_FORK_PARENT_WRITE_PROCESS(0));
+                IoWrite *write = ioFdWriteNew(strNew("storage client write"), HARNESS_FORK_PARENT_WRITE_PROCESS(0), 1000);
                 ioWriteOpen(write);
 
                 ProtocolClient *client = protocolClientNew(strNew("storage test client"), strNew("test"), read, write);
@@ -247,11 +199,15 @@ testRun(void)
                 Storage *storageRemote = storageRemoteNew(
                     STORAGE_MODE_FILE_DEFAULT, STORAGE_MODE_PATH_DEFAULT, false, NULL, client, 1);
 
+                TimeMSec timeBegin = timeMSec();
+
                 // Storage info list
                 TEST_RESULT_VOID(
                     storageInfoListP(storageRemote, NULL, storageTestDummyInfoListCallback, NULL),
                     "list %" PRIu64 " remote files", fileTotal);
 
+                TEST_LOG_FMT("list transferred in %ums", (unsigned int)(timeMSec() - timeBegin));
+
                 // Free client
                 protocolClientFree(client);
             }
@@ -282,7 +238,7 @@ testRun(void)
         ASSERT(bufUsed(block) == 1024 * 1024);
 
         // Build the input buffer
-        Buffer *input = bufNew(blockTotal * bufSize(block));
+        Buffer *input = bufNew((size_t)blockTotal * bufSize(block));
 
         for (unsigned int blockIdx = 0; blockIdx < blockTotal; blockIdx++)
             memcpy(bufPtr(input) + (blockIdx * bufSize(block)), bufPtr(block), bufSize(block));
@@ -291,7 +247,7 @@ testRun(void)
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE_FMT(
-            "%u iteration(s) of %" PRIu64 "MiB with %" PRIu64 "MB/s input, %" PRIu64 "MB/s output", iteration,
+            "%u iteration(s) of %zuMiB with %" PRIu64 "MB/s input, %" PRIu64 "MB/s output", iteration,
             bufUsed(input) / bufUsed(block), rateIn, rateOut);
 
         #define BENCHMARK_BEGIN()                                                                                                  \
@@ -334,7 +290,10 @@ testRun(void)
         uint64_t sha1Total = 1;
         uint64_t sha256Total = 1;
         uint64_t gzip6Total = 1;
+
+#ifdef HAVE_LIBLZ4
         uint64_t lz41Total = 1;
+#endif // HAVE_LIBLZ4
 
         for (unsigned int idx = 0; idx < iteration; idx++)
         {
@@ -393,6 +352,7 @@ testRun(void)
             MEM_CONTEXT_TEMP_END();
 
             // -------------------------------------------------------------------------------------------------------------------------
+#ifdef HAVE_LIBLZ4
             TEST_LOG_FMT("lz4 -1 iteration %u", idx + 1);
 
             MEM_CONTEXT_TEMP_BEGIN()
@@ -402,6 +362,7 @@ testRun(void)
                 BENCHMARK_END(lz41Total);
             }
             MEM_CONTEXT_TEMP_END();
+#endif // HAVE_LIBLZ4
         }
 
         // -------------------------------------------------------------------------------------------------------------------------
@@ -417,8 +378,11 @@ testRun(void)
         TEST_RESULT("sha1", sha1Total);
         TEST_RESULT("sha256", sha256Total);
         TEST_RESULT("gzip -6", gzip6Total);
+
+#ifdef HAVE_LIBLZ4
         TEST_RESULT("lz4 -1", lz41Total);
+#endif // HAVE_LIBLZ4
     }
 
-    FUNCTION_HARNESS_RESULT_VOID();
+    FUNCTION_HARNESS_RETURN_VOID();
 }
