@@ -1,13 +1,13 @@
 /***********************************************************************************************************************************
 Test Azure Storage
 ***********************************************************************************************************************************/
-#include "common/io/handleRead.h"
-#include "common/io/handleWrite.h"
+#include "common/io/fdRead.h"
+#include "common/io/fdWrite.h"
 
 #include "common/harnessConfig.h"
 #include "common/harnessFork.h"
+#include "common/harnessServer.h"
 #include "common/harnessStorage.h"
-#include "common/harnessTls.h"
 
 /***********************************************************************************************************************************
 Constants
@@ -33,11 +33,11 @@ typedef struct TestRequestParam
     const char *blobType;
 } TestRequestParam;
 
-#define testRequestP(verb, uri, ...)                                                                                               \
-    testRequest(verb, uri, (TestRequestParam){VAR_PARAM_INIT, __VA_ARGS__})
+#define testRequestP(write, verb, path, ...)                                                                                       \
+    testRequest(write, verb, path, (TestRequestParam){VAR_PARAM_INIT, __VA_ARGS__})
 
 static void
-testRequest(const char *verb, const char *uri, TestRequestParam param)
+testRequest(IoWrite *write, const char *verb, const char *path, TestRequestParam param)
 {
     String *request = strNewFmt("%s /" TEST_ACCOUNT "/" TEST_CONTAINER, verb);
 
@@ -45,23 +45,23 @@ testRequest(const char *verb, const char *uri, TestRequestParam param)
     if (driver->sasKey != NULL)
     {
         HttpQuery *query = httpQueryNewP();
-        StringList *uriQuery = strLstNewSplitZ(STR(uri), "?");
+        StringList *pathQuery = strLstNewSplitZ(STR(path), "?");
 
-        if (strLstSize(uriQuery) == 2)
-            query = httpQueryNewStr(strLstGet(uriQuery, 1));
+        if (strLstSize(pathQuery) == 2)
+            query = httpQueryNewStr(strLstGet(pathQuery, 1));
 
         httpQueryMerge(query, driver->sasKey);
 
-        strCat(request, strLstGet(uriQuery, 0));
+        strCat(request, strLstGet(pathQuery, 0));
         strCatZ(request, "?");
         strCat(request, httpQueryRenderP(query));
     }
-    // Else just output URI as is
+    // Else just output path as is
     else
-        strCatZ(request, uri);
+        strCatZ(request, path);
 
-    // Add HTTP version
-    strCatZ(request, " HTTP/1.1\r\n");
+    // Add HTTP version and user agent
+    strCatZ(request, " HTTP/1.1\r\nuser-agent:" PROJECT_NAME "/" PROJECT_VERSION "\r\n");
 
     // Add authorization string
     if (driver->sharedKey != NULL)
@@ -73,9 +73,9 @@ testRequest(const char *verb, const char *uri, TestRequestParam param)
     // Add md5
     if (param.content != NULL)
     {
-        char md5Hash[HASH_TYPE_MD5_SIZE_HEX];
-        encodeToStr(encodeBase64, bufPtr(cryptoHashOne(HASH_TYPE_MD5_STR, BUFSTRZ(param.content))), HASH_TYPE_M5_SIZE, md5Hash);
-        strCatFmt(request, "content-md5:%s\r\n", md5Hash);
+        strCatFmt(
+            request, "content-md5:%s\r\n",
+            strZ(strNewEncode(encodeBase64, cryptoHashOne(HASH_TYPE_MD5_STR, BUFSTRZ(param.content)))));
     }
 
     // Add date
@@ -83,7 +83,7 @@ testRequest(const char *verb, const char *uri, TestRequestParam param)
         strCatZ(request, "date:???, ?? ??? ???? ??:??:?? GMT\r\n");
 
     // Add host
-    strCatFmt(request, "host:%s\r\n", strPtr(hrnTlsServerHost()));
+    strCatFmt(request, "host:%s\r\n", strZ(hrnServerHost()));
 
     // Add blob type
     if (param.blobType != NULL)
@@ -100,7 +100,7 @@ testRequest(const char *verb, const char *uri, TestRequestParam param)
     if (param.content != NULL)
         strCatZ(request, param.content);
 
-    hrnTlsServerExpect(request);
+    hrnServerScriptExpect(write, request);
 }
 
 /***********************************************************************************************************************************
@@ -114,11 +114,11 @@ typedef struct TestResponseParam
     const char *content;
 } TestResponseParam;
 
-#define testResponseP(...)                                                                                                         \
-    testResponse((TestResponseParam){VAR_PARAM_INIT, __VA_ARGS__})
+#define testResponseP(write, ...)                                                                                                  \
+    testResponse(write, (TestResponseParam){VAR_PARAM_INIT, __VA_ARGS__})
 
 static void
-testResponse(TestResponseParam param)
+testResponse(IoWrite *write, TestResponseParam param)
 {
     // Set code to 200 if not specified
     param.code = param.code == 0 ? 200 : param.code;
@@ -130,16 +130,12 @@ testResponse(TestResponseParam param)
     switch (param.code)
     {
         case 200:
-        {
             strCatZ(response, "OK");
             break;
-        }
 
         case 403:
-        {
             strCatZ(response, "Forbidden");
             break;
-        }
     }
 
     // End header
@@ -162,7 +158,7 @@ testResponse(TestResponseParam param)
     else
         strCatZ(response, "\r\n");
 
-    hrnTlsServerReply(response);
+    hrnServerScriptReply(write, response);
 }
 
 /***********************************************************************************************************************************
@@ -182,21 +178,22 @@ testRun(void)
 
         StringList *argList = strLstNew();
         strLstAddZ(argList, "--" CFGOPT_STANZA "=test");
-        strLstAddZ(argList, "--" CFGOPT_REPO1_TYPE "=" STORAGE_AZURE_TYPE);
-        strLstAddZ(argList, "--" CFGOPT_REPO1_PATH "=/repo");
-        strLstAddZ(argList, "--" CFGOPT_REPO1_AZURE_CONTAINER "=" TEST_CONTAINER);
-        setenv("PGBACKREST_" CFGOPT_REPO1_AZURE_ACCOUNT, TEST_ACCOUNT, true);
-        setenv("PGBACKREST_" CFGOPT_REPO1_AZURE_KEY, TEST_KEY_SHARED, true);
+        hrnCfgArgRawZ(argList, cfgOptRepoType, STORAGE_AZURE_TYPE);
+        hrnCfgArgRawZ(argList, cfgOptRepoPath, "/repo");
+        hrnCfgArgRawZ(argList, cfgOptRepoAzureContainer, TEST_CONTAINER);
+        hrnCfgEnvRawZ(cfgOptRepoAzureAccount, TEST_ACCOUNT);
+        hrnCfgEnvRawZ(cfgOptRepoAzureKey, TEST_KEY_SHARED);
         harnessCfgLoad(cfgCmdArchivePush, argList);
 
         Storage *storage = NULL;
-        TEST_ASSIGN(storage, storageRepoGet(strNew(STORAGE_AZURE_TYPE), false), "get repo storage");
+        TEST_ASSIGN(storage, storageRepoGet(0, false), "get repo storage");
         TEST_RESULT_STR_Z(storage->path, "/repo", "    check path");
         TEST_RESULT_STR(((StorageAzure *)storage->driver)->account, TEST_ACCOUNT_STR, "    check account");
         TEST_RESULT_STR(((StorageAzure *)storage->driver)->container, TEST_CONTAINER_STR, "    check container");
-        TEST_RESULT_STR(((StorageAzure *)storage->driver)->sharedKey, TEST_KEY_SHARED_STR, "    check key");
+        TEST_RESULT_STR(
+            strNewEncode(encodeBase64, ((StorageAzure *)storage->driver)->sharedKey), TEST_KEY_SHARED_STR, "    check key");
         TEST_RESULT_STR_Z(((StorageAzure *)storage->driver)->host, TEST_ACCOUNT ".blob.core.windows.net", "    check host");
-        TEST_RESULT_STR_Z(((StorageAzure *)storage->driver)->uriPrefix, "/" TEST_CONTAINER, "    check uri prefix");
+        TEST_RESULT_STR_Z(((StorageAzure *)storage->driver)->pathPrefix, "/" TEST_CONTAINER, "    check path prefix");
         TEST_RESULT_UINT(((StorageAzure *)storage->driver)->blockSize, STORAGE_AZURE_BLOCKSIZE_MIN, "    check block size");
         TEST_RESULT_BOOL(storageFeature(storage, storageFeaturePath), false, "    check path feature");
         TEST_RESULT_BOOL(storageFeature(storage, storageFeatureCompress), false, "    check compress feature");
@@ -214,7 +211,7 @@ testRun(void)
             (StorageAzure *)storageDriver(
                 storageAzureNew(
                     STRDEF("/repo"), false, NULL, TEST_CONTAINER_STR, TEST_ACCOUNT_STR, storageAzureKeyTypeShared,
-                    TEST_KEY_SHARED_STR, 16, NULL, 443, 1000, true, NULL, NULL)),
+                    TEST_KEY_SHARED_STR, 16, NULL, STRDEF("blob.core.windows.net"), 443, 1000, true, NULL, NULL)),
             "new azure storage - shared key");
 
         // -------------------------------------------------------------------------------------------------------------------------
@@ -253,7 +250,7 @@ testRun(void)
             (StorageAzure *)storageDriver(
                 storageAzureNew(
                     STRDEF("/repo"), false, NULL, TEST_CONTAINER_STR, TEST_ACCOUNT_STR, storageAzureKeyTypeSas, TEST_KEY_SAS_STR,
-                    16, NULL, 443, 1000, true, NULL, NULL)),
+                    16, NULL, STRDEF("blob.core.usgovcloudapi.net"), 443, 1000, true, NULL, NULL)),
             "new azure storage - sas key");
 
         query = httpQueryAdd(httpQueryNewP(), STRDEF("a"), STRDEF("b"));
@@ -261,7 +258,7 @@ testRun(void)
 
         TEST_RESULT_VOID(storageAzureAuth(storage, HTTP_VERB_GET_STR, STRDEF("/path/file"), query, dateTime, header), "auth");
         TEST_RESULT_STR_Z(
-            httpHeaderToLog(header), "{content-length: '66', host: 'account.blob.core.windows.net'}", "check headers");
+            httpHeaderToLog(header), "{content-length: '66', host: 'account.blob.core.usgovcloudapi.net'}", "check headers");
         TEST_RESULT_STR_Z(httpQueryRenderP(query), "a=b&sig=key", "check query");
     }
 
@@ -273,36 +270,37 @@ testRun(void)
             HARNESS_FORK_CHILD_BEGIN(0, true)
             {
                 TEST_RESULT_VOID(
-                    hrnTlsServerRun(ioHandleReadNew(strNew("azure server read"), HARNESS_FORK_CHILD_READ(), 5000)),
-                    "azure server begin");
+                    hrnServerRunP(ioFdReadNew(strNew("azure server read"), HARNESS_FORK_CHILD_READ(), 5000), hrnServerProtocolTls),
+                    "azure server run");
             }
             HARNESS_FORK_CHILD_END();
 
             HARNESS_FORK_PARENT_BEGIN()
             {
-                hrnTlsClientBegin(ioHandleWriteNew(strNew("azure client write"), HARNESS_FORK_PARENT_WRITE_PROCESS(0)));
+                IoWrite *service = hrnServerScriptBegin(
+                    ioFdWriteNew(strNew("azure client write"), HARNESS_FORK_PARENT_WRITE_PROCESS(0), 2000));
 
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("test against local host");
 
                 StringList *argList = strLstNew();
                 strLstAddZ(argList, "--" CFGOPT_STANZA "=test");
-                strLstAddZ(argList, "--" CFGOPT_REPO1_TYPE "=" STORAGE_AZURE_TYPE);
-                strLstAddZ(argList, "--" CFGOPT_REPO1_PATH "=/");
-                strLstAddZ(argList, "--" CFGOPT_REPO1_AZURE_CONTAINER "=" TEST_CONTAINER);
-                strLstAdd(argList, strNewFmt("--" CFGOPT_REPO1_AZURE_HOST "=%s", strPtr(hrnTlsServerHost())));
-                strLstAdd(argList, strNewFmt("--" CFGOPT_REPO1_AZURE_PORT "=%u", hrnTlsServerPort()));
-                strLstAdd(argList, strNewFmt("--%s" CFGOPT_REPO1_AZURE_VERIFY_TLS, testContainer() ? "" : "no-"));
-                setenv("PGBACKREST_" CFGOPT_REPO1_AZURE_ACCOUNT, TEST_ACCOUNT, true);
-                setenv("PGBACKREST_" CFGOPT_REPO1_AZURE_KEY, TEST_KEY_SHARED, true);
+                hrnCfgArgRawZ(argList, cfgOptRepoType, STORAGE_AZURE_TYPE);
+                hrnCfgArgRawZ(argList, cfgOptRepoPath, "/");
+                hrnCfgArgRawZ(argList, cfgOptRepoAzureContainer, TEST_CONTAINER);
+                hrnCfgArgRaw(argList, cfgOptRepoStorageHost, hrnServerHost());
+                hrnCfgArgRawFmt(argList, cfgOptRepoStoragePort, "%u", hrnServerPort(0));
+                hrnCfgArgRawBool(argList, cfgOptRepoStorageVerifyTls, testContainer());
+                hrnCfgEnvRawZ(cfgOptRepoAzureAccount, TEST_ACCOUNT);
+                hrnCfgEnvRawZ(cfgOptRepoAzureKey, TEST_KEY_SHARED);
                 harnessCfgLoad(cfgCmdArchivePush, argList);
 
                 Storage *storage = NULL;
-                TEST_ASSIGN(storage, storageRepoGet(strNew(STORAGE_AZURE_TYPE), true), "get repo storage");
+                TEST_ASSIGN(storage, storageRepoGet(0, true), "get repo storage");
 
                 driver = (StorageAzure *)storage->driver;
-                TEST_RESULT_STR(driver->host, hrnTlsServerHost(), "    check host");
-                TEST_RESULT_STR_Z(driver->uriPrefix,  "/" TEST_ACCOUNT "/" TEST_CONTAINER, "    check uri prefix");
+                TEST_RESULT_STR(driver->host, hrnServerHost(), "    check host");
+                TEST_RESULT_STR_Z(driver->pathPrefix,  "/" TEST_ACCOUNT "/" TEST_CONTAINER, "    check path prefix");
                 TEST_RESULT_BOOL(driver->fileId == 0, false, "    check file id");
 
                 // Tests need the block size to be 16
@@ -311,9 +309,9 @@ testRun(void)
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("ignore missing file");
 
-                hrnTlsServerAccept();
-                testRequestP(HTTP_VERB_GET, "/fi%26le.txt");
-                testResponseP(.code = 404);
+                hrnServerScriptAccept(service);
+                testRequestP(service, HTTP_VERB_GET, "/fi%26le.txt");
+                testResponseP(service, .code = 404);
 
                 TEST_RESULT_PTR(
                     storageGetP(storageNewReadP(storage, strNew("fi&le.txt"), .ignoreMissing = true)), NULL, "get file");
@@ -321,18 +319,18 @@ testRun(void)
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("error on missing file");
 
-                testRequestP(HTTP_VERB_GET, "/file.txt");
-                testResponseP(.code = 404);
+                testRequestP(service, HTTP_VERB_GET, "/file.txt");
+                testResponseP(service, .code = 404);
 
                 TEST_ERROR(
                     storageGetP(storageNewReadP(storage, strNew("file.txt"))), FileMissingError,
-                    "unable to open '/file.txt': No such file or directory");
+                    "unable to open missing file '/file.txt' for read");
 
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("get file");
 
-                testRequestP(HTTP_VERB_GET, "/file.txt");
-                testResponseP(.content = "this is a sample file");
+                testRequestP(service, HTTP_VERB_GET, "/file.txt");
+                testResponseP(service, .content = "this is a sample file");
 
                 TEST_RESULT_STR_Z(
                     strNewBuf(storageGetP(storageNewReadP(storage, strNew("file.txt")))), "this is a sample file", "get file");
@@ -340,8 +338,8 @@ testRun(void)
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("get zero-length file");
 
-                testRequestP(HTTP_VERB_GET, "/file0.txt");
-                testResponseP();
+                testRequestP(service, HTTP_VERB_GET, "/file0.txt");
+                testResponseP(service);
 
                 TEST_RESULT_STR_Z(
                     strNewBuf(storageGetP(storageNewReadP(storage, strNew("file0.txt")))), "", "get zero-length file");
@@ -349,8 +347,8 @@ testRun(void)
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("non-404 error");
 
-                testRequestP(HTTP_VERB_GET, "/file.txt");
-                testResponseP(.code = 303, .content = "CONTENT");
+                testRequestP(service, HTTP_VERB_GET, "/file.txt");
+                testResponseP(service, .code = 303, .content = "CONTENT");
 
                 StorageRead *read = NULL;
                 TEST_ASSIGN(read, storageNewReadP(storage, strNew("file.txt"), .ignoreMissing = true), "new read file");
@@ -360,7 +358,7 @@ testRun(void)
                 TEST_ERROR_FMT(
                     ioReadOpen(storageReadIo(read)), ProtocolError,
                     "HTTP request failed with 303:\n"
-                    "*** URI/Query ***:\n"
+                    "*** Path/Query ***:\n"
                     "/account/container/file.txt\n"
                     "*** Request Headers ***:\n"
                     "authorization: <redacted>\n"
@@ -372,18 +370,18 @@ testRun(void)
                     "content-length: 7\n"
                     "*** Response Content ***:\n"
                     "CONTENT",
-                    strPtr(hrnTlsServerHost()));
+                    strZ(hrnServerHost()));
 
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("write error");
 
-                testRequestP(HTTP_VERB_PUT, "/file.txt", .blobType = "BlockBlob", .content = "ABCD");
-                testResponseP(.code = 403);
+                testRequestP(service, HTTP_VERB_PUT, "/file.txt", .blobType = "BlockBlob", .content = "ABCD");
+                testResponseP(service, .code = 403);
 
                 TEST_ERROR_FMT(
                     storagePutP(storageNewWriteP(storage, strNew("file.txt")), BUFSTRDEF("ABCD")), ProtocolError,
                     "HTTP request failed with 403 (Forbidden):\n"
-                    "*** URI/Query ***:\n"
+                    "*** Path/Query ***:\n"
                     "/account/container/file.txt\n"
                     "*** Request Headers ***:\n"
                     "authorization: <redacted>\n"
@@ -393,15 +391,15 @@ testRun(void)
                     "host: %s\n"
                     "x-ms-blob-type: BlockBlob\n"
                     "x-ms-version: 2019-02-02",
-                    strPtr(hrnTlsServerHost()));
+                    strZ(hrnServerHost()));
 
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("write file in one part (with retry)");
 
-                testRequestP(HTTP_VERB_PUT, "/file.txt", .blobType = "BlockBlob", .content = "ABCD");
-                testResponseP(.code = 503);
-                testRequestP(HTTP_VERB_PUT, "/file.txt", .blobType = "BlockBlob", .content = "ABCD");
-                testResponseP();
+                testRequestP(service, HTTP_VERB_PUT, "/file.txt", .blobType = "BlockBlob", .content = "ABCD");
+                testResponseP(service, .code = 503);
+                testRequestP(service, HTTP_VERB_PUT, "/file.txt", .blobType = "BlockBlob", .content = "ABCD");
+                testResponseP(service);
 
                 StorageWrite *write = NULL;
                 TEST_ASSIGN(write, storageNewWriteP(storage, strNew("file.txt")), "new write");
@@ -420,8 +418,8 @@ testRun(void)
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("write zero-length file");
 
-                testRequestP(HTTP_VERB_PUT, "/file.txt", .blobType = "BlockBlob", .content = "");
-                testResponseP();
+                testRequestP(service, HTTP_VERB_PUT, "/file.txt", .blobType = "BlockBlob", .content = "");
+                testResponseP(service);
 
                 TEST_ASSIGN(write, storageNewWriteP(storage, strNew("file.txt")), "new write");
                 TEST_RESULT_VOID(storagePutP(write, NULL), "write");
@@ -429,21 +427,23 @@ testRun(void)
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("write file in chunks with nothing left over on close");
 
-                testRequestP(HTTP_VERB_PUT, "/file.txt?blockid=0AAAAAAACCCCCCCCx0000000&comp=block", .content = "1234567890123456");
-                testResponseP();
-
-                testRequestP(HTTP_VERB_PUT, "/file.txt?blockid=0AAAAAAACCCCCCCCx0000001&comp=block", .content = "7890123456789012");
-                testResponseP();
+                testRequestP(
+                    service, HTTP_VERB_PUT, "/file.txt?blockid=0AAAAAAACCCCCCCCx0000000&comp=block", .content = "1234567890123456");
+                testResponseP(service);
 
                 testRequestP(
-                    HTTP_VERB_PUT, "/file.txt?comp=blocklist",
+                    service, HTTP_VERB_PUT, "/file.txt?blockid=0AAAAAAACCCCCCCCx0000001&comp=block", .content = "7890123456789012");
+                testResponseP(service);
+
+                testRequestP(
+                    service, HTTP_VERB_PUT, "/file.txt?comp=blocklist",
                     .content =
                         "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n"
                         "<BlockList>"
                         "<Uncommitted>0AAAAAAACCCCCCCCx0000000</Uncommitted>"
                         "<Uncommitted>0AAAAAAACCCCCCCCx0000001</Uncommitted>"
                         "</BlockList>\n");
-                testResponseP();
+                testResponseP(service);
 
                 // Test needs a predictable file id
                 driver->fileId = 0x0AAAAAAACCCCCCCC;
@@ -454,30 +454,37 @@ testRun(void)
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("write file in chunks with something left over on close");
 
-                testRequestP(HTTP_VERB_PUT, "/file.txt?blockid=0AAAAAAACCCCCCCDx0000000&comp=block", .content = "1234567890123456");
-                testResponseP();
-
-                testRequestP(HTTP_VERB_PUT, "/file.txt?blockid=0AAAAAAACCCCCCCDx0000001&comp=block", .content = "7890");
-                testResponseP();
+                testRequestP(
+                    service, HTTP_VERB_PUT, "/file.txt?blockid=0AAAAAAACCCCCCCDx0000000&comp=block", .content = "1234567890123456");
+                testResponseP(service);
 
                 testRequestP(
-                    HTTP_VERB_PUT, "/file.txt?comp=blocklist",
+                    service, HTTP_VERB_PUT, "/file.txt?blockid=0AAAAAAACCCCCCCDx0000001&comp=block", .content = "7890");
+                testResponseP(service);
+
+                testRequestP(
+                    service, HTTP_VERB_PUT, "/file.txt?comp=blocklist",
                     .content =
                         "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n"
                         "<BlockList>"
                         "<Uncommitted>0AAAAAAACCCCCCCDx0000000</Uncommitted>"
                         "<Uncommitted>0AAAAAAACCCCCCCDx0000001</Uncommitted>"
                         "</BlockList>\n");
-                testResponseP();
+                testResponseP(service);
 
                 TEST_ASSIGN(write, storageNewWriteP(storage, strNew("file.txt")), "new write");
                 TEST_RESULT_VOID(storagePutP(write, BUFSTRDEF("12345678901234567890")), "write");
 
+                // -----------------------------------------------------------------------------------------------------------------
+                TEST_TITLE("info for / does not exist");
+
+                TEST_RESULT_BOOL(storageInfoP(storage, NULL, .ignoreMissing = true).exists, false, "info for /");
+
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("info for missing file");
 
-                testRequestP(HTTP_VERB_HEAD, "/BOGUS");
-                testResponseP(.code = 404);
+                testRequestP(service, HTTP_VERB_HEAD, "/BOGUS");
+                testResponseP(service, .code = 404);
 
                 TEST_RESULT_BOOL(
                     storageInfoP(storage, strNew("BOGUS"), .ignoreMissing = true).exists, false, "file does not exist");
@@ -485,8 +492,8 @@ testRun(void)
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("info for file");
 
-                testRequestP(HTTP_VERB_HEAD, "/subdir/file1.txt");
-                testResponseP(.header = "content-length:9999\r\nLast-Modified: Wed, 21 Oct 2015 07:28:00 GMT");
+                testRequestP(service, HTTP_VERB_HEAD, "/subdir/file1.txt");
+                testResponseP(service, .header = "content-length:9999\r\nLast-Modified: Wed, 21 Oct 2015 07:28:00 GMT");
 
                 StorageInfo info;
                 TEST_ASSIGN(info, storageInfoP(storage, strNew("subdir/file1.txt")), "file exists");
@@ -498,8 +505,8 @@ testRun(void)
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("info check existence only");
 
-                testRequestP(HTTP_VERB_HEAD, "/subdir/file2.txt");
-                testResponseP(.header = "content-length:777\r\nLast-Modified: Wed, 22 Oct 2015 07:28:00 GMT");
+                testRequestP(service, HTTP_VERB_HEAD, "/subdir/file2.txt");
+                testResponseP(service, .header = "content-length:777\r\nLast-Modified: Wed, 22 Oct 2015 07:28:00 GMT");
 
                 TEST_ASSIGN(
                     info, storageInfoP(storage, strNew("subdir/file2.txt"), .level = storageInfoLevelExists), "file exists");
@@ -511,8 +518,9 @@ testRun(void)
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("list basic level");
 
-                testRequestP(HTTP_VERB_GET, "?comp=list&delimiter=%2F&prefix=path%2Fto%2F&restype=container");
+                testRequestP(service, HTTP_VERB_GET, "?comp=list&delimiter=%2F&prefix=path%2Fto%2F&restype=container");
                 testResponseP(
+                    service,
                     .content =
                         "<?xml version=\"1.0\" encoding=\"UTF-8\"?>"
                         "<EnumerationResults>"
@@ -551,8 +559,9 @@ testRun(void)
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("list exists level");
 
-                testRequestP(HTTP_VERB_GET, "?comp=list&delimiter=%2F&restype=container");
+                testRequestP(service, HTTP_VERB_GET, "?comp=list&delimiter=%2F&restype=container");
                 testResponseP(
+                    service,
                     .content =
                         "<?xml version=\"1.0\" encoding=\"UTF-8\"?>"
                         "<EnumerationResults>"
@@ -583,8 +592,9 @@ testRun(void)
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("list a file in root with expression");
 
-                testRequestP(HTTP_VERB_GET, "?comp=list&delimiter=%2F&prefix=test&restype=container");
+                testRequestP(service, HTTP_VERB_GET, "?comp=list&delimiter=%2F&prefix=test&restype=container");
                 testResponseP(
+                    service,
                     .content =
                         "<?xml version=\"1.0\" encoding=\"UTF-8\"?>"
                         "<EnumerationResults>"
@@ -612,8 +622,9 @@ testRun(void)
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("list files with continuation");
 
-                testRequestP(HTTP_VERB_GET, "?comp=list&delimiter=%2F&prefix=path%2Fto%2F&restype=container");
+                testRequestP(service, HTTP_VERB_GET, "?comp=list&delimiter=%2F&prefix=path%2Fto%2F&restype=container");
                 testResponseP(
+                    service,
                     .content =
                         "<?xml version=\"1.0\" encoding=\"UTF-8\"?>"
                         "<EnumerationResults>"
@@ -633,8 +644,10 @@ testRun(void)
                         "    <NextMarker>ueGcxLPRx1Tr</NextMarker>"
                         "</EnumerationResults>");
 
-                testRequestP(HTTP_VERB_GET, "?comp=list&delimiter=%2F&marker=ueGcxLPRx1Tr&prefix=path%2Fto%2F&restype=container");
+                testRequestP(
+                    service, HTTP_VERB_GET, "?comp=list&delimiter=%2F&marker=ueGcxLPRx1Tr&prefix=path%2Fto%2F&restype=container");
                 testResponseP(
+                    service,
                     .content =
                         "<?xml version=\"1.0\" encoding=\"UTF-8\"?>"
                         "<EnumerationResults>"
@@ -668,8 +681,9 @@ testRun(void)
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("list files with expression");
 
-                testRequestP(HTTP_VERB_GET, "?comp=list&delimiter=%2F&prefix=path%2Fto%2Ftest&restype=container");
+                testRequestP(service, HTTP_VERB_GET, "?comp=list&delimiter=%2F&prefix=path%2Fto%2Ftest&restype=container");
                 testResponseP(
+                    service,
                     .content =
                         "<?xml version=\"1.0\" encoding=\"UTF-8\"?>"
                         "<EnumerationResults>"
@@ -713,56 +727,57 @@ testRun(void)
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("switch to SAS auth");
 
-                hrnTlsServerClose();
+                hrnServerScriptClose(service);
 
-                strLstAddZ(argList, "--" CFGOPT_REPO1_AZURE_KEY_TYPE "=" STORAGE_AZURE_KEY_TYPE_SAS);
-                setenv("PGBACKREST_" CFGOPT_REPO1_AZURE_KEY, TEST_KEY_SAS, true);
+                hrnCfgArgRawZ(argList, cfgOptRepoAzureKeyType, STORAGE_AZURE_KEY_TYPE_SAS);
+                hrnCfgEnvRawZ(cfgOptRepoAzureKey, TEST_KEY_SAS);
                 harnessCfgLoad(cfgCmdArchivePush, argList);
 
-                TEST_ASSIGN(storage, storageRepoGet(strNew(STORAGE_AZURE_TYPE), true), "get repo storage");
+                TEST_ASSIGN(storage, storageRepoGet(0, true), "get repo storage");
 
                 driver = (StorageAzure *)storage->driver;
                 TEST_RESULT_PTR_NE(driver->sasKey, NULL, "check sas key");
 
-                hrnTlsServerAccept();
+                hrnServerScriptAccept(service);
 
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("remove file");
 
-                testRequestP(HTTP_VERB_DELETE, "/path/to/test.txt");
-                testResponseP();
+                testRequestP(service, HTTP_VERB_DELETE, "/path/to/test.txt");
+                testResponseP(service);
 
                 TEST_RESULT_VOID(storageRemoveP(storage, strNew("/path/to/test.txt")), "remove");
 
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("remove missing file");
 
-                testRequestP(HTTP_VERB_DELETE, "/path/to/missing.txt");
-                testResponseP(.code = 404);
+                testRequestP(service, HTTP_VERB_DELETE, "/path/to/missing.txt");
+                testResponseP(service, .code = 404);
 
                 TEST_RESULT_VOID(storageRemoveP(storage, strNew("/path/to/missing.txt")), "remove");
 
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("remove files error to check redacted sig");
 
-                testRequestP(HTTP_VERB_GET, "?comp=list&restype=container");
-                testResponseP(.code = 403);
+                testRequestP(service, HTTP_VERB_GET, "?comp=list&restype=container");
+                testResponseP(service, .code = 403);
 
                 TEST_ERROR_FMT(
                     storagePathRemoveP(storage, strNew("/"), .recurse = true), ProtocolError,
                     "HTTP request failed with 403 (Forbidden):\n"
-                    "*** URI/Query ***:\n"
+                    "*** Path/Query ***:\n"
                     "/account/container?comp=list&restype=container&sig=<redacted>\n"
                     "*** Request Headers ***:\n"
                     "content-length: 0\n"
                     "host: %s",
-                    strPtr(hrnTlsServerHost()));
+                    strZ(hrnServerHost()));
 
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("remove files from root");
 
-                testRequestP(HTTP_VERB_GET, "?comp=list&restype=container");
+                testRequestP(service, HTTP_VERB_GET, "?comp=list&restype=container");
                 testResponseP(
+                    service,
                     .content =
                         "<?xml version=\"1.0\" encoding=\"UTF-8\"?>"
                         "<EnumerationResults>"
@@ -782,19 +797,20 @@ testRun(void)
                         "    <NextMarker/>"
                         "</EnumerationResults>");
 
-                testRequestP(HTTP_VERB_DELETE, "/test1.txt");
-                testResponseP();
+                testRequestP(service, HTTP_VERB_DELETE, "/test1.txt");
+                testResponseP(service);
 
-                testRequestP(HTTP_VERB_DELETE, "/path1/xxx.zzz");
-                testResponseP();
+                testRequestP(service, HTTP_VERB_DELETE, "/path1/xxx.zzz");
+                testResponseP(service);
 
                 TEST_RESULT_VOID(storagePathRemoveP(storage, strNew("/"), .recurse = true), "remove");
 
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("remove files from path");
 
-                testRequestP(HTTP_VERB_GET, "?comp=list&prefix=path%2F&restype=container");
+                testRequestP(service, HTTP_VERB_GET, "?comp=list&prefix=path%2F&restype=container");
                 testResponseP(
+                    service,
                     .content =
                         "<?xml version=\"1.0\" encoding=\"UTF-8\"?>"
                         "<EnumerationResults>"
@@ -814,19 +830,20 @@ testRun(void)
                         "    <NextMarker/>"
                         "</EnumerationResults>");
 
-                testRequestP(HTTP_VERB_DELETE, "/path/test1.txt");
-                testResponseP();
+                testRequestP(service, HTTP_VERB_DELETE, "/path/test1.txt");
+                testResponseP(service);
 
-                testRequestP(HTTP_VERB_DELETE, "/path/path1/xxx.zzz");
-                testResponseP();
+                testRequestP(service, HTTP_VERB_DELETE, "/path/path1/xxx.zzz");
+                testResponseP(service);
 
                 TEST_RESULT_VOID(storagePathRemoveP(storage, strNew("/path"), .recurse = true), "remove");
 
                 // -----------------------------------------------------------------------------------------------------------------
                 TEST_TITLE("remove files in empty subpath (nothing to do)");
 
-                testRequestP(HTTP_VERB_GET, "?comp=list&prefix=path%2F&restype=container");
+                testRequestP(service, HTTP_VERB_GET, "?comp=list&prefix=path%2F&restype=container");
                 testResponseP(
+                    service,
                     .content =
                         "<?xml version=\"1.0\" encoding=\"UTF-8\"?>"
                         "<EnumerationResults>"
@@ -838,12 +855,12 @@ testRun(void)
                 TEST_RESULT_VOID(storagePathRemoveP(storage, strNew("/path"), .recurse = true), "remove");
 
                 // -----------------------------------------------------------------------------------------------------------------
-                hrnTlsClientEnd();
+                hrnServerScriptEnd(service);
             }
             HARNESS_FORK_PARENT_END();
         }
         HARNESS_FORK_END();
     }
 
-    FUNCTION_HARNESS_RESULT_VOID();
+    FUNCTION_HARNESS_RETURN_VOID();
 }
