@@ -87,6 +87,7 @@ test.pl [options]
    --no-performance     do not run performance tests
    --gen-only           only run auto-generation
    --no-gen             do not run code generation
+   --gen-check          check that auto-generated files are correct (used in CI to detect changes)
    --code-count         generate code counts
    --smart              perform bin/package builds only when source timestamps have changed
    --dev                --smart --no-optimize
@@ -135,7 +136,7 @@ my $bClean;
 my $bCleanOnly;
 my $strLogLevel = lc(INFO);
 my $strLogLevelTest = lc(OFF);
-my $strLogLevelTestFile = lc(TRACE);
+my $strLogLevelTestFile = lc(DEBUG);
 my $bNoLogTimestamp = false;
 my $bVmOut = false;
 my @stryModule;
@@ -168,6 +169,7 @@ my $bCOnly = false;
 my $bContainerOnly = false;
 my $bNoPerformance = false;
 my $bGenOnly = false;
+my $bGenCheck = false;
 my $bNoGen = false;
 my $bCodeCount = false;
 my $bSmart = false;
@@ -223,6 +225,7 @@ GetOptions ('q|quiet' => \$bQuiet,
             'container-only' => \$bContainerOnly,
             'no-performance' => \$bNoPerformance,
             'gen-only' => \$bGenOnly,
+            'gen-check' => \$bGenCheck,
             'no-gen' => \$bNoGen,
             'code-count' => \$bCodeCount,
             'smart' => \$bSmart,
@@ -515,6 +518,12 @@ eval
                     push(@stryModifiedList, @stryBuilt);
                 }
 
+                # Error when checking that files have already been generated but they change
+                if ($bGenCheck && @stryBuilt)
+                {
+                    confess &log(ERROR, "unexpected autogeneration of version in configure.ac script: " . join(', ', @stryBuilt));
+                }
+
                 &log(INFO,
                     "    autogenerated version in configure.ac script: " . (@stryBuilt ? join(', ', @stryBuilt) : 'no changes'));
             }
@@ -547,9 +556,15 @@ eval
                     $strConfigure =
                         trim($strConfigure) . "\n\n# Generated from src/build/configure.ac sha1 ${strConfigureAcHash}\n";
 
+                    # Remove cache created by autconf
+                    executeTest("rm -rf ${strBackRestBase}/src/build/autom4te.cache");
+
                     # Remove unused options from help
-                    $strConfigure =~ s/^  --((?!bin).)*dir=DIR.*\n//mg;
-                    $strConfigure =~ s/^  --sbindir=DIR.*\n//mg;
+                    my $strDirList =
+                        "sbin|libexec|sysconf|sharedstate|localstate|runstate|lib|include|oldinclude|dataroot|data|info" .
+                        "|locale|man|doc|html|dvi|pdf|ps";
+
+                    $strConfigure =~ s/^  --(${strDirList})*dir=DIR.*\n//mg;
 
                     # Save into the src dir
                     $oStorageBackRest->put(
@@ -561,12 +576,19 @@ eval
                     push(@stryModifiedList, @stryBuilt);
                 }
 
+                # Error when checking that files have already been generated but they change
+                if ($bGenCheck && @stryBuilt)
+                {
+                    confess &log(ERROR, "unexpected autogeneration of configure script: " . join(', ', @stryBuilt));
+                }
+
                 &log(INFO, "    autogenerated configure script: " . (@stryBuilt ? join(', ', @stryBuilt) : 'no changes'));
             }
 
             # Auto-generate C files
             #-----------------------------------------------------------------------------------------------------------------------
-            if (!$bSmart || grep(/^build\//, @stryModifiedList) || grep(/^doc\/xml\/reference\.xml/, @stryModifiedList))
+            if (!$bSmart || grep(/^build\//, @stryModifiedList) || grep(/^doc\/xml\/reference\.xml/, @stryModifiedList) ||
+                grep(/^src\/build\/config\/config\.yaml/, @stryModifiedList))
             {
                 errorDefineLoad(${$oStorageBackRest->get("build/error.yaml")});
 
@@ -598,6 +620,13 @@ eval
                 };
 
                 my @stryBuilt = buildAll("${strBackRestBase}/src", $rhBuild);
+
+                # Error when checking that files have already been generated but they change
+                if ($bGenCheck && @stryBuilt)
+                {
+                    confess &log(ERROR, "unexpected autogeneration of C code: " . join(', ', @stryBuilt));
+                }
+
                 &log(INFO, "    autogenerated C code: " . (@stryBuilt ? join(', ', @stryBuilt) : 'no changes'));
 
                 if (@stryBuilt)
@@ -642,7 +671,8 @@ eval
             }
 
             executeTest(
-                "rm -rf ${strTestPath}/temp ${strTestPath}/test-* ${strTestPath}/data-*" . ($bDev ? '' : " ${strTestPath}/gcov-*"));
+                "chmod 700 -R ${strTestPath}/test-* 2>&1 || true && rm -rf ${strTestPath}/temp ${strTestPath}/test-*" .
+                    " ${strTestPath}/data-*" . ($bDev ? '' : " ${strTestPath}/gcov-*"));
             $oStorageTest->pathCreate("${strTestPath}/temp", {strMode => '0770', bIgnoreExists => true, bCreateParent => true});
 
             # Remove old lcov dirs -- do it this way so the dirs stay open in finder/explorer, etc.
